@@ -14,7 +14,7 @@ from . import element, fhirtypes
 
 
 class Address(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -68,7 +68,7 @@ class Address(element.Element):
         None, alias="_district", title="Extension field for ``district``."
     )
 
-    line: typing.List[fhirtypes.String] = Field(
+    line: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="line",
         title="Street name, number, direction & P.O. Box etc.",
@@ -166,3 +166,24 @@ class Address(element.Element):
     use__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_use", title="Extension field for ``use``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Address`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "use",
+            "type",
+            "text",
+            "line",
+            "city",
+            "district",
+            "state",
+            "postalCode",
+            "country",
+            "period",
+        ]
