@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class AuditEvent(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -143,6 +143,33 @@ class AuditEvent(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AuditEvent`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "type",
+            "subtype",
+            "action",
+            "recorded",
+            "outcome",
+            "outcomeDesc",
+            "purposeOfEvent",
+            "agent",
+            "source",
+            "entity",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1198(
         cls, values: typing.Dict[str, typing.Any]
@@ -204,7 +231,7 @@ class AuditEvent(domainresource.DomainResource):
 
 
 class AuditEventAgent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -362,6 +389,29 @@ class AuditEventAgent(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AuditEventAgent`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "role",
+            "reference",
+            "userId",
+            "altId",
+            "name",
+            "requestor",
+            "location",
+            "policy",
+            "media",
+            "network",
+            "purposeOfUse",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1693(
         cls, values: typing.Dict[str, typing.Any]
@@ -423,7 +473,7 @@ class AuditEventAgent(backboneelement.BackboneElement):
 
 
 class AuditEventAgentNetwork(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -464,9 +514,17 @@ class AuditEventAgentNetwork(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AuditEventAgentNetwork`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "address", "type"]
+
 
 class AuditEventEntity(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -589,9 +647,31 @@ class AuditEventEntity(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AuditEventEntity`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "reference",
+            "type",
+            "role",
+            "lifecycle",
+            "securityLabel",
+            "name",
+            "description",
+            "query",
+            "detail",
+        ]
+
 
 class AuditEventEntityDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -627,6 +707,14 @@ class AuditEventEntityDetail(backboneelement.BackboneElement):
         None, alias="_value", title="Extension field for ``value``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AuditEventEntityDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "value"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2422(
         cls, values: typing.Dict[str, typing.Any]
@@ -688,7 +776,7 @@ class AuditEventEntityDetail(backboneelement.BackboneElement):
 
 
 class AuditEventSource(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -731,3 +819,11 @@ class AuditEventSource(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AuditEventSource`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "site", "identifier", "type"]
