@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Claim(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -397,9 +397,56 @@ class Claim(domainresource.DomainResource):
         None, alias="_use", title="Extension field for ``use``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Claim`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "type",
+            "subType",
+            "use",
+            "patient",
+            "billablePeriod",
+            "created",
+            "enterer",
+            "insurer",
+            "provider",
+            "organization",
+            "priority",
+            "fundsReserve",
+            "related",
+            "prescription",
+            "originalPrescription",
+            "payee",
+            "referral",
+            "facility",
+            "careTeam",
+            "information",
+            "diagnosis",
+            "procedure",
+            "insurance",
+            "accident",
+            "employmentImpacted",
+            "hospitalization",
+            "item",
+            "total",
+        ]
+
 
 class ClaimAccident(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -457,6 +504,22 @@ class ClaimAccident(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimAccident`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "date",
+            "type",
+            "locationAddress",
+            "locationReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1464(
         cls, values: typing.Dict[str, typing.Any]
@@ -556,7 +619,7 @@ class ClaimAccident(backboneelement.BackboneElement):
 
 
 class ClaimCareTeam(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -627,6 +690,23 @@ class ClaimCareTeam(backboneelement.BackboneElement):
         None, alias="_sequence", title="Extension field for ``sequence``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimCareTeam`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "provider",
+            "responsible",
+            "role",
+            "qualification",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1432(
         cls, values: typing.Dict[str, typing.Any]
@@ -688,7 +768,7 @@ class ClaimCareTeam(backboneelement.BackboneElement):
 
 
 class ClaimDiagnosis(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -761,6 +841,23 @@ class ClaimDiagnosis(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimDiagnosis`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "diagnosisCodeableConcept",
+            "diagnosisReference",
+            "type",
+            "packageCode",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1597(
         cls, values: typing.Dict[str, typing.Any]
@@ -862,7 +959,7 @@ class ClaimDiagnosis(backboneelement.BackboneElement):
 
 
 class ClaimInformation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1022,6 +1119,28 @@ class ClaimInformation(backboneelement.BackboneElement):
         None, alias="_valueString", title="Extension field for ``valueString``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimInformation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "category",
+            "code",
+            "timingDate",
+            "timingPeriod",
+            "valueString",
+            "valueQuantity",
+            "valueAttachment",
+            "valueReference",
+            "reason",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1821(
         cls, values: typing.Dict[str, typing.Any]
@@ -1129,7 +1248,7 @@ class ClaimInformation(backboneelement.BackboneElement):
 
 
 class ClaimInsurance(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1194,7 +1313,7 @@ class ClaimInsurance(backboneelement.BackboneElement):
         None, alias="_focal", title="Extension field for ``focal``."
     )
 
-    preAuthRef: typing.List[fhirtypes.String] = Field(
+    preAuthRef: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="preAuthRef",
         title="Pre-Authorization/Determination Reference",
@@ -1222,6 +1341,24 @@ class ClaimInsurance(backboneelement.BackboneElement):
         None, alias="_sequence", title="Extension field for ``sequence``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimInsurance`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "focal",
+            "coverage",
+            "businessArrangement",
+            "preAuthRef",
+            "claimResponse",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1590(
         cls, values: typing.Dict[str, typing.Any]
@@ -1283,7 +1420,7 @@ class ClaimInsurance(backboneelement.BackboneElement):
 
 
 class ClaimItem(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1607,6 +1744,42 @@ class ClaimItem(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimItem`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "careTeamLinkId",
+            "diagnosisLinkId",
+            "procedureLinkId",
+            "informationLinkId",
+            "revenue",
+            "category",
+            "service",
+            "modifier",
+            "programCode",
+            "servicedDate",
+            "servicedPeriod",
+            "locationCodeableConcept",
+            "locationAddress",
+            "locationReference",
+            "quantity",
+            "unitPrice",
+            "factor",
+            "net",
+            "udi",
+            "bodySite",
+            "subSite",
+            "encounter",
+            "detail",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1061(
         cls, values: typing.Dict[str, typing.Any]
@@ -1713,7 +1886,7 @@ class ClaimItem(backboneelement.BackboneElement):
 
 
 class ClaimItemDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1873,6 +2046,30 @@ class ClaimItemDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimItemDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "revenue",
+            "category",
+            "service",
+            "modifier",
+            "programCode",
+            "quantity",
+            "unitPrice",
+            "factor",
+            "net",
+            "udi",
+            "subDetail",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1655(
         cls, values: typing.Dict[str, typing.Any]
@@ -1934,7 +2131,7 @@ class ClaimItemDetail(backboneelement.BackboneElement):
 
 
 class ClaimItemDetailSubDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2078,6 +2275,29 @@ class ClaimItemDetailSubDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimItemDetailSubDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "revenue",
+            "category",
+            "service",
+            "modifier",
+            "programCode",
+            "quantity",
+            "unitPrice",
+            "factor",
+            "net",
+            "udi",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2548(
         cls, values: typing.Dict[str, typing.Any]
@@ -2139,7 +2359,7 @@ class ClaimItemDetailSubDetail(backboneelement.BackboneElement):
 
 
 class ClaimPayee(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2183,9 +2403,17 @@ class ClaimPayee(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimPayee`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "resourceType", "party"]
+
 
 class ClaimProcedure(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2246,6 +2474,22 @@ class ClaimProcedure(backboneelement.BackboneElement):
         None, alias="_sequence", title="Extension field for ``sequence``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimProcedure`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "date",
+            "procedureCodeableConcept",
+            "procedureReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1591(
         cls, values: typing.Dict[str, typing.Any]
@@ -2347,7 +2591,7 @@ class ClaimProcedure(backboneelement.BackboneElement):
 
 
 class ClaimRelated(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2393,3 +2637,18 @@ class ClaimRelated(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimRelated`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "claim",
+            "relationship",
+            "reference",
+        ]
