@@ -16,7 +16,7 @@ from . import element, fhirtypes
 
 
 class Contributor(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -71,6 +71,14 @@ class Contributor(element.Element):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Contributor`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "type", "name", "contact"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1360(
         cls, values: typing.Dict[str, typing.Any]
