@@ -16,7 +16,7 @@ from . import domainresource, fhirtypes
 
 
 class DeviceUseStatement(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -184,6 +184,36 @@ class DeviceUseStatement(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DeviceUseStatement`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "subject",
+            "whenUsed",
+            "timingTiming",
+            "timingPeriod",
+            "timingDateTime",
+            "recordedOn",
+            "source",
+            "device",
+            "indication",
+            "bodySite",
+            "note",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2026(
         cls, values: typing.Dict[str, typing.Any]
