@@ -16,7 +16,7 @@ from . import domainresource, fhirtypes
 
 
 class Endpoint(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -67,7 +67,7 @@ class Endpoint(domainresource.DomainResource):
         element_property=True,
     )
 
-    header: typing.List[fhirtypes.String] = Field(
+    header: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="header",
         title="Usage depends on the channel type",
@@ -183,6 +183,34 @@ class Endpoint(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Endpoint`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "connectionType",
+            "name",
+            "managingOrganization",
+            "contact",
+            "period",
+            "payloadType",
+            "payloadMimeType",
+            "address",
+            "header",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1018(
         cls, values: typing.Dict[str, typing.Any]
