@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ImplementationGuide(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -303,6 +303,41 @@ class ImplementationGuide(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImplementationGuide`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "version",
+            "name",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "copyright",
+            "fhirVersion",
+            "dependency",
+            "package",
+            "global",
+            "binary",
+            "page",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2146(
         cls, values: typing.Dict[str, typing.Any]
@@ -368,7 +403,7 @@ class ImplementationGuide(domainresource.DomainResource):
 
 
 class ImplementationGuideDependency(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -409,6 +444,14 @@ class ImplementationGuideDependency(backboneelement.BackboneElement):
         None, alias="_uri", title="Extension field for ``uri``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImplementationGuideDependency`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "uri"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3189(
         cls, values: typing.Dict[str, typing.Any]
@@ -470,7 +513,7 @@ class ImplementationGuideDependency(backboneelement.BackboneElement):
 
 
 class ImplementationGuideGlobal(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -505,6 +548,14 @@ class ImplementationGuideGlobal(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImplementationGuideGlobal`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "profile"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2746(
         cls, values: typing.Dict[str, typing.Any]
@@ -566,7 +617,7 @@ class ImplementationGuideGlobal(backboneelement.BackboneElement):
 
 
 class ImplementationGuidePackage(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -616,6 +667,21 @@ class ImplementationGuidePackage(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImplementationGuidePackage`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "name",
+            "description",
+            "resource",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2830(
         cls, values: typing.Dict[str, typing.Any]
@@ -677,7 +743,7 @@ class ImplementationGuidePackage(backboneelement.BackboneElement):
 
 
 class ImplementationGuidePackageResource(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -798,6 +864,25 @@ class ImplementationGuidePackageResource(backboneelement.BackboneElement):
         None, alias="_sourceUri", title="Extension field for ``sourceUri``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImplementationGuidePackageResource`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "example",
+            "name",
+            "description",
+            "acronym",
+            "sourceUri",
+            "sourceReference",
+            "exampleFor",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3670(
         cls, values: typing.Dict[str, typing.Any]
@@ -897,7 +982,7 @@ class ImplementationGuidePackageResource(backboneelement.BackboneElement):
 
 
 class ImplementationGuidePage(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -952,7 +1037,7 @@ class ImplementationGuidePage(backboneelement.BackboneElement):
         None, alias="_kind", title="Extension field for ``kind``."
     )
 
-    package: typing.List[fhirtypes.String] = Field(
+    package: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="package",
         title="Name of package to include",
@@ -1017,6 +1102,25 @@ class ImplementationGuidePage(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_type", title="Extension field for ``type``.")
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImplementationGuidePage`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "source",
+            "title",
+            "kind",
+            "type",
+            "package",
+            "format",
+            "page",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2527(
         cls, values: typing.Dict[str, typing.Any]
