@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class OperationDefinition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -374,6 +374,46 @@ class OperationDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``OperationDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "version",
+            "name",
+            "status",
+            "kind",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "idempotent",
+            "code",
+            "comment",
+            "base",
+            "resource",
+            "system",
+            "type",
+            "instance",
+            "parameter",
+            "overload",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2167(
         cls, values: typing.Dict[str, typing.Any]
@@ -443,7 +483,7 @@ class OperationDefinition(domainresource.DomainResource):
 
 
 class OperationDefinitionOverload(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -467,7 +507,7 @@ class OperationDefinitionOverload(backboneelement.BackboneElement):
         None, alias="_comment", title="Extension field for ``comment``."
     )
 
-    parameterName: typing.List[fhirtypes.String] = Field(
+    parameterName: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="parameterName",
         title="Name of parameter to include in overload",
@@ -481,9 +521,17 @@ class OperationDefinitionOverload(backboneelement.BackboneElement):
         None, alias="_parameterName", title="Extension field for ``parameterName``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``OperationDefinitionOverload`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "parameterName", "comment"]
+
 
 class OperationDefinitionParameter(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -639,6 +687,28 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
         None, alias="_use", title="Extension field for ``use``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``OperationDefinitionParameter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "name",
+            "use",
+            "min",
+            "max",
+            "documentation",
+            "type",
+            "searchType",
+            "profile",
+            "binding",
+            "part",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3100(
         cls, values: typing.Dict[str, typing.Any]
@@ -705,7 +775,7 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
 
 
 class OperationDefinitionParameterBinding(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -771,6 +841,21 @@ class OperationDefinitionParameterBinding(backboneelement.BackboneElement):
         None, alias="_valueSetUri", title="Extension field for ``valueSetUri``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``OperationDefinitionParameterBinding`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "strength",
+            "valueSetUri",
+            "valueSetReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3788(
         cls, values: typing.Dict[str, typing.Any]
