@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class PlanDefinition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -411,6 +411,49 @@ class PlanDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "name",
+            "title",
+            "type",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "description",
+            "purpose",
+            "usage",
+            "approvalDate",
+            "lastReviewDate",
+            "effectivePeriod",
+            "useContext",
+            "jurisdiction",
+            "topic",
+            "contributor",
+            "contact",
+            "copyright",
+            "relatedArtifact",
+            "library",
+            "goal",
+            "action",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1618(
         cls, values: typing.Dict[str, typing.Any]
@@ -472,7 +515,7 @@ class PlanDefinition(domainresource.DomainResource):
 
 
 class PlanDefinitionAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -874,6 +917,47 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionAction`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "label",
+            "title",
+            "description",
+            "textEquivalent",
+            "code",
+            "reason",
+            "documentation",
+            "goalId",
+            "triggerDefinition",
+            "condition",
+            "input",
+            "output",
+            "relatedAction",
+            "timingDateTime",
+            "timingPeriod",
+            "timingDuration",
+            "timingRange",
+            "timingTiming",
+            "participant",
+            "type",
+            "groupingBehavior",
+            "selectionBehavior",
+            "requiredBehavior",
+            "precheckBehavior",
+            "cardinalityBehavior",
+            "definition",
+            "transform",
+            "dynamicValue",
+            "action",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2224(
         cls, values: typing.Dict[str, typing.Any]
@@ -922,7 +1006,7 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
 
 
 class PlanDefinitionActionCondition(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -991,6 +1075,22 @@ class PlanDefinitionActionCondition(backboneelement.BackboneElement):
         None, alias="_language", title="Extension field for ``language``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionCondition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "kind",
+            "description",
+            "language",
+            "expression",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3159(
         cls, values: typing.Dict[str, typing.Any]
@@ -1052,7 +1152,7 @@ class PlanDefinitionActionCondition(backboneelement.BackboneElement):
 
 
 class PlanDefinitionActionDynamicValue(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1121,9 +1221,25 @@ class PlanDefinitionActionDynamicValue(backboneelement.BackboneElement):
         None, alias="_path", title="Extension field for ``path``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionDynamicValue`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "description",
+            "path",
+            "language",
+            "expression",
+        ]
+
 
 class PlanDefinitionActionParticipant(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1161,6 +1277,14 @@ class PlanDefinitionActionParticipant(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "role"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3381(
         cls, values: typing.Dict[str, typing.Any]
@@ -1222,7 +1346,7 @@ class PlanDefinitionActionParticipant(backboneelement.BackboneElement):
 
 
 class PlanDefinitionActionRelatedAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1305,6 +1429,22 @@ class PlanDefinitionActionRelatedAction(backboneelement.BackboneElement):
         None, alias="_relationship", title="Extension field for ``relationship``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionRelatedAction`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "actionId",
+            "relationship",
+            "offsetDuration",
+            "offsetRange",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3535(
         cls, values: typing.Dict[str, typing.Any]
@@ -1407,7 +1547,7 @@ class PlanDefinitionActionRelatedAction(backboneelement.BackboneElement):
 
 
 class PlanDefinitionGoal(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1498,9 +1638,28 @@ class PlanDefinitionGoal(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionGoal`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "category",
+            "description",
+            "priority",
+            "start",
+            "addresses",
+            "documentation",
+            "target",
+        ]
+
 
 class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1591,6 +1750,23 @@ class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionGoalTarget`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "measure",
+            "detailQuantity",
+            "detailRange",
+            "detailCodeableConcept",
+            "due",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2626(
         cls, values: typing.Dict[str, typing.Any]
