@@ -12,7 +12,7 @@ from . import fhirresourcemodel, fhirtypes
 
 
 class Resource(fhirresourcemodel.FHIRResourceModel):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -33,9 +33,6 @@ class Resource(fhirresourcemodel.FHIRResourceModel):
         # if property is element of this resource.
         element_property=True,
     )
-    id__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_id", title="Extension field for ``id``."
-    )
 
     implicitRules: fhirtypes.Uri = Field(
         None,
@@ -77,3 +74,11 @@ class Resource(fhirresourcemodel.FHIRResourceModel):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Resource`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "meta", "implicitRules", "language"]
