@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ActivityDefinition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -45,6 +45,39 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_approvalDate", title="Extension field for ``approvalDate``."
     )
 
+    asNeededBoolean: bool = Field(
+        None,
+        alias="asNeededBoolean",
+        title="Preconditions for service",
+        description=(
+            "If a CodeableConcept is present, it indicates the pre-condition for "
+            'performing the service.  For example "pain", "on flare-up", etc.'
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e asNeeded[x]
+        one_of_many="asNeeded",
+        one_of_many_required=False,
+    )
+    asNeededBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_asNeededBoolean", title="Extension field for ``asNeededBoolean``."
+    )
+
+    asNeededCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="asNeededCodeableConcept",
+        title="Preconditions for service",
+        description=(
+            "If a CodeableConcept is present, it indicates the pre-condition for "
+            'performing the service.  For example "pain", "on flare-up", etc.'
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e asNeeded[x]
+        one_of_many="asNeeded",
+        one_of_many_required=False,
+    )
+
     author: typing.List[fhirtypes.ContactDetailType] = Field(
         None,
         alias="author",
@@ -109,16 +142,33 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the activity definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the activity definition "
-            "changes."
+            "The date  (and optionally time) when the activity definition was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the activity definition"
+            " changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -216,8 +266,9 @@ class ActivityDefinition(domainresource.DomainResource):
         alias="endorser",
         title="Who endorsed the content",
         description=(
-            "An individual or organization responsible for officially endorsing the"
-            " content for use in some setting."
+            "An individual or organization asserted by the publisher to be "
+            "responsible for officially endorsing the content for use in some "
+            "setting."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -302,8 +353,7 @@ class ActivityDefinition(domainresource.DomainResource):
         description=(
             "A description of the kind of resource the activity definition is "
             "representing. For example, a MedicationRequest, a ServiceRequest, or a"
-            " CommunicationRequest. Typically, but not always, this is a Request "
-            "resource."
+            " CommunicationRequest."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -315,7 +365,7 @@ class ActivityDefinition(domainresource.DomainResource):
     lastReviewDate: fhirtypes.Date = Field(
         None,
         alias="lastReviewDate",
-        title="When the activity definition was last reviewed",
+        title="When the activity definition was last reviewed by the publisher",
         description=(
             "The date on which the resource content was last reviewed. Review "
             "happens periodically after approval but does not change the original "
@@ -345,7 +395,7 @@ class ActivityDefinition(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_library", title="Extension field for ``library``.")
 
-    location: fhirtypes.ReferenceType = Field(
+    location: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="location",
         title="Where it should happen",
@@ -375,7 +425,7 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
-    observationRequirement: typing.List[fhirtypes.ReferenceType] = Field(
+    observationRequirement: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="observationRequirement",
         title="What observations are required to perform this action",
@@ -388,8 +438,17 @@ class ActivityDefinition(domainresource.DomainResource):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["ObservationDefinition"],
     )
+    observationRequirement__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(
+        None,
+        alias="_observationRequirement",
+        title="Extension field for ``observationRequirement``.",
+    )
 
-    observationResultRequirement: typing.List[fhirtypes.ReferenceType] = Field(
+    observationResultRequirement: typing.List[
+        typing.Optional[fhirtypes.Canonical]
+    ] = Field(
         None,
         alias="observationResultRequirement",
         title="What observations must be produced by this action",
@@ -402,6 +461,13 @@ class ActivityDefinition(domainresource.DomainResource):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["ObservationDefinition"],
     )
+    observationResultRequirement__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(
+        None,
+        alias="_observationResultRequirement",
+        title="Extension field for ``observationResultRequirement``.",
+    )
 
     participant: typing.List[fhirtypes.ActivityDefinitionParticipantType] = Field(
         None,
@@ -459,7 +525,12 @@ class ActivityDefinition(domainresource.DomainResource):
         one_of_many="product",
         one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Medication", "Substance", "Ingredient"],
+        enum_reference_types=[
+            "Medication",
+            "Ingredient",
+            "Substance",
+            "SubstanceDefinition",
+        ],
     )
 
     profile: fhirtypes.Canonical = Field(
@@ -482,10 +553,10 @@ class ActivityDefinition(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the activity"
-            " definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the activity definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -524,7 +595,7 @@ class ActivityDefinition(domainresource.DomainResource):
     relatedArtifact: typing.List[fhirtypes.RelatedArtifactType] = Field(
         None,
         alias="relatedArtifact",
-        title="Additional documentation, citations, etc.",
+        title="Additional documentation, citations, etc",
         description=(
             "Related artifacts such as additional documentation, justification, or "
             "bibliographic references."
@@ -538,14 +609,14 @@ class ActivityDefinition(domainresource.DomainResource):
         alias="reviewer",
         title="Who reviewed the content",
         description=(
-            "An individual or organization primarily responsible for review of some"
-            " aspect of the content."
+            "An individual or organization asserted by the publisher to be "
+            "primarily responsible for review of some aspect of the content."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    specimenRequirement: typing.List[fhirtypes.ReferenceType] = Field(
+    specimenRequirement: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="specimenRequirement",
         title="What specimens are required to perform this action",
@@ -558,6 +629,13 @@ class ActivityDefinition(domainresource.DomainResource):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["SpecimenDefinition"],
     )
+    specimenRequirement__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(
+        None,
+        alias="_specimenRequirement",
+        title="Extension field for ``specimenRequirement``.",
+    )
 
     status: fhirtypes.Code = Field(
         None,
@@ -596,6 +674,8 @@ class ActivityDefinition(domainresource.DomainResource):
         # Choice of Data Types. i.e subject[x]
         one_of_many="subject",
         one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["EvidenceVariable"],
     )
     subjectCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None,
@@ -642,7 +722,14 @@ class ActivityDefinition(domainresource.DomainResource):
         one_of_many="subject",
         one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Group"],
+        enum_reference_types=[
+            "Group",
+            "MedicinalProductDefinition",
+            "SubstanceDefinition",
+            "AdministrableProductDefinition",
+            "ManufacturedItemDefinition",
+            "PackagedProductDefinition",
+        ],
     )
 
     subtitle: fhirtypes.String = Field(
@@ -664,10 +751,7 @@ class ActivityDefinition(domainresource.DomainResource):
         None,
         alias="timingAge",
         title="When activity is to occur",
-        description=(
-            "The period, timing or frequency upon which the described activity is "
-            "to occur."
-        ),
+        description="The timing or frequency upon which the described activity is to occur.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e timing[x]
@@ -675,47 +759,11 @@ class ActivityDefinition(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
-    timingDateTime: fhirtypes.DateTime = Field(
-        None,
-        alias="timingDateTime",
-        title="When activity is to occur",
-        description=(
-            "The period, timing or frequency upon which the described activity is "
-            "to occur."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e timing[x]
-        one_of_many="timing",
-        one_of_many_required=False,
-    )
-    timingDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_timingDateTime", title="Extension field for ``timingDateTime``."
-    )
-
     timingDuration: fhirtypes.DurationType = Field(
         None,
         alias="timingDuration",
         title="When activity is to occur",
-        description=(
-            "The period, timing or frequency upon which the described activity is "
-            "to occur."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e timing[x]
-        one_of_many="timing",
-        one_of_many_required=False,
-    )
-
-    timingPeriod: fhirtypes.PeriodType = Field(
-        None,
-        alias="timingPeriod",
-        title="When activity is to occur",
-        description=(
-            "The period, timing or frequency upon which the described activity is "
-            "to occur."
-        ),
+        description="The timing or frequency upon which the described activity is to occur.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e timing[x]
@@ -727,10 +775,7 @@ class ActivityDefinition(domainresource.DomainResource):
         None,
         alias="timingRange",
         title="When activity is to occur",
-        description=(
-            "The period, timing or frequency upon which the described activity is "
-            "to occur."
-        ),
+        description="The timing or frequency upon which the described activity is to occur.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e timing[x]
@@ -742,10 +787,7 @@ class ActivityDefinition(domainresource.DomainResource):
         None,
         alias="timingTiming",
         title="When activity is to occur",
-        description=(
-            "The period, timing or frequency upon which the described activity is "
-            "to occur."
-        ),
+        description="The timing or frequency upon which the described activity is to occur.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e timing[x]
@@ -768,7 +810,7 @@ class ActivityDefinition(domainresource.DomainResource):
     topic: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="topic",
-        title="E.g. Education, Treatment, Assessment, etc.",
+        title="E.g. Education, Treatment, Assessment, etc",
         description=(
             "Descriptive topics related to the content of the activity. Topics "
             "provide a high-level categorization of the activity that can be useful"
@@ -807,10 +849,10 @@ class ActivityDefinition(domainresource.DomainResource):
             "An absolute URI that is used to identify this activity definition when"
             " it is referenced in a specification, model, design or an instance; "
             "also called its canonical identifier. This SHOULD be globally unique "
-            "and SHOULD be a literal address at which at which an authoritative "
-            "instance of this activity definition is (or will be) published. This "
-            "URL can be the target of a canonical reference. It SHALL remain the "
-            "same when the activity definition is stored on different servers."
+            "and SHOULD be a literal address at which an authoritative instance of "
+            "this activity definition is (or will be) published. This URL can be "
+            "the target of a canonical reference. It SHALL remain the same when the"
+            " activity definition is stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -819,7 +861,7 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_url", title="Extension field for ``url``."
     )
 
-    usage: fhirtypes.String = Field(
+    usage: fhirtypes.Markdown = Field(
         None,
         alias="usage",
         title="Describes the clinical usage of the activity definition",
@@ -873,6 +915,41 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -891,6 +968,8 @@ class ActivityDefinition(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "subtitle",
@@ -908,6 +987,7 @@ class ActivityDefinition(domainresource.DomainResource):
             "purpose",
             "usage",
             "copyright",
+            "copyrightLabel",
             "approvalDate",
             "lastReviewDate",
             "effectivePeriod",
@@ -925,11 +1005,11 @@ class ActivityDefinition(domainresource.DomainResource):
             "priority",
             "doNotPerform",
             "timingTiming",
-            "timingDateTime",
             "timingAge",
-            "timingPeriod",
             "timingRange",
             "timingDuration",
+            "asNeededBoolean",
+            "asNeededCodeableConcept",
             "location",
             "participant",
             "productReference",
@@ -1020,20 +1100,15 @@ class ActivityDefinition(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
+            "asNeeded": ["asNeededBoolean", "asNeededCodeableConcept"],
             "product": ["productCodeableConcept", "productReference"],
             "subject": [
                 "subjectCanonical",
                 "subjectCodeableConcept",
                 "subjectReference",
             ],
-            "timing": [
-                "timingAge",
-                "timingDateTime",
-                "timingDuration",
-                "timingPeriod",
-                "timingRange",
-                "timingTiming",
-            ],
+            "timing": ["timingAge", "timingDuration", "timingRange", "timingTiming"],
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"],
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -1088,7 +1163,7 @@ class ActivityDefinitionDynamicValue(backboneelement.BackboneElement):
         description=(
             "The path to the element to be customized. This is the path on the "
             "resource that will hold the result of the calculation defined by the "
-            "expression. The specified path SHALL be a FHIRPath resolveable on the "
+            "expression. The specified path SHALL be a FHIRPath resolvable on the "
             "specified target type of the ActivityDefinition, and SHALL consist "
             "only of identifiers, constant indexers, and a restricted subset of "
             "functions. The path is allowed to contain qualifiers (.) to traverse "
@@ -1183,10 +1258,22 @@ class ActivityDefinitionParticipant(backboneelement.BackboneElement):
 
     resource_type = Field("ActivityDefinitionParticipant", const=True)
 
+    function: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="function",
+        title="E.g. Author, Reviewer, Witness, etc",
+        description=(
+            "Indicates how the actor will be involved in the action - author, "
+            "reviewer, witness, etc."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     role: fhirtypes.CodeableConceptType = Field(
         None,
         alias="role",
-        title="E.g. Nurse, Surgeon, Parent, etc.",
+        title="E.g. Nurse, Surgeon, Parent, etc",
         description=(
             "The role the participant should play in performing the described "
             "action."
@@ -1198,82 +1285,84 @@ class ActivityDefinitionParticipant(backboneelement.BackboneElement):
     type: fhirtypes.Code = Field(
         None,
         alias="type",
-        title="patient | practitioner | related-person | device",
+        title=(
+            "careteam | device | group | healthcareservice | location | "
+            "organization | patient | practitioner | practitionerrole | "
+            "relatedperson"
+        ),
         description="The type of participant in the action.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["patient", "practitioner", "related-person", "device"],
+        enum_values=[
+            "careteam",
+            "device",
+            "group",
+            "healthcareservice",
+            "location",
+            "organization",
+            "patient",
+            "practitioner",
+            "practitionerrole",
+            "relatedperson",
+        ],
     )
     type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    typeCanonical: fhirtypes.Canonical = Field(
+        None,
+        alias="typeCanonical",
+        title="Who or what can participate",
+        description="The type of participant in the action.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["CapabilityStatement"],
+    )
+    typeCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_typeCanonical", title="Extension field for ``typeCanonical``."
+    )
+
+    typeReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="typeReference",
+        title="Who or what can participate",
+        description="The type of participant in the action.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "CareTeam",
+            "Device",
+            "DeviceDefinition",
+            "Endpoint",
+            "Group",
+            "HealthcareService",
+            "Location",
+            "Organization",
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+        ],
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
         ``ActivityDefinitionParticipant`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "type", "role"]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_3210(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("type", "type__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "typeCanonical",
+            "typeReference",
+            "role",
+            "function",
+        ]
