@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Address
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
 from pydantic import Field
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Address(element.Element):
+class Address(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -25,6 +25,8 @@ class Address(element.Element):
     addresses for use in delivering mail as well as for visiting locations
     which might not be valid for mail delivery.  There are a variety of postal
     address formats defined around the world.
+    The ISO21090-codedString may be used to provide a coded representation of
+    the contents of strings in an Address.
     """
 
     resource_type = Field("Address", const=True)
@@ -47,7 +49,7 @@ class Address(element.Element):
     country: fhirtypes.String = Field(
         None,
         alias="country",
-        title="Country (e.g. can be ISO 3166 2 or 3 letter code)",
+        title="Country (e.g. may be ISO 3166 2 or 3 letter code)",
         description="Country - a nation as commonly understood or generally accepted.",
         # if property is element of this resource.
         element_property=True,
