@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/AllergyIntolerance
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -19,28 +19,12 @@ class AllergyIntolerance(domainresource.DomainResource):
     for FHIR Primitive Data Types.
 
     Allergy or Intolerance (generally: Risk of adverse reaction to a substance).
-    Risk of harmful or undesirable, physiological response which is unique to
+    Risk of harmful or undesirable physiological response which is specific to
     an individual and associated with exposure to a substance.
     """
 
     resource_type = Field("AllergyIntolerance", const=True)
 
-    asserter: fhirtypes.ReferenceType = Field(
-        None,
-        alias="asserter",
-        title="Source of the information about the allergy",
-        description="The source of the information about the allergy that is recorded.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Patient",
-            "RelatedPerson",
-            "Practitioner",
-            "PractitionerRole",
-        ],
-    )
-
     category: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="category",
@@ -242,10 +226,25 @@ class AllergyIntolerance(domainresource.DomainResource):
         None, alias="_onsetString", title="Extension field for ``onsetString``."
     )
 
+    participant: typing.List[fhirtypes.AllergyIntoleranceParticipantType] = Field(
+        None,
+        alias="participant",
+        title=(
+            "Who or what participated in the activities related to the allergy or "
+            "intolerance and how they were involved"
+        ),
+        description=(
+            "Indicates who or what participated in the activities related to the "
+            "allergy or intolerance and how they were involved."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     patient: fhirtypes.ReferenceType = Field(
         ...,
         alias="patient",
-        title="Who the sensitivity is for",
+        title="Who the allergy or intolerance is for",
         description="The patient who has the allergy or intolerance.",
         # if property is element of this resource.
         element_property=True,
@@ -268,7 +267,7 @@ class AllergyIntolerance(domainresource.DomainResource):
     recordedDate: fhirtypes.DateTime = Field(
         None,
         alias="recordedDate",
-        title="Date first version of the resource instance was recorded",
+        title="Date allergy or intolerance was first recorded",
         description=(
             "The recordedDate represents when this particular AllergyIntolerance "
             "record was created in the system, which is often a system-generated "
@@ -281,26 +280,7 @@ class AllergyIntolerance(domainresource.DomainResource):
         None, alias="_recordedDate", title="Extension field for ``recordedDate``."
     )
 
-    recorder: fhirtypes.ReferenceType = Field(
-        None,
-        alias="recorder",
-        title="Who recorded the sensitivity",
-        description=(
-            "Individual who recorded the record and takes responsibility for its "
-            "content."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Practitioner",
-            "PractitionerRole",
-            "Patient",
-            "RelatedPerson",
-        ],
-    )
-
-    type: fhirtypes.Code = Field(
+    type: fhirtypes.CodeableConceptType = Field(
         None,
         alias="type",
         title="allergy | intolerance - Underlying mechanism (if known)",
@@ -310,22 +290,18 @@ class AllergyIntolerance(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["allergy", "intolerance"],
-    )
-    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_type", title="Extension field for ``type``."
     )
 
     verificationStatus: fhirtypes.CodeableConceptType = Field(
         None,
         alias="verificationStatus",
-        title="unconfirmed | confirmed | refuted | entered-in-error",
+        title="unconfirmed | presumed | confirmed | refuted | entered-in-error",
         description=(
             "Assertion about certainty associated with the propensity, or potential"
             " risk, of a reaction to the identified substance (including "
-            "pharmaceutical product)."
+            "pharmaceutical product).  The verification status pertains to the "
+            "allergy or intolerance, itself, not to any specific AllergyIntolerance"
+            " attribute."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -361,8 +337,7 @@ class AllergyIntolerance(domainresource.DomainResource):
             "onsetRange",
             "onsetString",
             "recordedDate",
-            "recorder",
-            "asserter",
+            "participant",
             "lastOccurrence",
             "note",
             "reaction",
@@ -415,6 +390,65 @@ class AllergyIntolerance(domainresource.DomainResource):
         return values
 
 
+class AllergyIntoleranceParticipant(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Who or what participated in the activities related to the allergy or
+    intolerance and how they were involved.
+    Indicates who or what participated in the activities related to the allergy
+    or intolerance and how they were involved.
+    """
+
+    resource_type = Field("AllergyIntoleranceParticipant", const=True)
+
+    actor: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="actor",
+        title=(
+            "Who or what participated in the activities related to the allergy or "
+            "intolerance"
+        ),
+        description=(
+            "Indicates who or what participated in the activities related to the "
+            "allergy or intolerance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Patient",
+            "RelatedPerson",
+            "Device",
+            "Organization",
+            "CareTeam",
+        ],
+    )
+
+    function: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="function",
+        title="Type of involvement",
+        description=(
+            "Distinguishes the type of involvement of the actor in the activities "
+            "related to the allergy or intolerance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AllergyIntoleranceParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
+
+
 class AllergyIntoleranceReaction(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -454,7 +488,7 @@ class AllergyIntoleranceReaction(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    manifestation: typing.List[fhirtypes.CodeableConceptType] = Field(
+    manifestation: typing.List[fhirtypes.CodeableReferenceType] = Field(
         ...,
         alias="manifestation",
         title="Clinical symptoms/signs associated with the Event",
@@ -464,6 +498,8 @@ class AllergyIntoleranceReaction(backboneelement.BackboneElement):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Observation"],
     )
 
     note: typing.List[fhirtypes.AnnotationType] = Field(
