@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Annotation
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,11 +12,11 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Annotation(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+class Annotation(datatype.DataType):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -40,6 +40,7 @@ class Annotation(element.Element):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Practitioner",
+            "PractitionerRole",
             "Patient",
             "RelatedPerson",
             "Organization",
@@ -86,6 +87,14 @@ class Annotation(element.Element):
         None, alias="_time", title="Extension field for ``time``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Annotation`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "authorReference", "authorString", "time", "text"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1226(
         cls, values: typing.Dict[str, typing.Any]
