@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/AppointmentResponse
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -29,7 +29,7 @@ class AppointmentResponse(domainresource.DomainResource):
     actor: fhirtypes.ReferenceType = Field(
         None,
         alias="actor",
-        title="Person, Location, HealthcareService, or Device",
+        title="Person(s), Location, HealthcareService, or Device",
         description=(
             "A Person, Location, HealthcareService, or Device that is participating"
             " in the appointment."
@@ -39,6 +39,7 @@ class AppointmentResponse(domainresource.DomainResource):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Patient",
+            "Group",
             "Practitioner",
             "PractitionerRole",
             "RelatedPerson",
@@ -59,7 +60,7 @@ class AppointmentResponse(domainresource.DomainResource):
         enum_reference_types=["Appointment"],
     )
 
-    comment: fhirtypes.String = Field(
+    comment: fhirtypes.Markdown = Field(
         None,
         alias="comment",
         title="Additional comments",
@@ -101,10 +102,27 @@ class AppointmentResponse(domainresource.DomainResource):
         element_property=True,
     )
 
+    occurrenceDate: fhirtypes.Date = Field(
+        None,
+        alias="occurrenceDate",
+        title="Original date within a recurring request",
+        description=(
+            "The original date within a recurring request. This could be used in "
+            "place of the recurrenceId to be more direct (or where the template is "
+            "provided through the simple list of dates in "
+            "`Appointment.occurrenceDate`)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    occurrenceDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_occurrenceDate", title="Extension field for ``occurrenceDate``."
+    )
+
     participantStatus: fhirtypes.Code = Field(
         None,
         alias="participantStatus",
-        title="accepted | declined | tentative | needs-action",
+        title="accepted | declined | tentative | needs-action | entered-in-error",
         description=(
             "Participation status of the participant. When the status is declined "
             "or tentative if the start/end times are different to the appointment, "
@@ -117,7 +135,13 @@ class AppointmentResponse(domainresource.DomainResource):
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["accepted", "declined", "tentative", "needs-action"],
+        enum_values=[
+            "accepted",
+            "declined",
+            "tentative",
+            "needs-action",
+            "entered-in-error",
+        ],
     )
     participantStatus__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None,
@@ -134,6 +158,52 @@ class AppointmentResponse(domainresource.DomainResource):
         element_property=True,
     )
 
+    proposedNewTime: bool = Field(
+        None,
+        alias="proposedNewTime",
+        title="Indicator for a counter proposal",
+        description=(
+            "Indicates that the response is proposing a different time that was "
+            "initially requested.  The new proposed time will be indicated in the "
+            "start and end properties."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    proposedNewTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_proposedNewTime", title="Extension field for ``proposedNewTime``."
+    )
+
+    recurrenceId: fhirtypes.PositiveInt = Field(
+        None,
+        alias="recurrenceId",
+        title="The recurrence ID of the specific recurring request",
+        description=(
+            "The recurrence ID (sequence number) of the specific appointment when "
+            "responding to a recurring request."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    recurrenceId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_recurrenceId", title="Extension field for ``recurrenceId``."
+    )
+
+    recurring: bool = Field(
+        None,
+        alias="recurring",
+        title="This response is for all occurrences in a recurring request",
+        description=(
+            "Indicates that this AppointmentResponse applies to all occurrences in "
+            "a recurring request."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    recurring__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_recurring", title="Extension field for ``recurring``."
+    )
+
     start: fhirtypes.Instant = Field(
         None,
         alias="start",
@@ -166,12 +236,16 @@ class AppointmentResponse(domainresource.DomainResource):
             "modifierExtension",
             "identifier",
             "appointment",
+            "proposedNewTime",
             "start",
             "end",
             "participantType",
             "actor",
             "participantStatus",
             "comment",
+            "recurring",
+            "occurrenceDate",
+            "recurrenceId",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
