@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Attachment
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 from pydantic import Field
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Attachment(element.Element):
+class Attachment(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -65,6 +65,36 @@ class Attachment(element.Element):
         None, alias="_data", title="Extension field for ``data``."
     )
 
+    duration: fhirtypes.Decimal = Field(
+        None,
+        alias="duration",
+        title="Length in seconds (audio / video)",
+        description="The duration of the recording in seconds - for audio and video.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    duration__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_duration", title="Extension field for ``duration``."
+    )
+
+    frames: fhirtypes.PositiveInt = Field(
+        None,
+        alias="frames",
+        title="Number of frames if > 1 (photo)",
+        description=(
+            "The number of frames in a photo. This is used with a multi-page fax, "
+            "or an imaging acquisition context that takes multiple slices in a "
+            "single image, or an animated gif. If there is more than one frame, "
+            "this SHALL have a value in order to alert interface software that a "
+            "multi-frame capable rendering widget is required."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    frames__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_frames", title="Extension field for ``frames``."
+    )
+
     hash: fhirtypes.Base64Binary = Field(
         None,
         alias="hash",
@@ -77,6 +107,18 @@ class Attachment(element.Element):
         None, alias="_hash", title="Extension field for ``hash``."
     )
 
+    height: fhirtypes.PositiveInt = Field(
+        None,
+        alias="height",
+        title="Height of the image in pixels (photo/video)",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    height__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_height", title="Extension field for ``height``."
+    )
+
     language: fhirtypes.Code = Field(
         None,
         alias="language",
@@ -92,7 +134,19 @@ class Attachment(element.Element):
         None, alias="_language", title="Extension field for ``language``."
     )
 
-    size: fhirtypes.UnsignedInt = Field(
+    pages: fhirtypes.PositiveInt = Field(
+        None,
+        alias="pages",
+        title="Number of printed pages",
+        description="The number of pages when printed.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    pages__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_pages", title="Extension field for ``pages``."
+    )
+
+    size: fhirtypes.Integer64 = Field(
         None,
         alias="size",
         title="Number of bytes of content (if url provided)",
@@ -131,6 +185,18 @@ class Attachment(element.Element):
         None, alias="_url", title="Extension field for ``url``."
     )
 
+    width: fhirtypes.PositiveInt = Field(
+        None,
+        alias="width",
+        title="Width of the image in pixels (photo/video)",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    width__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_width", title="Extension field for ``width``."
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -148,4 +214,9 @@ class Attachment(element.Element):
             "hash",
             "title",
             "creation",
+            "height",
+            "width",
+            "frames",
+            "duration",
+            "pages",
         ]
