@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/BackboneElement
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -35,8 +35,8 @@ class BackboneElement(element.Element):
             "understanding of the element in which it is contained and/or the "
             "understanding of the containing element's descendants. Usually "
             "modifier elements provide negation or qualification. To make the use "
-            "of extensions safe and manageable, there is a strict set of governance"
-            " applied to the definition and use of extensions. Though any "
+            "of extensions safe and managable, there is a strict set of governance "
+            "applied to the definition and use of extensions. Though any "
             "implementer can define an extension, there is a set of requirements "
             "that SHALL be met as part of the definition of the extension. "
             "Applications processing a resource are required to check for modifier "
