@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Binary
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -70,7 +70,7 @@ class Binary(resource.Resource):
             "contains very few elements that can be used to determine the "
             "sensitivity of the data and relationships to individuals, the "
             "referenced resource stands in as a proxy equivalent for this purpose. "
-            "This referenced resource may be related to the Binary (e.g. Media, "
+            "This referenced resource may be related to the Binary (e.g. "
             "DocumentReference), or may be some non-related Resource purely as a "
             "security proxy. E.g. to identify that the binary resource relates to a"
             " patient, and access should only be granted to applications that have "
