@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/BiologicallyDerivedProduct
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -18,14 +18,28 @@ class BiologicallyDerivedProduct(domainresource.DomainResource):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    A material substance originating from a biological entity.
-    A material substance originating from a biological entity intended to be
+    This resource reflects an instance of a biologically derived product.
+    This resource reflects an instance of a biologically derived product. A
+    material substance originating from a biological entity intended to be
     transplanted or infused
     into another (possibly the same) biological entity.
     """
 
     resource_type = Field("BiologicallyDerivedProduct", const=True)
 
+    biologicalSourceEvent: fhirtypes.IdentifierType = Field(
+        None,
+        alias="biologicalSourceEvent",
+        title=(
+            "An identifier that supports traceability to the event during which "
+            "material in this product from one or more biological entities was "
+            "obtained or pooled"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     collection: fhirtypes.BiologicallyDerivedProductCollectionType = Field(
         None,
         alias="collection",
@@ -35,29 +49,42 @@ class BiologicallyDerivedProduct(domainresource.DomainResource):
         element_property=True,
     )
 
-    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+    division: fhirtypes.String = Field(
         None,
-        alias="identifier",
-        title="External ids for this item",
+        alias="division",
+        title="A unique identifier for an aliquot of a product",
         description=(
-            "This records identifiers associated with this biologically derived "
-            "product instance that are defined by business processes and/or used to"
-            " refer to it when a direct URL reference to the resource itself is not"
-            " appropriate (e.g. in CDA documents, or in written / printed "
-            "documentation)."
+            "A unique identifier for an aliquot of a product.  Used to distinguish "
+            "individual aliquots of a product carrying the same biologicalSource "
+            "and productCode identifiers."
         ),
         # if property is element of this resource.
         element_property=True,
     )
+    division__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_division", title="Extension field for ``division``."
+    )
 
-    manipulation: fhirtypes.BiologicallyDerivedProductManipulationType = Field(
+    expirationDate: fhirtypes.DateTime = Field(
         None,
-        alias="manipulation",
-        title="Any manipulation of product post-collection",
+        alias="expirationDate",
+        title="Date, and where relevant time, of expiration",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    expirationDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_expirationDate", title="Extension field for ``expirationDate``."
+    )
+
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title="Instance identifier",
         description=(
-            "Any manipulation of product post-collection that is intended to alter "
-            "the product.  For example a buffy-coat enrichment or CD8 reduction of "
-            "Peripheral Blood Stem Cells to make it more suitable for infusion."
+            "Unique instance identifiers assigned to a biologically derived "
+            "product. Note: This is a business identifier, not a resource "
+            "identifier."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -66,97 +93,90 @@ class BiologicallyDerivedProduct(domainresource.DomainResource):
     parent: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="parent",
-        title="BiologicallyDerivedProduct parent",
-        description="Parent product (if any).",
+        title="The parent biologically-derived product",
+        description="Parent product (if any) for this biologically-derived product.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["BiologicallyDerivedProduct"],
     )
 
-    processing: typing.List[fhirtypes.BiologicallyDerivedProductProcessingType] = Field(
+    processingFacility: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="processing",
-        title="Any processing of the product during collection",
-        description=(
-            "Any processing of the product during collection that does not change "
-            "the fundamental nature of the product. For example adding anti-"
-            "coagulants during the collection of Peripheral Blood Stem Cells."
+        alias="processingFacility",
+        title=(
+            "Processing facilities responsible for the labeling and distribution of"
+            " this biologically derived product"
         ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Organization"],
     )
 
-    productCategory: fhirtypes.Code = Field(
+    productCategory: fhirtypes.CodingType = Field(
         None,
         alias="productCategory",
         title="organ | tissue | fluid | cells | biologicalAgent",
         description="Broad category of this product.",
         # if property is element of this resource.
         element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["organ", "tissue", "fluid", "cells", "biologicalAgent"],
-    )
-    productCategory__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_productCategory", title="Extension field for ``productCategory``."
     )
 
     productCode: fhirtypes.CodeableConceptType = Field(
         None,
         alias="productCode",
-        title="What this biologically derived product is",
+        title="A code that identifies the kind of this biologically derived product",
         description=(
-            "A code that identifies the kind of this biologically derived product "
-            "(SNOMED Ctcode)."
+            "A codified value that systematically supports characterization and "
+            "classification of medical products of human origin inclusive of "
+            "processing conditions such as additives, volumes and handling "
+            "conditions."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    quantity: fhirtypes.Integer = Field(
+    productStatus: fhirtypes.CodingType = Field(
         None,
-        alias="quantity",
-        title="The amount of this biologically derived product",
-        description="Number of discrete units within this product.",
+        alias="productStatus",
+        title="available | unavailable",
+        description="Whether the product is currently available.",
         # if property is element of this resource.
         element_property=True,
     )
-    quantity__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_quantity", title="Extension field for ``quantity``."
+
+    property: typing.List[fhirtypes.BiologicallyDerivedProductPropertyType] = Field(
+        None,
+        alias="property",
+        title=(
+            "A property that is specific to this BiologicallyDerviedProduct " "instance"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
     )
 
     request: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="request",
-        title="Procedure request",
-        description="Procedure request to obtain this biologically derived product.",
+        title="Request to obtain and/or infuse this product",
+        description="Request to obtain and/or infuse this biologically derived product.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["ServiceRequest"],
     )
 
-    status: fhirtypes.Code = Field(
+    storageTempRequirements: fhirtypes.RangeType = Field(
         None,
-        alias="status",
-        title="available | unavailable",
-        description="Whether the product is currently available.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["available", "unavailable"],
-    )
-    status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_status", title="Extension field for ``status``."
-    )
-
-    storage: typing.List[fhirtypes.BiologicallyDerivedProductStorageType] = Field(
-        None,
-        alias="storage",
-        title="Product storage",
-        description=None,
+        alias="storageTempRequirements",
+        title="Product storage temperature requirements",
+        description=(
+            "The temperature requirements for storage of the biologically-derived "
+            "product."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -176,17 +196,19 @@ class BiologicallyDerivedProduct(domainresource.DomainResource):
             "contained",
             "extension",
             "modifierExtension",
-            "identifier",
             "productCategory",
             "productCode",
-            "status",
-            "request",
-            "quantity",
             "parent",
+            "request",
+            "identifier",
+            "biologicalSourceEvent",
+            "processingFacility",
+            "division",
+            "productStatus",
+            "expirationDate",
             "collection",
-            "processing",
-            "manipulation",
-            "storage",
+            "storageTempRequirements",
+            "property",
         ]
 
 
@@ -243,7 +265,10 @@ class BiologicallyDerivedProductCollection(backboneelement.BackboneElement):
     source: fhirtypes.ReferenceType = Field(
         None,
         alias="source",
-        title="Who is product from",
+        title=(
+            "The patient who underwent the medical procedure to collect the product"
+            " or the organization that facilitated the collection"
+        ),
         description=(
             "The patient or entity, such as a hospital or vendor in the case of a "
             "processed/manipulated/manufactured product, providing the product."
@@ -309,75 +334,169 @@ class BiologicallyDerivedProductCollection(backboneelement.BackboneElement):
         return values
 
 
-class BiologicallyDerivedProductManipulation(backboneelement.BackboneElement):
+class BiologicallyDerivedProductProperty(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Any manipulation of product post-collection.
-    Any manipulation of product post-collection that is intended to alter the
-    product.  For example a buffy-coat enrichment or CD8 reduction of
-    Peripheral Blood Stem Cells to make it more suitable for infusion.
+    A property that is specific to this BiologicallyDerviedProduct instance.
     """
 
-    resource_type = Field("BiologicallyDerivedProductManipulation", const=True)
+    resource_type = Field("BiologicallyDerivedProductProperty", const=True)
 
-    description: fhirtypes.String = Field(
-        None,
-        alias="description",
-        title="Description of manipulation",
-        description=None,
+    type: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="type",
+        title="Code that specifies the property",
+        description=(
+            "Code that specifies the property. It should reference an established "
+            "coding system."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
-    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_description", title="Extension field for ``description``."
-    )
 
-    timeDateTime: fhirtypes.DateTime = Field(
+    valueAttachment: fhirtypes.AttachmentType = Field(
         None,
-        alias="timeDateTime",
-        title="Time of manipulation",
+        alias="valueAttachment",
+        title="Property values",
         description=None,
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e time[x]
-        one_of_many="time",
-        one_of_many_required=False,
-    )
-    timeDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_timeDateTime", title="Extension field for ``timeDateTime``."
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
     )
 
-    timePeriod: fhirtypes.PeriodType = Field(
+    valueBoolean: bool = Field(
         None,
-        alias="timePeriod",
-        title="Time of manipulation",
+        alias="valueBoolean",
+        title="Property values",
         description=None,
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e time[x]
-        one_of_many="time",
-        one_of_many_required=False,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueBoolean", title="Extension field for ``valueBoolean``."
+    )
+
+    valueCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="valueCodeableConcept",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueInteger: fhirtypes.Integer = Field(
+        None,
+        alias="valueInteger",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueInteger__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueInteger", title="Extension field for ``valueInteger``."
+    )
+
+    valuePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="valuePeriod",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueQuantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="valueQuantity",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueRange: fhirtypes.RangeType = Field(
+        None,
+        alias="valueRange",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueRatio: fhirtypes.RatioType = Field(
+        None,
+        alias="valueRatio",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueString: fhirtypes.String = Field(
+        None,
+        alias="valueString",
+        title="Property values",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueString", title="Extension field for ``valueString``."
     )
 
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``BiologicallyDerivedProductManipulation`` according specification,
+        ``BiologicallyDerivedProductProperty`` according specification,
         with preserving original sequence order.
         """
         return [
             "id",
             "extension",
             "modifierExtension",
-            "description",
-            "timeDateTime",
-            "timePeriod",
+            "type",
+            "valueBoolean",
+            "valueInteger",
+            "valueCodeableConcept",
+            "valuePeriod",
+            "valueQuantity",
+            "valueRange",
+            "valueRatio",
+            "valueString",
+            "valueAttachment",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_4127(
+    def validate_one_of_many_3742(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
         """https://www.hl7.org/fhir/formats.html#choice
@@ -392,7 +511,19 @@ class BiologicallyDerivedProductManipulation(backboneelement.BackboneElement):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"time": ["timeDateTime", "timePeriod"]}
+        one_of_many_fields = {
+            "value": [
+                "valueAttachment",
+                "valueBoolean",
+                "valueCodeableConcept",
+                "valueInteger",
+                "valuePeriod",
+                "valueQuantity",
+                "valueRange",
+                "valueRatio",
+                "valueString",
+            ]
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
@@ -413,206 +544,3 @@ class BiologicallyDerivedProductManipulation(backboneelement.BackboneElement):
                 raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
-
-
-class BiologicallyDerivedProductProcessing(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Any processing of the product during collection.
-    Any processing of the product during collection that does not change the
-    fundamental nature of the product. For example adding anti-coagulants
-    during the collection of Peripheral Blood Stem Cells.
-    """
-
-    resource_type = Field("BiologicallyDerivedProductProcessing", const=True)
-
-    additive: fhirtypes.ReferenceType = Field(
-        None,
-        alias="additive",
-        title="Substance added during processing",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Substance"],
-    )
-
-    description: fhirtypes.String = Field(
-        None,
-        alias="description",
-        title="Description of of processing",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_description", title="Extension field for ``description``."
-    )
-
-    procedure: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="procedure",
-        title="Procesing code",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    timeDateTime: fhirtypes.DateTime = Field(
-        None,
-        alias="timeDateTime",
-        title="Time of processing",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e time[x]
-        one_of_many="time",
-        one_of_many_required=False,
-    )
-    timeDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_timeDateTime", title="Extension field for ``timeDateTime``."
-    )
-
-    timePeriod: fhirtypes.PeriodType = Field(
-        None,
-        alias="timePeriod",
-        title="Time of processing",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e time[x]
-        one_of_many="time",
-        one_of_many_required=False,
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``BiologicallyDerivedProductProcessing`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "description",
-            "procedure",
-            "additive",
-            "timeDateTime",
-            "timePeriod",
-        ]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_3908(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {"time": ["timeDateTime", "timePeriod"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
-
-class BiologicallyDerivedProductStorage(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Product storage.
-    """
-
-    resource_type = Field("BiologicallyDerivedProductStorage", const=True)
-
-    description: fhirtypes.String = Field(
-        None,
-        alias="description",
-        title="Description of storage",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_description", title="Extension field for ``description``."
-    )
-
-    duration: fhirtypes.PeriodType = Field(
-        None,
-        alias="duration",
-        title="Storage timeperiod",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    scale: fhirtypes.Code = Field(
-        None,
-        alias="scale",
-        title="farenheit | celsius | kelvin",
-        description="Temperature scale used.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["farenheit", "celsius", "kelvin"],
-    )
-    scale__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_scale", title="Extension field for ``scale``."
-    )
-
-    temperature: fhirtypes.Decimal = Field(
-        None,
-        alias="temperature",
-        title="Storage temperature",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    temperature__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_temperature", title="Extension field for ``temperature``."
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``BiologicallyDerivedProductStorage`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "description",
-            "temperature",
-            "scale",
-            "duration",
-        ]
