@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Bundle
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -50,6 +50,18 @@ class Bundle(resource.Resource):
         element_property=True,
     )
 
+    issues: fhirtypes.ResourceType = Field(
+        None,
+        alias="issues",
+        title="Issues with the Bundle",
+        description=(
+            "Captures issues and warnings that relate to the construction of the "
+            "Bundle and the content within it."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     link: typing.List[fhirtypes.BundleLinkType] = Field(
         None,
         alias="link",
@@ -63,7 +75,7 @@ class Bundle(resource.Resource):
         None,
         alias="signature",
         title="Digital Signature",
-        description="Digital Signature - base64 encoded. XML-DSig or a JWT.",
+        description="Digital Signature - base64 encoded. XML-DSig or a JWS.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -88,10 +100,10 @@ class Bundle(resource.Resource):
         alias="total",
         title="If search, the total number of matches",
         description=(
-            "If a set of search matches, this is the total number of entries of "
-            "type 'match' across all pages in the search.  It does not include "
-            "search.mode = 'include' or 'outcome' entries and it does not provide a"
-            " count of the number of entries in the Bundle."
+            "If a set of search matches, this is the (potentially estimated) total "
+            "number of entries of type 'match' across all pages in the search.  It "
+            "does not include search.mode = 'include' or 'outcome' entries and it "
+            "does not provide a count of the number of entries in the Bundle."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -105,7 +117,8 @@ class Bundle(resource.Resource):
         alias="type",
         title=(
             "document | message | transaction | transaction-response | batch | "
-            "batch-response | history | searchset | collection"
+            "batch-response | history | searchset | collection | subscription-"
+            "notification"
         ),
         description="Indicates the purpose of this bundle - how it is intended to be used.",
         # if property is element of this resource.
@@ -123,6 +136,7 @@ class Bundle(resource.Resource):
             "history",
             "searchset",
             "collection",
+            "subscription-notification",
         ],
     )
     type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
@@ -147,6 +161,7 @@ class Bundle(resource.Resource):
             "link",
             "entry",
             "signature",
+            "issues",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
@@ -224,16 +239,23 @@ class BundleEntry(backboneelement.BackboneElement):
     fullUrl: fhirtypes.Uri = Field(
         None,
         alias="fullUrl",
-        title="URI for resource (Absolute URL server address or URI for UUID/OID)",
+        title=(
+            "URI for resource (e.g. the absolute URL server address, URI for "
+            "UUID/OID, etc.)"
+        ),
         description=(
-            "The Absolute URL for the resource.  The fullUrl SHALL NOT disagree "
-            "with the id in the resource - i.e. if the fullUrl is not a urn:uuid, "
-            "the URL shall be version-independent URL consistent with the "
-            "Resource.id. The fullUrl is a version independent reference to the "
-            "resource. The fullUrl element SHALL have a value except that:  * "
-            "fullUrl can be empty on a POST (although it does not need to when "
-            "specifying a temporary id for reference in the bundle) * Results from "
-            "operations might involve resources that are not identified."
+            "The Absolute URL for the resource. Except for transactions and "
+            "batches, each entry in a Bundle must have a fullUrl. The fullUrl SHALL"
+            " NOT disagree with the id in the resource - i.e. if the fullUrl is not"
+            " a urn:uuid, the URL shall be version-independent URL consistent with "
+            "the Resource.id. The fullUrl is a version independent reference to the"
+            " resource. Even when not required, fullUrl MAY be set to a urn:uuid to"
+            " allow referencing entries in a transaction. The fullUrl can be an "
+            "arbitrary URI and is not limited to urn:uuid, urn:oid, http, and "
+            "https. The fullUrl element SHALL have a value except when:  * invoking"
+            " a create * invoking or responding to an operation where the body is "
+            "not a single identified resource * invoking or returning the results "
+            "of a search or history operation."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -270,7 +292,9 @@ class BundleEntry(backboneelement.BackboneElement):
         title="A resource in the bundle",
         description=(
             "The Resource for the entry. The purpose/meaning of the resource is "
-            "determined by the Bundle.type."
+            "determined by the Bundle.type. This is allowed to be a Parameters "
+            "resource if and only if it is referenced by something else within the "
+            "Bundle that provides context/meaning."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -384,7 +408,7 @@ class BundleEntryRequest(backboneelement.BackboneElement):
     ifNoneMatch: fhirtypes.String = Field(
         None,
         alias="ifNoneMatch",
-        title="For managing cache currency",
+        title="For managing cache validation",
         description=(
             "If the ETag values match, return a 304 Not Modified status. See the "
             'API documentation for ["Conditional Read"](http.html#cread).'
@@ -688,7 +712,7 @@ class BundleEntrySearch(backboneelement.BackboneElement):
     mode: fhirtypes.Code = Field(
         None,
         alias="mode",
-        title="match | include | outcome - why this is in the result set",
+        title="match | include - why this is in the result set",
         description=(
             "Why this entry is in the result set - whether it's included as a match"
             " or because of an _include requirement, or to convey information or "
@@ -698,7 +722,7 @@ class BundleEntrySearch(backboneelement.BackboneElement):
         element_property=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["match", "include", "outcome"],
+        enum_values=["match", "include"],
     )
     mode__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_mode", title="Extension field for ``mode``."
@@ -736,7 +760,7 @@ class BundleLink(backboneelement.BackboneElement):
 
     resource_type = Field("BundleLink", const=True)
 
-    relation: fhirtypes.String = Field(
+    relation: fhirtypes.Code = Field(
         None,
         alias="relation",
         title=(
