@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/CareTeam
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
-from pydantic import Field
+from pydantic import Field, root_validator
 
 from . import backboneelement, domainresource, fhirtypes
 
@@ -18,10 +18,9 @@ class CareTeam(domainresource.DomainResource):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Planned participants in the coordination and delivery of care for a patient
-    or group.
+    Planned participants in the coordination and delivery of care.
     The Care Team includes all the people and organizations who plan to
-    participate in the coordination and delivery of care for a patient.
+    participate in the coordination and delivery of care.
     """
 
     resource_type = Field("CareTeam", const=True)
@@ -39,20 +38,6 @@ class CareTeam(domainresource.DomainResource):
         element_property=True,
     )
 
-    encounter: fhirtypes.ReferenceType = Field(
-        None,
-        alias="encounter",
-        title="Encounter created as part of",
-        description=(
-            "The Encounter during which this CareTeam was created or to which the "
-            "creation of this record is tightly associated."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Encounter"],
-    )
-
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -125,22 +110,13 @@ class CareTeam(domainresource.DomainResource):
         element_property=True,
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Why the care team exists",
         description="Describes why the care team exists.",
         # if property is element of this resource.
         element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Why the care team exists",
-        description="Condition(s) that this care team addresses.",
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Condition"],
     )
@@ -206,11 +182,9 @@ class CareTeam(domainresource.DomainResource):
             "category",
             "name",
             "subject",
-            "encounter",
             "period",
             "participant",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "managingOrganization",
             "telecom",
             "note",
@@ -229,6 +203,30 @@ class CareTeamParticipant(backboneelement.BackboneElement):
 
     resource_type = Field("CareTeamParticipant", const=True)
 
+    coveragePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="coveragePeriod",
+        title="When the member is generally available within this care team",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e coverage[x]
+        one_of_many="coverage",
+        one_of_many_required=False,
+    )
+
+    coverageTiming: fhirtypes.TimingType = Field(
+        None,
+        alias="coverageTiming",
+        title="When the member is generally available within this care team",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e coverage[x]
+        one_of_many="coverage",
+        one_of_many_required=False,
+    )
+
     member: fhirtypes.ReferenceType = Field(
         None,
         alias="member",
@@ -261,19 +259,7 @@ class CareTeamParticipant(backboneelement.BackboneElement):
         enum_reference_types=["Organization"],
     )
 
-    period: fhirtypes.PeriodType = Field(
-        None,
-        alias="period",
-        title="Time period of participant",
-        description=(
-            "Indicates when the specific member or organization did (or is intended"
-            " to) come into effect and end."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    role: typing.List[fhirtypes.CodeableConceptType] = Field(
+    role: fhirtypes.CodeableConceptType = Field(
         None,
         alias="role",
         title="Type of involvement",
@@ -299,5 +285,44 @@ class CareTeamParticipant(backboneelement.BackboneElement):
             "role",
             "member",
             "onBehalfOf",
-            "period",
+            "coveragePeriod",
+            "coverageTiming",
         ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2104(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {"coverage": ["coveragePeriod", "coverageTiming"]}
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
