@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ChargeItem
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ChargeItem(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -61,20 +61,6 @@ class ChargeItem(domainresource.DomainResource):
         element_property=True,
     )
 
-    context: fhirtypes.ReferenceType = Field(
-        None,
-        alias="context",
-        title="Encounter / Episode associated with event",
-        description=(
-            "The encounter or episode of care that establishes the context for this"
-            " event."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Encounter", "EpisodeOfCare"],
-    )
-
     costCenter: fhirtypes.ReferenceType = Field(
         None,
         alias="costCenter",
@@ -86,7 +72,7 @@ class ChargeItem(domainresource.DomainResource):
         enum_reference_types=["Organization"],
     )
 
-    definitionCanonical: typing.List[fhirtypes.Canonical] = Field(
+    definitionCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="definitionCanonical",
         title="Resource defining the code of this ChargeItem",
@@ -107,7 +93,7 @@ class ChargeItem(domainresource.DomainResource):
         title="Extension field for ``definitionCanonical``.",
     )
 
-    definitionUri: typing.List[fhirtypes.Uri] = Field(
+    definitionUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="definitionUri",
         title="Defining information about the code of this charge item",
@@ -124,6 +110,20 @@ class ChargeItem(domainresource.DomainResource):
         None, alias="_definitionUri", title="Extension field for ``definitionUri``."
     )
 
+    encounter: fhirtypes.ReferenceType = Field(
+        None,
+        alias="encounter",
+        title="Encounter associated with this ChargeItem",
+        description=(
+            "This ChargeItem has the details of how the associated Encounter should"
+            " be billed or otherwise be handled by finance systems."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Encounter"],
+    )
+
     enteredDate: fhirtypes.DateTime = Field(
         None,
         alias="enteredDate",
@@ -154,21 +154,6 @@ class ChargeItem(domainresource.DomainResource):
         ],
     )
 
-    factorOverride: fhirtypes.Decimal = Field(
-        None,
-        alias="factorOverride",
-        title="Factor overriding the associated rules",
-        description=(
-            "Factor overriding the factor determined by the rules associated with "
-            "the code."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    factorOverride__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_factorOverride", title="Extension field for ``factorOverride``."
-    )
-
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -231,7 +216,7 @@ class ChargeItem(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
-    overrideReason: fhirtypes.String = Field(
+    overrideReason: fhirtypes.CodeableConceptType = Field(
         None,
         alias="overrideReason",
         title="Reason for overriding the list price/factor",
@@ -243,9 +228,6 @@ class ChargeItem(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
     )
-    overrideReason__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_overrideReason", title="Extension field for ``overrideReason``."
-    )
 
     partOf: typing.List[fhirtypes.ReferenceType] = Field(
         None,
@@ -276,28 +258,16 @@ class ChargeItem(domainresource.DomainResource):
         None,
         alias="performingOrganization",
         title="Organization providing the charged service",
-        description="The organization requesting the service.",
+        description="The organization performing the service.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Organization"],
     )
 
-    priceOverride: fhirtypes.MoneyType = Field(
+    product: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="priceOverride",
-        title="Price overriding the associated rules",
-        description=(
-            "Total price of the charge overriding the list price associated with "
-            "the code."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    productCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="productCodeableConcept",
+        alias="product",
         title="Product charged",
         description=(
             "Identifies the device, food, drug or other product being charged "
@@ -305,24 +275,6 @@ class ChargeItem(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e product[x]
-        one_of_many="product",
-        one_of_many_required=False,
-    )
-
-    productReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="productReference",
-        title="Product charged",
-        description=(
-            "Identifies the device, food, drug or other product being charged "
-            "either by type code or reference to an instance."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e product[x]
-        one_of_many="product",
-        one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Device", "Medication", "Substance"],
     )
@@ -349,14 +301,14 @@ class ChargeItem(domainresource.DomainResource):
         None,
         alias="requestingOrganization",
         title="Organization requesting the charged service",
-        description="The organization performing the service.",
+        description="The organization requesting the service.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Organization"],
     )
 
-    service: typing.List[fhirtypes.ReferenceType] = Field(
+    service: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="service",
         title="Which rendered service is being charged?",
@@ -370,8 +322,10 @@ class ChargeItem(domainresource.DomainResource):
             "Immunization",
             "MedicationAdministration",
             "MedicationDispense",
+            "MedicationRequest",
             "Observation",
             "Procedure",
+            "ServiceRequest",
             "SupplyDelivery",
         ],
     )
@@ -428,6 +382,69 @@ class ChargeItem(domainresource.DomainResource):
         enum_reference_types=["Resource"],
     )
 
+    totalPriceComponent: fhirtypes.MonetaryComponentType = Field(
+        None,
+        alias="totalPriceComponent",
+        title="Total price overriding the associated rules",
+        description="The total price for the chargable item, accounting for the quantity.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    unitPriceComponent: fhirtypes.MonetaryComponentType = Field(
+        None,
+        alias="unitPriceComponent",
+        title="Unit price overriding the associated rules",
+        description="The unit price of the chargable item.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ChargeItem`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "definitionUri",
+            "definitionCanonical",
+            "status",
+            "partOf",
+            "code",
+            "subject",
+            "encounter",
+            "occurrenceDateTime",
+            "occurrencePeriod",
+            "occurrenceTiming",
+            "performer",
+            "performingOrganization",
+            "requestingOrganization",
+            "costCenter",
+            "quantity",
+            "bodysite",
+            "unitPriceComponent",
+            "totalPriceComponent",
+            "overrideReason",
+            "enterer",
+            "enteredDate",
+            "reason",
+            "service",
+            "product",
+            "account",
+            "note",
+            "supportingInformation",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1161(
         cls, values: typing.Dict[str, typing.Any]
@@ -504,12 +521,7 @@ class ChargeItem(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "occurrence": [
-                "occurrenceDateTime",
-                "occurrencePeriod",
-                "occurrenceTiming",
-            ],
-            "product": ["productCodeableConcept", "productReference"],
+            "occurrence": ["occurrenceDateTime", "occurrencePeriod", "occurrenceTiming"]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -534,7 +546,7 @@ class ChargeItem(domainresource.DomainResource):
 
 
 class ChargeItemPerformer(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -559,6 +571,7 @@ class ChargeItemPerformer(backboneelement.BackboneElement):
             "Practitioner",
             "PractitionerRole",
             "Organization",
+            "HealthcareService",
             "CareTeam",
             "Patient",
             "Device",
@@ -577,3 +590,11 @@ class ChargeItemPerformer(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ChargeItemPerformer`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
