@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ChargeItemDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -59,7 +59,7 @@ class ChargeItemDefinition(domainresource.DomainResource):
     code: fhirtypes.CodeableConceptType = Field(
         None,
         alias="code",
-        title="Billing codes or product types this definition applies to",
+        title="Billing code or product type this definition applies to",
         description=(
             "The defined billing details in this resource pertain to the given "
             "billing code."
@@ -96,16 +96,33 @@ class ChargeItemDefinition(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
             "The date  (and optionally time) when the charge item definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the charge item definition "
-            "changes."
+            "last significantly changed. The date must change when the business "
+            "version changes and it must change if the status code changes. In "
+            "addition, it should change when the substantive content of the charge "
+            "item definition changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -114,7 +131,7 @@ class ChargeItemDefinition(domainresource.DomainResource):
         None, alias="_date", title="Extension field for ``date``."
     )
 
-    derivedFromUri: typing.List[fhirtypes.Uri] = Field(
+    derivedFromUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="derivedFromUri",
         title="Underlying externally-defined charge item definition",
@@ -146,18 +163,6 @@ class ChargeItemDefinition(domainresource.DomainResource):
         None, alias="_description", title="Extension field for ``description``."
     )
 
-    effectivePeriod: fhirtypes.PeriodType = Field(
-        None,
-        alias="effectivePeriod",
-        title="When the charge item definition is expected to be used",
-        description=(
-            "The period during which the charge item definition content was or is "
-            "planned to be in active use."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     experimental: bool = Field(
         None,
         alias="experimental",
@@ -198,7 +203,15 @@ class ChargeItemDefinition(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Medication", "Substance", "Device"],
+        enum_reference_types=[
+            "Medication",
+            "Substance",
+            "Device",
+            "DeviceDefinition",
+            "ActivityDefinition",
+            "PlanDefinition",
+            "HealthcareService",
+        ],
     )
 
     jurisdiction: typing.List[fhirtypes.CodeableConceptType] = Field(
@@ -216,7 +229,7 @@ class ChargeItemDefinition(domainresource.DomainResource):
     lastReviewDate: fhirtypes.Date = Field(
         None,
         alias="lastReviewDate",
-        title="When the charge item definition was last reviewed",
+        title="When the charge item definition was last reviewed by the publisher",
         description=(
             "The date on which the resource content was last reviewed. Review "
             "happens periodically after approval but does not change the original "
@@ -229,7 +242,23 @@ class ChargeItemDefinition(domainresource.DomainResource):
         None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
     )
 
-    partOf: typing.List[fhirtypes.Canonical] = Field(
+    name: fhirtypes.String = Field(
+        None,
+        alias="name",
+        title="Name for this charge item definition (computer friendly)",
+        description=(
+            "A natural language name identifying the ChargeItemDefinition. This "
+            "name should be usable as an identifier for the module by machine "
+            "processing applications such as code generation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_name", title="Extension field for ``name``."
+    )
+
+    partOf: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="partOf",
         title=(
@@ -262,10 +291,10 @@ class ChargeItemDefinition(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the charge "
-            "item definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the charge item definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -274,7 +303,22 @@ class ChargeItemDefinition(domainresource.DomainResource):
         None, alias="_publisher", title="Extension field for ``publisher``."
     )
 
-    replaces: typing.List[fhirtypes.Canonical] = Field(
+    purpose: fhirtypes.Markdown = Field(
+        None,
+        alias="purpose",
+        title="Why this charge item definition is defined",
+        description=(
+            "Explanation of why this charge item definition is needed and why it "
+            "has been designed as it has."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    purpose__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_purpose", title="Extension field for ``purpose``."
+    )
+
+    replaces: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="replaces",
         title=(
@@ -336,7 +380,7 @@ class ChargeItemDefinition(domainresource.DomainResource):
             "An absolute URI that is used to identify this charge item definition "
             "when it is referenced in a specification, model, design or an "
             "instance; also called its canonical identifier. This SHOULD be "
-            "globally unique and SHOULD be a literal address at which at which an "
+            "globally unique and SHOULD be a literal address at which an "
             "authoritative instance of this charge item definition is (or will be) "
             "published. This URL can be the target of a canonical reference. It "
             "SHALL remain the same when the charge item definition is stored on "
@@ -344,7 +388,6 @@ class ChargeItemDefinition(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
     )
     url__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_url", title="Extension field for ``url``."
@@ -390,6 +433,41 @@ class ChargeItemDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -408,6 +486,9 @@ class ChargeItemDefinition(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
+            "name",
             "title",
             "derivedFromUri",
             "partOf",
@@ -420,10 +501,11 @@ class ChargeItemDefinition(domainresource.DomainResource):
             "description",
             "useContext",
             "jurisdiction",
+            "purpose",
             "copyright",
+            "copyrightLabel",
             "approvalDate",
             "lastReviewDate",
-            "effectivePeriod",
             "code",
             "instance",
             "applicability",
@@ -441,7 +523,7 @@ class ChargeItemDefinition(domainresource.DomainResource):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("status", "status__ext"), ("url", "url__ext")]
+        required_fields = [("status", "status__ext")]
         _missing = object()
 
         def _fallback():
@@ -489,6 +571,46 @@ class ChargeItemDefinition(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2195(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class ChargeItemDefinitionApplicability(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -501,24 +623,9 @@ class ChargeItemDefinitionApplicability(backboneelement.BackboneElement):
 
     resource_type = Field("ChargeItemDefinitionApplicability", const=True)
 
-    description: fhirtypes.String = Field(
+    condition: fhirtypes.ExpressionType = Field(
         None,
-        alias="description",
-        title="Natural language description of the condition",
-        description=(
-            "A brief, natural language description of the condition that "
-            "effectively communicates the intended semantics."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_description", title="Extension field for ``description``."
-    )
-
-    expression: fhirtypes.String = Field(
-        None,
-        alias="expression",
+        alias="condition",
         title="Boolean-valued expression",
         description=(
             "An expression that returns true or false, indicating whether the "
@@ -529,24 +636,29 @@ class ChargeItemDefinitionApplicability(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
-    expression__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_expression", title="Extension field for ``expression``."
-    )
 
-    language: fhirtypes.String = Field(
+    effectivePeriod: fhirtypes.PeriodType = Field(
         None,
-        alias="language",
-        title="Language of the expression",
+        alias="effectivePeriod",
+        title="When the charge item definition is expected to be used",
         description=(
-            'The media type of the language for the expression, e.g. "text/cql" for'
-            ' Clinical Query Language expressions or "text/fhirpath" for FHIRPath '
-            "expressions."
+            "The period during which the charge item definition content was or is "
+            "planned to be in active use."
         ),
         # if property is element of this resource.
         element_property=True,
     )
-    language__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_language", title="Extension field for ``language``."
+
+    relatedArtifact: fhirtypes.RelatedArtifactType = Field(
+        None,
+        alias="relatedArtifact",
+        title=(
+            "Reference to / quotation of the external source of the group of "
+            "properties"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
     )
 
     @classmethod
@@ -559,9 +671,9 @@ class ChargeItemDefinitionApplicability(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "description",
-            "language",
-            "expression",
+            "condition",
+            "effectivePeriod",
+            "relatedArtifact",
         ]
 
 
@@ -590,9 +702,7 @@ class ChargeItemDefinitionPropertyGroup(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    priceComponent: typing.List[
-        fhirtypes.ChargeItemDefinitionPropertyGroupPriceComponentType
-    ] = Field(
+    priceComponent: typing.List[fhirtypes.MonetaryComponentType] = Field(
         None,
         alias="priceComponent",
         title="Components of total line item price",
@@ -622,154 +732,3 @@ class ChargeItemDefinitionPropertyGroup(backboneelement.BackboneElement):
             "applicability",
             "priceComponent",
         ]
-
-
-class ChargeItemDefinitionPropertyGroupPriceComponent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Components of total line item price.
-    The price for a ChargeItem may be calculated as a base price with
-    surcharges/deductions that apply in certain conditions. A
-    ChargeItemDefinition resource that defines the prices, factors and
-    conditions that apply to a billing code is currently under development. The
-    priceComponent element can be used to offer transparency to the recipient
-    of the Invoice of how the prices have been calculated.
-    """
-
-    resource_type = Field("ChargeItemDefinitionPropertyGroupPriceComponent", const=True)
-
-    amount: fhirtypes.MoneyType = Field(
-        None,
-        alias="amount",
-        title="Monetary amount associated with this component",
-        description="The amount calculated for this component.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    code: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="code",
-        title="Code identifying the specific component",
-        description=(
-            "A code that identifies the component. Codes may be used to "
-            "differentiate between kinds of taxes, surcharges, discounts etc."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    factor: fhirtypes.Decimal = Field(
-        None,
-        alias="factor",
-        title="Factor used for calculating this component",
-        description=(
-            "The factor that has been applied on the base price for calculating "
-            "this component."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    factor__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_factor", title="Extension field for ``factor``."
-    )
-
-    type: fhirtypes.Code = Field(
-        None,
-        alias="type",
-        title="base | surcharge | deduction | discount | tax | informational",
-        description="This code identifies the type of the component.",
-        # if property is element of this resource.
-        element_property=True,
-        element_required=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "base",
-            "surcharge",
-            "deduction",
-            "discount",
-            "tax",
-            "informational",
-        ],
-    )
-    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_type", title="Extension field for ``type``."
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``ChargeItemDefinitionPropertyGroupPriceComponent`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "type",
-            "code",
-            "factor",
-            "amount",
-        ]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_5041(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("type", "type__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
