@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ClinicalImpression
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -33,22 +33,18 @@ class ClinicalImpression(domainresource.DomainResource):
 
     resource_type = Field("ClinicalImpression", const=True)
 
-    assessor: fhirtypes.ReferenceType = Field(
+    changePattern: fhirtypes.CodeableConceptType = Field(
         None,
-        alias="assessor",
-        title="The clinician performing the assessment",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole"],
-    )
-
-    code: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="code",
-        title="Kind of assessment performed",
-        description="Categorizes the type of clinical assessment performed.",
+        alias="changePattern",
+        title=(
+            "Change in the status/pattern of a subject's condition since previously"
+            " assessed, such as worsening, improving, or no change"
+        ),
+        description=(
+            "Change in the status/pattern of a subject's condition since previously"
+            " assessed, such as worsening, improving, or no change.  It is a "
+            "subjective assessment of the direction of the change."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -112,7 +108,7 @@ class ClinicalImpression(domainresource.DomainResource):
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
-        title="Encounter created as part of",
+        title="The Encounter during which this ClinicalImpression was created",
         description=(
             "The Encounter during which this ClinicalImpression was created or to "
             "which the creation of this record is tightly associated."
@@ -148,21 +144,6 @@ class ClinicalImpression(domainresource.DomainResource):
         element_property=True,
     )
 
-    investigation: typing.List[fhirtypes.ClinicalImpressionInvestigationType] = Field(
-        None,
-        alias="investigation",
-        title="One or more sets of investigations (signs, symptoms, etc.)",
-        description=(
-            "One or more sets of investigations (signs, symptoms, etc.). The actual"
-            " grouping of investigations varies greatly depending on the type and "
-            "context of the assessment. These investigations may include data "
-            "generated during the assessment process, or data previously generated "
-            "and recorded that is pertinent to the outcomes."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     note: typing.List[fhirtypes.AnnotationType] = Field(
         None,
         alias="note",
@@ -176,6 +157,17 @@ class ClinicalImpression(domainresource.DomainResource):
         element_property=True,
     )
 
+    performer: fhirtypes.ReferenceType = Field(
+        None,
+        alias="performer",
+        title="The clinician performing the assessment",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Practitioner", "PractitionerRole"],
+    )
+
     previous: fhirtypes.ReferenceType = Field(
         None,
         alias="previous",
@@ -242,14 +234,26 @@ class ClinicalImpression(domainresource.DomainResource):
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title="in-progress | completed | entered-in-error",
+        title=(
+            "preparation | in-progress | not-done | on-hold | stopped | completed |"
+            " entered-in-error | unknown"
+        ),
         description="Identifies the workflow status of the assessment.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["in-progress", "completed", "entered-in-error"],
+        enum_values=[
+            "preparation",
+            "in-progress",
+            "not-done",
+            "on-hold",
+            "stopped",
+            "completed",
+            "entered-in-error",
+            "unknown",
+        ],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
@@ -291,7 +295,10 @@ class ClinicalImpression(domainresource.DomainResource):
         None,
         alias="supportingInfo",
         title="Information supporting the clinical impression",
-        description=None,
+        description=(
+            "Information supporting the clinical impression, which can contain "
+            "investigation results."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -316,17 +323,16 @@ class ClinicalImpression(domainresource.DomainResource):
             "identifier",
             "status",
             "statusReason",
-            "code",
             "description",
             "subject",
             "encounter",
             "effectiveDateTime",
             "effectivePeriod",
             "date",
-            "assessor",
+            "performer",
             "previous",
             "problem",
-            "investigation",
+            "changePattern",
             "protocol",
             "summary",
             "finding",
@@ -458,30 +464,18 @@ class ClinicalImpressionFinding(backboneelement.BackboneElement):
         None, alias="_basis", title="Extension field for ``basis``."
     )
 
-    itemCodeableConcept: fhirtypes.CodeableConceptType = Field(
+    item: fhirtypes.CodeableReferenceType = Field(
         None,
-        alias="itemCodeableConcept",
+        alias="item",
         title="What was found",
         description=(
-            "Specific text or code for finding or diagnosis, which may include "
-            "ruled-out or resolved conditions."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    itemReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="itemReference",
-        title="What was found",
-        description=(
-            "Specific reference for finding or diagnosis, which may include ruled-"
-            "out or resolved conditions."
+            "Specific text, code or reference for finding or diagnosis, which may "
+            "include ruled-out or resolved conditions."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Condition", "Observation", "Media"],
+        enum_reference_types=["Condition", "Observation", "DocumentReference"],
     )
 
     @classmethod
@@ -490,68 +484,4 @@ class ClinicalImpressionFinding(backboneelement.BackboneElement):
         ``ClinicalImpressionFinding`` according specification,
         with preserving original sequence order.
         """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "itemCodeableConcept",
-            "itemReference",
-            "basis",
-        ]
-
-
-class ClinicalImpressionInvestigation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    One or more sets of investigations (signs, symptoms, etc.).
-    One or more sets of investigations (signs, symptoms, etc.). The actual
-    grouping of investigations varies greatly depending on the type and context
-    of the assessment. These investigations may include data generated during
-    the assessment process, or data previously generated and recorded that is
-    pertinent to the outcomes.
-    """
-
-    resource_type = Field("ClinicalImpressionInvestigation", const=True)
-
-    code: fhirtypes.CodeableConceptType = Field(
-        ...,
-        alias="code",
-        title="A name/code for the set",
-        description=(
-            'A name/code for the group ("set") of investigations. Typically, this '
-            'will be something like "signs", "symptoms", "clinical", "diagnostic", '
-            "but the list is not constrained, and others such groups such as "
-            "(exposure|family|travel|nutritional) history may be used."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    item: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="item",
-        title="Record of a specific investigation",
-        description="A record of a specific investigation that was undertaken.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Observation",
-            "QuestionnaireResponse",
-            "FamilyMemberHistory",
-            "DiagnosticReport",
-            "RiskAssessment",
-            "ImagingStudy",
-            "Media",
-        ],
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``ClinicalImpressionInvestigation`` according specification,
-        with preserving original sequence order.
-        """
-        return ["id", "extension", "modifierExtension", "code", "item"]
+        return ["id", "extension", "modifierExtension", "item", "basis"]
