@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ClinicalUseDefinition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -78,6 +78,20 @@ class ClinicalUseDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
+    library: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
+        None,
+        alias="library",
+        title="Logic used by the clinical use definition",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Library"],
+    )
+    library__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_library", title="Extension field for ``library``.")
+
     population: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="population",
@@ -101,7 +115,10 @@ class ClinicalUseDefinition(domainresource.DomainResource):
     subject: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="subject",
-        title="The medication or procedure for which this is an indication",
+        title=(
+            "The medication, product, substance, device, procedure etc. for which "
+            "this is an indication"
+        ),
         description=None,
         # if property is element of this resource.
         element_property=True,
@@ -114,6 +131,8 @@ class ClinicalUseDefinition(domainresource.DomainResource):
             "Device",
             "DeviceDefinition",
             "Substance",
+            "NutritionProduct",
+            "BiologicallyDerivedProduct",
         ],
     )
 
@@ -195,6 +214,7 @@ class ClinicalUseDefinition(domainresource.DomainResource):
             "indication",
             "interaction",
             "population",
+            "library",
             "undesirableEffect",
             "warning",
         ]
@@ -269,6 +289,19 @@ class ClinicalUseDefinitionContraindication(backboneelement.BackboneElement):
 
     resource_type = Field("ClinicalUseDefinitionContraindication", const=True)
 
+    applicability: fhirtypes.ExpressionType = Field(
+        None,
+        alias="applicability",
+        title=(
+            "An expression that returns true or false, indicating whether the "
+            "indication is applicable or not, after having applied its other "
+            "elements"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     comorbidity: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="comorbidity",
@@ -350,6 +383,7 @@ class ClinicalUseDefinitionContraindication(backboneelement.BackboneElement):
             "diseaseStatus",
             "comorbidity",
             "indication",
+            "applicability",
             "otherTherapy",
         ]
 
@@ -386,17 +420,17 @@ class ClinicalUseDefinitionContraindicationOtherTherapy(
         element_property=True,
     )
 
-    therapy: fhirtypes.CodeableReferenceType = Field(
+    treatment: fhirtypes.CodeableReferenceType = Field(
         ...,
-        alias="therapy",
+        alias="treatment",
         title=(
-            "Reference to a specific medication as part of an indication or "
-            "contraindication"
+            "Reference to a specific medication, substance etc. as part of an "
+            "indication or contraindication"
         ),
         description=(
             "Reference to a specific medication (active substance, medicinal "
-            "product or class of products) as part of an indication or "
-            "contraindication."
+            "product or class of products, biological, food etc.) as part of an "
+            "indication or contraindication."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -406,6 +440,8 @@ class ClinicalUseDefinitionContraindicationOtherTherapy(
             "Medication",
             "Substance",
             "SubstanceDefinition",
+            "NutritionProduct",
+            "BiologicallyDerivedProduct",
             "ActivityDefinition",
         ],
     )
@@ -416,7 +452,7 @@ class ClinicalUseDefinitionContraindicationOtherTherapy(
         ``ClinicalUseDefinitionContraindicationOtherTherapy`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "relationshipType", "therapy"]
+        return ["id", "extension", "modifierExtension", "relationshipType", "treatment"]
 
 
 class ClinicalUseDefinitionIndication(backboneelement.BackboneElement):
@@ -429,6 +465,19 @@ class ClinicalUseDefinitionIndication(backboneelement.BackboneElement):
 
     resource_type = Field("ClinicalUseDefinitionIndication", const=True)
 
+    applicability: fhirtypes.ExpressionType = Field(
+        None,
+        alias="applicability",
+        title=(
+            "An expression that returns true or false, indicating whether the "
+            "indication is applicable or not, after having applied its other "
+            "elements"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     comorbidity: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="comorbidity",
@@ -567,6 +616,7 @@ class ClinicalUseDefinitionIndication(backboneelement.BackboneElement):
             "durationRange",
             "durationString",
             "undesirableEffect",
+            "applicability",
             "otherTherapy",
         ]
 
@@ -648,10 +698,13 @@ class ClinicalUseDefinitionInteraction(backboneelement.BackboneElement):
         None,
         alias="interactant",
         title=(
-            "The specific medication, food, substance or laboratory test that "
+            "The specific medication, product, food etc. or laboratory test that "
             "interacts"
         ),
-        description=None,
+        description=(
+            "The specific medication, product, food, substance etc. or laboratory "
+            "test that interacts."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -703,7 +756,10 @@ class ClinicalUseDefinitionInteractionInteractant(backboneelement.BackboneElemen
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    The specific medication, food, substance or laboratory test that interacts.
+    The specific medication, product, food etc. or laboratory test that
+    interacts.
+    The specific medication, product, food, substance etc. or laboratory test
+    that interacts.
     """
 
     resource_type = Field("ClinicalUseDefinitionInteractionInteractant", const=True)
@@ -711,8 +767,14 @@ class ClinicalUseDefinitionInteractionInteractant(backboneelement.BackboneElemen
     itemCodeableConcept: fhirtypes.CodeableConceptType = Field(
         None,
         alias="itemCodeableConcept",
-        title="The specific medication, food or laboratory test that interacts",
-        description=None,
+        title=(
+            "The specific medication, product, food etc. or laboratory test that "
+            "interacts"
+        ),
+        description=(
+            "The specific medication, product, food, substance etc. or laboratory "
+            "test that interacts."
+        ),
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e item[x]
@@ -723,8 +785,14 @@ class ClinicalUseDefinitionInteractionInteractant(backboneelement.BackboneElemen
     itemReference: fhirtypes.ReferenceType = Field(
         None,
         alias="itemReference",
-        title="The specific medication, food or laboratory test that interacts",
-        description=None,
+        title=(
+            "The specific medication, product, food etc. or laboratory test that "
+            "interacts"
+        ),
+        description=(
+            "The specific medication, product, food, substance etc. or laboratory "
+            "test that interacts."
+        ),
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e item[x]
@@ -735,6 +803,8 @@ class ClinicalUseDefinitionInteractionInteractant(backboneelement.BackboneElemen
             "MedicinalProductDefinition",
             "Medication",
             "Substance",
+            "NutritionProduct",
+            "BiologicallyDerivedProduct",
             "ObservationDefinition",
         ],
     )
