@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/CodeSystem
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class CodeSystem(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -29,6 +29,34 @@ class CodeSystem(domainresource.DomainResource):
 
     resource_type = Field("CodeSystem", const=True)
 
+    approvalDate: fhirtypes.Date = Field(
+        None,
+        alias="approvalDate",
+        title="When the CodeSystem was approved by publisher",
+        description=(
+            "The date on which the resource content was approved by the publisher. "
+            "Approval happens once when the content is officially approved for "
+            "usage."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    approvalDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_approvalDate", title="Extension field for ``approvalDate``."
+    )
+
+    author: typing.List[fhirtypes.ContactDetailType] = Field(
+        None,
+        alias="author",
+        title="Who authored the CodeSystem",
+        description=(
+            "An individiual or organization primarily involved in the creation and "
+            "maintenance of the CodeSystem."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     caseSensitive: bool = Field(
         None,
         alias="caseSensitive",
@@ -116,6 +144,23 @@ class CodeSystem(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     count: fhirtypes.UnsignedInt = Field(
         None,
         alias="count",
@@ -137,10 +182,11 @@ class CodeSystem(domainresource.DomainResource):
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the code system was published. "
-            "The date must change when the business version changes and it must "
-            "change if the status code changes. In addition, it should change when "
-            "the substantive content of the code system changes."
+            "The date  (and optionally time) when the code system was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the code system "
+            "changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -164,6 +210,43 @@ class CodeSystem(domainresource.DomainResource):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    editor: typing.List[fhirtypes.ContactDetailType] = Field(
+        None,
+        alias="editor",
+        title="Who edited the CodeSystem",
+        description=(
+            "An individual or organization primarily responsible for internal "
+            "coherence of the CodeSystem."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    effectivePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="effectivePeriod",
+        title="When the CodeSystem is expected to be used",
+        description=(
+            "The period during which the CodeSystem content was or is planned to be"
+            " in active use."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    endorser: typing.List[fhirtypes.ContactDetailType] = Field(
+        None,
+        alias="endorser",
+        title="Who endorsed the CodeSystem",
+        description=(
+            "An individual or organization asserted by the publisher to be "
+            "responsible for officially endorsing the CodeSystem for use in some "
+            "setting."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     experimental: bool = Field(
         None,
         alias="experimental",
@@ -237,6 +320,22 @@ class CodeSystem(domainresource.DomainResource):
         element_property=True,
     )
 
+    lastReviewDate: fhirtypes.Date = Field(
+        None,
+        alias="lastReviewDate",
+        title="When the CodeSystem was last reviewed by the publisher",
+        description=(
+            "The date on which the resource content was last reviewed. Review "
+            "happens periodically after approval but does not change the original "
+            "approval date."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    lastReviewDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
+    )
+
     name: fhirtypes.String = Field(
         None,
         alias="name",
@@ -268,10 +367,10 @@ class CodeSystem(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the code "
-            "system."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the code system."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -295,13 +394,38 @@ class CodeSystem(domainresource.DomainResource):
         None, alias="_purpose", title="Extension field for ``purpose``."
     )
 
+    relatedArtifact: typing.List[fhirtypes.RelatedArtifactType] = Field(
+        None,
+        alias="relatedArtifact",
+        title="Additional documentation, citations, etc",
+        description=(
+            "Related artifacts such as additional documentation, justification, "
+            "dependencies, bibliographic references, and predecessor and successor "
+            "artifacts."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    reviewer: typing.List[fhirtypes.ContactDetailType] = Field(
+        None,
+        alias="reviewer",
+        title="Who reviewed the CodeSystem",
+        description=(
+            "An individual or organization asserted by the publisher to be "
+            "primarily responsible for review of some aspect of the CodeSystem."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
         title="draft | active | retired | unknown",
         description=(
-            "The date (and optionally time) when the code system resource was "
-            "created or revised."
+            "The status of this code system. Enables tracking the life-cycle of the"
+            " content."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -343,6 +467,19 @@ class CodeSystem(domainresource.DomainResource):
         None, alias="_title", title="Extension field for ``title``."
     )
 
+    topic: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="topic",
+        title="E.g. Education, Treatment, Assessment, etc",
+        description=(
+            "Descriptions related to the content of the CodeSystem. Topics provide "
+            "a high-level categorization as well as keywords for the CodeSystem "
+            "that can be useful for filtering and searching."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     url: fhirtypes.Uri = Field(
         None,
         alias="url",
@@ -354,10 +491,10 @@ class CodeSystem(domainresource.DomainResource):
             "An absolute URI that is used to identify this code system when it is "
             "referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this code system is (or will be) published. This URL can "
-            "be the target of a canonical reference. It SHALL remain the same when "
-            "the code system is stored on different servers. This is used in "
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " code system is (or will be) published. This URL can be the target of "
+            "a canonical reference. It SHALL remain the same when the code system "
+            "is stored on different servers. This is used in "
             "[Coding](datatypes.html#Coding).system."
         ),
         # if property is element of this resource.
@@ -387,8 +524,8 @@ class CodeSystem(domainresource.DomainResource):
         alias="valueSet",
         title="Canonical reference to the value set with entire code system",
         description=(
-            "Canonical reference to the value set that contains the entire code "
-            "system."
+            "Canonical reference to the value set that contains all codes in the "
+            "code system independent of code status."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -420,6 +557,41 @@ class CodeSystem(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which "
+            "CodeSystem is more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which "
+            "CodeSystem is more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     versionNeeded: bool = Field(
         None,
         alias="versionNeeded",
@@ -436,6 +608,61 @@ class CodeSystem(domainresource.DomainResource):
         None, alias="_versionNeeded", title="Extension field for ``versionNeeded``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CodeSystem`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
+            "name",
+            "title",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "copyright",
+            "copyrightLabel",
+            "approvalDate",
+            "lastReviewDate",
+            "effectivePeriod",
+            "topic",
+            "author",
+            "editor",
+            "reviewer",
+            "endorser",
+            "relatedArtifact",
+            "caseSensitive",
+            "valueSet",
+            "hierarchyMeaning",
+            "compositional",
+            "versionNeeded",
+            "content",
+            "supplements",
+            "count",
+            "filter",
+            "property",
+            "concept",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1200(
         cls, values: typing.Dict[str, typing.Any]
@@ -495,9 +722,49 @@ class CodeSystem(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_1200(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class CodeSystemConcept(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -591,6 +858,24 @@ class CodeSystemConcept(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CodeSystemConcept`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "display",
+            "definition",
+            "designation",
+            "property",
+            "concept",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1923(
         cls, values: typing.Dict[str, typing.Any]
@@ -652,7 +937,7 @@ class CodeSystemConcept(backboneelement.BackboneElement):
 
 
 class CodeSystemConceptDesignation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -663,6 +948,18 @@ class CodeSystemConceptDesignation(backboneelement.BackboneElement):
 
     resource_type = Field("CodeSystemConceptDesignation", const=True)
 
+    additionalUse: typing.List[fhirtypes.CodingType] = Field(
+        None,
+        alias="additionalUse",
+        title="Additional ways how this designation would be used",
+        description=(
+            "Additional codes that detail how this designation would be used, if "
+            "there is more than one use."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     language: fhirtypes.Code = Field(
         None,
         alias="language",
@@ -697,6 +994,22 @@ class CodeSystemConceptDesignation(backboneelement.BackboneElement):
         None, alias="_value", title="Extension field for ``value``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CodeSystemConceptDesignation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "language",
+            "use",
+            "additionalUse",
+            "value",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3058(
         cls, values: typing.Dict[str, typing.Any]
@@ -758,7 +1071,7 @@ class CodeSystemConceptDesignation(backboneelement.BackboneElement):
 
 
 class CodeSystemConceptProperty(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -883,6 +1196,26 @@ class CodeSystemConceptProperty(backboneelement.BackboneElement):
         None, alias="_valueString", title="Extension field for ``valueString``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CodeSystemConceptProperty`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "valueCode",
+            "valueCoding",
+            "valueString",
+            "valueInteger",
+            "valueBoolean",
+            "valueDateTime",
+            "valueDecimal",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2797(
         cls, values: typing.Dict[str, typing.Any]
@@ -992,7 +1325,7 @@ class CodeSystemConceptProperty(backboneelement.BackboneElement):
 
 
 class CodeSystemFilter(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1031,12 +1364,12 @@ class CodeSystemFilter(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
-    operator: typing.List[fhirtypes.Code] = Field(
+    operator: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="operator",
         title=(
             "= | is-a | descendent-of | is-not-a | regex | in | not-in | "
-            "generalizes | exists"
+            "generalizes | child-of | descendent-leaf | exists"
         ),
         description="A list of operators that can be used with the filter.",
         # if property is element of this resource.
@@ -1053,6 +1386,8 @@ class CodeSystemFilter(backboneelement.BackboneElement):
             "in",
             "not-in",
             "generalizes",
+            "child-of",
+            "descendent-leaf",
             "exists",
         ],
     )
@@ -1073,6 +1408,22 @@ class CodeSystemFilter(backboneelement.BackboneElement):
         None, alias="_value", title="Extension field for ``value``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CodeSystemFilter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "description",
+            "operator",
+            "value",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1819(
         cls, values: typing.Dict[str, typing.Any]
@@ -1138,7 +1489,7 @@ class CodeSystemFilter(backboneelement.BackboneElement):
 
 
 class CodeSystemProperty(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1228,6 +1579,22 @@ class CodeSystemProperty(backboneelement.BackboneElement):
         None, alias="_uri", title="Extension field for ``uri``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CodeSystemProperty`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "uri",
+            "description",
+            "type",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2081(
         cls, values: typing.Dict[str, typing.Any]
