@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Communication
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,14 +16,16 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Communication(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    A record of information transmitted from a sender to a receiver.
-    An occurrence of information being transmitted; e.g. an alert that was sent
-    to a responsible provider, a public health agency that was notified about a
-    reportable condition.
+    A clinical or business level record of information being transmitted or
+    shared.
+    A clinical or business level record of information being transmitted or
+    shared; e.g. an alert that was sent to a responsible provider, a public
+    health agency communication to a provider/reporter in response to a case
+    report for a reportable condition.
     """
 
     resource_type = Field("Communication", const=True)
@@ -71,7 +73,7 @@ class Communication(domainresource.DomainResource):
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
-        title="Encounter created as part of",
+        title="The Encounter during which this Communication was created",
         description=(
             "The Encounter during which this Communication was created or to which "
             "the creation of this record is tightly associated."
@@ -106,7 +108,7 @@ class Communication(domainresource.DomainResource):
         enum_reference_types=["Communication"],
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -134,7 +136,7 @@ class Communication(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
@@ -176,8 +178,11 @@ class Communication(domainresource.DomainResource):
     partOf: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="partOf",
-        title="Part of this action",
-        description=None,
+        title="Part of referenced event (e.g. Communication, Procedure)",
+        description=(
+            "A larger event (e.g. Communication, Procedure) of which this "
+            "particular communication is a component or step."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -214,32 +219,15 @@ class Communication(domainresource.DomainResource):
         None, alias="_priority", title="Extension field for ``priority``."
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Indication for message",
         description="The reason or justification for the communication.",
         # if property is element of this resource.
         element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Why was communication done?",
-        description=(
-            "Indicates another resource whose existence justifies this "
-            "communication."
-        ),
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Condition",
-            "Observation",
-            "DiagnosticReport",
-            "DocumentReference",
-        ],
+        enum_reference_types=["Resource"],
     )
 
     received: fhirtypes.DateTime = Field(
@@ -257,39 +245,36 @@ class Communication(domainresource.DomainResource):
     recipient: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="recipient",
-        title="Message recipient",
+        title="Who the information is shared with",
         description=(
             "The entity (e.g. person, organization, clinical information system, "
-            "care team or device) which was the target of the communication. If "
-            "receipts need to be tracked by an individual, a separate resource "
-            "instance will need to be created for each recipient.  Multiple "
-            "recipient communications are intended where either receipts are not "
-            "tracked (e.g. a mass mail-out) or a receipt is captured in aggregate "
-            "(all emails confirmed received by a particular time)."
+            "care team or device) which is the target of the communication."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
+            "CareTeam",
             "Device",
+            "Group",
+            "HealthcareService",
+            "Location",
             "Organization",
             "Patient",
             "Practitioner",
             "PractitionerRole",
             "RelatedPerson",
-            "Group",
-            "CareTeam",
-            "HealthcareService",
+            "Endpoint",
         ],
     )
 
     sender: fhirtypes.ReferenceType = Field(
         None,
         alias="sender",
-        title="Message sender",
+        title="Who shares the information",
         description=(
             "The entity (e.g. person, organization, clinical information system, or"
-            " device) which was the source of the communication."
+            " device) which is the source of the communication."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -302,6 +287,8 @@ class Communication(domainresource.DomainResource):
             "PractitionerRole",
             "RelatedPerson",
             "HealthcareService",
+            "Endpoint",
+            "CareTeam",
         ],
     )
 
@@ -377,6 +364,45 @@ class Communication(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Communication`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "instantiatesCanonical",
+            "instantiatesUri",
+            "basedOn",
+            "partOf",
+            "inResponseTo",
+            "status",
+            "statusReason",
+            "category",
+            "priority",
+            "medium",
+            "subject",
+            "topic",
+            "about",
+            "encounter",
+            "sent",
+            "received",
+            "recipient",
+            "sender",
+            "reason",
+            "payload",
+            "note",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1543(
         cls, values: typing.Dict[str, typing.Any]
@@ -438,7 +464,7 @@ class Communication(domainresource.DomainResource):
 
 
 class CommunicationPayload(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -463,6 +489,21 @@ class CommunicationPayload(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    contentCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="contentCodeableConcept",
+        title="Message part content",
+        description=(
+            "A communicated content (or for multi-part communications, one portion "
+            "of the communication)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e content[x]
+        one_of_many="content",
+        one_of_many_required=True,
+    )
+
     contentReference: fhirtypes.ReferenceType = Field(
         None,
         alias="contentReference",
@@ -480,23 +521,20 @@ class CommunicationPayload(backboneelement.BackboneElement):
         enum_reference_types=["Resource"],
     )
 
-    contentString: fhirtypes.String = Field(
-        None,
-        alias="contentString",
-        title="Message part content",
-        description=(
-            "A communicated content (or for multi-part communications, one portion "
-            "of the communication)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e content[x]
-        one_of_many="content",
-        one_of_many_required=True,
-    )
-    contentString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_contentString", title="Extension field for ``contentString``."
-    )
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CommunicationPayload`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "contentAttachment",
+            "contentReference",
+            "contentCodeableConcept",
+        ]
 
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2247(
@@ -515,7 +553,11 @@ class CommunicationPayload(backboneelement.BackboneElement):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "content": ["contentAttachment", "contentReference", "contentString"]
+            "content": [
+                "contentAttachment",
+                "contentCodeableConcept",
+                "contentReference",
+            ]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
