@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/CommunicationRequest
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -101,7 +101,7 @@ class CommunicationRequest(domainresource.DomainResource):
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
-        title="Encounter created as part of",
+        title="The Encounter during which this CommunicationRequest was created",
         description=(
             "The Encounter during which this CommunicationRequest was created or to"
             " which the creation of this record is tightly associated."
@@ -117,9 +117,13 @@ class CommunicationRequest(domainresource.DomainResource):
         alias="groupIdentifier",
         title="Composite request this is part of",
         description=(
-            "A shared identifier common to all requests that were authorized more "
-            "or less simultaneously by a single author, representing the identifier"
-            " of the requisition, prescription or similar form."
+            "A shared identifier common to multiple independent Request instances "
+            "that were activated/authorized more or less simultaneously by a single"
+            " author.  The presence of the same identifier on each request ties "
+            "those requests together and may have business ramifications in terms "
+            "of reporting of results, billing, etc.  E.g. a requisition number "
+            "shared by a set of lab tests ordered together, or a prescription "
+            "number shared by all meds ordered at one time."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -138,6 +142,62 @@ class CommunicationRequest(domainresource.DomainResource):
         element_property=True,
     )
 
+    informationProvider: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="informationProvider",
+        title="Who should share the information",
+        description=(
+            "The entity (e.g. person, organization, clinical information system, or"
+            " device) which is to be the source of the communication."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Device",
+            "Organization",
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "HealthcareService",
+            "Endpoint",
+        ],
+    )
+
+    intent: fhirtypes.Code = Field(
+        None,
+        alias="intent",
+        title=(
+            "proposal | plan | directive | order | original-order | reflex-order | "
+            "filler-order | instance-order | option"
+        ),
+        description=(
+            "Indicates the level of authority/intentionality associated with the "
+            "CommunicationRequest and where the request fits into the workflow "
+            "chain."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=[
+            "proposal",
+            "plan",
+            "directive",
+            "order",
+            "original-order",
+            "reflex-order",
+            "filler-order",
+            "instance-order",
+            "option",
+        ],
+    )
+    intent__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_intent", title="Extension field for ``intent``."
+    )
+
     medium: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="medium",
@@ -218,35 +278,21 @@ class CommunicationRequest(domainresource.DomainResource):
         None, alias="_priority", title="Extension field for ``priority``."
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Why is communication needed?",
         description="Describes why the request is being made in coded or textual form.",
         # if property is element of this resource.
         element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Why is communication needed?",
-        description="Indicates another resource whose existence justifies this request.",
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Condition",
-            "Observation",
-            "DiagnosticReport",
-            "DocumentReference",
-        ],
+        enum_reference_types=["Resource"],
     )
 
     recipient: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="recipient",
-        title="Message recipient",
+        title="Who to share the information with",
         description=(
             "The entity (e.g. person, organization, clinical information system, "
             "device, group, or care team) which is the intended target of the "
@@ -265,6 +311,7 @@ class CommunicationRequest(domainresource.DomainResource):
             "Group",
             "CareTeam",
             "HealthcareService",
+            "Endpoint",
         ],
     )
 
@@ -285,10 +332,10 @@ class CommunicationRequest(domainresource.DomainResource):
     requester: fhirtypes.ReferenceType = Field(
         None,
         alias="requester",
-        title="Who/what is requesting service",
+        title="Who asks for the information to be shared",
         description=(
-            "The device, individual, or organization who initiated the request and "
-            "has responsibility for its activation."
+            "The device, individual, or organization who asks for the information "
+            "to be shared."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -303,28 +350,6 @@ class CommunicationRequest(domainresource.DomainResource):
         ],
     )
 
-    sender: fhirtypes.ReferenceType = Field(
-        None,
-        alias="sender",
-        title="Message sender",
-        description=(
-            "The entity (e.g. person, organization, clinical information system, or"
-            " device) which is to be the source of the communication."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Device",
-            "Organization",
-            "Patient",
-            "Practitioner",
-            "PractitionerRole",
-            "RelatedPerson",
-            "HealthcareService",
-        ],
-    )
-
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -393,6 +418,7 @@ class CommunicationRequest(domainresource.DomainResource):
             "groupIdentifier",
             "status",
             "statusReason",
+            "intent",
             "category",
             "priority",
             "doNotPerform",
@@ -406,9 +432,8 @@ class CommunicationRequest(domainresource.DomainResource):
             "authoredOn",
             "requester",
             "recipient",
-            "sender",
-            "reasonCode",
-            "reasonReference",
+            "informationProvider",
+            "reason",
             "note",
         ]
 
@@ -423,7 +448,7 @@ class CommunicationRequest(domainresource.DomainResource):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("status", "status__ext")]
+        required_fields = [("intent", "intent__ext"), ("status", "status__ext")]
         _missing = object()
 
         def _fallback():
@@ -536,6 +561,21 @@ class CommunicationRequestPayload(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    contentCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="contentCodeableConcept",
+        title="Message part content",
+        description=(
+            "The communicated content (or for multi-part communications, one "
+            "portion of the communication)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e content[x]
+        one_of_many="content",
+        one_of_many_required=True,
+    )
+
     contentReference: fhirtypes.ReferenceType = Field(
         None,
         alias="contentReference",
@@ -553,24 +593,6 @@ class CommunicationRequestPayload(backboneelement.BackboneElement):
         enum_reference_types=["Resource"],
     )
 
-    contentString: fhirtypes.String = Field(
-        None,
-        alias="contentString",
-        title="Message part content",
-        description=(
-            "The communicated content (or for multi-part communications, one "
-            "portion of the communication)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e content[x]
-        one_of_many="content",
-        one_of_many_required=True,
-    )
-    contentString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_contentString", title="Extension field for ``contentString``."
-    )
-
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -581,9 +603,9 @@ class CommunicationRequestPayload(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "contentString",
             "contentAttachment",
             "contentReference",
+            "contentCodeableConcept",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
@@ -603,7 +625,11 @@ class CommunicationRequestPayload(backboneelement.BackboneElement):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "content": ["contentAttachment", "contentReference", "contentString"]
+            "content": [
+                "contentAttachment",
+                "contentCodeableConcept",
+                "contentReference",
+            ]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
