@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/CompartmentDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class CompartmentDefinition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -30,14 +30,24 @@ class CompartmentDefinition(domainresource.DomainResource):
     code: fhirtypes.Code = Field(
         None,
         alias="code",
-        title="Patient | Encounter | RelatedPerson | Practitioner | Device",
+        title=(
+            "Patient | Encounter | RelatedPerson | Practitioner | Device | "
+            "EpisodeOfCare"
+        ),
         description="Which compartment this definition describes.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["Patient", "Encounter", "RelatedPerson", "Practitioner", "Device"],
+        enum_values=[
+            "Patient",
+            "Encounter",
+            "RelatedPerson",
+            "Practitioner",
+            "Device",
+            "EpisodeOfCare",
+        ],
     )
     code__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_code", title="Extension field for ``code``."
@@ -61,10 +71,10 @@ class CompartmentDefinition(domainresource.DomainResource):
         title="Date last changed",
         description=(
             "The date  (and optionally time) when the compartment definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the compartment definition "
-            "changes."
+            "last significantly changed. The date must change when the business "
+            "version changes and it must change if the status code changes. In "
+            "addition, it should change when the substantive content of the "
+            "compartment definition changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -124,10 +134,10 @@ class CompartmentDefinition(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the "
-            "compartment definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the compartment definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -192,6 +202,20 @@ class CompartmentDefinition(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    title: fhirtypes.String = Field(
+        None,
+        alias="title",
+        title="Name for this compartment definition (human friendly)",
+        description=(
+            "A short, descriptive, user-friendly title for the capability " "statement."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    title__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_title", title="Extension field for ``title``."
+    )
+
     url: fhirtypes.Uri = Field(
         None,
         alias="url",
@@ -203,7 +227,7 @@ class CompartmentDefinition(domainresource.DomainResource):
             "An absolute URI that is used to identify this compartment definition "
             "when it is referenced in a specification, model, design or an "
             "instance; also called its canonical identifier. This SHOULD be "
-            "globally unique and SHOULD be a literal address at which at which an "
+            "globally unique and SHOULD be a literal address at which an "
             "authoritative instance of this compartment definition is (or will be) "
             "published. This URL can be the target of a canonical reference. It "
             "SHALL remain the same when the compartment definition is stored on "
@@ -253,6 +277,75 @@ class CompartmentDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CompartmentDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
+            "name",
+            "title",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "purpose",
+            "code",
+            "search",
+            "resource",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2372(
         cls, values: typing.Dict[str, typing.Any]
@@ -318,9 +411,49 @@ class CompartmentDefinition(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2372(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class CompartmentDefinitionResource(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -355,7 +488,22 @@ class CompartmentDefinitionResource(backboneelement.BackboneElement):
         None, alias="_documentation", title="Extension field for ``documentation``."
     )
 
-    param: typing.List[fhirtypes.String] = Field(
+    endParam: fhirtypes.Uri = Field(
+        None,
+        alias="endParam",
+        title="Search Param for interpreting $everything.end",
+        description=(
+            "Search Parameter for mapping requests made with $everything.end (e.g. "
+            "on [Patient.$everything](patient-operation-everything.html))."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    endParam__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_endParam", title="Extension field for ``endParam``."
+    )
+
+    param: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="param",
         title="Search Parameter Name, or chained parameters",
@@ -371,6 +519,38 @@ class CompartmentDefinitionResource(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_param", title="Extension field for ``param``.")
 
+    startParam: fhirtypes.Uri = Field(
+        None,
+        alias="startParam",
+        title="Search Param for interpreting $everything.start",
+        description=(
+            "Search Parameter for mapping requests made with $everything.start "
+            "(e.g. on [Patient.$everything](patient-operation-everything.html))."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    startParam__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_startParam", title="Extension field for ``startParam``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CompartmentDefinitionResource`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "param",
+            "documentation",
+            "startParam",
+            "endParam",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3203(
         cls, values: typing.Dict[str, typing.Any]
