@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Composition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -81,18 +81,6 @@ class Composition(domainresource.DomainResource):
         element_property=True,
     )
 
-    confidentiality: fhirtypes.Code = Field(
-        None,
-        alias="confidentiality",
-        title="As defined by affinity domain",
-        description="The code specifying the level of confidentiality of the Composition.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-    confidentiality__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_confidentiality", title="Extension field for ``confidentiality``."
-    )
-
     custodian: fhirtypes.ReferenceType = Field(
         None,
         alias="custodian",
@@ -149,7 +137,7 @@ class Composition(domainresource.DomainResource):
         element_property=True,
     )
 
-    identifier: fhirtypes.IdentifierType = Field(
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
         title="Version-independent identifier for the Composition",
@@ -161,7 +149,32 @@ class Composition(domainresource.DomainResource):
         element_property=True,
     )
 
-    relatesTo: typing.List[fhirtypes.CompositionRelatesToType] = Field(
+    name: fhirtypes.String = Field(
+        None,
+        alias="name",
+        title="Name for this Composition (computer friendly)",
+        description=(
+            "A natural language name identifying the {{title}}. This name should be"
+            " usable as an identifier for the module by machine processing "
+            "applications such as code generation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_name", title="Extension field for ``name``."
+    )
+
+    note: typing.List[fhirtypes.AnnotationType] = Field(
+        None,
+        alias="note",
+        title="For any additional notes",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    relatesTo: typing.List[fhirtypes.RelatedArtifactType] = Field(
         None,
         alias="relatesTo",
         title="Relationships to other compositions/documents",
@@ -185,7 +198,10 @@ class Composition(domainresource.DomainResource):
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title="preliminary | final | amended | entered-in-error",
+        title=(
+            "registered | partial | preliminary | final | amended | corrected | "
+            "appended | cancelled | entered-in-error | deprecated | unknown"
+        ),
         description=(
             "The workflow/clinical status of this composition. The status is a "
             "marker for the clinical standing of the document."
@@ -195,13 +211,25 @@ class Composition(domainresource.DomainResource):
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["preliminary", "final", "amended", "entered-in-error"],
+        enum_values=[
+            "registered",
+            "partial",
+            "preliminary",
+            "final",
+            "amended",
+            "corrected",
+            "appended",
+            "cancelled",
+            "entered-in-error",
+            "deprecated",
+            "unknown",
+        ],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    subject: fhirtypes.ReferenceType = Field(
+    subject: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="subject",
         title="Who and/or what the composition is about",
@@ -243,6 +271,59 @@ class Composition(domainresource.DomainResource):
         element_property=True,
     )
 
+    url: fhirtypes.Uri = Field(
+        None,
+        alias="url",
+        title=(
+            "Canonical identifier for this Composition, represented as a URI "
+            "(globally unique)"
+        ),
+        description=(
+            "An absolute URI that is used to identify this Composition when it is "
+            "referenced in a specification, model, design or an instance; also "
+            "called its canonical identifier. This SHOULD be globally unique and "
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " Composition is (or will be) published. This URL can be the target of "
+            "a canonical reference. It SHALL remain the same when the Composition "
+            "is stored on different servers."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    url__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_url", title="Extension field for ``url``."
+    )
+
+    useContext: typing.List[fhirtypes.UsageContextType] = Field(
+        None,
+        alias="useContext",
+        title="The context that the content is intended to support",
+        description=(
+            "The content was developed with a focus and intent of supporting the "
+            "contexts that are listed. These contexts may be general categories "
+            "(gender, age, ...) or may be references to specific programs "
+            "(insurance plans, studies, ...) and may be used to assist with "
+            "indexing and searching for appropriate Composition instances."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    version: fhirtypes.String = Field(
+        None,
+        alias="version",
+        title=(
+            "An explicitly assigned identifer of a variation of the content in the "
+            "Composition"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    version__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_version", title="Extension field for ``version``."
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -258,16 +339,20 @@ class Composition(domainresource.DomainResource):
             "contained",
             "extension",
             "modifierExtension",
+            "url",
             "identifier",
+            "version",
             "status",
             "type",
             "category",
             "subject",
             "encounter",
             "date",
+            "useContext",
             "author",
+            "name",
             "title",
-            "confidentiality",
+            "note",
             "attester",
             "custodian",
             "relatesTo",
@@ -350,20 +435,13 @@ class CompositionAttester(backboneelement.BackboneElement):
 
     resource_type = Field("CompositionAttester", const=True)
 
-    mode: fhirtypes.Code = Field(
-        None,
+    mode: fhirtypes.CodeableConceptType = Field(
+        ...,
         alias="mode",
         title="personal | professional | legal | official",
         description="The type of attestation the authenticator offers.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["personal", "professional", "legal", "official"],
-    )
-    mode__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_mode", title="Extension field for ``mode``."
     )
 
     party: fhirtypes.ReferenceType = Field(
@@ -403,65 +481,6 @@ class CompositionAttester(backboneelement.BackboneElement):
         """
         return ["id", "extension", "modifierExtension", "mode", "time", "party"]
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_2197(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("mode", "mode__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
-
 
 class CompositionEvent(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -475,29 +494,17 @@ class CompositionEvent(backboneelement.BackboneElement):
 
     resource_type = Field("CompositionEvent", const=True)
 
-    code: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="code",
-        title="Code(s) that apply to the event being documented",
-        description=(
-            "This list of codes represents the main clinical acts, such as a "
-            "colonoscopy or an appendectomy, being documented. In some cases, the "
-            'event is inherent in the typeCode, such as a "History and Physical '
-            'Report" in which the procedure being documented is necessarily a '
-            '"History and Physical" act.'
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    detail: typing.List[fhirtypes.ReferenceType] = Field(
+    detail: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="detail",
-        title="The event(s) being documented",
+        title="The event(s) being documented, as code(s), reference(s), or both",
         description=(
-            "The description and/or reference of the event(s) being documented. For"
-            " example, this could be used to document such a colonoscopy or an "
-            "appendectomy."
+            "Represents the main clinical acts, such as a colonoscopy or an "
+            "appendectomy, being documented. In some cases, the event is inherent "
+            'in the typeCode, such as a "History and Physical Report" in which case'
+            ' the procedure being documented is necessarily a "History and '
+            'Physical" act. The events may be included as a code or as a reference '
+            "to an other resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -524,177 +531,7 @@ class CompositionEvent(backboneelement.BackboneElement):
         ``CompositionEvent`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "code", "period", "detail"]
-
-
-class CompositionRelatesTo(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Relationships to other compositions/documents.
-    Relationships that this composition has with other compositions or
-    documents that already exist.
-    """
-
-    resource_type = Field("CompositionRelatesTo", const=True)
-
-    code: fhirtypes.Code = Field(
-        None,
-        alias="code",
-        title="replaces | transforms | signs | appends",
-        description=(
-            "The type of relationship that this composition has with anther "
-            "composition or document."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        element_required=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["replaces", "transforms", "signs", "appends"],
-    )
-    code__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_code", title="Extension field for ``code``."
-    )
-
-    targetIdentifier: fhirtypes.IdentifierType = Field(
-        None,
-        alias="targetIdentifier",
-        title="Target of the relationship",
-        description="The target composition/document of this relationship.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e target[x]
-        one_of_many="target",
-        one_of_many_required=True,
-    )
-
-    targetReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="targetReference",
-        title="Target of the relationship",
-        description="The target composition/document of this relationship.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e target[x]
-        one_of_many="target",
-        one_of_many_required=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Composition"],
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``CompositionRelatesTo`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "code",
-            "targetIdentifier",
-            "targetReference",
-        ]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_2265(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("code", "code__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_2265(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {"target": ["targetIdentifier", "targetReference"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
+        return ["id", "extension", "modifierExtension", "period", "detail"]
 
 
 class CompositionSection(backboneelement.BackboneElement):
@@ -791,27 +628,6 @@ class CompositionSection(backboneelement.BackboneElement):
         enum_reference_types=["Resource"],
     )
 
-    mode: fhirtypes.Code = Field(
-        None,
-        alias="mode",
-        title="working | snapshot | changes",
-        description=(
-            "How the entry list was prepared - whether it is a working list that is"
-            " suitable for being maintained on an ongoing basis, or if it "
-            "represents a snapshot of a list of items from another source, or "
-            "whether it is a prepared list where items may be marked as added, "
-            "modified or deleted."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["working", "snapshot", "changes"],
-    )
-    mode__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_mode", title="Extension field for ``mode``."
-    )
-
     orderedBy: fhirtypes.CodeableConceptType = Field(
         None,
         alias="orderedBy",
@@ -876,7 +692,6 @@ class CompositionSection(backboneelement.BackboneElement):
             "author",
             "focus",
             "text",
-            "mode",
             "orderedBy",
             "entry",
             "emptyReason",
