@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Condition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Condition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -32,8 +32,9 @@ class Condition(domainresource.DomainResource):
         description=(
             "The date or estimated date that the condition resolved or went into "
             'remission. This is called "abatement" because of the many overloaded '
-            'connotations associated with "remission" or "resolution" - Conditions '
-            "are never really resolved, but they can abate."
+            'connotations associated with "remission" or "resolution" - Some '
+            "conditions, such as chronic conditions, are never really resolved, but"
+            " they can abate."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -49,8 +50,9 @@ class Condition(domainresource.DomainResource):
         description=(
             "The date or estimated date that the condition resolved or went into "
             'remission. This is called "abatement" because of the many overloaded '
-            'connotations associated with "remission" or "resolution" - Conditions '
-            "are never really resolved, but they can abate."
+            'connotations associated with "remission" or "resolution" - Some '
+            "conditions, such as chronic conditions, are never really resolved, but"
+            " they can abate."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -71,8 +73,9 @@ class Condition(domainresource.DomainResource):
         description=(
             "The date or estimated date that the condition resolved or went into "
             'remission. This is called "abatement" because of the many overloaded '
-            'connotations associated with "remission" or "resolution" - Conditions '
-            "are never really resolved, but they can abate."
+            'connotations associated with "remission" or "resolution" - Some '
+            "conditions, such as chronic conditions, are never really resolved, but"
+            " they can abate."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -88,8 +91,9 @@ class Condition(domainresource.DomainResource):
         description=(
             "The date or estimated date that the condition resolved or went into "
             'remission. This is called "abatement" because of the many overloaded '
-            'connotations associated with "remission" or "resolution" - Conditions '
-            "are never really resolved, but they can abate."
+            'connotations associated with "remission" or "resolution" - Some '
+            "conditions, such as chronic conditions, are never really resolved, but"
+            " they can abate."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -105,8 +109,9 @@ class Condition(domainresource.DomainResource):
         description=(
             "The date or estimated date that the condition resolved or went into "
             'remission. This is called "abatement" because of the many overloaded '
-            'connotations associated with "remission" or "resolution" - Conditions '
-            "are never really resolved, but they can abate."
+            'connotations associated with "remission" or "resolution" - Some '
+            "conditions, such as chronic conditions, are never really resolved, but"
+            " they can abate."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -118,22 +123,6 @@ class Condition(domainresource.DomainResource):
         None, alias="_abatementString", title="Extension field for ``abatementString``."
     )
 
-    asserter: fhirtypes.ReferenceType = Field(
-        None,
-        alias="asserter",
-        title="Person who asserts this condition",
-        description="Individual who is making the condition statement.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Practitioner",
-            "PractitionerRole",
-            "Patient",
-            "RelatedPerson",
-        ],
-    )
-
     bodySite: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="bodySite",
@@ -153,9 +142,12 @@ class Condition(domainresource.DomainResource):
     )
 
     clinicalStatus: fhirtypes.CodeableConceptType = Field(
-        None,
+        ...,
         alias="clinicalStatus",
-        title="active | recurrence | relapse | inactive | remission | resolved",
+        title=(
+            "active | recurrence | relapse | inactive | remission | resolved | "
+            "unknown"
+        ),
         description="The clinical status of the condition.",
         # if property is element of this resource.
         element_property=True,
@@ -173,7 +165,7 @@ class Condition(domainresource.DomainResource):
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
-        title="Encounter created as part of",
+        title="The Encounter during which this Condition was created",
         description=(
             "The Encounter during which this Condition was created or to which the "
             "creation of this record is tightly associated."
@@ -184,10 +176,10 @@ class Condition(domainresource.DomainResource):
         enum_reference_types=["Encounter"],
     )
 
-    evidence: typing.List[fhirtypes.ConditionEvidenceType] = Field(
+    evidence: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="evidence",
-        title="Supporting evidence",
+        title="Supporting evidence for the verification status",
         description=(
             "Supporting evidence / manifestations that are the basis of the "
             "Condition's verification status, such as evidence that confirmed or "
@@ -195,6 +187,8 @@ class Condition(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
     )
 
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
@@ -304,10 +298,25 @@ class Condition(domainresource.DomainResource):
         None, alias="_onsetString", title="Extension field for ``onsetString``."
     )
 
+    participant: typing.List[fhirtypes.ConditionParticipantType] = Field(
+        None,
+        alias="participant",
+        title=(
+            "Who or what participated in the activities related to the condition "
+            "and how they were involved"
+        ),
+        description=(
+            "Indicates who or what participated in the activities related to the "
+            "condition and how they were involved."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     recordedDate: fhirtypes.DateTime = Field(
         None,
         alias="recordedDate",
-        title="Date record was first recorded",
+        title="Date condition was first recorded",
         description=(
             "The recordedDate represents when this particular Condition record was "
             "created in the system, which is often a system-generated date."
@@ -319,25 +328,6 @@ class Condition(domainresource.DomainResource):
         None, alias="_recordedDate", title="Extension field for ``recordedDate``."
     )
 
-    recorder: fhirtypes.ReferenceType = Field(
-        None,
-        alias="recorder",
-        title="Who recorded the condition",
-        description=(
-            "Individual who recorded the record and takes responsibility for its "
-            "content."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Practitioner",
-            "PractitionerRole",
-            "Patient",
-            "RelatedPerson",
-        ],
-    )
-
     severity: fhirtypes.CodeableConceptType = Field(
         None,
         alias="severity",
@@ -355,8 +345,10 @@ class Condition(domainresource.DomainResource):
         alias="stage",
         title="Stage/grade, usually assessed formally",
         description=(
-            "Clinical stage or grade of a condition. May include formal severity "
-            "assessments."
+            'A simple summary of the stage such as "Stage 3" or "Early Onset". The '
+            "determination of the stage is disease-specific, such as cancer, "
+            "retinopathy of prematurity, kidney diseases, Alzheimer's, or Parkinson"
+            " disease."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -385,12 +377,54 @@ class Condition(domainresource.DomainResource):
         ),
         description=(
             "The verification status to support the clinical status of the "
-            "condition."
+            "condition.  The verification status pertains to the condition, itself,"
+            " not to any specific condition attribute."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Condition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "clinicalStatus",
+            "verificationStatus",
+            "category",
+            "severity",
+            "code",
+            "bodySite",
+            "subject",
+            "encounter",
+            "onsetDateTime",
+            "onsetAge",
+            "onsetPeriod",
+            "onsetRange",
+            "onsetString",
+            "abatementDateTime",
+            "abatementAge",
+            "abatementPeriod",
+            "abatementRange",
+            "abatementString",
+            "recordedDate",
+            "participant",
+            "stage",
+            "evidence",
+            "note",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1112(
         cls, values: typing.Dict[str, typing.Any]
@@ -445,50 +479,71 @@ class Condition(domainresource.DomainResource):
         return values
 
 
-class ConditionEvidence(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+class ConditionParticipant(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Supporting evidence.
-    Supporting evidence / manifestations that are the basis of the Condition's
-    verification status, such as evidence that confirmed or refuted the
-    condition.
+    Who or what participated in the activities related to the condition and how
+    they were involved.
+    Indicates who or what participated in the activities related to the
+    condition and how they were involved.
     """
 
-    resource_type = Field("ConditionEvidence", const=True)
+    resource_type = Field("ConditionParticipant", const=True)
 
-    code: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="code",
-        title="Manifestation/symptom",
+    actor: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="actor",
+        title="Who or what participated in the activities related to the condition",
         description=(
-            "A manifestation or symptom that led to the recording of this " "condition."
+            "Indicates who or what participated in the activities related to the "
+            "condition."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Patient",
+            "RelatedPerson",
+            "Device",
+            "Organization",
+            "CareTeam",
+        ],
+    )
+
+    function: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="function",
+        title="Type of involvement",
+        description=(
+            "Distinguishes the type of involvement of the actor in the activities "
+            "related to the condition."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    detail: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="detail",
-        title="Supporting information found elsewhere",
-        description="Links to other relevant information, including pathology reports.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Resource"],
-    )
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ConditionParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
 
 
 class ConditionStage(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     Stage/grade, usually assessed formally.
-    Clinical stage or grade of a condition. May include formal severity
-    assessments.
+    A simple summary of the stage such as "Stage 3" or "Early Onset". The
+    determination of the stage is disease-specific, such as cancer, retinopathy
+    of prematurity, kidney diseases, Alzheimer's, or Parkinson disease.
     """
 
     resource_type = Field("ConditionStage", const=True)
@@ -512,8 +567,10 @@ class ConditionStage(backboneelement.BackboneElement):
         alias="summary",
         title="Simple summary (disease specific)",
         description=(
-            'A simple summary of the stage such as "Stage 3". The determination of '
-            "the stage is disease-specific."
+            'A simple summary of the stage such as "Stage 3" or "Early Onset". The '
+            "determination of the stage is disease-specific, such as cancer, "
+            "retinopathy of prematurity, kidney diseases, Alzheimer's, or Parkinson"
+            " disease."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -527,3 +584,11 @@ class ConditionStage(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ConditionStage`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "summary", "assessment", "type"]
