@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Consent
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -20,17 +20,19 @@ class Consent(domainresource.DomainResource):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    A healthcare consumer's  choices to permit or deny recipients or roles to
-    perform actions for specific purposes and periods of time.
-    A record of a healthcare consumer’s  choices, which permits or denies
-    identified recipient(s) or recipient role(s) to perform one or more actions
-    within a given policy context, for specific purposes and periods of time.
+    A healthcare consumer's  or third party's choices to permit or deny
+    recipients or roles to perform actions for specific purposes and periods of
+    time.
+    A record of a healthcare consumer’s  choices  or choices made on their
+    behalf by a third party, which permits or denies identified recipient(s) or
+    recipient role(s) to perform one or more actions within a given policy
+    context, for specific purposes and periods of time.
     """
 
     resource_type = Field("Consent", const=True)
 
     category: typing.List[fhirtypes.CodeableConceptType] = Field(
-        ...,
+        None,
         alias="category",
         title="Classification of the consent statement - for indexing/retrieval",
         description=(
@@ -41,16 +43,92 @@ class Consent(domainresource.DomainResource):
         element_property=True,
     )
 
-    dateTime: fhirtypes.DateTime = Field(
+    controller: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="dateTime",
-        title="When this Consent was created or indexed",
-        description="When this  Consent was issued / created / indexed.",
+        alias="controller",
+        title="Consent Enforcer",
+        description="The actor that controls/enforces the access according to the consent.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "HealthcareService",
+            "Organization",
+            "Patient",
+            "Practitioner",
+        ],
+    )
+
+    date: fhirtypes.Date = Field(
+        None,
+        alias="date",
+        title="Fully executed date of the consent",
+        description="Date the consent instance was agreed to.",
         # if property is element of this resource.
         element_property=True,
     )
-    dateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_dateTime", title="Extension field for ``dateTime``."
+    date__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_date", title="Extension field for ``date``."
+    )
+
+    decision: fhirtypes.Code = Field(
+        None,
+        alias="decision",
+        title="deny | permit",
+        description="Action to take - permit or deny - as default.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["deny", "permit"],
+    )
+    decision__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_decision", title="Extension field for ``decision``."
+    )
+
+    grantee: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="grantee",
+        title="Who is agreeing to the policy and rules",
+        description=(
+            "The entity responsible for complying with the Consent Directive, "
+            "including any obligations or limitations on authorizations and "
+            "enforcement of prohibitions."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "CareTeam",
+            "HealthcareService",
+            "Organization",
+            "Patient",
+            "Practitioner",
+            "RelatedPerson",
+            "PractitionerRole",
+        ],
+    )
+
+    grantor: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="grantor",
+        title="Who is granting rights according to the policy and rules",
+        description=(
+            "The entity responsible for granting the rights listed in a Consent "
+            "Directive."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "CareTeam",
+            "HealthcareService",
+            "Organization",
+            "Patient",
+            "Practitioner",
+            "RelatedPerson",
+            "PractitionerRole",
+        ],
     )
 
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
@@ -62,80 +140,66 @@ class Consent(domainresource.DomainResource):
         element_property=True,
     )
 
-    organization: typing.List[fhirtypes.ReferenceType] = Field(
+    manager: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="organization",
-        title="Custodian of the consent",
-        description=(
-            "The organization that manages the consent, and the framework within "
-            "which it is executed."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Organization"],
-    )
-
-    patient: fhirtypes.ReferenceType = Field(
-        None,
-        alias="patient",
-        title="Who the consent applies to",
-        description="The patient/healthcare consumer to whom this consent applies.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient"],
-    )
-
-    performer: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="performer",
-        title="Who is agreeing to the policy and rules",
-        description=(
-            "Either the Grantor, which is the entity responsible for granting the "
-            "rights listed in a Consent Directive or the Grantee, which is the "
-            "entity responsible for complying with the Consent Directive, including"
-            " any obligations or limitations on authorizations and enforcement of "
-            "prohibitions."
-        ),
+        alias="manager",
+        title="Consent workflow management",
+        description="The actor that manages the consent through its lifecycle.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
+            "HealthcareService",
             "Organization",
             "Patient",
             "Practitioner",
-            "RelatedPerson",
-            "PractitionerRole",
         ],
     )
 
-    policy: typing.List[fhirtypes.ConsentPolicyType] = Field(
+    period: fhirtypes.PeriodType = Field(
         None,
-        alias="policy",
-        title="Policies covered by this consent",
+        alias="period",
+        title="Effective period for this Consent",
         description=(
-            "The references to the policies that are included in this consent "
-            "scope. Policies may be organizational, but are often defined "
-            "jurisdictionally, or in law."
+            "Effective period for this Consent Resource and all provisions unless "
+            "specified in that provision."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    policyRule: fhirtypes.CodeableConceptType = Field(
+    policyBasis: fhirtypes.ConsentPolicyBasisType = Field(
         None,
-        alias="policyRule",
-        title="Regulation that this consents to",
-        description="A reference to the specific base computable regulation or policy.",
+        alias="policyBasis",
+        title="Computable version of the backing policy",
+        description=(
+            "A Reference or URL used to uniquely identify the policy the "
+            "organization will enforce for this Consent. This Reference or URL "
+            "should be specific to the version of the policy and should be "
+            "dereferencable to a computable policy of some form."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    provision: fhirtypes.ConsentProvisionType = Field(
+    policyText: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="policyText",
+        title="Human Readable Policy",
+        description=(
+            "A Reference to the human readable policy explaining the basis for the "
+            "Consent."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["DocumentReference"],
+    )
+
+    provision: typing.List[fhirtypes.ConsentProvisionType] = Field(
         None,
         alias="provision",
-        title="Constraints to the base Consent.policyRule",
+        title="Constraints to the base Consent.policyRule/Consent.policy",
         description=(
             "An exception to the base policy of this consent. An exception can be "
             "an addition or removal of access permissions."
@@ -144,50 +208,41 @@ class Consent(domainresource.DomainResource):
         element_property=True,
     )
 
-    scope: fhirtypes.CodeableConceptType = Field(
-        ...,
-        alias="scope",
-        title="Which of the four areas this resource covers (extensible)",
+    regulatoryBasis: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="regulatoryBasis",
+        title="Regulations establishing base Consent",
         description=(
-            "A selector of the type of consent being presented: ADR, Privacy, "
-            "Treatment, Research.  This list is now extensible."
+            "A set of codes that indicate the regulatory basis (if any) that this "
+            "consent supports."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    sourceAttachment: fhirtypes.AttachmentType = Field(
+    sourceAttachment: typing.List[fhirtypes.AttachmentType] = Field(
         None,
         alias="sourceAttachment",
         title="Source from which this consent is taken",
         description=(
             "The source on which this consent statement is based. The source might "
-            "be a scanned original paper form, or a reference to a consent that "
-            "links back to such a source, a reference to a document repository "
-            "(e.g. XDS) that stores the original consent document."
+            "be a scanned original paper form."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e source[x]
-        one_of_many="source",
-        one_of_many_required=False,
     )
 
-    sourceReference: fhirtypes.ReferenceType = Field(
+    sourceReference: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="sourceReference",
         title="Source from which this consent is taken",
         description=(
-            "The source on which this consent statement is based. The source might "
-            "be a scanned original paper form, or a reference to a consent that "
-            "links back to such a source, a reference to a document repository "
-            "(e.g. XDS) that stores the original consent document."
+            "A reference to a consent that links back to such a source, a reference"
+            " to a document repository (e.g. XDS) that stores the original consent "
+            "document."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e source[x]
-        one_of_many="source",
-        one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Consent",
@@ -200,8 +255,8 @@ class Consent(domainresource.DomainResource):
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title="draft | proposed | active | rejected | inactive | entered-in-error",
-        description="Indicates the current state of this consent.",
+        title="draft | active | inactive | not-done | entered-in-error | unknown",
+        description="Indicates the current state of this Consent resource.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -209,23 +264,37 @@ class Consent(domainresource.DomainResource):
         # but use in your own responsibilities, read official FHIR documentation.
         enum_values=[
             "draft",
-            "proposed",
             "active",
-            "rejected",
             "inactive",
+            "not-done",
             "entered-in-error",
+            "unknown",
         ],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    subject: fhirtypes.ReferenceType = Field(
+        None,
+        alias="subject",
+        title="Who the consent applies to",
+        description=(
+            "The patient/healthcare practitioner or group of persons to whom this "
+            "consent applies."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Patient", "Practitioner", "Group"],
+    )
+
     verification: typing.List[fhirtypes.ConsentVerificationType] = Field(
         None,
         alias="verification",
         title="Consent Verified by patient or family",
         description=(
-            "Whether a treatment instruction (e.g. artificial respiration yes or "
+            "Whether a treatment instruction (e.g. artificial respiration: yes or "
             "no) was verified with the patient, his/her family or another "
             "authorized person."
         ),
@@ -250,17 +319,21 @@ class Consent(domainresource.DomainResource):
             "modifierExtension",
             "identifier",
             "status",
-            "scope",
             "category",
-            "patient",
-            "dateTime",
-            "performer",
-            "organization",
+            "subject",
+            "date",
+            "period",
+            "grantor",
+            "grantee",
+            "manager",
+            "controller",
             "sourceAttachment",
             "sourceReference",
-            "policy",
-            "policyRule",
+            "regulatoryBasis",
+            "policyBasis",
+            "policyText",
             "verification",
+            "decision",
             "provision",
         ]
 
@@ -323,97 +396,57 @@ class Consent(domainresource.DomainResource):
 
         return values
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_913(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
 
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {"source": ["sourceAttachment", "sourceReference"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
-
-class ConsentPolicy(backboneelement.BackboneElement):
+class ConsentPolicyBasis(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Policies covered by this consent.
-    The references to the policies that are included in this consent scope.
-    Policies may be organizational, but are often defined jurisdictionally, or
-    in law.
+    Computable version of the backing policy.
+    A Reference or URL used to uniquely identify the policy the organization
+    will enforce for this Consent. This Reference or URL should be specific to
+    the version of the policy and should be dereferencable to a computable
+    policy of some form.
     """
 
-    resource_type = Field("ConsentPolicy", const=True)
+    resource_type = Field("ConsentPolicyBasis", const=True)
 
-    authority: fhirtypes.Uri = Field(
+    reference: fhirtypes.ReferenceType = Field(
         None,
-        alias="authority",
-        title="Enforcement source for policy",
+        alias="reference",
+        title="Reference backing policy resource",
         description=(
-            "Entity or Organization having regulatory jurisdiction or "
-            "accountability for  enforcing policies pertaining to Consent "
-            "Directives."
+            "A Reference that identifies the policy the organization will enforce "
+            "for this Consent."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
+    url: fhirtypes.Url = Field(
+        None,
+        alias="url",
+        title="URL to a computable backing policy",
+        description=(
+            "A URL that links to a computable version of the policy the "
+            "organization will enforce for this Consent."
         ),
         # if property is element of this resource.
         element_property=True,
     )
-    authority__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_authority", title="Extension field for ``authority``."
-    )
-
-    uri: fhirtypes.Uri = Field(
-        None,
-        alias="uri",
-        title="Specific policy covered by this consent",
-        description=(
-            "The references to the policies that are included in this consent "
-            "scope. Policies may be organizational, but are often defined "
-            "jurisdictionally, or in law."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    uri__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_uri", title="Extension field for ``uri``."
+    url__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_url", title="Extension field for ``url``."
     )
 
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``ConsentPolicy`` according specification,
+        ``ConsentPolicyBasis`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "authority", "uri"]
+        return ["id", "extension", "modifierExtension", "reference", "url"]
 
 
 class ConsentProvision(backboneelement.BackboneElement):
@@ -421,7 +454,7 @@ class ConsentProvision(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Constraints to the base Consent.policyRule.
+    Constraints to the base Consent.policyRule/Consent.policy.
     An exception to the base policy of this consent. An exception can be an
     addition or removal of access permissions.
     """
@@ -431,8 +464,8 @@ class ConsentProvision(backboneelement.BackboneElement):
     action: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="action",
-        title="Actions controlled by this rule",
-        description="Actions controlled by this Rule.",
+        title="Actions controlled by this provision",
+        description=None,
         # if property is element of this resource.
         element_property=True,
     )
@@ -440,23 +473,10 @@ class ConsentProvision(backboneelement.BackboneElement):
     actor: typing.List[fhirtypes.ConsentProvisionActorType] = Field(
         None,
         alias="actor",
-        title="Who|what controlled by this rule (or group, by role)",
+        title="Who|what controlled by this provision (or group, by role)",
         description=(
-            "Who or what is controlled by this rule. Use group to identify a set of"
-            " actors by some property they share (e.g. 'admitting officers')."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    class_fhir: typing.List[fhirtypes.CodingType] = Field(
-        None,
-        alias="class",
-        title="e.g. Resource Type, Profile, CDA, etc.",
-        description=(
-            "The class of information covered by this rule. The type can be a FHIR "
-            "resource type, a profile on a type, or a CDA document, or some other "
-            "type that indicates what sort of information the consent relates to."
+            "Who or what is controlled by this provision. Use group to identify a "
+            "set of actors by some property they share (e.g. 'admitting officers')."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -466,7 +486,7 @@ class ConsentProvision(backboneelement.BackboneElement):
         None,
         alias="code",
         title="e.g. LOINC or SNOMED CT code, etc. in the content",
-        description="If this code is found in an instance, then the rule applies.",
+        description="If this code is found in an instance, then the provision applies.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -474,9 +494,9 @@ class ConsentProvision(backboneelement.BackboneElement):
     data: typing.List[fhirtypes.ConsentProvisionDataType] = Field(
         None,
         alias="data",
-        title="Data controlled by this rule",
+        title="Data controlled by this provision",
         description=(
-            "The resources controlled by this rule if specific resources are "
+            "The resources controlled by this provision if specific resources are "
             "referenced."
         ),
         # if property is element of this resource.
@@ -486,10 +506,35 @@ class ConsentProvision(backboneelement.BackboneElement):
     dataPeriod: fhirtypes.PeriodType = Field(
         None,
         alias="dataPeriod",
-        title="Timeframe for data controlled by this rule",
+        title="Timeframe for data controlled by this provision",
         description=(
             "Clinical or Operational Relevant period of time that bounds the data "
-            "controlled by this rule."
+            "controlled by this provision."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    documentType: typing.List[fhirtypes.CodingType] = Field(
+        None,
+        alias="documentType",
+        title="e.g. Resource Type, Profile, CDA, etc",
+        description=(
+            "The documentType(s) covered by this provision. The type can be a CDA "
+            "document, or some other type that indicates what sort of information "
+            "the consent relates to."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    expression: fhirtypes.ExpressionType = Field(
+        None,
+        alias="expression",
+        title="A computable expression of the consent",
+        description=(
+            "A computable (FHIRPath or other) definition of what is controlled by "
+            "this consent."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -498,8 +543,8 @@ class ConsentProvision(backboneelement.BackboneElement):
     period: fhirtypes.PeriodType = Field(
         None,
         alias="period",
-        title="Timeframe for this rule",
-        description="The timeframe in this rule is valid.",
+        title="Timeframe for this provision",
+        description=None,
         # if property is element of this resource.
         element_property=True,
     )
@@ -507,8 +552,11 @@ class ConsentProvision(backboneelement.BackboneElement):
     provision: typing.List[fhirtypes.ConsentProvisionType] = Field(
         None,
         alias="provision",
-        title="Nested Exception Rules",
-        description="Rules which provide exceptions to the base rule or subrules.",
+        title="Nested Exception Provisions",
+        description=(
+            "Provisions which provide exceptions to the base provision or "
+            "subprovisions."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -516,10 +564,23 @@ class ConsentProvision(backboneelement.BackboneElement):
     purpose: typing.List[fhirtypes.CodingType] = Field(
         None,
         alias="purpose",
-        title="Context of activities covered by this rule",
+        title="Context of activities covered by this provision",
         description=(
             "The context of the activities a user is taking - why the user is "
-            "accessing the data - that are controlled by this rule."
+            "accessing the data - that are controlled by this provision."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    resourceType: typing.List[fhirtypes.CodingType] = Field(
+        None,
+        alias="resourceType",
+        title="e.g. Resource Type, Profile, etc",
+        description=(
+            "The resourceType(s) covered by this provision. The type can be a FHIR "
+            "resource type or a profile on a type that indicates what information "
+            "the consent relates to."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -537,24 +598,6 @@ class ConsentProvision(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    type: fhirtypes.Code = Field(
-        None,
-        alias="type",
-        title="deny | permit",
-        description=(
-            "Action  to take - permit or deny - when the rule conditions are met.  "
-            "Not permitted in root rule, required in all nested rules."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["deny", "permit"],
-    )
-    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_type", title="Extension field for ``type``."
-    )
-
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -565,16 +608,17 @@ class ConsentProvision(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "type",
             "period",
             "actor",
             "action",
             "securityLabel",
             "purpose",
-            "class",
+            "documentType",
+            "resourceType",
             "code",
             "dataPeriod",
             "data",
+            "expression",
             "provision",
         ]
 
@@ -584,15 +628,15 @@ class ConsentProvisionActor(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Who|what controlled by this rule (or group, by role).
-    Who or what is controlled by this rule. Use group to identify a set of
+    Who|what controlled by this provision (or group, by role).
+    Who or what is controlled by this provision. Use group to identify a set of
     actors by some property they share (e.g. 'admitting officers').
     """
 
     resource_type = Field("ConsentProvisionActor", const=True)
 
     reference: fhirtypes.ReferenceType = Field(
-        ...,
+        None,
         alias="reference",
         title="Resource for the actor (or group, by role)",
         description=(
@@ -616,7 +660,7 @@ class ConsentProvisionActor(backboneelement.BackboneElement):
     )
 
     role: fhirtypes.CodeableConceptType = Field(
-        ...,
+        None,
         alias="role",
         title="How the actor is involved",
         description=(
@@ -641,8 +685,9 @@ class ConsentProvisionData(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Data controlled by this rule.
-    The resources controlled by this rule if specific resources are referenced.
+    Data controlled by this provision.
+    The resources controlled by this provision if specific resources are
+    referenced.
     """
 
     resource_type = Field("ConsentProvisionData", const=True)
@@ -754,26 +799,40 @@ class ConsentVerification(backboneelement.BackboneElement):
     for FHIR Primitive Data Types.
 
     Consent Verified by patient or family.
-    Whether a treatment instruction (e.g. artificial respiration yes or no) was
-    verified with the patient, his/her family or another authorized person.
+    Whether a treatment instruction (e.g. artificial respiration: yes or no)
+    was verified with the patient, his/her family or another authorized person.
     """
 
     resource_type = Field("ConsentVerification", const=True)
 
-    verificationDate: fhirtypes.DateTime = Field(
+    verificationDate: typing.List[typing.Optional[fhirtypes.DateTime]] = Field(
         None,
         alias="verificationDate",
         title="When consent verified",
-        description="Date verification was collected.",
+        description="Date(s) verification was collected.",
         # if property is element of this resource.
         element_property=True,
     )
-    verificationDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+    verificationDate__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(
         None,
         alias="_verificationDate",
         title="Extension field for ``verificationDate``.",
     )
 
+    verificationType: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="verificationType",
+        title="Business case of verification",
+        description=(
+            "Extensible list of verification type starting with verification and "
+            "re-validation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     verified: bool = Field(
         None,
         alias="verified",
@@ -787,6 +846,20 @@ class ConsentVerification(backboneelement.BackboneElement):
         None, alias="_verified", title="Extension field for ``verified``."
     )
 
+    verifiedBy: fhirtypes.ReferenceType = Field(
+        None,
+        alias="verifiedBy",
+        title="Person conducting verification",
+        description=(
+            "The person who conducted the verification/validation of the Grantor "
+            "decision."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Organization", "Practitioner", "PractitionerRole"],
+    )
+
     verifiedWith: fhirtypes.ReferenceType = Field(
         None,
         alias="verifiedWith",
@@ -812,6 +885,8 @@ class ConsentVerification(backboneelement.BackboneElement):
             "extension",
             "modifierExtension",
             "verified",
+            "verificationType",
+            "verifiedBy",
             "verifiedWith",
             "verificationDate",
         ]
