@@ -30,6 +30,7 @@ ROOT_NS = "http://hl7.org/fhir"
 XHTML_NS = "http://www.w3.org/1999/xhtml"
 EMPTY_VALUE = None
 FHIR_ROOT_MODULES: typing.Dict[str, typing.Any] = {
+    "R5": None,
     "R4": None,
     "R4B": None,
     "STU3": None,
@@ -71,7 +72,7 @@ def get_fhir_root_module(fhir_release: str):
     global FHIR_ROOT_MODULES
     if FHIR_ROOT_MODULES[fhir_release] is None:
         mod_name = "fhir.resources"
-        if fhir_release != "R4B":
+        if fhir_release != "R5":
             mod_name += f".{fhir_release}"
         FHIR_ROOT_MODULES[fhir_release] = importlib.import_module(mod_name)
 
@@ -79,7 +80,6 @@ def get_fhir_root_module(fhir_release: str):
 
 
 class SimpleNodeStorage:
-
     __slots__ = ("__storage__", "node")
     if typing.TYPE_CHECKING:
         node: "Node"
@@ -800,7 +800,6 @@ class Node:
             return me
 
         for child in self.children:
-
             if isinstance(child, Node):
                 child_node = child.to_xml(me)
             elif isinstance(child, etree._Element):
