@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Count
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 from pydantic import Field
 
