@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Coverage
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Coverage(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -78,7 +78,7 @@ class Coverage(domainresource.DomainResource):
         None,
         alias="dependent",
         title="Dependent number",
-        description="A unique identifier for a dependent under the coverage.",
+        description="A designator for a dependent under the coverage.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -89,12 +89,56 @@ class Coverage(domainresource.DomainResource):
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
-        title="Business Identifier for the coverage",
-        description="A unique identifier assigned to this coverage.",
+        title="Business identifier(s) for this coverage",
+        description="The identifier of the coverage as issued by the insurer.",
         # if property is element of this resource.
         element_property=True,
     )
 
+    insurancePlan: fhirtypes.ReferenceType = Field(
+        None,
+        alias="insurancePlan",
+        title="Insurance plan details",
+        description=(
+            "The insurance plan details, benefits and costs, which constitute this "
+            "insurance coverage."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["InsurancePlan"],
+    )
+
+    insurer: fhirtypes.ReferenceType = Field(
+        None,
+        alias="insurer",
+        title="Issuer of the policy",
+        description="The program or plan underwriter, payor, insurance company.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Organization"],
+    )
+
+    kind: fhirtypes.Code = Field(
+        None,
+        alias="kind",
+        title="insurance | self-pay | other",
+        description=(
+            "The nature of the coverage be it insurance, or cash payment such as "
+            "self-pay."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["insurance", "self-pay", "other"],
+    )
+    kind__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_kind", title="Extension field for ``kind``."
+    )
+
     network: fhirtypes.String = Field(
         None,
         alias="network",
@@ -120,7 +164,12 @@ class Coverage(domainresource.DomainResource):
             "The order of applicability of this coverage relative to other "
             "coverages which are currently in force. Note, there may be gaps in the"
             " numbering and this does not imply primary, secondary etc. as the "
-            "specific positioning of coverages depends upon the episode of care."
+            "specific positioning of coverages depends upon the episode of care. "
+            "For example; a patient might have (0) auto insurance (1) their own "
+            "health insurance and (2) spouse's health insurance. When claiming for "
+            "treatments which were not the result of an auto accident then only "
+            "coverages (1) and (2) above would be applicatble and would apply in "
+            "the order specified in parenthesis."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -129,18 +178,16 @@ class Coverage(domainresource.DomainResource):
         None, alias="_order", title="Extension field for ``order``."
     )
 
-    payor: typing.List[fhirtypes.ReferenceType] = Field(
-        ...,
-        alias="payor",
-        title="Issuer of the policy",
+    paymentBy: typing.List[fhirtypes.CoveragePaymentByType] = Field(
+        None,
+        alias="paymentBy",
+        title="Self-pay parties and responsibility",
         description=(
-            "The program or plan underwriter or payor including both insurance and "
-            "non-insurance agreements, such as patient-pay agreements."
+            "Link to the paying party and optionally what specifically they will be"
+            " responsible to pay."
         ),
         # if property is element of this resource.
         element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Organization", "Patient", "RelatedPerson"],
     )
 
     period: fhirtypes.PeriodType = Field(
@@ -223,7 +270,7 @@ class Coverage(domainresource.DomainResource):
         enum_reference_types=["Patient", "RelatedPerson"],
     )
 
-    subscriberId: fhirtypes.String = Field(
+    subscriberId: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="subscriberId",
         title="ID assigned to the subscriber",
@@ -231,9 +278,6 @@ class Coverage(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
     )
-    subscriberId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_subscriberId", title="Extension field for ``subscriberId``."
-    )
 
     type: fhirtypes.CodeableConceptType = Field(
         None,
@@ -248,6 +292,43 @@ class Coverage(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Coverage`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "kind",
+            "paymentBy",
+            "type",
+            "policyHolder",
+            "subscriber",
+            "subscriberId",
+            "beneficiary",
+            "dependent",
+            "relationship",
+            "period",
+            "insurer",
+            "class",
+            "order",
+            "network",
+            "costToBeneficiary",
+            "subrogation",
+            "contract",
+            "insurancePlan",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_980(
         cls, values: typing.Dict[str, typing.Any]
@@ -259,7 +340,7 @@ class Coverage(domainresource.DomainResource):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("status", "status__ext")]
+        required_fields = [("kind", "kind__ext"), ("status", "status__ext")]
         _missing = object()
 
         def _fallback():
@@ -309,7 +390,7 @@ class Coverage(domainresource.DomainResource):
 
 
 class CoverageClass(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -337,90 +418,34 @@ class CoverageClass(backboneelement.BackboneElement):
         title="Type of class such as 'group' or 'plan'",
         description=(
             "The type of classification for which an insurer-specific class label "
-            "or number and optional name is provided, for example may be used to "
-            "identify a class of coverage or employer group, Policy, Plan."
+            "or number and optional name is provided.  For example, type may be "
+            "used to identify a class of coverage or employer group, policy, or "
+            "plan."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    value: fhirtypes.String = Field(
-        None,
+    value: fhirtypes.IdentifierType = Field(
+        ...,
         alias="value",
         title="Value associated with the type",
-        description=(
-            "The alphanumeric string value associated with the insurer issued " "label."
-        ),
+        description="The alphanumeric identifier associated with the insurer issued label.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
-    )
-    value__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_value", title="Extension field for ``value``."
     )
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_1496(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageClass`` according specification,
+        with preserving original sequence order.
         """
-        required_fields = [("value", "value__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
+        return ["id", "extension", "modifierExtension", "type", "value", "name"]
 
 
 class CoverageCostToBeneficiary(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -432,6 +457,18 @@ class CoverageCostToBeneficiary(backboneelement.BackboneElement):
 
     resource_type = Field("CoverageCostToBeneficiary", const=True)
 
+    category: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="category",
+        title="Benefit classification",
+        description=(
+            "Code to identify the general type of benefits under which products and"
+            " services are provided."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     exception: typing.List[fhirtypes.CoverageCostToBeneficiaryExceptionType] = Field(
         None,
         alias="exception",
@@ -444,6 +481,30 @@ class CoverageCostToBeneficiary(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    network: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="network",
+        title="In or out of network",
+        description=(
+            "Is a flag to indicate whether the benefits refer to in-network "
+            "providers or out-of-network providers."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    term: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="term",
+        title="Annual or lifetime",
+        description=(
+            "The term or period of the values such as 'maximum lifetime benefit' or"
+            " 'maximum annual visits'."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     type: fhirtypes.CodeableConceptType = Field(
         None,
         alias="type",
@@ -453,6 +514,15 @@ class CoverageCostToBeneficiary(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    unit: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="unit",
+        title="Individual or family",
+        description="Indicates if the benefits apply to an individual or to the family.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     valueMoney: fhirtypes.MoneyType = Field(
         None,
         alias="valueMoney",
@@ -462,7 +532,7 @@ class CoverageCostToBeneficiary(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=True,
+        one_of_many_required=False,
     )
 
     valueQuantity: fhirtypes.QuantityType = Field(
@@ -474,9 +544,29 @@ class CoverageCostToBeneficiary(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=True,
+        one_of_many_required=False,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageCostToBeneficiary`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "category",
+            "network",
+            "unit",
+            "term",
+            "valueQuantity",
+            "valueMoney",
+            "exception",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2725(
         cls, values: typing.Dict[str, typing.Any]
@@ -517,7 +607,7 @@ class CoverageCostToBeneficiary(backboneelement.BackboneElement):
 
 
 class CoverageCostToBeneficiaryException(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -532,7 +622,7 @@ class CoverageCostToBeneficiaryException(backboneelement.BackboneElement):
         None,
         alias="period",
         title="The effective period of the exception",
-        description="The timeframe during when the exception is in force.",
+        description="The timeframe the exception is in force.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -545,3 +635,58 @@ class CoverageCostToBeneficiaryException(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageCostToBeneficiaryException`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "period"]
+
+
+class CoveragePaymentBy(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Self-pay parties and responsibility.
+    Link to the paying party and optionally what specifically they will be
+    responsible to pay.
+    """
+
+    resource_type = Field("CoveragePaymentBy", const=True)
+
+    party: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="party",
+        title="Parties performing self-payment",
+        description=(
+            "The list of parties providing non-insurance payment for the treatment "
+            "costs."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Patient", "RelatedPerson", "Organization"],
+    )
+
+    responsibility: fhirtypes.String = Field(
+        None,
+        alias="responsibility",
+        title="Party's responsibility",
+        description=" Description of the financial responsibility.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    responsibility__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_responsibility", title="Extension field for ``responsibility``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoveragePaymentBy`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "party", "responsibility"]
