@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/CoverageEligibilityResponse
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class CoverageEligibilityResponse(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -61,6 +61,15 @@ class CoverageEligibilityResponse(domainresource.DomainResource):
         element_property=True,
     )
 
+    event: typing.List[fhirtypes.CoverageEligibilityResponseEventType] = Field(
+        None,
+        alias="event",
+        title="Event information",
+        description="Information code for an event with a corresponding date or period.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     form: fhirtypes.CodeableConceptType = Field(
         None,
         alias="form",
@@ -150,7 +159,7 @@ class CoverageEligibilityResponse(domainresource.DomainResource):
         None, alias="_preAuthRef", title="Extension field for ``preAuthRef``."
     )
 
-    purpose: typing.List[fhirtypes.Code] = Field(
+    purpose: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="purpose",
         title="auth-requirements | benefits | discovery | validation",
@@ -243,6 +252,40 @@ class CoverageEligibilityResponse(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageEligibilityResponse`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "purpose",
+            "patient",
+            "event",
+            "servicedDate",
+            "servicedPeriod",
+            "created",
+            "requestor",
+            "request",
+            "outcome",
+            "disposition",
+            "insurer",
+            "insurance",
+            "preAuthRef",
+            "form",
+            "error",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2970(
         cls, values: typing.Dict[str, typing.Any]
@@ -347,7 +390,7 @@ class CoverageEligibilityResponse(domainresource.DomainResource):
 
 
 class CoverageEligibilityResponseError(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -369,9 +412,141 @@ class CoverageEligibilityResponseError(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    expression: typing.List[typing.Optional[fhirtypes.String]] = Field(
+        None,
+        alias="expression",
+        title="FHIRPath of element(s) related to issue",
+        description=(
+            "A [simple subset of FHIRPath](fhirpath.html#simple) limited to element"
+            " names, repetition indicators and the default child accessor that "
+            "identifies one of the elements in the resource that caused this issue "
+            "to be raised."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    expression__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_expression", title="Extension field for ``expression``.")
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageEligibilityResponseError`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "code", "expression"]
+
+
+class CoverageEligibilityResponseEvent(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Event information.
+    Information code for an event with a corresponding date or period.
+    """
+
+    resource_type = Field("CoverageEligibilityResponseEvent", const=True)
+
+    type: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="type",
+        title="Specific event",
+        description="A coded event such as when a service is expected or a card printed.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    whenDateTime: fhirtypes.DateTime = Field(
+        None,
+        alias="whenDateTime",
+        title="Occurance date or period",
+        description=(
+            "A date or period in the past or future indicating when the event "
+            "occurred or is expectd to occur."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e when[x]
+        one_of_many="when",
+        one_of_many_required=True,
+    )
+    whenDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_whenDateTime", title="Extension field for ``whenDateTime``."
+    )
+
+    whenPeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="whenPeriod",
+        title="Occurance date or period",
+        description=(
+            "A date or period in the past or future indicating when the event "
+            "occurred or is expectd to occur."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e when[x]
+        one_of_many="when",
+        one_of_many_required=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageEligibilityResponseEvent`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "whenDateTime",
+            "whenPeriod",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_3499(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {"when": ["whenDateTime", "whenPeriod"]}
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class CoverageEligibilityResponseInsurance(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -435,9 +610,25 @@ class CoverageEligibilityResponseInsurance(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageEligibilityResponseInsurance`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "coverage",
+            "inforce",
+            "benefitPeriod",
+            "item",
+        ]
+
 
 class CoverageEligibilityResponseInsuranceItem(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -628,9 +819,35 @@ class CoverageEligibilityResponseInsuranceItem(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageEligibilityResponseInsuranceItem`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "category",
+            "productOrService",
+            "modifier",
+            "provider",
+            "excluded",
+            "name",
+            "description",
+            "network",
+            "unit",
+            "term",
+            "benefit",
+            "authorizationRequired",
+            "authorizationSupporting",
+            "authorizationUrl",
+        ]
+
 
 class CoverageEligibilityResponseInsuranceItemBenefit(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -735,6 +952,25 @@ class CoverageEligibilityResponseInsuranceItemBenefit(backboneelement.BackboneEl
         None, alias="_usedUnsignedInt", title="Extension field for ``usedUnsignedInt``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CoverageEligibilityResponseInsuranceItemBenefit`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "allowedUnsignedInt",
+            "allowedString",
+            "allowedMoney",
+            "usedUnsignedInt",
+            "usedString",
+            "usedMoney",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_5021(
         cls, values: typing.Dict[str, typing.Any]
