@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DataRequirement
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,10 +12,10 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import element, fhirtypes
+from . import datatype, element, fhirtypes
 
 
-class DataRequirement(element.Element):
+class DataRequirement(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -84,8 +84,8 @@ class DataRequirement(element.Element):
             "required for this element, only that the consuming system must "
             "understand the element and be able to provide values for it if they "
             "are available.   The value of mustSupport SHALL be a FHIRPath "
-            "resolveable on the type of the DataRequirement. The path SHALL consist"
-            " only of identifiers, constant indexers, and .resolve() (see the "
+            "resolvable on the type of the DataRequirement. The path SHALL consist "
+            "only of identifiers, constant indexers, and .resolve() (see the "
             "[Simple FHIRPath Profile](fhirpath.html#simple) for full details)."
         ),
         # if property is element of this resource.
@@ -176,6 +176,20 @@ class DataRequirement(element.Element):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    valueFilter: typing.List[fhirtypes.DataRequirementValueFilterType] = Field(
+        None,
+        alias="valueFilter",
+        title="What values are expected",
+        description=(
+            "Value filters specify additional constraints on the data for elements "
+            "other than code-valued or date-valued. Each value filter specifies an "
+            "additional constraint on the data (i.e. valueFilters are AND'ed, not "
+            "OR'ed)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -192,6 +206,7 @@ class DataRequirement(element.Element):
             "mustSupport",
             "codeFilter",
             "dateFilter",
+            "valueFilter",
             "limit",
             "sort",
         ]
@@ -329,14 +344,14 @@ class DataRequirementCodeFilter(element.Element):
         title="A code-valued attribute to filter on",
         description=(
             "The code-valued attribute of the filter. The specified path SHALL be a"
-            " FHIRPath resolveable on the specified type of the DataRequirement, "
-            "and SHALL consist only of identifiers, constant indexers, and "
-            ".resolve(). The path is allowed to contain qualifiers (.) to traverse "
-            "sub-elements, as well as indexers ([x]) to traverse multiple-"
-            "cardinality sub-elements (see the [Simple FHIRPath "
-            "Profile](fhirpath.html#simple) for full details). Note that the index "
-            "must be an integer constant. The path must resolve to an element of "
-            "type code, Coding, or CodeableConcept."
+            " FHIRPath resolvable on the specified type of the DataRequirement, and"
+            " SHALL consist only of identifiers, constant indexers, and .resolve()."
+            " The path is allowed to contain qualifiers (.) to traverse sub-"
+            "elements, as well as indexers ([x]) to traverse multiple-cardinality "
+            "sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) "
+            "for full details). Note that the index must be an integer constant. "
+            "The path must resolve to an element of type code, Coding, or "
+            "CodeableConcept."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -364,7 +379,7 @@ class DataRequirementCodeFilter(element.Element):
     valueSet: fhirtypes.Canonical = Field(
         None,
         alias="valueSet",
-        title="Valueset for the filter",
+        title="ValueSet for the filter",
         description=(
             "The valueset for the code filter. The valueSet and code elements are "
             "additive. If valueSet is specified, the filter will return only those "
@@ -408,14 +423,14 @@ class DataRequirementDateFilter(element.Element):
         title="A date-valued attribute to filter on",
         description=(
             "The date-valued attribute of the filter. The specified path SHALL be a"
-            " FHIRPath resolveable on the specified type of the DataRequirement, "
-            "and SHALL consist only of identifiers, constant indexers, and "
-            ".resolve(). The path is allowed to contain qualifiers (.) to traverse "
-            "sub-elements, as well as indexers ([x]) to traverse multiple-"
-            "cardinality sub-elements (see the [Simple FHIRPath "
-            "Profile](fhirpath.html#simple) for full details). Note that the index "
-            "must be an integer constant. The path must resolve to an element of "
-            "type date, dateTime, Period, Schedule, or Timing."
+            " FHIRPath resolvable on the specified type of the DataRequirement, and"
+            " SHALL consist only of identifiers, constant indexers, and .resolve()."
+            " The path is allowed to contain qualifiers (.) to traverse sub-"
+            "elements, as well as indexers ([x]) to traverse multiple-cardinality "
+            "sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) "
+            "for full details). Note that the index must be an integer constant. "
+            "The path must resolve to an element of type date, dateTime, Period, "
+            "Schedule, or Timing."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -672,3 +687,166 @@ class DataRequirementSort(element.Element):
             raise ValidationError(errors, cls)  # type: ignore
 
         return values
+
+
+class DataRequirementValueFilter(element.Element):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    What values are expected.
+    Value filters specify additional constraints on the data for elements other
+    than code-valued or date-valued. Each value filter specifies an additional
+    constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
+    """
+
+    resource_type = Field("DataRequirementValueFilter", const=True)
+
+    comparator: fhirtypes.Code = Field(
+        None,
+        alias="comparator",
+        title="eq | gt | lt | ge | le | sa | eb",
+        description="The comparator to be used to determine whether the value is matching.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["eq", "gt", "lt", "ge", "le", "sa", "eb"],
+    )
+    comparator__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_comparator", title="Extension field for ``comparator``."
+    )
+
+    path: fhirtypes.String = Field(
+        None,
+        alias="path",
+        title="An attribute to filter on",
+        description=(
+            "The attribute of the filter. The specified path SHALL be a FHIRPath "
+            "resolvable on the specified type of the DataRequirement, and SHALL "
+            "consist only of identifiers, constant indexers, and .resolve(). The "
+            "path is allowed to contain qualifiers (.) to traverse sub-elements, as"
+            " well as indexers ([x]) to traverse multiple-cardinality sub-elements "
+            "(see the [Simple FHIRPath Profile](fhirpath.html#simple) for full "
+            "details). Note that the index must be an integer constant. The path "
+            "must resolve to an element of a type that is comparable to the "
+            "valueFilter.value[x] element for the filter."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    path__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_path", title="Extension field for ``path``."
+    )
+
+    searchParam: fhirtypes.String = Field(
+        None,
+        alias="searchParam",
+        title="A parameter to search on",
+        description=(
+            "A search parameter defined on the specified type of the "
+            "DataRequirement, and which searches on elements of a type compatible "
+            "with the type of the valueFilter.value[x] for the filter."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    searchParam__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_searchParam", title="Extension field for ``searchParam``."
+    )
+
+    valueDateTime: fhirtypes.DateTime = Field(
+        None,
+        alias="valueDateTime",
+        title="The value of the filter, as a Period, DateTime, or Duration value",
+        description="The value of the filter.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+    valueDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueDateTime", title="Extension field for ``valueDateTime``."
+    )
+
+    valueDuration: fhirtypes.DurationType = Field(
+        None,
+        alias="valueDuration",
+        title="The value of the filter, as a Period, DateTime, or Duration value",
+        description="The value of the filter.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
+    valuePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="valuePeriod",
+        title="The value of the filter, as a Period, DateTime, or Duration value",
+        description="The value of the filter.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DataRequirementValueFilter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "path",
+            "searchParam",
+            "comparator",
+            "valueDateTime",
+            "valuePeriod",
+            "valueDuration",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2852(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "value": ["valueDateTime", "valueDuration", "valuePeriod"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
