@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DetectedIssue
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -24,7 +24,7 @@ class DetectedIssue(domainresource.DomainResource):
     Indicates an actual or potential clinical issue with or between one or more
     active or proposed clinical actions for a patient; e.g. Drug-drug
     interaction, Ineffective treatment frequency, Procedure-condition conflict,
-    etc.
+    gaps in care, etc.
     """
 
     resource_type = Field("DetectedIssue", const=True)
@@ -41,19 +41,36 @@ class DetectedIssue(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole", "Device"],
+        enum_reference_types=[
+            "Patient",
+            "RelatedPerson",
+            "Practitioner",
+            "PractitionerRole",
+            "Device",
+        ],
+    )
+
+    category: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="category",
+        title="Type of detected issue, e.g. drug-drug, duplicate therapy, etc",
+        description="A code that classifies the general type of detected issue.",
+        # if property is element of this resource.
+        element_property=True,
     )
 
     code: fhirtypes.CodeableConceptType = Field(
         None,
         alias="code",
-        title="Issue Category, e.g. drug-drug, duplicate therapy, etc.",
-        description="Identifies the general type of issue identified.",
+        title=(
+            "Specific type of detected issue, e.g. drug-drug, duplicate therapy, " "etc"
+        ),
+        description="Identifies the specific type of issue identified.",
         # if property is element of this resource.
         element_property=True,
     )
 
-    detail: fhirtypes.String = Field(
+    detail: fhirtypes.Markdown = Field(
         None,
         alias="detail",
         title="Description and context",
@@ -65,6 +82,17 @@ class DetectedIssue(domainresource.DomainResource):
         None, alias="_detail", title="Extension field for ``detail``."
     )
 
+    encounter: fhirtypes.ReferenceType = Field(
+        None,
+        alias="encounter",
+        title="Encounter detected issue is part of",
+        description="The encounter during which this issue was detected.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Encounter"],
+    )
+
     evidence: typing.List[fhirtypes.DetectedIssueEvidenceType] = Field(
         None,
         alias="evidence",
@@ -144,20 +172,6 @@ class DetectedIssue(domainresource.DomainResource):
         element_property=True,
     )
 
-    patient: fhirtypes.ReferenceType = Field(
-        None,
-        alias="patient",
-        title="Associated patient",
-        description=(
-            "Indicates the patient whose record the detected issue is associated "
-            "with."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient"],
-    )
-
     reference: fhirtypes.Uri = Field(
         None,
         alias="reference",
@@ -194,19 +208,45 @@ class DetectedIssue(domainresource.DomainResource):
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title="registered | preliminary | final | amended +",
+        title="preliminary | final | entered-in-error | mitigated",
         description="Indicates the status of the detected issue.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["registered", "preliminary", "final", "amended", "+"],
+        enum_values=["preliminary", "final", "entered-in-error", "mitigated"],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    subject: fhirtypes.ReferenceType = Field(
+        None,
+        alias="subject",
+        title="Associated subject",
+        description=(
+            "Indicates the subject whose record the detected issue is associated "
+            "with."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "Device",
+            "Location",
+            "Organization",
+            "Procedure",
+            "Practitioner",
+            "Medication",
+            "Substance",
+            "BiologicallyDerivedProduct",
+            "NutritionProduct",
+        ],
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -224,9 +264,11 @@ class DetectedIssue(domainresource.DomainResource):
             "modifierExtension",
             "identifier",
             "status",
+            "category",
             "code",
             "severity",
-            "patient",
+            "subject",
+            "encounter",
             "identifiedDateTime",
             "identifiedPeriod",
             "author",
@@ -431,10 +473,32 @@ class DetectedIssueMitigation(backboneelement.BackboneElement):
         None, alias="_date", title="Extension field for ``date``."
     )
 
+    note: typing.List[fhirtypes.AnnotationType] = Field(
+        None,
+        alias="note",
+        title="Additional notes about the mitigation",
+        description=(
+            "Clinicians may add additional notes or justifications about the "
+            "mitigation action. For example, patient can have this drug because "
+            "they have had it before without any issues. Multiple justifications "
+            "may be provided."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
         ``DetectedIssueMitigation`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "action", "date", "author"]
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "action",
+            "date",
+            "author",
+            "note",
+        ]
