@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DeviceMetric
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,13 +16,12 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class DeviceMetric(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     Measurement, calculation or setting capability of a medical device.
-    Describes a measurement, calculation or setting capability of a medical
-    device.
+    Describes a measurement, calculation or setting capability of a device.
     """
 
     resource_type = Field("DeviceMetric", const=True)
@@ -62,60 +61,62 @@ class DeviceMetric(domainresource.DomainResource):
     color: fhirtypes.Code = Field(
         None,
         alias="color",
-        title="black | red | green | yellow | blue | magenta | cyan | white",
+        title="Color name (from CSS4) or #RRGGBB code",
         description=(
-            "Describes the color representation for the metric. This is often used "
-            "to aid clinicians to track and identify parameter types by color. In "
-            "practice, consider a Patient Monitor that has ECG/HR and Pleth for "
-            "example; the parameters are displayed in different characteristic "
-            "colors, such as HR-blue, BP-green, and PR and SpO2- magenta."
+            "The preferred color associated with the metric (e.g., display color). "
+            "This is often used to aid clinicians to track and identify parameter "
+            "types by color. In practice, consider a Patient Monitor that has "
+            "ECG/HR and Pleth; the metrics are displayed in different "
+            "characteristic colors, such as HR in blue, BP in green, and PR and "
+            "SpO2 in magenta."
         ),
         # if property is element of this resource.
         element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "black",
-            "red",
-            "green",
-            "yellow",
-            "blue",
-            "magenta",
-            "cyan",
-            "white",
-        ],
     )
     color__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_color", title="Extension field for ``color``."
     )
 
+    device: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="device",
+        title="Describes the link to the Device",
+        description=(
+            "Describes the link to the Device.  This is also known as a channel "
+            "device."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Device"],
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
         title="Instance identifier",
         description=(
-            "Unique instance identifiers assigned to a device by the device or "
-            "gateway software, manufacturers, other organizations or owners. For "
-            "example: handle ID."
+            "Instance identifiers assigned to a device, by the device or gateway "
+            "software, manufacturers, other organizations or owners. For example, "
+            "handle ID."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    measurementPeriod: fhirtypes.TimingType = Field(
+    measurementFrequency: fhirtypes.QuantityType = Field(
         None,
-        alias="measurementPeriod",
-        title="Describes the measurement repetition time",
+        alias="measurementFrequency",
+        title="Indicates how often the metric is taken or recorded",
         description=(
-            "Describes the measurement repetition time. This is not necessarily the"
-            " same as the update period. The measurement repetition time can range "
-            "from milliseconds up to hours. An example for a measurement repetition"
-            " time in the range of milliseconds is the sampling rate of an ECG. An "
-            "example for a measurement repetition time in the range of hours is a "
-            "NIBP that is triggered automatically every hour. The update period may"
-            " be different than the measurement repetition time, if the device does"
-            " not update the published observed value with the same frequency as it"
-            " was measured."
+            "The frequency at which the metric is taken or recorded. Devices "
+            "measure metrics at a wide range of frequencies; for example, an ECG "
+            "might sample measurements in the millisecond range, while an NIBP "
+            "might trigger only once an hour. Less often, the measurementFrequency "
+            "may be based on a unit other than time, such as distance (e.g. for a "
+            "measuring wheel). The update period may be different than the "
+            "measurement frequency, if the device does not update the published "
+            "observed value with the same frequency as it was measured."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -141,39 +142,6 @@ class DeviceMetric(domainresource.DomainResource):
         title="Extension field for ``operationalStatus``.",
     )
 
-    parent: fhirtypes.ReferenceType = Field(
-        None,
-        alias="parent",
-        title="Describes the link to the parent Device",
-        description=(
-            "Describes the link to the  Device that this DeviceMetric belongs to "
-            "and that provide information about the location of this DeviceMetric "
-            "in the containment structure of the parent Device. An example would be"
-            " a Device that represents a Channel. This reference can be used by a "
-            "client application to distinguish DeviceMetrics that have the same "
-            "type, but should be interpreted based on their containment location."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Device"],
-    )
-
-    source: fhirtypes.ReferenceType = Field(
-        None,
-        alias="source",
-        title="Describes the link to the source Device",
-        description=(
-            "Describes the link to the  Device that this DeviceMetric belongs to "
-            "and that contains administrative device information such as "
-            "manufacturer, serial number, etc."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Device"],
-    )
-
     type: fhirtypes.CodeableConceptType = Field(
         ...,
         alias="type",
@@ -198,6 +166,32 @@ class DeviceMetric(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DeviceMetric`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "type",
+            "unit",
+            "device",
+            "operationalStatus",
+            "color",
+            "category",
+            "measurementFrequency",
+            "calibration",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1371(
         cls, values: typing.Dict[str, typing.Any]
@@ -259,7 +253,7 @@ class DeviceMetric(domainresource.DomainResource):
 
 
 class DeviceMetricCalibration(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -315,3 +309,11 @@ class DeviceMetricCalibration(backboneelement.BackboneElement):
     type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_type", title="Extension field for ``type``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DeviceMetricCalibration`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "state", "time"]
