@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DeviceRequest
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -28,6 +28,30 @@ class DeviceRequest(domainresource.DomainResource):
 
     resource_type = Field("DeviceRequest", const=True)
 
+    asNeeded: bool = Field(
+        None,
+        alias="asNeeded",
+        title="PRN status of request",
+        description=(
+            "This status is to indicate whether the request is a PRN or may be "
+            "given as needed."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    asNeeded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_asNeeded", title="Extension field for ``asNeeded``."
+    )
+
+    asNeededFor: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="asNeededFor",
+        title="Device usage reason",
+        description="The reason for using the device.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     authoredOn: fhirtypes.DateTime = Field(
         None,
         alias="authoredOn",
@@ -51,30 +75,33 @@ class DeviceRequest(domainresource.DomainResource):
         enum_reference_types=["Resource"],
     )
 
-    codeCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="codeCodeableConcept",
+    code: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="code",
         title="Device requested",
         description="The details of the device to be used.",
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e code[x]
-        one_of_many="code",
-        one_of_many_required=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Device", "DeviceDefinition"],
     )
 
-    codeReference: fhirtypes.ReferenceType = Field(
+    doNotPerform: bool = Field(
         None,
-        alias="codeReference",
-        title="Device requested",
-        description="The details of the device to be used.",
+        alias="doNotPerform",
+        title="True if the request is to stop or not to start using the device",
+        description=(
+            "If true, indicates that the provider is asking for the patient to "
+            "either stop using or to not start using the specified device or "
+            "category of devices. For example, the patient has undergone surgery "
+            "and the provider is indicating that the patient should not wear "
+            "contact lenses."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e code[x]
-        one_of_many="code",
-        one_of_many_required=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Device"],
+    )
+    doNotPerform__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_doNotPerform", title="Extension field for ``doNotPerform``."
     )
 
     encounter: fhirtypes.ReferenceType = Field(
@@ -95,7 +122,15 @@ class DeviceRequest(domainresource.DomainResource):
         None,
         alias="groupIdentifier",
         title="Identifier of composite request",
-        description="Composite request this is part of.",
+        description=(
+            "A shared identifier common to multiple independent Request instances "
+            "that were activated/authorized more or less simultaneously by a single"
+            " author.  The presence of the same identifier on each request ties "
+            "those requests together and may have business ramifications in terms "
+            "of reporting of results, billing, etc.  E.g. a requisition number "
+            "shared by a set of lab tests ordered together, or a prescription "
+            "number shared by all meds ordered at one time."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -109,7 +144,7 @@ class DeviceRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -131,7 +166,7 @@ class DeviceRequest(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
@@ -278,11 +313,14 @@ class DeviceRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    performer: fhirtypes.ReferenceType = Field(
+    performer: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="performer",
         title="Requested Filler",
-        description="The desired performer for doing the diagnostic testing.",
+        description=(
+            "The desired individual or entity to provide the device to the subject "
+            "of the request (e.g., patient, location)."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -298,36 +336,13 @@ class DeviceRequest(domainresource.DomainResource):
         ],
     )
 
-    performerType: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="performerType",
-        title="Filler role",
-        description="Desired type of performer for doing the diagnostic testing.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    priorRequest: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="priorRequest",
-        title="What request replaces",
-        description=(
-            "The request takes the place of the referenced completed or terminated "
-            "request(s)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Resource"],
-    )
-
     priority: fhirtypes.Code = Field(
         None,
         alias="priority",
         title="routine | urgent | asap | stat",
         description=(
-            "Indicates how quickly the {{title}} should be addressed with respect "
-            "to other requests."
+            "Indicates how quickly the request should be addressed with respect to "
+            "other requests."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -339,19 +354,22 @@ class DeviceRequest(domainresource.DomainResource):
         None, alias="_priority", title="Extension field for ``priority``."
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    quantity: fhirtypes.Integer = Field(
         None,
-        alias="reasonCode",
-        title="Coded Reason for request",
-        description="Reason or justification for the use of this device.",
+        alias="quantity",
+        title="Quantity of devices to supply",
+        description="The number of devices to be provided.",
         # if property is element of this resource.
         element_property=True,
     )
+    quantity__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_quantity", title="Extension field for ``quantity``."
+    )
 
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonReference",
-        title="Linked Reason for request",
+        alias="reason",
+        title="Coded/Linked Reason for request",
         description="Reason or justification for the use of this device.",
         # if property is element of this resource.
         element_property=True,
@@ -375,13 +393,27 @@ class DeviceRequest(domainresource.DomainResource):
         enum_reference_types=["Provenance"],
     )
 
+    replaces: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="replaces",
+        title="What request replaces",
+        description=(
+            "The request takes the place of the referenced completed or terminated "
+            "request(s)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["DeviceRequest"],
+    )
+
     requester: fhirtypes.ReferenceType = Field(
         None,
         alias="requester",
-        title="Who/what is requesting diagnostics",
+        title="Who/what submitted the device request",
         description=(
-            "The individual who initiated the request and has responsibility for "
-            "its activation."
+            "The individual or entity who initiated the request and has "
+            "responsibility for its activation."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -465,13 +497,14 @@ class DeviceRequest(domainresource.DomainResource):
             "instantiatesCanonical",
             "instantiatesUri",
             "basedOn",
-            "priorRequest",
+            "replaces",
             "groupIdentifier",
             "status",
             "intent",
             "priority",
-            "codeReference",
-            "codeCodeableConcept",
+            "doNotPerform",
+            "code",
+            "quantity",
             "parameter",
             "subject",
             "encounter",
@@ -480,10 +513,10 @@ class DeviceRequest(domainresource.DomainResource):
             "occurrenceTiming",
             "authoredOn",
             "requester",
-            "performerType",
             "performer",
-            "reasonCode",
-            "reasonReference",
+            "reason",
+            "asNeeded",
+            "asNeededFor",
             "insurance",
             "supportingInfo",
             "note",
@@ -566,12 +599,7 @@ class DeviceRequest(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "code": ["codeCodeableConcept", "codeReference"],
-            "occurrence": [
-                "occurrenceDateTime",
-                "occurrencePeriod",
-                "occurrenceTiming",
-            ],
+            "occurrence": ["occurrenceDateTime", "occurrencePeriod", "occurrenceTiming"]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
