@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DiagnosticReport
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -22,11 +22,13 @@ class DiagnosticReport(domainresource.DomainResource):
 
     A Diagnostic report - a combination of request information, atomic results,
     images, interpretation, as well as formatted reports.
-    The findings and interpretation of diagnostic  tests performed on patients,
-    groups of patients, devices, and locations, and/or specimens derived from
-    these. The report includes clinical context such as requesting and provider
-    information, and some mix of atomic results, images, textual and coded
-    interpretations, and formatted representation of diagnostic reports.
+    The findings and interpretation of diagnostic tests performed on patients,
+    groups of patients, products, substances, devices, and locations, and/or
+    specimens derived from these. The report includes clinical context such as
+    requesting provider information, and some mix of atomic results, images,
+    textual and coded interpretations, and formatted representation of
+    diagnostic reports. The report also includes non-clinical context such as
+    batch analysis and stability reporting of products and substances.
     """
 
     resource_type = Field("DiagnosticReport", const=True)
@@ -71,7 +73,21 @@ class DiagnosticReport(domainresource.DomainResource):
         element_property=True,
     )
 
-    conclusion: fhirtypes.String = Field(
+    composition: fhirtypes.ReferenceType = Field(
+        None,
+        alias="composition",
+        title="Reference to a Composition resource for the DiagnosticReport structure",
+        description=(
+            "Reference to a Composition resource instance that provides structure "
+            "for organizing the contents of the DiagnosticReport."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Composition"],
+    )
+
+    conclusion: fhirtypes.Markdown = Field(
         None,
         alias="conclusion",
         title="Clinical conclusion (interpretation) of test results",
@@ -160,26 +176,6 @@ class DiagnosticReport(domainresource.DomainResource):
         element_property=True,
     )
 
-    imagingStudy: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="imagingStudy",
-        title=(
-            "Reference to full details of imaging associated with the diagnostic "
-            "report"
-        ),
-        description=(
-            "One or more links to full details of any imaging performed during the "
-            "diagnostic investigation. Typically, this is imaging performed by "
-            "DICOM enabled modalities, but this is not required. A fully enabled "
-            "PACS viewer can use this information to provide views of the source "
-            "images."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["ImagingStudy"],
-    )
-
     issued: fhirtypes.Instant = Field(
         None,
         alias="issued",
@@ -198,16 +194,26 @@ class DiagnosticReport(domainresource.DomainResource):
     media: typing.List[fhirtypes.DiagnosticReportMediaType] = Field(
         None,
         alias="media",
-        title="Key images associated with this report",
+        title="Key images or data associated with this report",
         description=(
-            "A list of key images associated with this report. The images are "
-            "generally created during the diagnostic process, and may be directly "
-            "of the patient, or of treated specimens (i.e. slides of interest)."
+            "A list of key images or data associated with this report. The images "
+            "or data are generally created during the diagnostic process, and may "
+            "be directly of the patient, or of treated specimens (i.e. slides of "
+            "interest)."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
+    note: typing.List[fhirtypes.AnnotationType] = Field(
+        None,
+        alias="note",
+        title="Comments about the diagnostic report",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     performer: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="performer",
@@ -284,19 +290,59 @@ class DiagnosticReport(domainresource.DomainResource):
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title="registered | partial | preliminary | final +",
+        title=(
+            "registered | partial | preliminary | modified | final | amended | "
+            "corrected | appended | cancelled | entered-in-error | unknown"
+        ),
         description="The status of the diagnostic report.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["registered", "partial", "preliminary", "final", "+"],
+        enum_values=[
+            "registered",
+            "partial",
+            "preliminary",
+            "modified",
+            "final",
+            "amended",
+            "corrected",
+            "appended",
+            "cancelled",
+            "entered-in-error",
+            "unknown",
+        ],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    study: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="study",
+        title=(
+            "Reference to full details of an analysis associated with the "
+            "diagnostic report"
+        ),
+        description=(
+            "One or more links to full details of any study performed during the "
+            "diagnostic investigation. An ImagingStudy might comprise a set of "
+            "radiologic images obtained via a procedure that are analyzed as a "
+            "group. Typically, this is imaging performed by DICOM enabled "
+            "modalities, but this is not required. A fully enabled PACS viewer can "
+            "use this information to provide views of the source images. A "
+            "GenomicStudy might comprise one or more analyses, each serving a "
+            "specific purpose. These analyses may vary in method (e.g., "
+            "karyotyping, CNV, or SNV detection), performer, software, devices "
+            "used, or regions targeted."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["GenomicStudy", "ImagingStudy"],
+    )
+
     subject: fhirtypes.ReferenceType = Field(
         None,
         alias="subject",
@@ -309,7 +355,30 @@ class DiagnosticReport(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient", "Group", "Device", "Location"],
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "Device",
+            "Location",
+            "Organization",
+            "Practitioner",
+            "Medication",
+            "Substance",
+            "BiologicallyDerivedProduct",
+        ],
+    )
+
+    supportingInfo: typing.List[fhirtypes.DiagnosticReportSupportingInfoType] = Field(
+        None,
+        alias="supportingInfo",
+        title="Additional information supporting the diagnostic report",
+        description=(
+            "This backbone element contains supporting information that was used in"
+            " the creation of the report not included in the results already "
+            "included in the report."
+        ),
+        # if property is element of this resource.
+        element_property=True,
     )
 
     @classmethod
@@ -341,8 +410,11 @@ class DiagnosticReport(domainresource.DomainResource):
             "resultsInterpreter",
             "specimen",
             "result",
-            "imagingStudy",
+            "note",
+            "study",
+            "supportingInfo",
             "media",
+            "composition",
             "conclusion",
             "conclusionCode",
             "presentedForm",
@@ -451,10 +523,10 @@ class DiagnosticReportMedia(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Key images associated with this report.
-    A list of key images associated with this report. The images are generally
-    created during the diagnostic process, and may be directly of the patient,
-    or of treated specimens (i.e. slides of interest).
+    Key images or data associated with this report.
+    A list of key images or data associated with this report. The images or
+    data are generally created during the diagnostic process, and may be
+    directly of the patient, or of treated specimens (i.e. slides of interest).
     """
 
     resource_type = Field("DiagnosticReportMedia", const=True)
@@ -462,11 +534,11 @@ class DiagnosticReportMedia(backboneelement.BackboneElement):
     comment: fhirtypes.String = Field(
         None,
         alias="comment",
-        title="Comment about the image (e.g. explanation)",
+        title="Comment about the image or data (e.g. explanation)",
         description=(
-            "A comment about the image. Typically, this is used to provide an "
-            "explanation for why the image is included, or to draw the viewer's "
-            "attention to important features."
+            "A comment about the image or data. Typically, this is used to provide "
+            "an explanation for why the image or data is included, or to draw the "
+            "viewer's attention to important features."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -478,12 +550,12 @@ class DiagnosticReportMedia(backboneelement.BackboneElement):
     link: fhirtypes.ReferenceType = Field(
         ...,
         alias="link",
-        title="Reference to the image source",
+        title="Reference to the image or data source",
         description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Media"],
+        enum_reference_types=["DocumentReference"],
     )
 
     @classmethod
@@ -493,3 +565,53 @@ class DiagnosticReportMedia(backboneelement.BackboneElement):
         with preserving original sequence order.
         """
         return ["id", "extension", "modifierExtension", "comment", "link"]
+
+
+class DiagnosticReportSupportingInfo(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Additional information supporting the diagnostic report.
+    This backbone element contains supporting information that was used in the
+    creation of the report not included in the results already included in the
+    report.
+    """
+
+    resource_type = Field("DiagnosticReportSupportingInfo", const=True)
+
+    reference: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="reference",
+        title="Supporting information reference",
+        description="The reference for the supporting information in the diagnostic report.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Procedure",
+            "Observation",
+            "DiagnosticReport",
+            "Citation",
+        ],
+    )
+
+    type: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="type",
+        title="Supporting information role code",
+        description=(
+            "The code value for the role of the supporting information in the "
+            "diagnostic report."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DiagnosticReportSupportingInfo`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "reference"]
