@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DomainResource
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -31,7 +31,9 @@ class DomainResource(resource.Resource):
         description=(
             "These resources do not have an independent existence apart from the "
             "resource that contains them - they cannot be identified independently,"
-            " and nor can they have their own independent transaction scope."
+            " nor can they have their own independent transaction scope. This is "
+            "allowed to be a Parameters resource if and only if it is referenced by"
+            " a resource that provides context/meaning."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -44,10 +46,10 @@ class DomainResource(resource.Resource):
         description=(
             "May be used to represent additional information that is not part of "
             "the basic definition of the resource. To make the use of extensions "
-            "safe and manageable, there is a strict set of governance  applied to "
-            "the definition and use of extensions. Though any implementer can "
-            "define an extension, there is a set of requirements that SHALL be met "
-            "as part of the definition of the extension."
+            "safe and managable, there is a strict set of governance applied to the"
+            " definition and use of extensions. Though any implementer can define "
+            "an extension, there is a set of requirements that SHALL be met as part"
+            " of the definition of the extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -63,7 +65,7 @@ class DomainResource(resource.Resource):
             "understanding of the element that contains it and/or the understanding"
             " of the containing element's descendants. Usually modifier elements "
             "provide negation or qualification. To make the use of extensions safe "
-            "and manageable, there is a strict set of governance applied to the "
+            "and managable, there is a strict set of governance applied to the "
             "definition and use of extensions. Though any implementer is allowed to"
             " define an extension, there is a set of requirements that SHALL be met"
             " as part of the definition of the extension. Applications processing a"
