@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Dosage
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
 from pydantic import Field, root_validator
 
-from . import backboneelement, element, fhirtypes
+from . import backbonetype, element, fhirtypes
 
 
-class Dosage(backboneelement.BackboneElement):
+class Dosage(backbonetype.BackboneType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -43,46 +43,45 @@ class Dosage(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    asNeededBoolean: bool = Field(
+    asNeeded: bool = Field(
         None,
-        alias="asNeededBoolean",
-        title='Take "as needed" (for x)',
+        alias="asNeeded",
+        title='Take "as needed"',
         description=(
             "Indicates whether the Medication is only taken when needed within a "
-            "specific dosing schedule (Boolean option), or it indicates the "
-            "precondition for taking the Medication (CodeableConcept)."
+            "specific dosing schedule (Boolean option)."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e asNeeded[x]
-        one_of_many="asNeeded",
-        one_of_many_required=False,
     )
-    asNeededBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_asNeededBoolean", title="Extension field for ``asNeededBoolean``."
+    asNeeded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_asNeeded", title="Extension field for ``asNeeded``."
     )
 
-    asNeededCodeableConcept: fhirtypes.CodeableConceptType = Field(
+    asNeededFor: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
-        alias="asNeededCodeableConcept",
+        alias="asNeededFor",
         title='Take "as needed" (for x)',
         description=(
-            "Indicates whether the Medication is only taken when needed within a "
-            "specific dosing schedule (Boolean option), or it indicates the "
-            "precondition for taking the Medication (CodeableConcept)."
+            "Indicates whether the Medication is only taken based on a precondition"
+            " for taking the Medication (CodeableConcept)."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e asNeeded[x]
-        one_of_many="asNeeded",
-        one_of_many_required=False,
     )
 
     doseAndRate: typing.List[fhirtypes.DosageDoseAndRateType] = Field(
         None,
         alias="doseAndRate",
-        title="Amount of medication administered",
-        description="The amount of medication administered.",
+        title=(
+            "Amount of medication administered, to be administered or typical "
+            "amount to be administered"
+        ),
+        description=(
+            "Depending on the resource,this is the amount of medication "
+            "administered, to  be administered or typical amount to be "
+            "administered."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -105,7 +104,7 @@ class Dosage(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    maxDosePerPeriod: fhirtypes.RatioType = Field(
+    maxDosePerPeriod: typing.List[fhirtypes.RatioType] = Field(
         None,
         alias="maxDosePerPeriod",
         title="Upper limit on medication per unit of time",
@@ -206,8 +205,8 @@ class Dosage(backboneelement.BackboneElement):
             "additionalInstruction",
             "patientInstruction",
             "timing",
-            "asNeededBoolean",
-            "asNeededCodeableConcept",
+            "asNeeded",
+            "asNeededFor",
             "site",
             "route",
             "method",
@@ -217,54 +216,16 @@ class Dosage(backboneelement.BackboneElement):
             "maxDosePerLifetime",
         ]
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_764(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {
-            "asNeeded": ["asNeededBoolean", "asNeededCodeableConcept"]
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
 
 class DosageDoseAndRate(element.Element):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Amount of medication administered.
-    The amount of medication administered.
+    Amount of medication administered, to be administered or typical amount to
+    be administered.
+    Depending on the resource,this is the amount of medication administered, to
+    be administered or typical amount to be administered.
     """
 
     resource_type = Field("DosageDoseAndRate", const=True)
