@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Encounter
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,14 +16,16 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Encounter(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     An interaction during which services are provided to the patient.
     An interaction between a patient and healthcare provider(s) for the purpose
     of providing healthcare service(s) or assessing the health status of a
-    patient.
+    patient.  Encounter is primarily used to record information about the
+    actual activities that occurred, where Appointment is used to record
+    planned activities.
     """
 
     resource_type = Field("Encounter", const=True)
@@ -39,6 +41,29 @@ class Encounter(domainresource.DomainResource):
         enum_reference_types=["Account"],
     )
 
+    actualPeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="actualPeriod",
+        title="The actual start and end time of the encounter",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    admission: fhirtypes.EncounterAdmissionType = Field(
+        None,
+        alias="admission",
+        title="Details about the admission to a healthcare service",
+        description=(
+            "Details about the stay during which a healthcare service is provided."
+            "  This does not describe the event of admitting the patient, but "
+            "rather any information that is relevant from the time of admittance "
+            "until the time of discharge."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     appointment: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="appointment",
@@ -53,7 +78,7 @@ class Encounter(domainresource.DomainResource):
     basedOn: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="basedOn",
-        title="The ServiceRequest that initiated this encounter",
+        title="The request that initiated this encounter",
         description=(
             "The request this encounter satisfies (e.g. incoming referral or "
             "procedure request)."
@@ -61,31 +86,37 @@ class Encounter(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["ServiceRequest"],
+        enum_reference_types=[
+            "CarePlan",
+            "DeviceRequest",
+            "MedicationRequest",
+            "ServiceRequest",
+        ],
     )
 
-    classHistory: typing.List[fhirtypes.EncounterClassHistoryType] = Field(
+    careTeam: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="classHistory",
-        title="List of past encounter classes",
+        alias="careTeam",
+        title="The group(s) that are allocated to participate in this encounter",
         description=(
-            "The class history permits the tracking of the encounters transitions "
-            "without needing to go  through the resource history.  This would be "
-            "used for a case where an admission starts of as an emergency "
-            "encounter, then transitions into an inpatient scenario. Doing this and"
-            " not restarting a new encounter ensures that any lab/diagnostic "
-            "results can more easily follow the patient and not require re-"
-            "processing and not get lost or cancelled during a kind of discharge "
-            "from emergency to inpatient."
+            "The group(s) of individuals, organizations that are allocated to "
+            "participate in this encounter. The participants backbone will record "
+            "the actuals of when these individuals participated during the "
+            "encounter."
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["CareTeam"],
     )
 
-    class_fhir: fhirtypes.CodingType = Field(
-        ...,
+    class_fhir: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
         alias="class",
-        title="Classification of patient encounter",
+        title=(
+            "Classification of patient encounter context - e.g. Inpatient, "
+            "outpatient"
+        ),
         description=(
             "Concepts representing classification of patient encounter such as "
             "ambulatory (outpatient), inpatient, emergency, home health or others "
@@ -104,6 +135,15 @@ class Encounter(domainresource.DomainResource):
         element_property=True,
     )
 
+    dietPreference: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="dietPreference",
+        title="Diet preferences reported by the patient",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     episodeOfCare: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="episodeOfCare",
@@ -124,15 +164,6 @@ class Encounter(domainresource.DomainResource):
         enum_reference_types=["EpisodeOfCare"],
     )
 
-    hospitalization: fhirtypes.EncounterHospitalizationType = Field(
-        None,
-        alias="hospitalization",
-        title="Details about the admission to a healthcare service",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -145,10 +176,11 @@ class Encounter(domainresource.DomainResource):
     length: fhirtypes.DurationType = Field(
         None,
         alias="length",
-        title="Quantity of time the encounter lasted (less time absent)",
+        title="Actual quantity of time the encounter lasted (less time absent)",
         description=(
-            "Quantity of time the encounter lasted. This excludes the time during "
-            "leaves of absence."
+            "Actual quantity of time the encounter lasted. This excludes the time "
+            "during leaves of absence.  When missing it is the time in between the "
+            "start and end values."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -186,14 +218,31 @@ class Encounter(domainresource.DomainResource):
         element_property=True,
     )
 
-    period: fhirtypes.PeriodType = Field(
+    plannedEndDate: fhirtypes.DateTime = Field(
         None,
-        alias="period",
-        title="The start and end time of the encounter",
+        alias="plannedEndDate",
+        title="The planned end date/time (or discharge date) of the encounter",
         description=None,
         # if property is element of this resource.
         element_property=True,
     )
+    plannedEndDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_plannedEndDate", title="Extension field for ``plannedEndDate``."
+    )
+
+    plannedStartDate: fhirtypes.DateTime = Field(
+        None,
+        alias="plannedStartDate",
+        title="The planned start date/time (or admission date) of the encounter",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    plannedStartDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_plannedStartDate",
+        title="Extension field for ``plannedStartDate``.",
+    )
 
     priority: fhirtypes.CodeableConceptType = Field(
         None,
@@ -204,37 +253,18 @@ class Encounter(domainresource.DomainResource):
         element_property=True,
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.EncounterReasonType] = Field(
         None,
-        alias="reasonCode",
-        title="Coded reason the encounter takes place",
-        description=(
-            "Reason the encounter takes place, expressed as a code. For admissions,"
-            " this can be used for a coded admission diagnosis."
+        alias="reason",
+        title=(
+            "The list of medical reasons that are expected to be addressed during "
+            "the episode of care"
         ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
     )
 
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Reason the encounter takes place (reference)",
-        description=(
-            "Reason the encounter takes place, expressed as a code. For admissions,"
-            " this can be used for a coded admission diagnosis."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Condition",
-            "Procedure",
-            "Observation",
-            "ImmunizationRecommendation",
-        ],
-    )
-
     serviceProvider: fhirtypes.ReferenceType = Field(
         None,
         alias="serviceProvider",
@@ -244,8 +274,8 @@ class Encounter(domainresource.DomainResource):
             "services. This MAY be the same as the organization on the Patient "
             "record, however it could be different, such as if the actor performing"
             " the services was from an external organization (which may be billed "
-            "seperately) for an external consultation.  Refer to the example bundle"
-            " showing an abbreviated set of Encounters for a colonoscopy."
+            "seperately) for an external consultation.  Refer to the colonoscopy "
+            "example on the Encounter examples tab."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -253,7 +283,7 @@ class Encounter(domainresource.DomainResource):
         enum_reference_types=["Organization"],
     )
 
-    serviceType: fhirtypes.CodeableConceptType = Field(
+    serviceType: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="serviceType",
         title="Specific type of service",
@@ -263,16 +293,45 @@ class Encounter(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["HealthcareService"],
+    )
+
+    specialArrangement: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="specialArrangement",
+        title="Wheelchair, translator, stretcher, etc",
+        description=(
+            "Any special requests that have been made for this encounter, such as "
+            "the provision of specific equipment or other things."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    specialCourtesy: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="specialCourtesy",
+        title="Special courtesies (VIP, board member)",
+        description=(
+            "Special courtesies that may be provided to the patient during the "
+            "encounter (VIP, board member, professional courtesy)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
     )
 
     status: fhirtypes.Code = Field(
         None,
         alias="status",
         title=(
-            "planned | arrived | triaged | in-progress | onleave | finished | "
-            "cancelled +"
+            "planned | in-progress | on-hold | discharged | completed | cancelled |"
+            " discontinued | entered-in-error | unknown"
+        ),
+        description=(
+            "The current state of the encounter (not the state of the patient "
+            "within the encounter - that is subjectState)."
         ),
-        description=None,
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -280,47 +339,55 @@ class Encounter(domainresource.DomainResource):
         # but use in your own responsibilities, read official FHIR documentation.
         enum_values=[
             "planned",
-            "arrived",
-            "triaged",
             "in-progress",
-            "onleave",
-            "finished",
+            "on-hold",
+            "discharged",
+            "completed",
             "cancelled",
-            "+",
+            "discontinued",
+            "entered-in-error",
+            "unknown",
         ],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    statusHistory: typing.List[fhirtypes.EncounterStatusHistoryType] = Field(
-        None,
-        alias="statusHistory",
-        title="List of past encounter statuses",
-        description=(
-            "The status history permits the encounter resource to contain the "
-            "status history without needing to read through the historical versions"
-            " of the resource, or even have the server store them."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     subject: fhirtypes.ReferenceType = Field(
         None,
         alias="subject",
-        title="The patient or group present at the encounter",
-        description=None,
+        title="The patient or group related to this encounter",
+        description=(
+            "The patient or group related to this encounter. In some use-cases the "
+            "patient MAY not be present, such as a case meeting about a patient "
+            "between several practitioners or a careteam."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Patient", "Group"],
     )
 
+    subjectStatus: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="subjectStatus",
+        title="The current status of the subject in relation to the Encounter",
+        description=(
+            "The subjectStatus value can be used to track the patient's status "
+            "within the encounter. It details whether the patient has arrived or "
+            "departed, has been triaged or is currently in a waiting status."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     type: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="type",
-        title="Specific type of encounter",
+        title=(
+            "Specific type of encounter (e.g. e-mail consultation, surgical day-"
+            "care, ...)"
+        ),
         description=(
             "Specific type of encounter (e.g. e-mail consultation, surgical day-"
             "care, skilled nursing, rehabilitation)."
@@ -329,6 +396,60 @@ class Encounter(domainresource.DomainResource):
         element_property=True,
     )
 
+    virtualService: typing.List[fhirtypes.VirtualServiceDetailType] = Field(
+        None,
+        alias="virtualService",
+        title="Connection details of a virtual service (e.g. conference call)",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Encounter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "class",
+            "priority",
+            "type",
+            "serviceType",
+            "subject",
+            "subjectStatus",
+            "episodeOfCare",
+            "basedOn",
+            "careTeam",
+            "partOf",
+            "serviceProvider",
+            "participant",
+            "appointment",
+            "virtualService",
+            "actualPeriod",
+            "plannedStartDate",
+            "plannedEndDate",
+            "length",
+            "reason",
+            "diagnosis",
+            "account",
+            "dietPreference",
+            "specialArrangement",
+            "specialCourtesy",
+            "admission",
+            "location",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1130(
         cls, values: typing.Dict[str, typing.Any]
@@ -389,102 +510,20 @@ class Encounter(domainresource.DomainResource):
         return values
 
 
-class EncounterClassHistory(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    List of past encounter classes.
-    The class history permits the tracking of the encounters transitions
-    without needing to go  through the resource history.  This would be used
-    for a case where an admission starts of as an emergency encounter, then
-    transitions into an inpatient scenario. Doing this and not restarting a new
-    encounter ensures that any lab/diagnostic results can more easily follow
-    the patient and not require re-processing and not get lost or cancelled
-    during a kind of discharge from emergency to inpatient.
-    """
-
-    resource_type = Field("EncounterClassHistory", const=True)
-
-    class_fhir: fhirtypes.CodingType = Field(
-        ...,
-        alias="class",
-        title="inpatient | outpatient | ambulatory | emergency +",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    period: fhirtypes.PeriodType = Field(
-        ...,
-        alias="period",
-        title="The time that the episode was in the specified class",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-
-class EncounterDiagnosis(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    The list of diagnosis relevant to this encounter.
-    """
-
-    resource_type = Field("EncounterDiagnosis", const=True)
-
-    condition: fhirtypes.ReferenceType = Field(
-        ...,
-        alias="condition",
-        title="The diagnosis or procedure relevant to the encounter",
-        description=(
-            "Reason the encounter takes place, as specified using information from "
-            "another resource. For admissions, this is the admission diagnosis. The"
-            " indication will typically be a Condition (with other resources "
-            "referenced in the evidence.detail), or a Procedure."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Condition", "Procedure"],
-    )
-
-    rank: fhirtypes.PositiveInt = Field(
-        None,
-        alias="rank",
-        title="Ranking of the diagnosis (for each role type)",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    rank__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_rank", title="Extension field for ``rank``."
-    )
-
-    use: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="use",
-        title=(
-            "Role that this diagnosis has within the encounter (e.g. admission, "
-            "billing, discharge \u2026)"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-
-class EncounterHospitalization(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+class EncounterAdmission(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     Details about the admission to a healthcare service.
+    Details about the stay during which a healthcare service is provided.
+
+    This does not describe the event of admitting the patient, but rather any
+    information that is relevant from the time of admittance until the time of
+    discharge.
     """
 
-    resource_type = Field("EncounterHospitalization", const=True)
+    resource_type = Field("EncounterAdmission", const=True)
 
     admitSource: fhirtypes.CodeableConceptType = Field(
         None,
@@ -506,15 +545,6 @@ class EncounterHospitalization(backboneelement.BackboneElement):
         enum_reference_types=["Location", "Organization"],
     )
 
-    dietPreference: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="dietPreference",
-        title="Diet preferences reported by the patient",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     dischargeDisposition: fhirtypes.CodeableConceptType = Field(
         None,
         alias="dischargeDisposition",
@@ -547,40 +577,83 @@ class EncounterHospitalization(backboneelement.BackboneElement):
     reAdmission: fhirtypes.CodeableConceptType = Field(
         None,
         alias="reAdmission",
-        title=(
-            "The type of hospital re-admission that has occurred (if any). If the "
-            "value is absent, then this is not identified as a readmission"
-        ),
-        description="Whether this hospitalization is a readmission and why if known.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    specialArrangement: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="specialArrangement",
-        title="Wheelchair, translator, stretcher, etc.",
+        title="Indicates that the patient is being re-admitted",
         description=(
-            "Any special requests that have been made for this hospitalization "
-            "encounter, such as the provision of specific equipment or other "
-            "things."
+            "Indicates that this encounter is directly related to a prior "
+            "admission, often because the conditions addressed in the prior "
+            "admission were not fully addressed."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    specialCourtesy: typing.List[fhirtypes.CodeableConceptType] = Field(
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EncounterAdmission`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "preAdmissionIdentifier",
+            "origin",
+            "admitSource",
+            "reAdmission",
+            "destination",
+            "dischargeDisposition",
+        ]
+
+
+class EncounterDiagnosis(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    The list of diagnosis relevant to this encounter.
+    """
+
+    resource_type = Field("EncounterDiagnosis", const=True)
+
+    condition: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="specialCourtesy",
-        title="Special courtesies (VIP, board member)",
+        alias="condition",
+        title="The diagnosis relevant to the encounter",
+        description=(
+            "The coded diagnosis or a reference to a Condition (with other "
+            "resources referenced in the evidence.detail), the use property will "
+            "indicate the purpose of this specific diagnosis."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Condition"],
+    )
+
+    use: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="use",
+        title=(
+            "Role that this diagnosis has within the encounter (e.g. admission, "
+            "billing, discharge \u2026)"
+        ),
         description=None,
         # if property is element of this resource.
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EncounterDiagnosis`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "condition", "use"]
+
 
 class EncounterLocation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -590,6 +663,21 @@ class EncounterLocation(backboneelement.BackboneElement):
 
     resource_type = Field("EncounterLocation", const=True)
 
+    form: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="form",
+        title=(
+            "The physical type of the location (usually the level in the location "
+            "hierarchy - bed, room, ward, virtual etc.)"
+        ),
+        description=(
+            "This will be used to specify the required levels (bed/ward/room/etc.) "
+            "desired to be recorded to simplify either messaging or query."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     location: fhirtypes.ReferenceType = Field(
         ...,
         alias="location",
@@ -610,21 +698,6 @@ class EncounterLocation(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    physicalType: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="physicalType",
-        title=(
-            "The physical type of the location (usually the level in the location "
-            "hierachy - bed room ward etc.)"
-        ),
-        description=(
-            "This will be used to specify the required levels (bed/ward/room/etc.) "
-            "desired to be recorded to simplify either messaging or query."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -644,9 +717,25 @@ class EncounterLocation(backboneelement.BackboneElement):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EncounterLocation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "location",
+            "status",
+            "form",
+            "period",
+        ]
+
 
 class EncounterParticipant(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -656,15 +745,29 @@ class EncounterParticipant(backboneelement.BackboneElement):
 
     resource_type = Field("EncounterParticipant", const=True)
 
-    individual: fhirtypes.ReferenceType = Field(
+    actor: fhirtypes.ReferenceType = Field(
         None,
-        alias="individual",
-        title="Persons involved in the encounter other than the patient",
-        description=None,
+        alias="actor",
+        title="The individual, device, or service participating in the encounter",
+        description=(
+            "Person involved in the encounter, the patient/group is also included "
+            "here to indicate that the patient was actually participating in the "
+            "encounter. Not including the patient here covers use cases such as a "
+            "case meeting between practitioners about a patient - non contact "
+            "times."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole", "RelatedPerson"],
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "RelatedPerson",
+            "Practitioner",
+            "PractitionerRole",
+            "Device",
+            "HealthcareService",
+        ],
     )
 
     period: fhirtypes.PeriodType = Field(
@@ -689,112 +792,63 @@ class EncounterParticipant(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EncounterParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "period", "actor"]
 
-class EncounterStatusHistory(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+
+class EncounterReason(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    List of past encounter statuses.
-    The status history permits the encounter resource to contain the status
-    history without needing to read through the historical versions of the
-    resource, or even have the server store them.
+    The list of medical reasons that are expected to be addressed during the
+    episode of care.
     """
 
-    resource_type = Field("EncounterStatusHistory", const=True)
+    resource_type = Field("EncounterReason", const=True)
 
-    period: fhirtypes.PeriodType = Field(
-        ...,
-        alias="period",
-        title="The time that the episode was in the specified status",
-        description=None,
+    use: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="use",
+        title="What the reason value should be used for/as",
+        description=(
+            "What the reason value should be used as e.g. Chief Complaint, Health "
+            "Concern, Health Maintenance (including screening)."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    status: fhirtypes.Code = Field(
+    value: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="status",
-        title=(
-            "planned | arrived | triaged | in-progress | onleave | finished | "
-            "cancelled +"
+        alias="value",
+        title="Reason the encounter takes place (core or reference)",
+        description=(
+            "Reason the encounter takes place, expressed as a code or a reference "
+            "to another resource. For admissions, this can be used for a coded "
+            "admission diagnosis."
         ),
-        description=None,
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "planned",
-            "arrived",
-            "triaged",
-            "in-progress",
-            "onleave",
-            "finished",
-            "cancelled",
-            "+",
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Condition",
+            "DiagnosticReport",
+            "Observation",
+            "ImmunizationRecommendation",
+            "Procedure",
         ],
     )
-    status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_status", title="Extension field for ``status``."
-    )
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_2535(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EncounterReason`` according specification,
+        with preserving original sequence order.
         """
-        required_fields = [("status", "status__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
+        return ["id", "extension", "modifierExtension", "use", "value"]
