@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Endpoint
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,19 +12,20 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import domainresource, fhirtypes
+from . import backboneelement, domainresource, fhirtypes
 
 
 class Endpoint(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     The technical details of an endpoint that can be used for electronic
     services.
     The technical details of an endpoint that can be used for electronic
-    services, such as for web services providing XDS.b or a REST endpoint for
-    another FHIR server. This may include any security context information.
+    services, such as for web services providing XDS.b, a REST endpoint for
+    another FHIR server, or a s/Mime email address. This may include any
+    security context information.
     """
 
     resource_type = Field("Endpoint", const=True)
@@ -42,7 +43,7 @@ class Endpoint(domainresource.DomainResource):
         None, alias="_address", title="Extension field for ``address``."
     )
 
-    connectionType: fhirtypes.CodingType = Field(
+    connectionType: typing.List[fhirtypes.CodeableConceptType] = Field(
         ...,
         alias="connectionType",
         title="Protocol/Profile/Standard to be used with this endpoint connection",
@@ -60,14 +61,45 @@ class Endpoint(domainresource.DomainResource):
         alias="contact",
         title="Contact details for source (e.g. troubleshooting)",
         description=(
-            "Contact details for a human to contact about the subscription. The "
-            "primary use of this for system administrator troubleshooting."
+            "Contact details for a human to contact about the endpoint. The primary"
+            " use of this for system administrator troubleshooting."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    header: typing.List[fhirtypes.String] = Field(
+    description: fhirtypes.String = Field(
+        None,
+        alias="description",
+        title=(
+            "Additional details about the endpoint that could be displayed as "
+            "further information to identify the description beyond its name"
+        ),
+        description=(
+            "The description of the endpoint and what it is for (typically used as "
+            "supplemental information in an endpoint directory describing its "
+            "usage/purpose)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_description", title="Extension field for ``description``."
+    )
+
+    environmentType: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="environmentType",
+        title="The type of environment(s) exposed at this endpoint",
+        description=(
+            "The type of environment(s) exposed at this endpoint (dev, prod, test, "
+            "etc.)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    header: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="header",
         title="Usage depends on the channel type",
@@ -121,39 +153,11 @@ class Endpoint(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
-    payloadMimeType: typing.List[fhirtypes.Code] = Field(
+    payload: typing.List[fhirtypes.EndpointPayloadType] = Field(
         None,
-        alias="payloadMimeType",
-        title=(
-            "Mimetype to send. If not specified, the content could be anything "
-            "(including no payload, if the connectionType defined this)"
-        ),
-        description=(
-            "The mime type to send the payload in - e.g. application/fhir+xml, "
-            "application/fhir+json. If the mime type is not specified, then the "
-            "sender could send any content (including no content depending on the "
-            "connectionType)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    payloadMimeType__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(
-        None, alias="_payloadMimeType", title="Extension field for ``payloadMimeType``."
-    )
-
-    payloadType: typing.List[fhirtypes.CodeableConceptType] = Field(
-        ...,
-        alias="payloadType",
-        title=(
-            "The type of content that may be used at this endpoint (e.g. XDS "
-            "Discharge summaries)"
-        ),
-        description=(
-            "The payload type describes the acceptable content that can be "
-            "communicated on the endpoint."
-        ),
+        alias="payload",
+        title="Set of payloads that are provided by this endpoint",
+        description="The set of payloads that are provided/available at this endpoint.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -171,7 +175,10 @@ class Endpoint(domainresource.DomainResource):
         None,
         alias="status",
         title="active | suspended | error | off | entered-in-error | test",
-        description="active | suspended | error | off | test.",
+        description=(
+            "The endpoint status represents the general expected availability of an"
+            " endpoint."
+        ),
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -183,6 +190,35 @@ class Endpoint(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Endpoint`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "connectionType",
+            "name",
+            "description",
+            "environmentType",
+            "managingOrganization",
+            "contact",
+            "period",
+            "payload",
+            "address",
+            "header",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1018(
         cls, values: typing.Dict[str, typing.Any]
@@ -241,3 +277,58 @@ class Endpoint(domainresource.DomainResource):
             raise ValidationError(errors, cls)  # type: ignore
 
         return values
+
+
+class EndpointPayload(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Set of payloads that are provided by this endpoint.
+    The set of payloads that are provided/available at this endpoint.
+    """
+
+    resource_type = Field("EndpointPayload", const=True)
+
+    mimeType: typing.List[typing.Optional[fhirtypes.Code]] = Field(
+        None,
+        alias="mimeType",
+        title=(
+            "Mimetype to send. If not specified, the content could be anything "
+            "(including no payload, if the connectionType defined this)"
+        ),
+        description=(
+            "The mime type to send the payload in - e.g. application/fhir+xml, "
+            "application/fhir+json. If the mime type is not specified, then the "
+            "sender could send any content (including no content depending on the "
+            "connectionType)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    mimeType__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_mimeType", title="Extension field for ``mimeType``.")
+
+    type: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="type",
+        title=(
+            "The type of content that may be used at this endpoint (e.g. XDS "
+            "Discharge summaries)"
+        ),
+        description=(
+            "The payload type describes the acceptable content that can be "
+            "communicated on the endpoint."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EndpointPayload`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "mimeType"]
