@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/EpisodeOfCare
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -58,10 +58,27 @@ class EpisodeOfCare(domainresource.DomainResource):
         enum_reference_types=["Practitioner", "PractitionerRole"],
     )
 
+    careTeam: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="careTeam",
+        title="Other practitioners facilitating this episode of care",
+        description=(
+            "The list of practitioners that may be facilitating this episode of "
+            "care for specific purposes."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["CareTeam"],
+    )
+
     diagnosis: typing.List[fhirtypes.EpisodeOfCareDiagnosisType] = Field(
         None,
         alias="diagnosis",
-        title="The list of diagnosis relevant to this episode of care",
+        title=(
+            "The list of medical conditions that were addressed during the episode "
+            "of care"
+        ),
         description=None,
         # if property is element of this resource.
         element_property=True,
@@ -83,10 +100,11 @@ class EpisodeOfCare(domainresource.DomainResource):
     managingOrganization: fhirtypes.ReferenceType = Field(
         None,
         alias="managingOrganization",
-        title="Organization that assumes care",
+        title="Organization that assumes responsibility for care coordination",
         description=(
             "The organization that has assumed the specific responsibilities for "
-            "the specified duration."
+            "care coordination, care delivery, or other services for the specified "
+            "duration."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -117,6 +135,18 @@ class EpisodeOfCare(domainresource.DomainResource):
         element_property=True,
     )
 
+    reason: typing.List[fhirtypes.EpisodeOfCareReasonType] = Field(
+        None,
+        alias="reason",
+        title=(
+            "The list of medical reasons that are expected to be addressed during "
+            "the episode of care"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     referralRequest: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="referralRequest",
@@ -173,20 +203,6 @@ class EpisodeOfCare(domainresource.DomainResource):
         element_property=True,
     )
 
-    team: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="team",
-        title="Other practitioners facilitating this episode of care",
-        description=(
-            "The list of practitioners that may be facilitating this episode of "
-            "care for specific purposes."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["CareTeam"],
-    )
-
     type: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="type",
@@ -218,13 +234,14 @@ class EpisodeOfCare(domainresource.DomainResource):
             "status",
             "statusHistory",
             "type",
+            "reason",
             "diagnosis",
             "patient",
             "managingOrganization",
             "period",
             "referralRequest",
             "careManager",
-            "team",
+            "careTeam",
             "account",
         ]
 
@@ -293,18 +310,19 @@ class EpisodeOfCareDiagnosis(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    The list of diagnosis relevant to this episode of care.
+    The list of medical conditions that were addressed during the episode of
+    care.
     """
 
     resource_type = Field("EpisodeOfCareDiagnosis", const=True)
 
-    condition: fhirtypes.ReferenceType = Field(
-        ...,
+    condition: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
         alias="condition",
-        title="Conditions/problems/diagnoses this episode of care is for",
+        title="The medical condition that was addressed during the episode of care",
         description=(
-            "A list of conditions/problems/diagnoses that this episode of care is "
-            "intended to be providing care for."
+            "The medical condition that was addressed during the episode of care, "
+            "expressed as a text, code or a reference to another resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -312,21 +330,9 @@ class EpisodeOfCareDiagnosis(backboneelement.BackboneElement):
         enum_reference_types=["Condition"],
     )
 
-    rank: fhirtypes.PositiveInt = Field(
+    use: fhirtypes.CodeableConceptType = Field(
         None,
-        alias="rank",
-        title="Ranking of the diagnosis (for each role type)",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    rank__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_rank", title="Extension field for ``rank``."
-    )
-
-    role: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="role",
+        alias="use",
         title=(
             "Role that this diagnosis has within the episode of care (e.g. "
             "admission, billing, discharge \u2026)"
@@ -342,7 +348,59 @@ class EpisodeOfCareDiagnosis(backboneelement.BackboneElement):
         ``EpisodeOfCareDiagnosis`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "condition", "role", "rank"]
+        return ["id", "extension", "modifierExtension", "condition", "use"]
+
+
+class EpisodeOfCareReason(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    The list of medical reasons that are expected to be addressed during the
+    episode of care.
+    """
+
+    resource_type = Field("EpisodeOfCareReason", const=True)
+
+    use: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="use",
+        title="What the reason value should be used for/as",
+        description=(
+            "What the reason value should be used as e.g. Chief Complaint, Health "
+            "Concern, Health Maintenance (including screening)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    value: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
+        alias="value",
+        title="Medical reason to be addressed",
+        description=(
+            "The medical reason that is expected to be addressed during the episode"
+            " of care, expressed as a text, code or a reference to another "
+            "resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Condition",
+            "Procedure",
+            "Observation",
+            "HealthcareService",
+        ],
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EpisodeOfCareReason`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "use", "value"]
 
 
 class EpisodeOfCareStatusHistory(backboneelement.BackboneElement):
