@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Evidence
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -22,7 +22,7 @@ class Evidence(domainresource.DomainResource):
 
     Single evidence bit.
     The Evidence Resource provides a machine-interpretable expression of an
-    evidence concept including the evidence variables (eg population,
+    evidence concept including the evidence variables (e.g., population,
     exposures/interventions, comparators, outcomes, measured variables,
     confounding variables), the statistics, and the certainty of this evidence.
     """
@@ -122,15 +122,48 @@ class Evidence(domainresource.DomainResource):
         element_property=True,
     )
 
+    copyright: fhirtypes.Markdown = Field(
+        None,
+        alias="copyright",
+        title="Use and/or publishing restrictions",
+        description=(
+            "A copyright statement relating to the Evidence and/or its contents. "
+            "Copyright statements are generally legal restrictions on the use and "
+            "publishing of the Evidence."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyright__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyright", title="Extension field for ``copyright``."
+    )
+
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the summary was published. The "
-            "date must change when the business version changes and it must change "
-            "if the status code changes. In addition, it should change when the "
-            "substantive content of the summary changes."
+            "The date  (and optionally time) when the summary was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the summary changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -178,6 +211,22 @@ class Evidence(domainresource.DomainResource):
         element_property=True,
     )
 
+    experimental: bool = Field(
+        None,
+        alias="experimental",
+        title="For testing purposes, not real usage",
+        description=(
+            "A Boolean value to indicate that this resource is authored for testing"
+            " purposes (or education/evaluation/marketing) and is not intended to "
+            "be used for genuine usage."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    experimental__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_experimental", title="Extension field for ``experimental``."
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -194,7 +243,7 @@ class Evidence(domainresource.DomainResource):
     lastReviewDate: fhirtypes.Date = Field(
         None,
         alias="lastReviewDate",
-        title="When the summary was last reviewed",
+        title="When the summary was last reviewed by the publisher",
         description=(
             "The date on which the resource content was last reviewed. Review "
             "happens periodically after approval but does not change the original "
@@ -207,6 +256,22 @@ class Evidence(domainresource.DomainResource):
         None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
     )
 
+    name: fhirtypes.String = Field(
+        None,
+        alias="name",
+        title="Name for this summary (machine friendly)",
+        description=(
+            "A natural language name identifying the evidence. This name should be "
+            "usable as an identifier for the module by machine processing "
+            "applications such as code generation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_name", title="Extension field for ``name``."
+    )
+
     note: typing.List[fhirtypes.AnnotationType] = Field(
         None,
         alias="note",
@@ -219,9 +284,10 @@ class Evidence(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the " "evidence."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the evidence."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -230,6 +296,21 @@ class Evidence(domainresource.DomainResource):
         None, alias="_publisher", title="Extension field for ``publisher``."
     )
 
+    purpose: fhirtypes.Markdown = Field(
+        None,
+        alias="purpose",
+        title="Why this Evidence is defined",
+        description=(
+            "Explanation of why this Evidence is needed and why it has been "
+            "designed as it has."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    purpose__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_purpose", title="Extension field for ``purpose``."
+    )
+
     relatedArtifact: typing.List[fhirtypes.RelatedArtifactType] = Field(
         None,
         alias="relatedArtifact",
@@ -279,11 +360,14 @@ class Evidence(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    studyType: fhirtypes.CodeableConceptType = Field(
+    studyDesign: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
-        alias="studyType",
-        title="The type of study that produced this evidence",
-        description=None,
+        alias="studyDesign",
+        title="The design of the study that produced this evidence",
+        description=(
+            "The design of the study that produced this evidence. The design is "
+            "described with any number of study design characteristics."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -320,10 +404,10 @@ class Evidence(domainresource.DomainResource):
             "An absolute URI that is used to identify this evidence when it is "
             "referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this summary is (or will be) published. This URL can be "
-            "the target of a canonical reference. It SHALL remain the same when the"
-            " summary is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " summary is (or will be) published. This URL can be the target of a "
+            "canonical reference. It SHALL remain the same when the summary is "
+            "stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -376,6 +460,41 @@ class Evidence(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -394,12 +513,15 @@ class Evidence(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
+            "name",
             "title",
             "citeAsReference",
             "citeAsMarkdown",
             "status",
+            "experimental",
             "date",
-            "useContext",
             "approvalDate",
             "lastReviewDate",
             "publisher",
@@ -408,13 +530,17 @@ class Evidence(domainresource.DomainResource):
             "editor",
             "reviewer",
             "endorser",
+            "useContext",
+            "purpose",
+            "copyright",
+            "copyrightLabel",
             "relatedArtifact",
             "description",
             "assertion",
             "note",
             "variableDefinition",
             "synthesisType",
-            "studyType",
+            "studyDesign",
             "statistic",
             "certainty",
         ]
@@ -494,7 +620,10 @@ class Evidence(domainresource.DomainResource):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"citeAs": ["citeAsMarkdown", "citeAsReference"]}
+        one_of_many_fields = {
+            "citeAs": ["citeAsMarkdown", "citeAsReference"],
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"],
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
@@ -529,7 +658,7 @@ class EvidenceCertainty(backboneelement.BackboneElement):
 
     resource_type = Field("EvidenceCertainty", const=True)
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Textual description of certainty",
@@ -644,7 +773,7 @@ class EvidenceStatistic(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Description of content",
@@ -728,7 +857,7 @@ class EvidenceStatistic(backboneelement.BackboneElement):
     statisticType: fhirtypes.CodeableConceptType = Field(
         None,
         alias="statisticType",
-        title="Type of statistic, eg relative risk",
+        title="Type of statistic, e.g., relative risk",
         description=None,
         # if property is element of this resource.
         element_property=True,
@@ -783,7 +912,7 @@ class EvidenceStatisticAttributeEstimate(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Textual description of the attribute estimate",
@@ -798,7 +927,7 @@ class EvidenceStatisticAttributeEstimate(backboneelement.BackboneElement):
     level: fhirtypes.Decimal = Field(
         None,
         alias="level",
-        title="Level of confidence interval, eg 0.95 for 95% confidence interval",
+        title="Level of confidence interval, e.g., 0.95 for 95% confidence interval",
         description="Use 95 for a 95% confidence interval.",
         # if property is element of this resource.
         element_property=True,
@@ -841,7 +970,7 @@ class EvidenceStatisticAttributeEstimate(backboneelement.BackboneElement):
     type: fhirtypes.CodeableConceptType = Field(
         None,
         alias="type",
-        title="The type of attribute estimate, eg confidence interval or p value",
+        title="The type of attribute estimate, e.g., confidence interval or p value",
         description=None,
         # if property is element of this resource.
         element_property=True,
@@ -1029,7 +1158,7 @@ class EvidenceStatisticSampleSize(backboneelement.BackboneElement):
 
     resource_type = Field("EvidenceStatisticSampleSize", const=True)
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Textual description of sample size for statistic",
