@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/EvidenceReport
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -22,7 +22,7 @@ class EvidenceReport(domainresource.DomainResource):
 
     A EvidenceReport.
     The EvidenceReport Resource is a specialized container for a collection of
-    resources and codable concepts, adapted to support compositions of
+    resources and codeable concepts, adapted to support compositions of
     Evidence, EvidenceVariable, and Citation resources and related concepts.
     """
 
@@ -130,10 +130,10 @@ class EvidenceReport(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the evidence"
-            " report."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the evidence report."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -253,10 +253,10 @@ class EvidenceReport(domainresource.DomainResource):
             "An absolute URI that is used to identify this EvidenceReport when it "
             "is referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this summary is (or will be) published. This URL can be "
-            "the target of a canonical reference. It SHALL remain the same when the"
-            " summary is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " summary is (or will be) published. This URL can be the target of a "
+            "canonical reference. It SHALL remain the same when the summary is "
+            "stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -457,30 +457,13 @@ class EvidenceReportRelatesTo(backboneelement.BackboneElement):
         None, alias="_code", title="Extension field for ``code``."
     )
 
-    targetIdentifier: fhirtypes.IdentifierType = Field(
-        None,
-        alias="targetIdentifier",
+    target: fhirtypes.EvidenceReportRelatesToTargetType = Field(
+        ...,
+        alias="target",
         title="Target of the relationship",
         description="The target composition/document of this relationship.",
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e target[x]
-        one_of_many="target",
-        one_of_many_required=True,
-    )
-
-    targetReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="targetReference",
-        title="Target of the relationship",
-        description="The target composition/document of this relationship.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e target[x]
-        one_of_many="target",
-        one_of_many_required=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["EvidenceReport"],
     )
 
     @classmethod
@@ -489,14 +472,7 @@ class EvidenceReportRelatesTo(backboneelement.BackboneElement):
         ``EvidenceReportRelatesTo`` according specification,
         with preserving original sequence order.
         """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "code",
-            "targetIdentifier",
-            "targetReference",
-        ]
+        return ["id", "extension", "modifierExtension", "code", "target"]
 
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2534(
@@ -557,43 +533,77 @@ class EvidenceReportRelatesTo(backboneelement.BackboneElement):
 
         return values
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_2534(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
 
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
+class EvidenceReportRelatesToTarget(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Target of the relationship.
+    The target composition/document of this relationship.
+    """
+
+    resource_type = Field("EvidenceReportRelatesToTarget", const=True)
+
+    display: fhirtypes.Markdown = Field(
+        None,
+        alias="display",
+        title="Target of the relationship Display",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    display__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_display", title="Extension field for ``display``."
+    )
+
+    identifier: fhirtypes.IdentifierType = Field(
+        None,
+        alias="identifier",
+        title="Target of the relationship Identifier",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    resource: fhirtypes.ReferenceType = Field(
+        None,
+        alias="resource",
+        title="Target of the relationship Resource reference",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
+    url: fhirtypes.Uri = Field(
+        None,
+        alias="url",
+        title="Target of the relationship URL",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    url__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_url", title="Extension field for ``url``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EvidenceReportRelatesToTarget`` according specification,
+        with preserving original sequence order.
         """
-        one_of_many_fields = {"target": ["targetIdentifier", "targetReference"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "display",
+            "resource",
+        ]
 
 
 class EvidenceReportSection(backboneelement.BackboneElement):
@@ -618,7 +628,15 @@ class EvidenceReportSection(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Person", "Device", "Group", "Organization"],
+        enum_reference_types=[
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "Device",
+            "Group",
+            "Organization",
+        ],
     )
 
     emptyReason: fhirtypes.CodeableConceptType = Field(
