@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Extension
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
 from pydantic import Field, root_validator
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Extension(element.Element):
+class Extension(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -97,6 +97,21 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    valueAvailability: fhirtypes.AvailabilityType = Field(
+        None,
+        alias="valueAvailability",
+        title="Value of extension",
+        description=(
+            "Value of extension - must be one of a constrained set of the data "
+            "types (see [Extensibility](extensibility.html) for a list)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueBase64Binary: fhirtypes.Base64Binary = Field(
         None,
         alias="valueBase64Binary",
@@ -232,21 +247,6 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
-    valueContributor: fhirtypes.ContributorType = Field(
-        None,
-        alias="valueContributor",
-        title="Value of extension",
-        description=(
-            "Value of extension - must be one of a constrained set of the data "
-            "types (see [Extensibility](extensibility.html) for a list)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e value[x]
-        one_of_many="value",
-        one_of_many_required=False,
-    )
-
     valueCount: fhirtypes.CountType = Field(
         None,
         alias="valueCount",
@@ -382,6 +382,21 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    valueExtendedContactDetail: fhirtypes.ExtendedContactDetailType = Field(
+        None,
+        alias="valueExtendedContactDetail",
+        title="Value of extension",
+        description=(
+            "Value of extension - must be one of a constrained set of the data "
+            "types (see [Extensibility](extensibility.html) for a list)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueHumanName: fhirtypes.HumanNameType = Field(
         None,
         alias="valueHumanName",
@@ -457,6 +472,21 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    valueInteger64: fhirtypes.Integer64 = Field(
+        None,
+        alias="valueInteger64",
+        title="Value of extension",
+        description=(
+            "Value of extension - must be one of a constrained set of the data "
+            "types (see [Extensibility](extensibility.html) for a list)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueMarkdown: fhirtypes.Markdown = Field(
         None,
         alias="valueMarkdown",
@@ -472,6 +502,21 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    valueMeta: fhirtypes.MetaType = Field(
+        None,
+        alias="valueMeta",
+        title="Value of extension",
+        description=(
+            "Value of extension - must be one of a constrained set of the data "
+            "types (see [Extensibility](extensibility.html) for a list)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueMoney: fhirtypes.MoneyType = Field(
         None,
         alias="valueMoney",
@@ -822,6 +867,7 @@ class Extension(element.Element):
             "valueId",
             "valueInstant",
             "valueInteger",
+            "valueInteger64",
             "valueMarkdown",
             "valueOid",
             "valuePositiveInt",
@@ -855,14 +901,16 @@ class Extension(element.Element):
             "valueSignature",
             "valueTiming",
             "valueContactDetail",
-            "valueContributor",
             "valueDataRequirement",
             "valueExpression",
             "valueParameterDefinition",
             "valueRelatedArtifact",
             "valueTriggerDefinition",
             "valueUsageContext",
+            "valueAvailability",
+            "valueExtendedContactDetail",
             "valueDosage",
+            "valueMeta",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
@@ -887,6 +935,7 @@ class Extension(element.Element):
                 "valueAge",
                 "valueAnnotation",
                 "valueAttachment",
+                "valueAvailability",
                 "valueBase64Binary",
                 "valueBoolean",
                 "valueCanonical",
@@ -896,7 +945,6 @@ class Extension(element.Element):
                 "valueCoding",
                 "valueContactDetail",
                 "valueContactPoint",
-                "valueContributor",
                 "valueCount",
                 "valueDataRequirement",
                 "valueDate",
@@ -906,12 +954,15 @@ class Extension(element.Element):
                 "valueDosage",
                 "valueDuration",
                 "valueExpression",
+                "valueExtendedContactDetail",
                 "valueHumanName",
                 "valueId",
                 "valueIdentifier",
                 "valueInstant",
                 "valueInteger",
+                "valueInteger64",
                 "valueMarkdown",
+                "valueMeta",
                 "valueMoney",
                 "valueOid",
                 "valueParameterDefinition",
