@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/FamilyMemberHistory
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -338,6 +338,21 @@ class FamilyMemberHistory(domainresource.DomainResource):
         element_property=True,
     )
 
+    participant: typing.List[fhirtypes.FamilyMemberHistoryParticipantType] = Field(
+        None,
+        alias="participant",
+        title=(
+            "Who or what participated in the activities related to the family "
+            "member history and how they were involved"
+        ),
+        description=(
+            "Indicates who or what participated in the activities related to the "
+            "family member history and how they were involved."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     patient: fhirtypes.ReferenceType = Field(
         ...,
         alias="patient",
@@ -349,24 +364,27 @@ class FamilyMemberHistory(domainresource.DomainResource):
         enum_reference_types=["Patient"],
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    procedure: typing.List[fhirtypes.FamilyMemberHistoryProcedureType] = Field(
         None,
-        alias="reasonCode",
-        title="Why was family member history performed?",
+        alias="procedure",
+        title="Procedures that the related person had",
         description=(
-            "Describes why the family member history occurred in coded or textual "
-            "form."
+            "The significant Procedures (or procedure) that the family member had. "
+            "This is a repeating section to allow a system to represent more than "
+            "one procedure per resource, though there is nothing stopping multiple "
+            "resources - one per procedure."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonReference",
+        alias="reason",
         title="Why was family member history performed?",
         description=(
-            "Indicates a Condition, Observation, AllergyIntolerance, or "
+            "Describes why the family member history occurred in coded or textual "
+            "form, or Indicates a Condition, Observation, AllergyIntolerance, or "
             "QuestionnaireResponse that justifies this family member history event."
         ),
         # if property is element of this resource.
@@ -444,6 +462,7 @@ class FamilyMemberHistory(domainresource.DomainResource):
             "dataAbsentReason",
             "patient",
             "date",
+            "participant",
             "name",
             "relationship",
             "sex",
@@ -459,10 +478,10 @@ class FamilyMemberHistory(domainresource.DomainResource):
             "deceasedRange",
             "deceasedDate",
             "deceasedString",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "note",
             "condition",
+            "procedure",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
@@ -700,7 +719,7 @@ class FamilyMemberHistoryCondition(backboneelement.BackboneElement):
     outcome: fhirtypes.CodeableConceptType = Field(
         None,
         alias="outcome",
-        title="deceased | permanent disability | etc.",
+        title="deceased | permanent disability | etc",
         description=(
             "Indicates what happened following the condition.  If the condition "
             "resulted in death, deceased date is captured on the relation."
@@ -768,3 +787,291 @@ class FamilyMemberHistoryCondition(backboneelement.BackboneElement):
                 raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
+
+
+class FamilyMemberHistoryParticipant(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Who or what participated in the activities related to the family member
+    history and how they were involved.
+    Indicates who or what participated in the activities related to the family
+    member history and how they were involved.
+    """
+
+    resource_type = Field("FamilyMemberHistoryParticipant", const=True)
+
+    actor: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="actor",
+        title=(
+            "Who or what participated in the activities related to the family "
+            "member history"
+        ),
+        description=(
+            "Indicates who or what participated in the activities related to the "
+            "family member history."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Patient",
+            "RelatedPerson",
+            "Device",
+            "Organization",
+            "CareTeam",
+        ],
+    )
+
+    function: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="function",
+        title="Type of involvement",
+        description=(
+            "Distinguishes the type of involvement of the actor in the activities "
+            "related to the family member history."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``FamilyMemberHistoryParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
+
+
+class FamilyMemberHistoryProcedure(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Procedures that the related person had.
+    The significant Procedures (or procedure) that the family member had. This
+    is a repeating section to allow a system to represent more than one
+    procedure per resource, though there is nothing stopping multiple resources
+    - one per procedure.
+    """
+
+    resource_type = Field("FamilyMemberHistoryProcedure", const=True)
+
+    code: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="code",
+        title="Procedures performed on the related person",
+        description=(
+            "The actual procedure specified. Could be a coded procedure or a less "
+            "specific string depending on how much is known about the procedure and"
+            " the capabilities of the creating system."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    contributedToDeath: bool = Field(
+        None,
+        alias="contributedToDeath",
+        title="Whether the procedure contributed to the cause of death",
+        description=(
+            "This procedure contributed to the cause of death of the related "
+            "person. If contributedToDeath is not populated, then it is unknown."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    contributedToDeath__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_contributedToDeath",
+        title="Extension field for ``contributedToDeath``.",
+    )
+
+    note: typing.List[fhirtypes.AnnotationType] = Field(
+        None,
+        alias="note",
+        title="Extra information about the procedure",
+        description=(
+            "An area where general notes can be placed about this specific "
+            "procedure."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    outcome: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="outcome",
+        title="What happened following the procedure",
+        description=(
+            "Indicates what happened following the procedure. If the procedure "
+            "resulted in death, deceased date is captured on the relation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    performedAge: fhirtypes.AgeType = Field(
+        None,
+        alias="performedAge",
+        title="When the procedure was performed",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " was performed. Allows a period to support complex procedures that "
+            "span more than one date, and also allows for the length of the "
+            "procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e performed[x]
+        one_of_many="performed",
+        one_of_many_required=False,
+    )
+
+    performedDateTime: fhirtypes.DateTime = Field(
+        None,
+        alias="performedDateTime",
+        title="When the procedure was performed",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " was performed. Allows a period to support complex procedures that "
+            "span more than one date, and also allows for the length of the "
+            "procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e performed[x]
+        one_of_many="performed",
+        one_of_many_required=False,
+    )
+    performedDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_performedDateTime",
+        title="Extension field for ``performedDateTime``.",
+    )
+
+    performedPeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="performedPeriod",
+        title="When the procedure was performed",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " was performed. Allows a period to support complex procedures that "
+            "span more than one date, and also allows for the length of the "
+            "procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e performed[x]
+        one_of_many="performed",
+        one_of_many_required=False,
+    )
+
+    performedRange: fhirtypes.RangeType = Field(
+        None,
+        alias="performedRange",
+        title="When the procedure was performed",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " was performed. Allows a period to support complex procedures that "
+            "span more than one date, and also allows for the length of the "
+            "procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e performed[x]
+        one_of_many="performed",
+        one_of_many_required=False,
+    )
+
+    performedString: fhirtypes.String = Field(
+        None,
+        alias="performedString",
+        title="When the procedure was performed",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " was performed. Allows a period to support complex procedures that "
+            "span more than one date, and also allows for the length of the "
+            "procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e performed[x]
+        one_of_many="performed",
+        one_of_many_required=False,
+    )
+    performedString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_performedString", title="Extension field for ``performedString``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``FamilyMemberHistoryProcedure`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "outcome",
+            "contributedToDeath",
+            "performedAge",
+            "performedRange",
+            "performedPeriod",
+            "performedString",
+            "performedDateTime",
+            "note",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_3072(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "performed": [
+                "performedAge",
+                "performedDateTime",
+                "performedPeriod",
+                "performedRange",
+                "performedString",
+            ]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
