@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Flag
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import domainresource, fhirtypes
 
 
 class Flag(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -39,6 +39,7 @@ class Flag(domainresource.DomainResource):
             "Device",
             "Organization",
             "Patient",
+            "RelatedPerson",
             "Practitioner",
             "PractitionerRole",
         ],
@@ -47,7 +48,7 @@ class Flag(domainresource.DomainResource):
     category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
-        title="Clinical, administrative, etc.",
+        title="Clinical, administrative, etc",
         description=(
             "Allows a flag to be divided into different categories like clinical, "
             "administrative etc. Intended to be used as a means of filtering which "
@@ -127,24 +128,51 @@ class Flag(domainresource.DomainResource):
         alias="subject",
         title="Who/What is flag about?",
         description=(
-            "The patient, location, group, organization, or practitioner etc. this "
-            "is about record this flag is associated with."
+            "The patient, related person, location, group, organization, or "
+            "practitioner etc. this is about record this flag is associated with."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Patient",
+            "RelatedPerson",
             "Location",
             "Group",
             "Organization",
             "Practitioner",
+            "PractitionerRole",
             "PlanDefinition",
             "Medication",
             "Procedure",
         ],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Flag`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "category",
+            "code",
+            "subject",
+            "period",
+            "encounter",
+            "author",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_551(
         cls, values: typing.Dict[str, typing.Any]
