@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Goal
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -59,21 +59,38 @@ class Goal(domainresource.DomainResource):
             "Condition",
             "Observation",
             "MedicationStatement",
+            "MedicationRequest",
             "NutritionOrder",
             "ServiceRequest",
             "RiskAssessment",
+            "Procedure",
         ],
     )
 
     category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
-        title="E.g. Treatment, dietary, behavioral, etc.",
+        title="E.g. Treatment, dietary, behavioral, etc",
         description="Indicates a category the goal falls within.",
         # if property is element of this resource.
         element_property=True,
     )
 
+    continuous: bool = Field(
+        None,
+        alias="continuous",
+        title=(
+            "After meeting the goal, ongoing activity is needed to sustain the goal"
+            " objective"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    continuous__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_continuous", title="Extension field for ``continuous``."
+    )
+
     description: fhirtypes.CodeableConceptType = Field(
         ...,
         alias="description",
@@ -87,22 +104,6 @@ class Goal(domainresource.DomainResource):
         element_property=True,
     )
 
-    expressedBy: fhirtypes.ReferenceType = Field(
-        None,
-        alias="expressedBy",
-        title="Who's responsible for creating Goal?",
-        description="Indicates whose goal this is - patient goal, practitioner goal, etc.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Patient",
-            "Practitioner",
-            "PractitionerRole",
-            "RelatedPerson",
-        ],
-    )
-
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -154,9 +155,9 @@ class Goal(domainresource.DomainResource):
         element_property=True,
     )
 
-    outcomeCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    outcome: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="outcomeCode",
+        alias="outcome",
         title="What result was achieved regarding the goal?",
         description=(
             "Identifies the change (or lack of change) at the point when the status"
@@ -164,15 +165,6 @@ class Goal(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-
-    outcomeReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="outcomeReference",
-        title="Observation that resulted from goal",
-        description="Details of what's changed (or not changed).",
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Observation"],
     )
@@ -189,6 +181,23 @@ class Goal(domainresource.DomainResource):
         element_property=True,
     )
 
+    source: fhirtypes.ReferenceType = Field(
+        None,
+        alias="source",
+        title="Who's responsible for creating Goal?",
+        description="Indicates whose goal this is - patient goal, practitioner goal, etc.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "CareTeam",
+        ],
+    )
+
     startCodeableConcept: fhirtypes.CodeableConceptType = Field(
         None,
         alias="startCodeableConcept",
@@ -285,6 +294,7 @@ class Goal(domainresource.DomainResource):
             "lifecycleStatus",
             "achievementStatus",
             "category",
+            "continuous",
             "priority",
             "description",
             "subject",
@@ -293,11 +303,10 @@ class Goal(domainresource.DomainResource):
             "target",
             "statusDate",
             "statusReason",
-            "expressedBy",
+            "source",
             "addresses",
             "note",
-            "outcomeCode",
-            "outcomeReference",
+            "outcome",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
