@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/GraphDefinition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -40,15 +40,49 @@ class GraphDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
+    copyright: fhirtypes.Markdown = Field(
+        None,
+        alias="copyright",
+        title="Use and/or publishing restrictions",
+        description=(
+            "A copyright statement relating to the graph definition and/or its "
+            "contents. Copyright statements are generally legal restrictions on the"
+            " use and publishing of the graph definition."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyright__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyright", title="Extension field for ``copyright``."
+    )
+
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the graph definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the graph definition changes."
+            "The date  (and optionally time) when the graph definition was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the graph definition "
+            "changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -88,6 +122,19 @@ class GraphDefinition(domainresource.DomainResource):
         None, alias="_experimental", title="Extension field for ``experimental``."
     )
 
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title="Additional identifier for the GraphDefinition (business identifier)",
+        description=(
+            "A formal identifier that is used to identify this GraphDefinition when"
+            " it is represented in other formats, or referenced in a specification,"
+            " model, design or an instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     jurisdiction: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="jurisdiction",
@@ -126,27 +173,22 @@ class GraphDefinition(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
-    profile: fhirtypes.Canonical = Field(
+    node: typing.List[fhirtypes.GraphDefinitionNodeType] = Field(
         None,
-        alias="profile",
-        title="Profile on base resource",
-        description="The profile that describes the use of the base resource.",
+        alias="node",
+        title="Potential target for the link",
+        description=None,
         # if property is element of this resource.
         element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["StructureDefinition"],
-    )
-    profile__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_profile", title="Extension field for ``profile``."
     )
 
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the graph "
-            "definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the graph definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -170,14 +212,16 @@ class GraphDefinition(domainresource.DomainResource):
         None, alias="_purpose", title="Extension field for ``purpose``."
     )
 
-    start: fhirtypes.Code = Field(
+    start: fhirtypes.Id = Field(
         None,
         alias="start",
-        title="Type of resource at which the graph starts",
-        description="The type of FHIR resource at which instances of this graph start.",
+        title="Starting Node",
+        description=(
+            "The Node at which instances of this graph start. If there is no "
+            "nominated start, the graph can start at any of the nodes."
+        ),
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
     )
     start__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_start", title="Extension field for ``start``."
@@ -202,6 +246,20 @@ class GraphDefinition(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    title: fhirtypes.String = Field(
+        None,
+        alias="title",
+        title="Name for this graph definition (human friendly)",
+        description=(
+            "A short, descriptive, user-friendly title for the capability " "statement."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    title__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_title", title="Extension field for ``title``."
+    )
+
     url: fhirtypes.Uri = Field(
         None,
         alias="url",
@@ -213,10 +271,10 @@ class GraphDefinition(domainresource.DomainResource):
             "An absolute URI that is used to identify this graph definition when it"
             " is referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this graph definition is (or will be) published. This URL "
-            "can be the target of a canonical reference. It SHALL remain the same "
-            "when the graph definition is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " graph definition is (or will be) published. This URL can be the "
+            "target of a canonical reference. It SHALL remain the same when the "
+            "graph definition is stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -260,6 +318,41 @@ class GraphDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -276,8 +369,12 @@ class GraphDefinition(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "url",
+            "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
+            "title",
             "status",
             "experimental",
             "date",
@@ -287,8 +384,10 @@ class GraphDefinition(domainresource.DomainResource):
             "useContext",
             "jurisdiction",
             "purpose",
+            "copyright",
+            "copyrightLabel",
             "start",
-            "profile",
+            "node",
             "link",
         ]
 
@@ -303,11 +402,7 @@ class GraphDefinition(domainresource.DomainResource):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [
-            ("name", "name__ext"),
-            ("start", "start__ext"),
-            ("status", "status__ext"),
-        ]
+        required_fields = [("name", "name__ext"), ("status", "status__ext")]
         _missing = object()
 
         def _fallback():
@@ -355,6 +450,46 @@ class GraphDefinition(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_1712(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class GraphDefinitionLink(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -366,6 +501,15 @@ class GraphDefinitionLink(backboneelement.BackboneElement):
 
     resource_type = Field("GraphDefinitionLink", const=True)
 
+    compartment: typing.List[fhirtypes.GraphDefinitionLinkCompartmentType] = Field(
+        None,
+        alias="compartment",
+        title="Compartment Consistency Rules",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     description: fhirtypes.String = Field(
         None,
         alias="description",
@@ -405,12 +549,24 @@ class GraphDefinitionLink(backboneelement.BackboneElement):
         None, alias="_min", title="Extension field for ``min``."
     )
 
+    params: fhirtypes.String = Field(
+        None,
+        alias="params",
+        title="Criteria for reverse lookup",
+        description="A set of parameters to look up.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    params__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_params", title="Extension field for ``params``."
+    )
+
     path: fhirtypes.String = Field(
         None,
         alias="path",
         title="Path in the resource that contains the link",
         description=(
-            "A FHIR expression that identifies one of FHIR References to other "
+            "A FHIRPath expression that identifies one of FHIR References to other "
             "resources."
         ),
         # if property is element of this resource.
@@ -432,13 +588,30 @@ class GraphDefinitionLink(backboneelement.BackboneElement):
         None, alias="_sliceName", title="Extension field for ``sliceName``."
     )
 
-    target: typing.List[fhirtypes.GraphDefinitionLinkTargetType] = Field(
+    sourceId: fhirtypes.Id = Field(
         None,
-        alias="target",
-        title="Potential target for the link",
-        description=None,
+        alias="sourceId",
+        title="Source Node for this link",
+        description="The source node for this link.",
         # if property is element of this resource.
         element_property=True,
+        element_required=True,
+    )
+    sourceId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_sourceId", title="Extension field for ``sourceId``."
+    )
+
+    targetId: fhirtypes.Id = Field(
+        None,
+        alias="targetId",
+        title="Target Node for this link",
+        description="The target node for this link.",
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+    )
+    targetId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_targetId", title="Extension field for ``targetId``."
     )
 
     @classmethod
@@ -451,103 +624,19 @@ class GraphDefinitionLink(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "path",
-            "sliceName",
+            "description",
             "min",
             "max",
-            "description",
-            "target",
-        ]
-
-
-class GraphDefinitionLinkTarget(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Potential target for the link.
-    """
-
-    resource_type = Field("GraphDefinitionLinkTarget", const=True)
-
-    compartment: typing.List[
-        fhirtypes.GraphDefinitionLinkTargetCompartmentType
-    ] = Field(
-        None,
-        alias="compartment",
-        title="Compartment Consistency Rules",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    link: typing.List[fhirtypes.GraphDefinitionLinkType] = Field(
-        None,
-        alias="link",
-        title="Additional links from target resource",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    params: fhirtypes.String = Field(
-        None,
-        alias="params",
-        title="Criteria for reverse lookup",
-        description="A set of parameters to look up.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-    params__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_params", title="Extension field for ``params``."
-    )
-
-    profile: fhirtypes.Canonical = Field(
-        None,
-        alias="profile",
-        title="Profile for the target resource",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["StructureDefinition"],
-    )
-    profile__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_profile", title="Extension field for ``profile``."
-    )
-
-    type: fhirtypes.Code = Field(
-        None,
-        alias="type",
-        title="Type of resource this link refers to",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        element_required=True,
-    )
-    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_type", title="Extension field for ``type``."
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``GraphDefinitionLinkTarget`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "type",
+            "sourceId",
+            "path",
+            "sliceName",
+            "targetId",
             "params",
-            "profile",
             "compartment",
-            "link",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_2731(
+    def validate_required_primitive_elements_2107(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
         """https://www.hl7.org/fhir/extensibility.html#Special-Case
@@ -557,7 +646,7 @@ class GraphDefinitionLinkTarget(backboneelement.BackboneElement):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("type", "type__ext")]
+        required_fields = [("sourceId", "sourceId__ext"), ("targetId", "targetId__ext")]
         _missing = object()
 
         def _fallback():
@@ -606,7 +695,7 @@ class GraphDefinitionLinkTarget(backboneelement.BackboneElement):
         return values
 
 
-class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
+class GraphDefinitionLinkCompartment(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -614,19 +703,29 @@ class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
     Compartment Consistency Rules.
     """
 
-    resource_type = Field("GraphDefinitionLinkTargetCompartment", const=True)
+    resource_type = Field("GraphDefinitionLinkCompartment", const=True)
 
     code: fhirtypes.Code = Field(
         None,
         alias="code",
-        title="Patient | Encounter | RelatedPerson | Practitioner | Device",
+        title=(
+            "Patient | Encounter | RelatedPerson | Practitioner | Device | "
+            "EpisodeOfCare"
+        ),
         description="Identifies the compartment.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["Patient", "Encounter", "RelatedPerson", "Practitioner", "Device"],
+        enum_values=[
+            "Patient",
+            "Encounter",
+            "RelatedPerson",
+            "Practitioner",
+            "Device",
+            "EpisodeOfCare",
+        ],
     )
     code__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_code", title="Extension field for ``code``."
@@ -675,7 +774,7 @@ class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
     use: fhirtypes.Code = Field(
         None,
         alias="use",
-        title="condition | requirement",
+        title="where | requires",
         description=(
             "Defines how the compartment rule is used - whether it it is used to "
             "test whether resources are subject to the rule, or whether it is a "
@@ -686,7 +785,7 @@ class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["condition", "requirement"],
+        enum_values=["where", "requires"],
     )
     use__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_use", title="Extension field for ``use``."
@@ -695,7 +794,7 @@ class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``GraphDefinitionLinkTargetCompartment`` according specification,
+        ``GraphDefinitionLinkCompartment`` according specification,
         with preserving original sequence order.
         """
         return [
@@ -703,14 +802,14 @@ class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
             "extension",
             "modifierExtension",
             "use",
-            "code",
             "rule",
+            "code",
             "expression",
             "description",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_3893(
+    def validate_required_primitive_elements_3278(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
         """https://www.hl7.org/fhir/extensibility.html#Special-Case
@@ -771,3 +870,144 @@ class GraphDefinitionLinkTargetCompartment(backboneelement.BackboneElement):
             raise ValidationError(errors, cls)  # type: ignore
 
         return values
+
+
+class GraphDefinitionNode(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Potential target for the link.
+    """
+
+    resource_type = Field("GraphDefinitionNode", const=True)
+
+    description: fhirtypes.String = Field(
+        None,
+        alias="description",
+        title="Why this node is specified",
+        description=(
+            "Information about why this node is of interest in this graph "
+            "definition."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_description", title="Extension field for ``description``."
+    )
+
+    nodeId: fhirtypes.Id = Field(
+        None,
+        alias="nodeId",
+        title="Internal ID - target for link references",
+        description="Internal ID of node - target for link references.",
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+    )
+    nodeId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_nodeId", title="Extension field for ``nodeId``."
+    )
+
+    profile: fhirtypes.Canonical = Field(
+        None,
+        alias="profile",
+        title="Profile for the target resource",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["StructureDefinition"],
+    )
+    profile__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_profile", title="Extension field for ``profile``."
+    )
+
+    type: fhirtypes.Code = Field(
+        None,
+        alias="type",
+        title="Type of resource this link refers to",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+    )
+    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_type", title="Extension field for ``type``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``GraphDefinitionNode`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "nodeId",
+            "description",
+            "type",
+            "profile",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_required_primitive_elements_2093(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/extensibility.html#Special-Case
+        In some cases, implementers might find that they do not have appropriate data for
+        an element with minimum cardinality = 1. In this case, the element must be present,
+        but unless the resource or a profile on it has made the actual value of the primitive
+        data type mandatory, it is possible to provide an extension that explains why
+        the primitive value is not present.
+        """
+        required_fields = [("nodeId", "nodeId__ext"), ("type", "type__ext")]
+        _missing = object()
+
+        def _fallback():
+            return ""
+
+        errors: typing.List["ErrorWrapper"] = []
+        for name, ext in required_fields:
+            field = cls.__fields__[name]
+            ext_field = cls.__fields__[ext]
+            value = values.get(field.alias, _missing)
+            if value not in (_missing, None):
+                continue
+            ext_value = values.get(ext_field.alias, _missing)
+            missing_ext = True
+            if ext_value not in (_missing, None):
+                if isinstance(ext_value, dict):
+                    missing_ext = len(ext_value.get("extension", [])) == 0
+                elif (
+                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
+                    == "FHIRPrimitiveExtension"
+                ):
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+                else:
+                    validate_pass = True
+                    for validator in ext_field.type_.__get_validators__():
+                        try:
+                            ext_value = validator(v=ext_value)
+                        except ValidationError as exc:
+                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
+                            validate_pass = False
+                    if not validate_pass:
+                        continue
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+            if missing_ext:
+                if value is _missing:
+                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
+                else:
+                    errors.append(
+                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
+                    )
+        if len(errors) > 0:
+            raise ValidationError(errors, cls)  # type: ignore
+
+        return values
