@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Group
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Group(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -44,23 +44,6 @@ class Group(domainresource.DomainResource):
         None, alias="_active", title="Extension field for ``active``."
     )
 
-    actual: bool = Field(
-        None,
-        alias="actual",
-        title="Descriptive or actual",
-        description=(
-            "If true, indicates that the resource refers to a specific group of "
-            "real individuals.  If false, the group defines a set of intended "
-            "individuals."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        element_required=True,
-    )
-    actual__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_actual", title="Extension field for ``actual``."
-    )
-
     characteristic: typing.List[fhirtypes.GroupCharacteristicType] = Field(
         None,
         alias="characteristic",
@@ -85,11 +68,30 @@ class Group(domainresource.DomainResource):
         element_property=True,
     )
 
+    description: fhirtypes.Markdown = Field(
+        None,
+        alias="description",
+        title="Natural language description of the group",
+        description=(
+            "Explanation of what the group represents and how it is intended to be "
+            "used."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_description", title="Extension field for ``description``."
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
-        title="Unique id",
-        description="A unique business identifier for this group.",
+        title="Business Identifier for this Group",
+        description=(
+            "Business identifiers assigned to this participant by one of the "
+            "applications involved.  These identifiers remain constant as the "
+            "resource is updated and propagates from server to server."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -122,6 +124,32 @@ class Group(domainresource.DomainResource):
         element_property=True,
     )
 
+    membership: fhirtypes.Code = Field(
+        None,
+        alias="membership",
+        title="definitional | enumerated",
+        description=(
+            "Basis for membership in the Group:  * 'definitional': The "
+            "Group.characteristics specified are both necessary and sufficient to "
+            "determine membership. All entities that meet the criteria are "
+            "considered to be members of the group, whether referenced by the group"
+            " or not. If members are present, they are individuals that happen to "
+            "be known as meeting the Group.characteristics. The list cannot be "
+            "presumed to be complete. * 'enumerated': The Group.characteristics are"
+            " necessary but not sufficient to determine membership. Membership is "
+            "determined by being listed as one of the Group.member."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["definitional", "enumerated"],
+    )
+    membership__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_membership", title="Extension field for ``membership``."
+    )
+
     name: fhirtypes.String = Field(
         None,
         alias="name",
@@ -154,7 +182,10 @@ class Group(domainresource.DomainResource):
     type: fhirtypes.Code = Field(
         None,
         alias="type",
-        title="person | animal | practitioner | device | medication | substance",
+        title=(
+            "person | animal | practitioner | device | careteam | healthcareservice"
+            " | location | organization | relatedperson | specimen"
+        ),
         description=(
             "Identifies the broad classification of the kind of resources the group"
             " includes."
@@ -169,14 +200,46 @@ class Group(domainresource.DomainResource):
             "animal",
             "practitioner",
             "device",
-            "medication",
-            "substance",
+            "careteam",
+            "healthcareservice",
+            "location",
+            "organization",
+            "relatedperson",
+            "specimen",
         ],
     )
     type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Group`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "active",
+            "type",
+            "membership",
+            "code",
+            "name",
+            "description",
+            "quantity",
+            "managingEntity",
+            "characteristic",
+            "member",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_708(
         cls, values: typing.Dict[str, typing.Any]
@@ -188,7 +251,7 @@ class Group(domainresource.DomainResource):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("actual", "actual__ext"), ("type", "type__ext")]
+        required_fields = [("membership", "membership__ext"), ("type", "type__ext")]
         _missing = object()
 
         def _fallback():
@@ -238,7 +301,7 @@ class Group(domainresource.DomainResource):
 
 
 class GroupCharacteristic(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -364,6 +427,26 @@ class GroupCharacteristic(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``GroupCharacteristic`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "valueCodeableConcept",
+            "valueBoolean",
+            "valueQuantity",
+            "valueRange",
+            "valueReference",
+            "exclude",
+            "period",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2144(
         cls, values: typing.Dict[str, typing.Any]
@@ -471,7 +554,7 @@ class GroupCharacteristic(backboneelement.BackboneElement):
 
 
 class GroupMember(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -494,13 +577,17 @@ class GroupMember(backboneelement.BackboneElement):
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
+            "CareTeam",
+            "Device",
+            "Group",
+            "HealthcareService",
+            "Location",
+            "Organization",
             "Patient",
             "Practitioner",
             "PractitionerRole",
-            "Device",
-            "Medication",
-            "Substance",
-            "Group",
+            "RelatedPerson",
+            "Specimen",
         ],
     )
 
@@ -527,3 +614,11 @@ class GroupMember(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``GroupMember`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "entity", "period", "inactive"]
