@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/GuidanceResponse
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -57,7 +57,7 @@ class GuidanceResponse(domainresource.DomainResource):
         enum_reference_types=["Encounter"],
     )
 
-    evaluationMessage: typing.List[fhirtypes.ReferenceType] = Field(
+    evaluationMessage: fhirtypes.ReferenceType = Field(
         None,
         alias="evaluationMessage",
         title="Messages resulting from the evaluation of the artifact or artifacts",
@@ -191,39 +191,22 @@ class GuidanceResponse(domainresource.DomainResource):
         enum_reference_types=["Device"],
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Why guidance is needed",
         description=(
             "Describes the reason for the guidance response in coded or textual "
-            "form."
+            "form, or Indicates the reason the request was initiated. This is "
+            "typically provided as a parameter to the evaluation and echoed by the "
+            "service, although for some use cases, such as subscription- or event-"
+            "based scenarios, it may provide an indication of the cause for the "
+            "response."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Why guidance is needed",
-        description=(
-            "Indicates the reason the request was initiated. This is typically "
-            "provided as a parameter to the evaluation and echoed by the service, "
-            "although for some use cases, such as subscription- or event-based "
-            "scenarios, it may provide an indication of the cause for the response."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Condition",
-            "Observation",
-            "DiagnosticReport",
-            "DocumentReference",
-        ],
-    )
-
     requestIdentifier: fhirtypes.IdentifierType = Field(
         None,
         alias="requestIdentifier",
@@ -238,7 +221,7 @@ class GuidanceResponse(domainresource.DomainResource):
         element_property=True,
     )
 
-    result: fhirtypes.ReferenceType = Field(
+    result: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="result",
         title="Proposed actions, if any",
@@ -246,7 +229,25 @@ class GuidanceResponse(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["CarePlan", "RequestGroup"],
+        enum_reference_types=[
+            "Appointment",
+            "AppointmentResponse",
+            "CarePlan",
+            "Claim",
+            "CommunicationRequest",
+            "Contract",
+            "CoverageEligibilityRequest",
+            "DeviceRequest",
+            "EnrollmentRequest",
+            "ImmunizationRecommendation",
+            "MedicationRequest",
+            "NutritionOrder",
+            "RequestOrchestration",
+            "ServiceRequest",
+            "SupplyRequest",
+            "Task",
+            "VisionPrescription",
+        ],
     )
 
     status: fhirtypes.Code = Field(
@@ -321,8 +322,7 @@ class GuidanceResponse(domainresource.DomainResource):
             "encounter",
             "occurrenceDateTime",
             "performer",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "note",
             "evaluationMessage",
             "outputParameters",
