@@ -1,16 +1,14 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/HealthcareService
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
-from pydantic import Field, root_validator
-from pydantic.error_wrappers import ErrorWrapper, ValidationError
-from pydantic.errors import MissingError, NoneIsNotAllowedError
+from pydantic import Field
 
 from . import backboneelement, domainresource, fhirtypes
 
@@ -60,30 +58,11 @@ class HealthcareService(domainresource.DomainResource):
         title="Extension field for ``appointmentRequired``.",
     )
 
-    availabilityExceptions: fhirtypes.String = Field(
+    availability: typing.List[fhirtypes.AvailabilityType] = Field(
         None,
-        alias="availabilityExceptions",
-        title="Description of availability exceptions",
-        description=(
-            "A description of site availability exceptions, e.g. public holiday "
-            "availability. Succinctly describing all possible exceptions to normal "
-            "site availability as details in the available Times and not available "
-            "Times."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    availabilityExceptions__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_availabilityExceptions",
-        title="Extension field for ``availabilityExceptions``.",
-    )
-
-    availableTime: typing.List[fhirtypes.HealthcareServiceAvailableTimeType] = Field(
-        None,
-        alias="availableTime",
-        title="Times the Service Site is available",
-        description="A collection of times that the Service Site is available.",
+        alias="availability",
+        title="Times the healthcare service is available (including exceptions)",
+        description="A collection of times that the healthcare service is available.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -106,7 +85,7 @@ class HealthcareService(domainresource.DomainResource):
         element_property=True,
     )
 
-    comment: fhirtypes.String = Field(
+    comment: fhirtypes.Markdown = Field(
         None,
         alias="comment",
         title=(
@@ -138,6 +117,19 @@ class HealthcareService(domainresource.DomainResource):
         element_property=True,
     )
 
+    contact: typing.List[fhirtypes.ExtendedContactDetailType] = Field(
+        None,
+        alias="contact",
+        title="Official contact details for the HealthcareService",
+        description=(
+            "The contact details of communication devices available relevant to the"
+            " specific HealthcareService. This can include addresses, phone "
+            "numbers, fax numbers, mobile numbers, email addresses and web sites."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     coverageArea: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="coverageArea",
@@ -231,16 +223,18 @@ class HealthcareService(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
-    notAvailable: typing.List[fhirtypes.HealthcareServiceNotAvailableType] = Field(
+    offeredIn: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="notAvailable",
-        title="Not available during this time due to provided reason",
+        alias="offeredIn",
+        title="The service within which this service is offered",
         description=(
-            "The HealthcareService is not available during this period of time due "
-            "to the provided reason."
+            "When the HealthcareService is representing a specific, schedulable "
+            "service, the availableIn property can refer to a generic service."
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["HealthcareService"],
     )
 
     photo: fhirtypes.AttachmentType = Field(
@@ -305,22 +299,13 @@ class HealthcareService(domainresource.DomainResource):
         alias="specialty",
         title="Specialties handled by the HealthcareService",
         description=(
-            "Collection of specialties handled by the service site. This is more of"
-            " a medical term."
+            "Collection of specialties handled by the Healthcare service. This is "
+            "more of a medical term."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    telecom: typing.List[fhirtypes.ContactPointType] = Field(
-        None,
-        alias="telecom",
-        title="Contacts related to the healthcare service",
-        description="List of contacts related to this specific healthcare service.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     type: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="type",
@@ -348,6 +333,7 @@ class HealthcareService(domainresource.DomainResource):
             "identifier",
             "active",
             "providedBy",
+            "offeredIn",
             "category",
             "type",
             "specialty",
@@ -356,7 +342,7 @@ class HealthcareService(domainresource.DomainResource):
             "comment",
             "extraDetails",
             "photo",
-            "telecom",
+            "contact",
             "coverageArea",
             "serviceProvisionCode",
             "eligibility",
@@ -365,108 +351,11 @@ class HealthcareService(domainresource.DomainResource):
             "communication",
             "referralMethod",
             "appointmentRequired",
-            "availableTime",
-            "notAvailable",
-            "availabilityExceptions",
+            "availability",
             "endpoint",
         ]
 
 
-class HealthcareServiceAvailableTime(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Times the Service Site is available.
-    A collection of times that the Service Site is available.
-    """
-
-    resource_type = Field("HealthcareServiceAvailableTime", const=True)
-
-    allDay: bool = Field(
-        None,
-        alias="allDay",
-        title="Always available? e.g. 24 hour service",
-        description=(
-            "Is this always available? (hence times are irrelevant) e.g. 24 hour "
-            "service."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    allDay__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_allDay", title="Extension field for ``allDay``."
-    )
-
-    availableEndTime: fhirtypes.Time = Field(
-        None,
-        alias="availableEndTime",
-        title="Closing time of day (ignored if allDay = true)",
-        description=(
-            "The closing time of day. Note: If the AllDay flag is set, then this "
-            "time is ignored."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    availableEndTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_availableEndTime",
-        title="Extension field for ``availableEndTime``.",
-    )
-
-    availableStartTime: fhirtypes.Time = Field(
-        None,
-        alias="availableStartTime",
-        title="Opening time of day (ignored if allDay = true)",
-        description=(
-            "The opening time of day. Note: If the AllDay flag is set, then this "
-            "time is ignored."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    availableStartTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_availableStartTime",
-        title="Extension field for ``availableStartTime``.",
-    )
-
-    daysOfWeek: typing.List[typing.Optional[fhirtypes.Code]] = Field(
-        None,
-        alias="daysOfWeek",
-        title="mon | tue | wed | thu | fri | sat | sun",
-        description=(
-            "Indicates which days of the week are available between the start and "
-            "end Times."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["mon", "tue", "wed", "thu", "fri", "sat", "sun"],
-    )
-    daysOfWeek__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(None, alias="_daysOfWeek", title="Extension field for ``daysOfWeek``.")
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``HealthcareServiceAvailableTime`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "daysOfWeek",
-            "allDay",
-            "availableStartTime",
-            "availableEndTime",
-        ]
-
-
 class HealthcareServiceEligibility(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -507,111 +396,3 @@ class HealthcareServiceEligibility(backboneelement.BackboneElement):
         with preserving original sequence order.
         """
         return ["id", "extension", "modifierExtension", "code", "comment"]
-
-
-class HealthcareServiceNotAvailable(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Not available during this time due to provided reason.
-    The HealthcareService is not available during this period of time due to
-    the provided reason.
-    """
-
-    resource_type = Field("HealthcareServiceNotAvailable", const=True)
-
-    description: fhirtypes.String = Field(
-        None,
-        alias="description",
-        title="Reason presented to the user explaining why time not available",
-        description=(
-            "The reason that can be presented to the user as to why this time is "
-            "not available."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        element_required=True,
-    )
-    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_description", title="Extension field for ``description``."
-    )
-
-    during: fhirtypes.PeriodType = Field(
-        None,
-        alias="during",
-        title="Service not available from this date",
-        description=(
-            "Service is not available (seasonally or for a public holiday) from "
-            "this date."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``HealthcareServiceNotAvailable`` according specification,
-        with preserving original sequence order.
-        """
-        return ["id", "extension", "modifierExtension", "description", "during"]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_3105(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("description", "description__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
