@@ -1,25 +1,27 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/HumanName
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
 from pydantic import Field
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class HumanName(element.Element):
+class HumanName(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Name of a human - parts and usage.
-    A human's name with the ability to identify parts and usage.
+    Name of a human or other living entity - parts and usage.
+    A name, normally of a human, that can be used for other living entities
+    (e.g. animals but not organizations) that have been assigned names by a
+    human and may need the use of name parts or the need for usage information.
     """
 
     resource_type = Field("HumanName", const=True)
