@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ImagingStudy
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -101,25 +101,11 @@ class ImagingStudy(domainresource.DomainResource):
         None,
         alias="identifier",
         title="Identifiers for the whole study",
-        description=(
-            "Identifiers for the ImagingStudy such as DICOM Study Instance UID, and"
-            " Accession Number."
-        ),
+        description="Identifiers for the ImagingStudy such as DICOM Study Instance UID.",
         # if property is element of this resource.
         element_property=True,
     )
 
-    interpreter: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="interpreter",
-        title="Who interpreted images",
-        description="Who read the study and interpreted the images or other content.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole"],
-    )
-
     location: fhirtypes.ReferenceType = Field(
         None,
         alias="location",
@@ -131,14 +117,13 @@ class ImagingStudy(domainresource.DomainResource):
         enum_reference_types=["Location"],
     )
 
-    modality: typing.List[fhirtypes.CodingType] = Field(
+    modality: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="modality",
-        title="All series modality if actual acquisition modalities",
+        title="All of the distinct values for series' modalities",
         description=(
-            "A list of all the series.modality values that are actual acquisition "
-            "modalities, i.e. those in the DICOM Context Group 29 (value set OID "
-            "1.2.840.10008.6.1.19)."
+            "A list of all the distinct values of series.modality. This may include"
+            " both acquisition and non-acquisition modalities."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -194,50 +179,50 @@ class ImagingStudy(domainresource.DomainResource):
         None, alias="_numberOfSeries", title="Extension field for ``numberOfSeries``."
     )
 
-    procedureCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    partOf: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="procedureCode",
-        title="The performed procedure code",
-        description="The code for the performed procedure type.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    procedureReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="procedureReference",
-        title="The performed Procedure reference",
-        description="The procedure which this ImagingStudy was part of.",
+        alias="partOf",
+        title="Part of referenced event",
+        description=(
+            "A larger event of which this particular ImagingStudy is a component or"
+            " step.  For example,  an ImagingStudy as part of a procedure."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Procedure"],
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    procedure: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
-        title="Why the study was requested",
+        alias="procedure",
+        title="The performed procedure or code",
         description=(
-            "Description of clinical condition indicating why the ImagingStudy was "
-            "requested."
+            "This field corresponds to the DICOM Procedure Code Sequence "
+            "(0008,1032). This is different from the FHIR Procedure resource that "
+            "may include the ImagingStudy."
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["PlanDefinition", "ActivityDefinition"],
     )
 
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonReference",
-        title="Why was study performed",
-        description="Indicates another resource whose existence justifies this Study.",
+        alias="reason",
+        title="Why the study was requested / performed",
+        description=(
+            "Description of clinical condition indicating why the ImagingStudy was "
+            "requested, and/or Indicates another resource whose existence justifies"
+            " this Study."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Condition",
             "Observation",
-            "Media",
             "DiagnosticReport",
             "DocumentReference",
         ],
@@ -279,7 +264,11 @@ class ImagingStudy(domainresource.DomainResource):
         None,
         alias="status",
         title="registered | available | cancelled | entered-in-error | unknown",
-        description="The current state of the ImagingStudy.",
+        description=(
+            "The current state of the ImagingStudy resource. This is not the status"
+            " of any ServiceRequest or Task resources associated with the "
+            "ImagingStudy."
+        ),
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -330,16 +319,14 @@ class ImagingStudy(domainresource.DomainResource):
             "encounter",
             "started",
             "basedOn",
+            "partOf",
             "referrer",
-            "interpreter",
             "endpoint",
             "numberOfSeries",
             "numberOfInstances",
-            "procedureReference",
-            "procedureCode",
+            "procedure",
             "location",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "note",
             "description",
             "series",
@@ -416,7 +403,7 @@ class ImagingStudySeries(backboneelement.BackboneElement):
 
     resource_type = Field("ImagingStudySeries", const=True)
 
-    bodySite: fhirtypes.CodingType = Field(
+    bodySite: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="bodySite",
         title="Body part examined",
@@ -429,6 +416,8 @@ class ImagingStudySeries(backboneelement.BackboneElement):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["BodyStructure"],
     )
 
     description: fhirtypes.String = Field(
@@ -471,7 +460,7 @@ class ImagingStudySeries(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    laterality: fhirtypes.CodingType = Field(
+    laterality: fhirtypes.CodeableConceptType = Field(
         None,
         alias="laterality",
         title="Body part laterality",
@@ -485,11 +474,14 @@ class ImagingStudySeries(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    modality: fhirtypes.CodingType = Field(
+    modality: fhirtypes.CodeableConceptType = Field(
         ...,
         alias="modality",
-        title="The modality of the instances in the series",
-        description="The modality of this series sequence.",
+        title="The modality used for this series",
+        description=(
+            "The distinct modality for this series. This may include both "
+            "acquisition and non-acquisition modalities."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -815,6 +807,7 @@ class ImagingStudySeriesPerformer(backboneelement.BackboneElement):
             "Patient",
             "Device",
             "RelatedPerson",
+            "HealthcareService",
         ],
     )
 
