@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Immunization
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -27,6 +27,42 @@ class Immunization(domainresource.DomainResource):
 
     resource_type = Field("Immunization", const=True)
 
+    administeredProduct: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="administeredProduct",
+        title="Product that was administered",
+        description=(
+            "An indication of which product was administered to the patient. This "
+            "is typically a more detailed representation of the concept conveyed by"
+            " the vaccineCode data element. If a Medication resource is referenced,"
+            " it may be to a stand-alone resource or a contained resource within "
+            "the Immunization resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Medication"],
+    )
+
+    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="basedOn",
+        title="Authority that the immunization event is based on",
+        description=(
+            "A plan, order or recommendation fulfilled in whole or in part by this "
+            "immunization."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "CarePlan",
+            "MedicationRequest",
+            "ServiceRequest",
+            "ImmunizationRecommendation",
+        ],
+    )
+
     doseQuantity: fhirtypes.QuantityType = Field(
         None,
         alias="doseQuantity",
@@ -36,18 +72,6 @@ class Immunization(domainresource.DomainResource):
         element_property=True,
     )
 
-    education: typing.List[fhirtypes.ImmunizationEducationType] = Field(
-        None,
-        alias="education",
-        title="Educational material presented to patient",
-        description=(
-            "Educational material presented to the patient (or guardian) at the "
-            "time of vaccine administration."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
@@ -98,6 +122,27 @@ class Immunization(domainresource.DomainResource):
         element_property=True,
     )
 
+    informationSource: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="informationSource",
+        title="Indicates the source of a  reported record",
+        description=(
+            "Typically the source of the data when the report of the immunization "
+            "event is not based on information from the person who administered the"
+            " vaccine."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "Organization",
+        ],
+    )
+
     isSubpotent: bool = Field(
         None,
         alias="isSubpotent",
@@ -139,7 +184,7 @@ class Immunization(domainresource.DomainResource):
         None, alias="_lotNumber", title="Extension field for ``lotNumber``."
     )
 
-    manufacturer: fhirtypes.ReferenceType = Field(
+    manufacturer: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="manufacturer",
         title="Vaccine manufacturer",
@@ -219,11 +264,14 @@ class Immunization(domainresource.DomainResource):
     primarySource: bool = Field(
         None,
         alias="primarySource",
-        title="Indicates context the data was recorded in",
+        title="Indicates context the data was captured in",
         description=(
-            "An indication that the content of the record is based on information "
-            "from the person who administered the vaccine. This reflects the "
-            "context under which the data was originally recorded."
+            "Indicates whether the data contained in the resource was captured by "
+            "the individual/organization which was responsible for the "
+            "administration of the vaccine rather than as 'secondary reported' data"
+            " documented by a third party. A value of 'true' means this data "
+            "originated with the individual/organization which was responsible for "
+            "the administration of the vaccine."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -232,10 +280,12 @@ class Immunization(domainresource.DomainResource):
         None, alias="_primarySource", title="Extension field for ``primarySource``."
     )
 
-    programEligibility: typing.List[fhirtypes.CodeableConceptType] = Field(
+    programEligibility: typing.List[
+        fhirtypes.ImmunizationProgramEligibilityType
+    ] = Field(
         None,
         alias="programEligibility",
-        title="Patient eligibility for a vaccination program",
+        title="Patient eligibility for a specific vaccination program",
         description="Indicates a patient's eligibility for a funding program.",
         # if property is element of this resource.
         element_property=True,
@@ -265,22 +315,14 @@ class Immunization(domainresource.DomainResource):
         element_property=True,
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
-        title="Why immunization occurred",
-        description="Reasons why the vaccine was administered.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
+        alias="reason",
         title="Why immunization occurred",
         description=(
-            "Condition, Observation or DiagnosticReport that supports why the "
-            "immunization was administered."
+            "Describes why the immunization occurred in coded or textual form, or "
+            "Indicates another resource (Condition, Observation or "
+            "DiagnosticReport) whose existence justifies this immunization."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -288,33 +330,6 @@ class Immunization(domainresource.DomainResource):
         enum_reference_types=["Condition", "Observation", "DiagnosticReport"],
     )
 
-    recorded: fhirtypes.DateTime = Field(
-        None,
-        alias="recorded",
-        title="When the immunization was first captured in the subject's record",
-        description=(
-            "The date the occurrence of the immunization was first captured in the "
-            "record - potentially significantly after the occurrence of the event."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    recorded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_recorded", title="Extension field for ``recorded``."
-    )
-
-    reportOrigin: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="reportOrigin",
-        title="Indicates the source of a secondarily reported record",
-        description=(
-            "The source of the data when the report of the immunization event is "
-            "not based on information from the person who administered the vaccine."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     route: fhirtypes.CodeableConceptType = Field(
         None,
         alias="route",
@@ -352,7 +367,7 @@ class Immunization(domainresource.DomainResource):
     statusReason: fhirtypes.CodeableConceptType = Field(
         None,
         alias="statusReason",
-        title="Reason not done",
+        title="Reason for current status",
         description="Indicates the reason the immunization event was not performed.",
         # if property is element of this resource.
         element_property=True,
@@ -367,10 +382,29 @@ class Immunization(domainresource.DomainResource):
         element_property=True,
     )
 
+    supportingInformation: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="supportingInformation",
+        title="Additional information in support of the immunization",
+        description=(
+            "Additional information that is relevant to the immunization (e.g. for "
+            "a vaccine recipient who is pregnant, the gestational age of the "
+            "fetus). The reason why a vaccine was given (e.g. occupation, "
+            "underlying medical condition) should be conveyed in "
+            "Immunization.reason, not as supporting information. The reason why a "
+            "vaccine was not given (e.g. contraindication) should be conveyed in "
+            "Immunization.statusReason, not as supporting information."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
     vaccineCode: fhirtypes.CodeableConceptType = Field(
         ...,
         alias="vaccineCode",
-        title="Vaccine product administered",
+        title="Vaccine administered",
         description="Vaccine that was administered or was to be administered.",
         # if property is element of this resource.
         element_property=True,
@@ -392,30 +426,30 @@ class Immunization(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "identifier",
+            "basedOn",
             "status",
             "statusReason",
             "vaccineCode",
-            "patient",
-            "encounter",
-            "occurrenceDateTime",
-            "occurrenceString",
-            "recorded",
-            "primarySource",
-            "reportOrigin",
-            "location",
+            "administeredProduct",
             "manufacturer",
             "lotNumber",
             "expirationDate",
+            "patient",
+            "encounter",
+            "supportingInformation",
+            "occurrenceDateTime",
+            "occurrenceString",
+            "primarySource",
+            "informationSource",
+            "location",
             "site",
             "route",
             "doseQuantity",
             "performer",
             "note",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "isSubpotent",
             "subpotentReason",
-            "education",
             "programEligibility",
             "fundingSource",
             "reaction",
@@ -520,88 +554,6 @@ class Immunization(domainresource.DomainResource):
         return values
 
 
-class ImmunizationEducation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Educational material presented to patient.
-    Educational material presented to the patient (or guardian) at the time of
-    vaccine administration.
-    """
-
-    resource_type = Field("ImmunizationEducation", const=True)
-
-    documentType: fhirtypes.String = Field(
-        None,
-        alias="documentType",
-        title="Educational material document identifier",
-        description="Identifier of the material presented to the patient.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-    documentType__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_documentType", title="Extension field for ``documentType``."
-    )
-
-    presentationDate: fhirtypes.DateTime = Field(
-        None,
-        alias="presentationDate",
-        title="Educational material presentation date",
-        description="Date the educational material was given to the patient.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-    presentationDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_presentationDate",
-        title="Extension field for ``presentationDate``.",
-    )
-
-    publicationDate: fhirtypes.DateTime = Field(
-        None,
-        alias="publicationDate",
-        title="Educational material publication date",
-        description="Date the educational material was published.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-    publicationDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_publicationDate", title="Extension field for ``publicationDate``."
-    )
-
-    reference: fhirtypes.Uri = Field(
-        None,
-        alias="reference",
-        title="Educational material reference pointer",
-        description=(
-            "Reference pointer to the educational material given to the patient if "
-            "the information was on line."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    reference__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_reference", title="Extension field for ``reference``."
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``ImmunizationEducation`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "documentType",
-            "reference",
-            "publicationDate",
-            "presentationDate",
-        ]
-
-
 class ImmunizationPerformer(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -621,7 +573,13 @@ class ImmunizationPerformer(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole", "Organization"],
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Organization",
+            "Patient",
+            "RelatedPerson",
+        ],
     )
 
     function: fhirtypes.CodeableConceptType = Field(
@@ -645,6 +603,47 @@ class ImmunizationPerformer(backboneelement.BackboneElement):
         return ["id", "extension", "modifierExtension", "function", "actor"]
 
 
+class ImmunizationProgramEligibility(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Patient eligibility for a specific vaccination program.
+    Indicates a patient's eligibility for a funding program.
+    """
+
+    resource_type = Field("ImmunizationProgramEligibility", const=True)
+
+    program: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="program",
+        title="The program that eligibility is declared for",
+        description="Indicates which program the patient had their eligility evaluated for.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    programStatus: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="programStatus",
+        title="The patient's eligibility status for the program",
+        description=(
+            "Indicates the patient's eligility status for for a specific payment "
+            "program."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationProgramEligibility`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "program", "programStatus"]
+
+
 class ImmunizationProtocolApplied(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -671,38 +670,20 @@ class ImmunizationProtocolApplied(backboneelement.BackboneElement):
         enum_reference_types=["Organization"],
     )
 
-    doseNumberPositiveInt: fhirtypes.PositiveInt = Field(
+    doseNumber: fhirtypes.String = Field(
         None,
-        alias="doseNumberPositiveInt",
+        alias="doseNumber",
         title="Dose number within series",
-        description="Nominal position in a series.",
+        description=(
+            "Nominal position in a series as intended by the practitioner "
+            "administering the dose."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e doseNumber[x]
-        one_of_many="doseNumber",
-        one_of_many_required=True,
+        element_required=True,
     )
-    doseNumberPositiveInt__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_doseNumberPositiveInt",
-        title="Extension field for ``doseNumberPositiveInt``.",
-    )
-
-    doseNumberString: fhirtypes.String = Field(
-        None,
-        alias="doseNumberString",
-        title="Dose number within series",
-        description="Nominal position in a series.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e doseNumber[x]
-        one_of_many="doseNumber",
-        one_of_many_required=True,
-    )
-    doseNumberString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_doseNumberString",
-        title="Extension field for ``doseNumberString``.",
+    doseNumber__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_doseNumber", title="Extension field for ``doseNumber``."
     )
 
     series: fhirtypes.String = Field(
@@ -720,44 +701,25 @@ class ImmunizationProtocolApplied(backboneelement.BackboneElement):
         None, alias="_series", title="Extension field for ``series``."
     )
 
-    seriesDosesPositiveInt: fhirtypes.PositiveInt = Field(
+    seriesDoses: fhirtypes.String = Field(
         None,
-        alias="seriesDosesPositiveInt",
+        alias="seriesDoses",
         title="Recommended number of doses for immunity",
-        description="The recommended number of doses to achieve immunity.",
+        description=(
+            "The recommended number of doses to achieve immunity as intended by the"
+            " practitioner administering the dose."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e seriesDoses[x]
-        one_of_many="seriesDoses",
-        one_of_many_required=False,
     )
-    seriesDosesPositiveInt__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_seriesDosesPositiveInt",
-        title="Extension field for ``seriesDosesPositiveInt``.",
-    )
-
-    seriesDosesString: fhirtypes.String = Field(
-        None,
-        alias="seriesDosesString",
-        title="Recommended number of doses for immunity",
-        description="The recommended number of doses to achieve immunity.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e seriesDoses[x]
-        one_of_many="seriesDoses",
-        one_of_many_required=False,
-    )
-    seriesDosesString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_seriesDosesString",
-        title="Extension field for ``seriesDosesString``.",
+    seriesDoses__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_seriesDoses", title="Extension field for ``seriesDoses``."
     )
 
     targetDisease: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="targetDisease",
-        title="Vaccine preventatable disease being targetted",
+        title="Vaccine preventatable disease being targeted",
         description=(
             "The vaccine preventable disease the dose is being administered " "against."
         ),
@@ -778,50 +740,66 @@ class ImmunizationProtocolApplied(backboneelement.BackboneElement):
             "series",
             "authority",
             "targetDisease",
-            "doseNumberPositiveInt",
-            "doseNumberString",
-            "seriesDosesPositiveInt",
-            "seriesDosesString",
+            "doseNumber",
+            "seriesDoses",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_3010(
+    def validate_required_primitive_elements_3010(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
+        """https://www.hl7.org/fhir/extensibility.html#Special-Case
+        In some cases, implementers might find that they do not have appropriate data for
+        an element with minimum cardinality = 1. In this case, the element must be present,
+        but unless the resource or a profile on it has made the actual value of the primitive
+        data type mandatory, it is possible to provide an extension that explains why
+        the primitive value is not present.
         """
-        one_of_many_fields = {
-            "doseNumber": ["doseNumberPositiveInt", "doseNumberString"],
-            "seriesDoses": ["seriesDosesPositiveInt", "seriesDosesString"],
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
+        required_fields = [("doseNumber", "doseNumber__ext")]
+        _missing = object()
+
+        def _fallback():
+            return ""
+
+        errors: typing.List["ErrorWrapper"] = []
+        for name, ext in required_fields:
+            field = cls.__fields__[name]
+            ext_field = cls.__fields__[ext]
+            value = values.get(field.alias, _missing)
+            if value not in (_missing, None):
+                continue
+            ext_value = values.get(ext_field.alias, _missing)
+            missing_ext = True
+            if ext_value not in (_missing, None):
+                if isinstance(ext_value, dict):
+                    missing_ext = len(ext_value.get("extension", [])) == 0
+                elif (
+                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
+                    == "FHIRPrimitiveExtension"
+                ):
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+                else:
+                    validate_pass = True
+                    for validator in ext_field.type_.__get_validators__():
+                        try:
+                            ext_value = validator(v=ext_value)
+                        except ValidationError as exc:
+                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
+                            validate_pass = False
+                    if not validate_pass:
+                        continue
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+            if missing_ext:
+                if value is _missing:
+                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
+                else:
+                    errors.append(
+                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
+                    )
+        if len(errors) > 0:
+            raise ValidationError(errors, cls)  # type: ignore
 
         return values
 
@@ -850,9 +828,9 @@ class ImmunizationReaction(backboneelement.BackboneElement):
         None, alias="_date", title="Extension field for ``date``."
     )
 
-    detail: fhirtypes.ReferenceType = Field(
+    manifestation: fhirtypes.CodeableReferenceType = Field(
         None,
-        alias="detail",
+        alias="manifestation",
         title="Additional information on reaction",
         description="Details of the reaction.",
         # if property is element of this resource.
@@ -879,4 +857,11 @@ class ImmunizationReaction(backboneelement.BackboneElement):
         ``ImmunizationReaction`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "date", "detail", "reported"]
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "date",
+            "manifestation",
+            "reported",
+        ]
