@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ImmunizationEvaluation
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -54,7 +54,7 @@ class ImmunizationEvaluation(domainresource.DomainResource):
         None, alias="_date", title="Extension field for ``date``."
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Evaluation notes",
@@ -66,38 +66,19 @@ class ImmunizationEvaluation(domainresource.DomainResource):
         None, alias="_description", title="Extension field for ``description``."
     )
 
-    doseNumberPositiveInt: fhirtypes.PositiveInt = Field(
+    doseNumber: fhirtypes.String = Field(
         None,
-        alias="doseNumberPositiveInt",
+        alias="doseNumber",
         title="Dose number within series",
-        description="Nominal position in a series.",
+        description=(
+            "Nominal position in a series as determined by the outcome of the "
+            "evaluation process."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e doseNumber[x]
-        one_of_many="doseNumber",
-        one_of_many_required=False,
     )
-    doseNumberPositiveInt__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_doseNumberPositiveInt",
-        title="Extension field for ``doseNumberPositiveInt``.",
-    )
-
-    doseNumberString: fhirtypes.String = Field(
-        None,
-        alias="doseNumberString",
-        title="Dose number within series",
-        description="Nominal position in a series.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e doseNumber[x]
-        one_of_many="doseNumber",
-        one_of_many_required=False,
-    )
-    doseNumberString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_doseNumberString",
-        title="Extension field for ``doseNumberString``.",
+    doseNumber__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_doseNumber", title="Extension field for ``doseNumber``."
     )
 
     doseStatus: fhirtypes.CodeableConceptType = Field(
@@ -115,7 +96,7 @@ class ImmunizationEvaluation(domainresource.DomainResource):
     doseStatusReason: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="doseStatusReason",
-        title="Reason for the dose status",
+        title="Reason why the doese is considered valid, invalid or some other status",
         description=(
             "Provides an explanation as to why the vaccine administration event is "
             "valid or not relative to the published recommendations."
@@ -170,38 +151,19 @@ class ImmunizationEvaluation(domainresource.DomainResource):
         None, alias="_series", title="Extension field for ``series``."
     )
 
-    seriesDosesPositiveInt: fhirtypes.PositiveInt = Field(
+    seriesDoses: fhirtypes.String = Field(
         None,
-        alias="seriesDosesPositiveInt",
+        alias="seriesDoses",
         title="Recommended number of doses for immunity",
-        description="The recommended number of doses to achieve immunity.",
+        description=(
+            "The recommended number of doses to achieve immunity as determined by "
+            "the outcome of the evaluation process."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e seriesDoses[x]
-        one_of_many="seriesDoses",
-        one_of_many_required=False,
     )
-    seriesDosesPositiveInt__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_seriesDosesPositiveInt",
-        title="Extension field for ``seriesDosesPositiveInt``.",
-    )
-
-    seriesDosesString: fhirtypes.String = Field(
-        None,
-        alias="seriesDosesString",
-        title="Recommended number of doses for immunity",
-        description="The recommended number of doses to achieve immunity.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e seriesDoses[x]
-        one_of_many="seriesDoses",
-        one_of_many_required=False,
-    )
-    seriesDosesString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_seriesDosesString",
-        title="Extension field for ``seriesDosesString``.",
+    seriesDoses__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_seriesDoses", title="Extension field for ``seriesDoses``."
     )
 
     status: fhirtypes.Code = Field(
@@ -226,7 +188,7 @@ class ImmunizationEvaluation(domainresource.DomainResource):
     targetDisease: fhirtypes.CodeableConceptType = Field(
         ...,
         alias="targetDisease",
-        title="Evaluation target disease",
+        title="The vaccine preventable disease schedule being evaluated",
         description="The vaccine preventable disease the dose is being evaluated against.",
         # if property is element of this resource.
         element_property=True,
@@ -258,10 +220,8 @@ class ImmunizationEvaluation(domainresource.DomainResource):
             "doseStatusReason",
             "description",
             "series",
-            "doseNumberPositiveInt",
-            "doseNumberString",
-            "seriesDosesPositiveInt",
-            "seriesDosesString",
+            "doseNumber",
+            "seriesDoses",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
@@ -322,44 +282,3 @@ class ImmunizationEvaluation(domainresource.DomainResource):
             raise ValidationError(errors, cls)  # type: ignore
 
         return values
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_2515(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {
-            "doseNumber": ["doseNumberPositiveInt", "doseNumberString"],
-            "seriesDoses": ["seriesDosesPositiveInt", "seriesDosesString"],
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
