@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ImmunizationRecommendation
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -197,7 +197,7 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Protocol details",
@@ -212,44 +212,20 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
-    doseNumberPositiveInt: fhirtypes.PositiveInt = Field(
+    doseNumber: fhirtypes.String = Field(
         None,
-        alias="doseNumberPositiveInt",
+        alias="doseNumber",
         title="Recommended dose number within series",
         description=(
-            "Nominal position of the recommended dose in a series (e.g. dose 2 is "
-            "the next recommended dose)."
+            "Nominal position of the recommended dose in a series as determined by "
+            "the evaluation and forecasting process (e.g. dose 2 is the next "
+            "recommended dose)."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e doseNumber[x]
-        one_of_many="doseNumber",
-        one_of_many_required=False,
     )
-    doseNumberPositiveInt__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_doseNumberPositiveInt",
-        title="Extension field for ``doseNumberPositiveInt``.",
-    )
-
-    doseNumberString: fhirtypes.String = Field(
-        None,
-        alias="doseNumberString",
-        title="Recommended dose number within series",
-        description=(
-            "Nominal position of the recommended dose in a series (e.g. dose 2 is "
-            "the next recommended dose)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e doseNumber[x]
-        one_of_many="doseNumber",
-        one_of_many_required=False,
-    )
-    doseNumberString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_doseNumberString",
-        title="Extension field for ``doseNumberString``.",
+    doseNumber__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_doseNumber", title="Extension field for ``doseNumber``."
     )
 
     forecastReason: typing.List[fhirtypes.CodeableConceptType] = Field(
@@ -288,38 +264,19 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
         None, alias="_series", title="Extension field for ``series``."
     )
 
-    seriesDosesPositiveInt: fhirtypes.PositiveInt = Field(
+    seriesDoses: fhirtypes.String = Field(
         None,
-        alias="seriesDosesPositiveInt",
+        alias="seriesDoses",
         title="Recommended number of doses for immunity",
-        description="The recommended number of doses to achieve immunity.",
+        description=(
+            "The recommended number of doses to achieve immunity as determined by "
+            "the evaluation and forecasting process."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e seriesDoses[x]
-        one_of_many="seriesDoses",
-        one_of_many_required=False,
     )
-    seriesDosesPositiveInt__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_seriesDosesPositiveInt",
-        title="Extension field for ``seriesDosesPositiveInt``.",
-    )
-
-    seriesDosesString: fhirtypes.String = Field(
-        None,
-        alias="seriesDosesString",
-        title="Recommended number of doses for immunity",
-        description="The recommended number of doses to achieve immunity.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e seriesDoses[x]
-        one_of_many="seriesDoses",
-        one_of_many_required=False,
-    )
-    seriesDosesString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_seriesDosesString",
-        title="Extension field for ``seriesDosesString``.",
+    seriesDoses__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_seriesDoses", title="Extension field for ``seriesDoses``."
     )
 
     supportingImmunization: typing.List[fhirtypes.ReferenceType] = Field(
@@ -351,7 +308,7 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
         enum_reference_types=["Resource"],
     )
 
-    targetDisease: fhirtypes.CodeableConceptType = Field(
+    targetDisease: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="targetDisease",
         title="Disease to be immunized against",
@@ -387,55 +344,12 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
             "dateCriterion",
             "description",
             "series",
-            "doseNumberPositiveInt",
-            "doseNumberString",
-            "seriesDosesPositiveInt",
-            "seriesDosesString",
+            "doseNumber",
+            "seriesDoses",
             "supportingImmunization",
             "supportingPatientInformation",
         ]
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_4389(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {
-            "doseNumber": ["doseNumberPositiveInt", "doseNumberString"],
-            "seriesDoses": ["seriesDosesPositiveInt", "seriesDosesString"],
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
 
 class ImmunizationRecommendationRecommendationDateCriterion(
     backboneelement.BackboneElement
