@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ImplementationGuide
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -57,16 +57,33 @@ class ImplementationGuide(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the implementation guide was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the implementation guide "
-            "changes."
+            "The date  (and optionally time) when the implementation guide was last"
+            " significantly changed. The date must change when the business version"
+            " changes and it must change if the status code changes. In addition, "
+            "it should change when the substantive content of the implementation "
+            "guide changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -139,7 +156,7 @@ class ImplementationGuide(domainresource.DomainResource):
             "The version(s) of the FHIR specification that this ImplementationGuide"
             " targets - e.g. describes how to use. The value of this element is the"
             " formal version of the specification, without the revision number, "
-            "e.g. [publication].[major].[minor], which is 4.3.0 for this version."
+            "e.g. [publication].[major].[minor], which is 4.6.0. for this version."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -161,6 +178,22 @@ class ImplementationGuide(domainresource.DomainResource):
         element_property=True,
     )
 
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title=(
+            "Additional identifier for the implementation guide (business "
+            "identifier)"
+        ),
+        description=(
+            "A formal identifier that is used to identify this implementation guide"
+            " when it is represented in other formats, or referenced in a "
+            "specification, model, design or an instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     jurisdiction: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="jurisdiction",
@@ -238,10 +271,10 @@ class ImplementationGuide(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the "
-            "implementation guide."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the implementation guide."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -250,6 +283,21 @@ class ImplementationGuide(domainresource.DomainResource):
         None, alias="_publisher", title="Extension field for ``publisher``."
     )
 
+    purpose: fhirtypes.Markdown = Field(
+        None,
+        alias="purpose",
+        title="Why this implementation guide is defined",
+        description=(
+            "Explanation of why this implementation guide is needed and why it has "
+            "been designed as it has."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    purpose__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_purpose", title="Extension field for ``purpose``."
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -294,7 +342,7 @@ class ImplementationGuide(domainresource.DomainResource):
             "An absolute URI that is used to identify this implementation guide "
             "when it is referenced in a specification, model, design or an "
             "instance; also called its canonical identifier. This SHOULD be "
-            "globally unique and SHOULD be a literal address at which at which an "
+            "globally unique and SHOULD be a literal address at which an "
             "authoritative instance of this implementation guide is (or will be) "
             "published. This URL can be the target of a canonical reference. It "
             "SHALL remain the same when the implementation guide is stored on "
@@ -343,6 +391,41 @@ class ImplementationGuide(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -359,7 +442,10 @@ class ImplementationGuide(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "url",
+            "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "status",
@@ -370,7 +456,9 @@ class ImplementationGuide(domainresource.DomainResource):
             "description",
             "useContext",
             "jurisdiction",
+            "purpose",
             "copyright",
+            "copyrightLabel",
             "packageId",
             "license",
             "fhirVersion",
@@ -445,6 +533,46 @@ class ImplementationGuide(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2146(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class ImplementationGuideDefinition(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -488,13 +616,17 @@ class ImplementationGuideDefinition(backboneelement.BackboneElement):
         None,
         alias="parameter",
         title="Defines how IG is built by tools",
-        description=None,
+        description=(
+            "A set of parameters that defines how the implementation guide is "
+            "built. The parameters are defined by the relevant tools that build the"
+            " implementation guides."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
 
     resource: typing.List[fhirtypes.ImplementationGuideDefinitionResourceType] = Field(
-        ...,
+        None,
         alias="resource",
         title="Resource in the implementation guide",
         description=(
@@ -546,7 +678,7 @@ class ImplementationGuideDefinitionGrouping(backboneelement.BackboneElement):
 
     resource_type = Field("ImplementationGuideDefinitionGrouping", const=True)
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Human readable text describing the package",
@@ -670,33 +802,17 @@ class ImplementationGuideDefinitionPage(backboneelement.BackboneElement):
         None, alias="_generation", title="Extension field for ``generation``."
     )
 
-    nameReference: fhirtypes.ReferenceType = Field(
+    name: fhirtypes.Url = Field(
         None,
-        alias="nameReference",
-        title="Where to find that page",
-        description="The source address for the page.",
+        alias="name",
+        title="Name of the page when published",
+        description="The url by which the page should be known when published.",
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e name[x]
-        one_of_many="name",
-        one_of_many_required=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Binary"],
+        element_required=True,
     )
-
-    nameUrl: fhirtypes.Url = Field(
-        None,
-        alias="nameUrl",
-        title="Where to find that page",
-        description="The source address for the page.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e name[x]
-        one_of_many="name",
-        one_of_many_required=True,
-    )
-    nameUrl__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_nameUrl", title="Extension field for ``nameUrl``."
+    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_name", title="Extension field for ``name``."
     )
 
     page: typing.List[fhirtypes.ImplementationGuideDefinitionPageType] = Field(
@@ -708,6 +824,51 @@ class ImplementationGuideDefinitionPage(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    sourceMarkdown: fhirtypes.Markdown = Field(
+        None,
+        alias="sourceMarkdown",
+        title="Source for page",
+        description="Indicates the URL or the actual content to provide for the page.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e source[x]
+        one_of_many="source",
+        one_of_many_required=False,
+    )
+    sourceMarkdown__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_sourceMarkdown", title="Extension field for ``sourceMarkdown``."
+    )
+
+    sourceString: fhirtypes.String = Field(
+        None,
+        alias="sourceString",
+        title="Source for page",
+        description="Indicates the URL or the actual content to provide for the page.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e source[x]
+        one_of_many="source",
+        one_of_many_required=False,
+    )
+    sourceString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_sourceString", title="Extension field for ``sourceString``."
+    )
+
+    sourceUrl: fhirtypes.Url = Field(
+        None,
+        alias="sourceUrl",
+        title="Source for page",
+        description="Indicates the URL or the actual content to provide for the page.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e source[x]
+        one_of_many="source",
+        one_of_many_required=False,
+    )
+    sourceUrl__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_sourceUrl", title="Extension field for ``sourceUrl``."
+    )
+
     title: fhirtypes.String = Field(
         None,
         alias="title",
@@ -734,8 +895,10 @@ class ImplementationGuideDefinitionPage(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "nameUrl",
-            "nameReference",
+            "sourceUrl",
+            "sourceString",
+            "sourceMarkdown",
+            "name",
             "title",
             "generation",
             "page",
@@ -752,7 +915,11 @@ class ImplementationGuideDefinitionPage(backboneelement.BackboneElement):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("generation", "generation__ext"), ("title", "title__ext")]
+        required_fields = [
+            ("generation", "generation__ext"),
+            ("name", "name__ext"),
+            ("title", "title__ext"),
+        ]
         _missing = object()
 
         def _fallback():
@@ -816,7 +983,7 @@ class ImplementationGuideDefinitionPage(backboneelement.BackboneElement):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"name": ["nameReference", "nameUrl"]}
+        one_of_many_fields = {"source": ["sourceMarkdown", "sourceString", "sourceUrl"]}
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
@@ -845,39 +1012,20 @@ class ImplementationGuideDefinitionParameter(backboneelement.BackboneElement):
     for FHIR Primitive Data Types.
 
     Defines how IG is built by tools.
+    A set of parameters that defines how the implementation guide is built. The
+    parameters are defined by the relevant tools that build the implementation
+    guides.
     """
 
     resource_type = Field("ImplementationGuideDefinitionParameter", const=True)
 
-    code: fhirtypes.Code = Field(
-        None,
+    code: fhirtypes.CodingType = Field(
+        ...,
         alias="code",
-        title=(
-            "apply | path-resource | path-pages | path-tx-cache | expansion-"
-            "parameter | rule-broken-links | generate-xml | generate-json | "
-            "generate-turtle | html-template"
-        ),
-        description=None,
+        title="Code that identifies parameter",
+        description="A tool-specific code that defines the parameter.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "apply",
-            "path-resource",
-            "path-pages",
-            "path-tx-cache",
-            "expansion-parameter",
-            "rule-broken-links",
-            "generate-xml",
-            "generate-json",
-            "generate-turtle",
-            "html-template",
-        ],
-    )
-    code__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_code", title="Extension field for ``code``."
     )
 
     value: fhirtypes.String = Field(
@@ -912,7 +1060,7 @@ class ImplementationGuideDefinitionParameter(backboneelement.BackboneElement):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("code", "code__ext"), ("value", "value__ext")]
+        required_fields = [("value", "value__ext")]
         _missing = object()
 
         def _fallback():
@@ -975,7 +1123,7 @@ class ImplementationGuideDefinitionResource(backboneelement.BackboneElement):
 
     resource_type = Field("ImplementationGuideDefinitionResource", const=True)
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Reason why included in guide",
@@ -990,48 +1138,6 @@ class ImplementationGuideDefinitionResource(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
-    exampleBoolean: bool = Field(
-        None,
-        alias="exampleBoolean",
-        title="Is an example/What is this an example of?",
-        description=(
-            "If true or a reference, indicates the resource is an example instance."
-            "  If a reference is present, indicates that the example is an example "
-            "of the specified profile."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e example[x]
-        one_of_many="example",
-        one_of_many_required=False,
-    )
-    exampleBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_exampleBoolean", title="Extension field for ``exampleBoolean``."
-    )
-
-    exampleCanonical: fhirtypes.Canonical = Field(
-        None,
-        alias="exampleCanonical",
-        title="Is an example/What is this an example of?",
-        description=(
-            "If true or a reference, indicates the resource is an example instance."
-            "  If a reference is present, indicates that the example is an example "
-            "of the specified profile."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e example[x]
-        one_of_many="example",
-        one_of_many_required=False,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["StructureDefinition"],
-    )
-    exampleCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_exampleCanonical",
-        title="Extension field for ``exampleCanonical``.",
-    )
-
     fhirVersion: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="fhirVersion",
@@ -1060,10 +1166,22 @@ class ImplementationGuideDefinitionResource(backboneelement.BackboneElement):
         None, alias="_groupingId", title="Extension field for ``groupingId``."
     )
 
+    isExample: bool = Field(
+        None,
+        alias="isExample",
+        title="Is this an example",
+        description="If true, indicates the resource is an example instance.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    isExample__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_isExample", title="Extension field for ``isExample``."
+    )
+
     name: fhirtypes.String = Field(
         None,
         alias="name",
-        title="Human Name for the resource",
+        title="Human readable name for the resource",
         description=(
             "A human assigned name for the resource. All resources SHOULD have a "
             "name, but the name may be extracted from the resource (e.g. "
@@ -1076,6 +1194,20 @@ class ImplementationGuideDefinitionResource(backboneelement.BackboneElement):
         None, alias="_name", title="Extension field for ``name``."
     )
 
+    profile: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
+        None,
+        alias="profile",
+        title="Profile(s) this is an example of",
+        description="If present, indicates profile(s) the instance is valid against.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["StructureDefinition"],
+    )
+    profile__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_profile", title="Extension field for ``profile``.")
+
     reference: fhirtypes.ReferenceType = Field(
         ...,
         alias="reference",
@@ -1101,49 +1233,11 @@ class ImplementationGuideDefinitionResource(backboneelement.BackboneElement):
             "fhirVersion",
             "name",
             "description",
-            "exampleBoolean",
-            "exampleCanonical",
+            "isExample",
+            "profile",
             "groupingId",
         ]
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_4019(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {"example": ["exampleBoolean", "exampleCanonical"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
 
 class ImplementationGuideDefinitionTemplate(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -1289,6 +1383,20 @@ class ImplementationGuideDependsOn(backboneelement.BackboneElement):
         None, alias="_packageId", title="Extension field for ``packageId``."
     )
 
+    reason: fhirtypes.Markdown = Field(
+        None,
+        alias="reason",
+        title="Why dependency exists",
+        description=(
+            "A description explaining the nature of the dependency on the listed " "IG."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    reason__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_reason", title="Extension field for ``reason``."
+    )
+
     uri: fhirtypes.Canonical = Field(
         None,
         alias="uri",
@@ -1325,7 +1433,15 @@ class ImplementationGuideDependsOn(backboneelement.BackboneElement):
         ``ImplementationGuideDependsOn`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "uri", "packageId", "version"]
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "uri",
+            "packageId",
+            "version",
+            "reason",
+        ]
 
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3051(
@@ -1721,47 +1837,31 @@ class ImplementationGuideManifestResource(backboneelement.BackboneElement):
 
     resource_type = Field("ImplementationGuideManifestResource", const=True)
 
-    exampleBoolean: bool = Field(
+    isExample: bool = Field(
         None,
-        alias="exampleBoolean",
-        title="Is an example/What is this an example of?",
-        description=(
-            "If true or a reference, indicates the resource is an example instance."
-            "  If a reference is present, indicates that the example is an example "
-            "of the specified profile."
-        ),
+        alias="isExample",
+        title="Is this an example",
+        description="If true, indicates the resource is an example instance.",
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e example[x]
-        one_of_many="example",
-        one_of_many_required=False,
     )
-    exampleBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_exampleBoolean", title="Extension field for ``exampleBoolean``."
+    isExample__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_isExample", title="Extension field for ``isExample``."
     )
 
-    exampleCanonical: fhirtypes.Canonical = Field(
+    profile: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
-        alias="exampleCanonical",
-        title="Is an example/What is this an example of?",
-        description=(
-            "If true or a reference, indicates the resource is an example instance."
-            "  If a reference is present, indicates that the example is an example "
-            "of the specified profile."
-        ),
+        alias="profile",
+        title="Profile(s) this is an example of",
+        description="If present, indicates profile(s) the instance is valid against.",
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e example[x]
-        one_of_many="example",
-        one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["StructureDefinition"],
     )
-    exampleCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_exampleCanonical",
-        title="Extension field for ``exampleCanonical``.",
-    )
+    profile__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_profile", title="Extension field for ``profile``.")
 
     reference: fhirtypes.ReferenceType = Field(
         ...,
@@ -1797,45 +1897,7 @@ class ImplementationGuideManifestResource(backboneelement.BackboneElement):
             "extension",
             "modifierExtension",
             "reference",
-            "exampleBoolean",
-            "exampleCanonical",
+            "isExample",
+            "profile",
             "relativePath",
         ]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_3809(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {"example": ["exampleBoolean", "exampleCanonical"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
