@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Ingredient
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -44,6 +44,21 @@ class Ingredient(domainresource.DomainResource):
         title="Extension field for ``allergenicIndicator``.",
     )
 
+    comment: fhirtypes.Markdown = Field(
+        None,
+        alias="comment",
+        title=(
+            "A place for providing any notes that are relevant to the component, "
+            "e.g. removed during process, adjusted for loss on drying"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    comment__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_comment", title="Extension field for ``comment``."
+    )
+
     for_fhir: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="for",
@@ -75,6 +90,19 @@ class Ingredient(domainresource.DomainResource):
         element_property=True,
     )
 
+    group: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="group",
+        title=(
+            "A classification of the ingredient according to where in the physical "
+            "item it tends to be used, such the outer shell of a tablet, inner body"
+            " or ink"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     identifier: fhirtypes.IdentifierType = Field(
         None,
         alias="identifier",
@@ -164,7 +192,9 @@ class Ingredient(domainresource.DomainResource):
             "for",
             "role",
             "function",
+            "group",
             "allergenicIndicator",
+            "comment",
             "manufacturer",
             "substance",
         ]
@@ -348,6 +378,43 @@ class IngredientSubstanceStrength(backboneelement.BackboneElement):
 
     resource_type = Field("IngredientSubstanceStrength", const=True)
 
+    basis: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="basis",
+        title=(
+            "A code that indicates if the strength is, for example, based on the "
+            "ingredient substance as stated or on the substance base (when the "
+            "ingredient is a salt)"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    concentrationCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="concentrationCodeableConcept",
+        title="The strength per unitary volume (or mass)",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e concentration[x]
+        one_of_many="concentration",
+        one_of_many_required=False,
+    )
+
+    concentrationQuantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="concentrationQuantity",
+        title="The strength per unitary volume (or mass)",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e concentration[x]
+        one_of_many="concentration",
+        one_of_many_required=False,
+    )
+
     concentrationRatio: fhirtypes.RatioType = Field(
         None,
         alias="concentrationRatio",
@@ -400,6 +467,44 @@ class IngredientSubstanceStrength(backboneelement.BackboneElement):
         title="Extension field for ``measurementPoint``.",
     )
 
+    presentationCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="presentationCodeableConcept",
+        title="The quantity of substance in the unit of presentation",
+        description=(
+            "The quantity of substance in the unit of presentation, or in the "
+            "volume (or mass) of the single pharmaceutical product or manufactured "
+            "item. Unit of presentation refers to the quantity that the item occurs"
+            " in e.g. a strength per tablet size, perhaps 'per 20mg' (the size of "
+            "the tablet). It is not generally normalized as a unitary unit, which "
+            "would be 'per mg')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e presentation[x]
+        one_of_many="presentation",
+        one_of_many_required=False,
+    )
+
+    presentationQuantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="presentationQuantity",
+        title="The quantity of substance in the unit of presentation",
+        description=(
+            "The quantity of substance in the unit of presentation, or in the "
+            "volume (or mass) of the single pharmaceutical product or manufactured "
+            "item. Unit of presentation refers to the quantity that the item occurs"
+            " in e.g. a strength per tablet size, perhaps 'per 20mg' (the size of "
+            "the tablet). It is not generally normalized as a unitary unit, which "
+            "would be 'per mg')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e presentation[x]
+        one_of_many="presentation",
+        one_of_many_required=False,
+    )
+
     presentationRatio: fhirtypes.RatioType = Field(
         None,
         alias="presentationRatio",
@@ -511,10 +616,15 @@ class IngredientSubstanceStrength(backboneelement.BackboneElement):
             "modifierExtension",
             "presentationRatio",
             "presentationRatioRange",
+            "presentationCodeableConcept",
+            "presentationQuantity",
             "textPresentation",
             "concentrationRatio",
             "concentrationRatioRange",
+            "concentrationCodeableConcept",
+            "concentrationQuantity",
             "textConcentration",
+            "basis",
             "measurementPoint",
             "country",
             "referenceStrength",
@@ -537,8 +647,18 @@ class IngredientSubstanceStrength(backboneelement.BackboneElement):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "concentration": ["concentrationRatio", "concentrationRatioRange"],
-            "presentation": ["presentationRatio", "presentationRatioRange"],
+            "concentration": [
+                "concentrationCodeableConcept",
+                "concentrationQuantity",
+                "concentrationRatio",
+                "concentrationRatioRange",
+            ],
+            "presentation": [
+                "presentationCodeableConcept",
+                "presentationQuantity",
+                "presentationRatio",
+                "presentationRatioRange",
+            ],
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -602,6 +722,18 @@ class IngredientSubstanceStrengthReferenceStrength(backboneelement.BackboneEleme
         title="Extension field for ``measurementPoint``.",
     )
 
+    strengthQuantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="strengthQuantity",
+        title="Strength expressed in terms of a reference substance",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e strength[x]
+        one_of_many="strength",
+        one_of_many_required=True,
+    )
+
     strengthRatio: fhirtypes.RatioType = Field(
         None,
         alias="strengthRatio",
@@ -627,7 +759,7 @@ class IngredientSubstanceStrengthReferenceStrength(backboneelement.BackboneEleme
     )
 
     substance: fhirtypes.CodeableReferenceType = Field(
-        None,
+        ...,
         alias="substance",
         title="Relevant reference substance",
         description=None,
@@ -650,6 +782,7 @@ class IngredientSubstanceStrengthReferenceStrength(backboneelement.BackboneEleme
             "substance",
             "strengthRatio",
             "strengthRatioRange",
+            "strengthQuantity",
             "measurementPoint",
             "country",
         ]
@@ -670,7 +803,9 @@ class IngredientSubstanceStrengthReferenceStrength(backboneelement.BackboneEleme
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"strength": ["strengthRatio", "strengthRatioRange"]}
+        one_of_many_fields = {
+            "strength": ["strengthQuantity", "strengthRatio", "strengthRatioRange"]
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
