@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/InsurancePlan
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -38,7 +38,7 @@ class InsurancePlan(domainresource.DomainResource):
         enum_reference_types=["Organization"],
     )
 
-    alias: typing.List[fhirtypes.String] = Field(
+    alias: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="alias",
         title="Alternate names",
@@ -53,11 +53,15 @@ class InsurancePlan(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_alias", title="Extension field for ``alias``.")
 
-    contact: typing.List[fhirtypes.InsurancePlanContactType] = Field(
+    contact: typing.List[fhirtypes.ExtendedContactDetailType] = Field(
         None,
         alias="contact",
-        title="Contact for the product",
-        description="The contact for the health insurance product for a certain purpose.",
+        title="Official contact details relevant to the health insurance plan/product",
+        description=(
+            "The contact details of communication devices available relevant to the"
+            " specific Insurance Plan/Product. This can include addresses, phone "
+            "numbers, fax numbers, mobile numbers, email addresses and web sites."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -141,7 +145,7 @@ class InsurancePlan(domainresource.DomainResource):
     ownedBy: fhirtypes.ReferenceType = Field(
         None,
         alias="ownedBy",
-        title="Plan issuer",
+        title="Product issuer",
         description=(
             "The entity that is providing  the health insurance product and "
             "underwriting the risk.  This is typically an insurance carriers, other"
@@ -228,73 +232,6 @@ class InsurancePlan(domainresource.DomainResource):
         ]
 
 
-class InsurancePlanContact(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Contact for the product.
-    The contact for the health insurance product for a certain purpose.
-    """
-
-    resource_type = Field("InsurancePlanContact", const=True)
-
-    address: fhirtypes.AddressType = Field(
-        None,
-        alias="address",
-        title="Visiting or postal addresses for the contact",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    name: fhirtypes.HumanNameType = Field(
-        None,
-        alias="name",
-        title="A name associated with the contact",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    purpose: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="purpose",
-        title="The type of contact",
-        description="Indicates a purpose for which the contact can be reached.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    telecom: typing.List[fhirtypes.ContactPointType] = Field(
-        None,
-        alias="telecom",
-        title="Contact details (telephone, email, etc.)  for a contact",
-        description=(
-            "A contact detail (e.g. a telephone number or an email address) by "
-            "which the party may be contacted."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``InsurancePlanContact`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "purpose",
-            "name",
-            "telecom",
-            "address",
-        ]
-
-
 class InsurancePlanCoverage(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
