@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Invoice
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -53,11 +53,23 @@ class Invoice(domainresource.DomainResource):
         None, alias="_cancelledReason", title="Extension field for ``cancelledReason``."
     )
 
+    creation: fhirtypes.DateTime = Field(
+        None,
+        alias="creation",
+        title="When posted",
+        description="Date/time(s) of when this Invoice was posted.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    creation__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_creation", title="Extension field for ``creation``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
-        title="Invoice date / posting date",
-        description="Date/time(s) of when this Invoice was posted.",
+        title="DEPRICATED",
+        description="Depricared by the element below.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -94,8 +106,8 @@ class Invoice(domainresource.DomainResource):
         title="Line items of this Invoice",
         description=(
             "Each line item represents one charge for goods and services rendered. "
-            "Details such as date, code and amount are found in the referenced "
-            "ChargeItem resource."
+            "Details such.ofType(date), code and amount are found in the referenced"
+            " ChargeItem resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -139,6 +151,33 @@ class Invoice(domainresource.DomainResource):
         None, alias="_paymentTerms", title="Extension field for ``paymentTerms``."
     )
 
+    periodDate: fhirtypes.Date = Field(
+        None,
+        alias="periodDate",
+        title="Billing date or period",
+        description="Date/time(s) range of services included in this invoice.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e period[x]
+        one_of_many="period",
+        one_of_many_required=False,
+    )
+    periodDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_periodDate", title="Extension field for ``periodDate``."
+    )
+
+    periodPeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="periodPeriod",
+        title="Billing date or period",
+        description="Date/time(s) range of services included in this invoice.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e period[x]
+        one_of_many="period",
+        one_of_many_required=False,
+    )
+
     recipient: fhirtypes.ReferenceType = Field(
         None,
         alias="recipient",
@@ -201,9 +240,7 @@ class Invoice(domainresource.DomainResource):
         element_property=True,
     )
 
-    totalPriceComponent: typing.List[
-        fhirtypes.InvoiceLineItemPriceComponentType
-    ] = Field(
+    totalPriceComponent: typing.List[fhirtypes.MonetaryComponentType] = Field(
         None,
         alias="totalPriceComponent",
         title="Components of Invoice total",
@@ -252,6 +289,9 @@ class Invoice(domainresource.DomainResource):
             "subject",
             "recipient",
             "date",
+            "creation",
+            "periodDate",
+            "periodPeriod",
             "participant",
             "issuer",
             "account",
@@ -322,6 +362,44 @@ class Invoice(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_891(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {"period": ["periodDate", "periodPeriod"]}
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class InvoiceLineItem(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -330,7 +408,7 @@ class InvoiceLineItem(backboneelement.BackboneElement):
 
     Line items of this Invoice.
     Each line item represents one charge for goods and services rendered.
-    Details such as date, code and amount are found in the referenced
+    Details such.ofType(date), code and amount are found in the referenced
     ChargeItem resource.
     """
 
@@ -378,7 +456,7 @@ class InvoiceLineItem(backboneelement.BackboneElement):
         enum_reference_types=["ChargeItem"],
     )
 
-    priceComponent: typing.List[fhirtypes.InvoiceLineItemPriceComponentType] = Field(
+    priceComponent: typing.List[fhirtypes.MonetaryComponentType] = Field(
         None,
         alias="priceComponent",
         title="Components of total line item price",
@@ -407,6 +485,33 @@ class InvoiceLineItem(backboneelement.BackboneElement):
         None, alias="_sequence", title="Extension field for ``sequence``."
     )
 
+    servicedDate: fhirtypes.Date = Field(
+        None,
+        alias="servicedDate",
+        title="Service data or period",
+        description="Date/time(s) range when this service was delivered or completed.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e serviced[x]
+        one_of_many="serviced",
+        one_of_many_required=False,
+    )
+    servicedDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_servicedDate", title="Extension field for ``servicedDate``."
+    )
+
+    servicedPeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="servicedPeriod",
+        title="Service data or period",
+        description="Date/time(s) range when this service was delivered or completed.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e serviced[x]
+        one_of_many="serviced",
+        one_of_many_required=False,
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -418,6 +523,8 @@ class InvoiceLineItem(backboneelement.BackboneElement):
             "extension",
             "modifierExtension",
             "sequence",
+            "servicedDate",
+            "servicedPeriod",
             "chargeItemReference",
             "chargeItemCodeableConcept",
             "priceComponent",
@@ -440,7 +547,8 @@ class InvoiceLineItem(backboneelement.BackboneElement):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "chargeItem": ["chargeItemCodeableConcept", "chargeItemReference"]
+            "chargeItem": ["chargeItemCodeableConcept", "chargeItemReference"],
+            "serviced": ["servicedDate", "servicedPeriod"],
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -464,157 +572,6 @@ class InvoiceLineItem(backboneelement.BackboneElement):
         return values
 
 
-class InvoiceLineItemPriceComponent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Components of total line item price.
-    The price for a ChargeItem may be calculated as a base price with
-    surcharges/deductions that apply in certain conditions. A
-    ChargeItemDefinition resource that defines the prices, factors and
-    conditions that apply to a billing code is currently under development. The
-    priceComponent element can be used to offer transparency to the recipient
-    of the Invoice as to how the prices have been calculated.
-    """
-
-    resource_type = Field("InvoiceLineItemPriceComponent", const=True)
-
-    amount: fhirtypes.MoneyType = Field(
-        None,
-        alias="amount",
-        title="Monetary amount associated with this component",
-        description="The amount calculated for this component.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    code: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="code",
-        title="Code identifying the specific component",
-        description=(
-            "A code that identifies the component. Codes may be used to "
-            "differentiate between kinds of taxes, surcharges, discounts etc."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    factor: fhirtypes.Decimal = Field(
-        None,
-        alias="factor",
-        title="Factor used for calculating this component",
-        description=(
-            "The factor that has been applied on the base price for calculating "
-            "this component."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    factor__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_factor", title="Extension field for ``factor``."
-    )
-
-    type: fhirtypes.Code = Field(
-        None,
-        alias="type",
-        title="base | surcharge | deduction | discount | tax | informational",
-        description="This code identifies the type of the component.",
-        # if property is element of this resource.
-        element_property=True,
-        element_required=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "base",
-            "surcharge",
-            "deduction",
-            "discount",
-            "tax",
-            "informational",
-        ],
-    )
-    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_type", title="Extension field for ``type``."
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``InvoiceLineItemPriceComponent`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "type",
-            "code",
-            "factor",
-            "amount",
-        ]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_3143(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("type", "type__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
-
-
 class InvoiceParticipant(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
