@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Library
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -99,6 +99,23 @@ class Library(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     dataRequirement: typing.List[fhirtypes.DataRequirementType] = Field(
         None,
         alias="dataRequirement",
@@ -116,10 +133,10 @@ class Library(domainresource.DomainResource):
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the library was published. The "
-            "date must change when the business version changes and it must change "
-            "if the status code changes. In addition, it should change when the "
-            "substantive content of the library changes."
+            "The date  (and optionally time) when the library was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the library changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -172,8 +189,9 @@ class Library(domainresource.DomainResource):
         alias="endorser",
         title="Who endorsed the content",
         description=(
-            "An individual or organization responsible for officially endorsing the"
-            " content for use in some setting."
+            "An individual or organization asserted by the publisher to be "
+            "responsible for officially endorsing the content for use in some "
+            "setting."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -225,7 +243,7 @@ class Library(domainresource.DomainResource):
     lastReviewDate: fhirtypes.Date = Field(
         None,
         alias="lastReviewDate",
-        title="When the library was last reviewed",
+        title="When the library was last reviewed by the publisher",
         description=(
             "The date on which the resource content was last reviewed. Review "
             "happens periodically after approval but does not change the original "
@@ -266,8 +284,11 @@ class Library(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
-        description="The name of the organization or individual that published the library.",
+        title="Name of the publisher/steward (organization or individual)",
+        description=(
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the library."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -293,7 +314,7 @@ class Library(domainresource.DomainResource):
     relatedArtifact: typing.List[fhirtypes.RelatedArtifactType] = Field(
         None,
         alias="relatedArtifact",
-        title="Additional documentation, citations, etc.",
+        title="Additional documentation, citations, etc",
         description=(
             "Related artifacts such as additional documentation, justification, or "
             "bibliographic references."
@@ -307,8 +328,8 @@ class Library(domainresource.DomainResource):
         alias="reviewer",
         title="Who reviewed the content",
         description=(
-            "An individual or organization primarily responsible for review of some"
-            " aspect of the content."
+            "An individual or organization asserted by the publisher to be "
+            "primarily responsible for review of some aspect of the content."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -395,7 +416,7 @@ class Library(domainresource.DomainResource):
     topic: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="topic",
-        title="E.g. Education, Treatment, Assessment, etc.",
+        title="E.g. Education, Treatment, Assessment, etc",
         description=(
             "Descriptive topics related to the content of the library. Topics "
             "provide a high-level categorization of the library that can be useful "
@@ -430,10 +451,10 @@ class Library(domainresource.DomainResource):
             "An absolute URI that is used to identify this library when it is "
             "referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this library is (or will be) published. This URL can be "
-            "the target of a canonical reference. It SHALL remain the same when the"
-            " library is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " library is (or will be) published. This URL can be the target of a "
+            "canonical reference. It SHALL remain the same when the library is "
+            "stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -442,7 +463,7 @@ class Library(domainresource.DomainResource):
         None, alias="_url", title="Extension field for ``url``."
     )
 
-    usage: fhirtypes.String = Field(
+    usage: fhirtypes.Markdown = Field(
         None,
         alias="usage",
         title="Describes the clinical usage of the library",
@@ -496,6 +517,41 @@ class Library(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -514,6 +570,8 @@ class Library(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "subtitle",
@@ -531,6 +589,7 @@ class Library(domainresource.DomainResource):
             "purpose",
             "usage",
             "copyright",
+            "copyrightLabel",
             "approvalDate",
             "lastReviewDate",
             "effectivePeriod",
@@ -620,7 +679,10 @@ class Library(domainresource.DomainResource):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"subject": ["subjectCodeableConcept", "subjectReference"]}
+        one_of_many_fields = {
+            "subject": ["subjectCodeableConcept", "subjectReference"],
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"],
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
