@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Location
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,13 +16,13 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Location(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Details and position information for a physical place.
-    Details and position information for a physical place where services are
-    provided and resources and participants may be stored, found, contained, or
+    Details and position information for a place.
+    Details and position information for a place where services are provided
+    and resources and participants may be stored, found, contained, or
     accommodated.
     """
 
@@ -37,7 +37,7 @@ class Location(domainresource.DomainResource):
         element_property=True,
     )
 
-    alias: typing.List[fhirtypes.String] = Field(
+    alias: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="alias",
         title=(
@@ -52,26 +52,29 @@ class Location(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_alias", title="Extension field for ``alias``.")
 
-    availabilityExceptions: fhirtypes.String = Field(
+    characteristic: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
-        alias="availabilityExceptions",
-        title="Description of availability exceptions",
+        alias="characteristic",
+        title="Collection of characteristics (attributes)",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    contact: typing.List[fhirtypes.ExtendedContactDetailType] = Field(
+        None,
+        alias="contact",
+        title="Official contact details for the location",
         description=(
-            "A description of when the locations opening ours are different to "
-            "normal, e.g. public holiday availability. Succinctly describing all "
-            "possible exceptions to normal site availability as detailed in the "
-            "opening hours Times."
+            "The contact details of communication devices available at the "
+            "location. This can include addresses, phone numbers, fax numbers, "
+            "mobile numbers, email addresses and web sites."
         ),
         # if property is element of this resource.
         element_property=True,
     )
-    availabilityExceptions__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_availabilityExceptions",
-        title="Extension field for ``availabilityExceptions``.",
-    )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title=(
@@ -103,11 +106,29 @@ class Location(domainresource.DomainResource):
         enum_reference_types=["Endpoint"],
     )
 
-    hoursOfOperation: typing.List[fhirtypes.LocationHoursOfOperationType] = Field(
+    form: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="form",
+        title="Physical form of the location",
+        description=(
+            "Physical form of the location, e.g. building, room, vehicle, road, "
+            "virtual."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    hoursOfOperation: typing.List[fhirtypes.AvailabilityType] = Field(
         None,
         alias="hoursOfOperation",
-        title="What days/times during a week is this location usually open",
-        description=None,
+        title=(
+            "What days/times during a week is this location usually open (including"
+            " exceptions)"
+        ),
+        description=(
+            "What days/times during a week is this location usually open, and any "
+            "exceptions where the location is not available."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -190,15 +211,6 @@ class Location(domainresource.DomainResource):
         enum_reference_types=["Location"],
     )
 
-    physicalType: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="physicalType",
-        title="Physical form of the location",
-        description="Physical form of the location, e.g. building, room, vehicle, road.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     position: fhirtypes.LocationPositionType = Field(
         None,
         alias="position",
@@ -230,19 +242,6 @@ class Location(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    telecom: typing.List[fhirtypes.ContactPointType] = Field(
-        None,
-        alias="telecom",
-        title="Contact details of the location",
-        description=(
-            "The contact details of communication devices available at the "
-            "location. This can include phone numbers, fax numbers, mobile numbers,"
-            " email addresses and web sites."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     type: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="type",
@@ -252,74 +251,56 @@ class Location(domainresource.DomainResource):
         element_property=True,
     )
 
-
-class LocationHoursOfOperation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    What days/times during a week is this location usually open.
-    """
-
-    resource_type = Field("LocationHoursOfOperation", const=True)
-
-    allDay: bool = Field(
+    virtualService: typing.List[fhirtypes.VirtualServiceDetailType] = Field(
         None,
-        alias="allDay",
-        title="The Location is open all day",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    allDay__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_allDay", title="Extension field for ``allDay``."
-    )
-
-    closingTime: fhirtypes.Time = Field(
-        None,
-        alias="closingTime",
-        title="Time that the Location closes",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    closingTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_closingTime", title="Extension field for ``closingTime``."
-    )
-
-    daysOfWeek: typing.List[fhirtypes.Code] = Field(
-        None,
-        alias="daysOfWeek",
-        title="mon | tue | wed | thu | fri | sat | sun",
+        alias="virtualService",
+        title="Connection details of a virtual service (e.g. conference call)",
         description=(
-            "Indicates which days of the week are available between the start and "
-            "end Times."
+            "Connection details of a virtual service (e.g. shared conference call "
+            "facility with dedicated number/details)."
         ),
         # if property is element of this resource.
         element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["mon", "tue", "wed", "thu", "fri", "sat", "sun"],
     )
-    daysOfWeek__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(None, alias="_daysOfWeek", title="Extension field for ``daysOfWeek``.")
 
-    openingTime: fhirtypes.Time = Field(
-        None,
-        alias="openingTime",
-        title="Time that the Location opens",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    openingTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_openingTime", title="Extension field for ``openingTime``."
-    )
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Location`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "operationalStatus",
+            "name",
+            "alias",
+            "description",
+            "mode",
+            "type",
+            "contact",
+            "address",
+            "form",
+            "position",
+            "managingOrganization",
+            "partOf",
+            "characteristic",
+            "hoursOfOperation",
+            "virtualService",
+            "endpoint",
+        ]
 
 
 class LocationPosition(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -336,7 +317,8 @@ class LocationPosition(backboneelement.BackboneElement):
         title="Altitude with WGS84 datum",
         description=(
             "Altitude. The value domain and the interpretation are the same as for "
-            "the text of the altitude element in KML (see notes below)."
+            "the text of the altitude element in KML (see notes on Location main "
+            "page)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -351,7 +333,8 @@ class LocationPosition(backboneelement.BackboneElement):
         title="Latitude with WGS84 datum",
         description=(
             "Latitude. The value domain and the interpretation are the same as for "
-            "the text of the latitude element in KML (see notes below)."
+            "the text of the latitude element in KML (see notes on Location main "
+            "page)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -367,7 +350,8 @@ class LocationPosition(backboneelement.BackboneElement):
         title="Longitude with WGS84 datum",
         description=(
             "Longitude. The value domain and the interpretation are the same as for"
-            " the text of the longitude element in KML (see notes below)."
+            " the text of the longitude element in KML (see notes on Location main "
+            "page)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -377,6 +361,21 @@ class LocationPosition(backboneelement.BackboneElement):
         None, alias="_longitude", title="Extension field for ``longitude``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``LocationPosition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "longitude",
+            "latitude",
+            "altitude",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1864(
         cls, values: typing.Dict[str, typing.Any]
