@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MarketingStatus
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 from pydantic import Field
 
-from . import backboneelement, fhirtypes
+from . import backbonetype, fhirtypes
 
 
-class MarketingStatus(backboneelement.BackboneElement):
+class MarketingStatus(backbonetype.BackboneType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -27,7 +27,7 @@ class MarketingStatus(backboneelement.BackboneElement):
         None,
         alias="country",
         title=(
-            "The country in which the marketing authorisation has been granted "
+            "The country in which the marketing authorization has been granted "
             "shall be specified It should be specified using the ISO 3166 \u2011 1 "
             "alpha-2 code elements"
         ),
@@ -41,7 +41,7 @@ class MarketingStatus(backboneelement.BackboneElement):
         alias="dateRange",
         title=(
             "The date when the Medicinal Product is placed on the market by the "
-            "Marketing Authorisation Holder (or where applicable, the "
+            "Marketing Authorization Holder (or where applicable, the "
             "manufacturer/distributor) in a country and/or jurisdiction shall be "
             "provided A complete date consisting of day, month and year shall be "
             "specified using the ISO 8601 date format NOTE \u201cPlaced on the market\u201d "
@@ -58,7 +58,7 @@ class MarketingStatus(backboneelement.BackboneElement):
         alias="jurisdiction",
         title=(
             "Where a Medicines Regulatory Agency has granted a marketing "
-            "authorisation for which specific provisions within a jurisdiction "
+            "authorization for which specific provisions within a jurisdiction "
             "apply, the jurisdiction can be specified using an appropriate "
             "controlled terminology The controlled term and the controlled term "
             "identifier shall be specified"
@@ -73,7 +73,7 @@ class MarketingStatus(backboneelement.BackboneElement):
         alias="restoreDate",
         title=(
             "The date when the Medicinal Product is placed on the market by the "
-            "Marketing Authorisation Holder (or where applicable, the "
+            "Marketing Authorization Holder (or where applicable, the "
             "manufacturer/distributor) in a country and/or jurisdiction shall be "
             "provided A complete date consisting of day, month and year shall be "
             "specified using the ISO 8601 date format NOTE \u201cPlaced on the market\u201d "
