@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Measure
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Measure(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -54,6 +54,28 @@ class Measure(domainresource.DomainResource):
         element_property=True,
     )
 
+    basis: fhirtypes.Code = Field(
+        None,
+        alias="basis",
+        title="Population basis",
+        description=(
+            "The population basis specifies the type of elements in the population."
+            " For a subject-based measure, this is boolean (because the subject and"
+            " the population basis are the same, and the population criteria define"
+            " yes/no values for each individual in the population). For measures "
+            "that have a population basis that is different than the subject, this "
+            "element specifies the type of the population basis. For example, an "
+            "encounter-based measure has a subject of Patient and a population "
+            "basis of Encounter, and the population criteria all return lists of "
+            "Encounters."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    basis__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_basis", title="Extension field for ``basis``."
+    )
+
     clinicalRecommendationStatement: fhirtypes.Markdown = Field(
         None,
         alias="clinicalRecommendationStatement",
@@ -111,15 +133,32 @@ class Measure(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the measure was published. The "
-            "date must change when the business version changes and it must change "
-            "if the status code changes. In addition, it should change when the "
-            "substantive content of the measure changes."
+            "The date  (and optionally time) when the measure was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the measure changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -128,18 +167,6 @@ class Measure(domainresource.DomainResource):
         None, alias="_date", title="Extension field for ``date``."
     )
 
-    definition: typing.List[fhirtypes.Markdown] = Field(
-        None,
-        alias="definition",
-        title="Defined terms used in the measure documentation",
-        description="Provides a description of an individual term used within the measure.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-    definition__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(None, alias="_definition", title="Extension field for ``definition``.")
-
     description: fhirtypes.Markdown = Field(
         None,
         alias="description",
@@ -200,8 +227,9 @@ class Measure(domainresource.DomainResource):
         alias="endorser",
         title="Who endorsed the content",
         description=(
-            "An individual or organization responsible for officially endorsing the"
-            " content for use in some setting."
+            "An individual or organization asserted by the publisher to be "
+            "responsible for officially endorsing the content for use in some "
+            "setting."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -235,7 +263,7 @@ class Measure(domainresource.DomainResource):
     guidance: fhirtypes.Markdown = Field(
         None,
         alias="guidance",
-        title="Additional guidance for implementers",
+        title="Additional guidance for implementers (deprecated)",
         description=(
             "Additional guidance for the measure including how it can be used in a "
             "clinical context, and the intent of the measure."
@@ -288,7 +316,7 @@ class Measure(domainresource.DomainResource):
     lastReviewDate: fhirtypes.Date = Field(
         None,
         alias="lastReviewDate",
-        title="When the measure was last reviewed",
+        title="When the measure was last reviewed by the publisher",
         description=(
             "The date on which the resource content was last reviewed. Review "
             "happens periodically after approval but does not change the original "
@@ -301,7 +329,7 @@ class Measure(domainresource.DomainResource):
         None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
     )
 
-    library: typing.List[fhirtypes.Canonical] = Field(
+    library: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="library",
         title="Logic used by the measure",
@@ -337,8 +365,11 @@ class Measure(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
-        description="The name of the organization or individual that published the measure.",
+        title="Name of the publisher/steward (organization or individual)",
+        description=(
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the measure."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -361,7 +392,7 @@ class Measure(domainresource.DomainResource):
         None, alias="_purpose", title="Extension field for ``purpose``."
     )
 
-    rateAggregation: fhirtypes.String = Field(
+    rateAggregation: fhirtypes.Markdown = Field(
         None,
         alias="rateAggregation",
         title="How is rate aggregation performed for this measure",
@@ -395,7 +426,7 @@ class Measure(domainresource.DomainResource):
     relatedArtifact: typing.List[fhirtypes.RelatedArtifactType] = Field(
         None,
         alias="relatedArtifact",
-        title="Additional documentation, citations, etc.",
+        title="Additional documentation, citations, etc",
         description=(
             "Related artifacts such as additional documentation, justification, or "
             "bibliographic references."
@@ -409,14 +440,14 @@ class Measure(domainresource.DomainResource):
         alias="reviewer",
         title="Who reviewed the content",
         description=(
-            "An individual or organization primarily responsible for review of some"
-            " aspect of the content."
+            "An individual or organization asserted by the publisher to be "
+            "primarily responsible for review of some aspect of the content."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    riskAdjustment: fhirtypes.String = Field(
+    riskAdjustment: fhirtypes.Markdown = Field(
         None,
         alias="riskAdjustment",
         title="How risk adjustment is applied for this measure",
@@ -446,6 +477,18 @@ class Measure(domainresource.DomainResource):
         element_property=True,
     )
 
+    scoringUnit: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="scoringUnit",
+        title="What units?",
+        description=(
+            "Defines the expected units of measure for the measure score. This "
+            "element SHOULD be specified as a UCUM unit."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -533,6 +576,15 @@ class Measure(domainresource.DomainResource):
         element_property=True,
     )
 
+    term: typing.List[fhirtypes.MeasureTermType] = Field(
+        None,
+        alias="term",
+        title="Defined terms used in the measure documentation",
+        description="Provides a description of an individual term used within the measure.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     title: fhirtypes.String = Field(
         None,
         alias="title",
@@ -550,7 +602,7 @@ class Measure(domainresource.DomainResource):
         alias="topic",
         title=(
             "The category of the measure, such as Education, Treatment, Assessment,"
-            " etc."
+            " etc"
         ),
         description=(
             "Descriptive topics related to the content of the measure. Topics "
@@ -585,10 +637,10 @@ class Measure(domainresource.DomainResource):
             "An absolute URI that is used to identify this measure when it is "
             "referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this measure is (or will be) published. This URL can be "
-            "the target of a canonical reference. It SHALL remain the same when the"
-            " measure is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " measure is (or will be) published. This URL can be the target of a "
+            "canonical reference. It SHALL remain the same when the measure is "
+            "stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -597,7 +649,7 @@ class Measure(domainresource.DomainResource):
         None, alias="_url", title="Extension field for ``url``."
     )
 
-    usage: fhirtypes.String = Field(
+    usage: fhirtypes.Markdown = Field(
         None,
         alias="usage",
         title="Describes the clinical usage of the measure",
@@ -651,6 +703,105 @@ class Measure(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Measure`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
+            "name",
+            "title",
+            "subtitle",
+            "status",
+            "experimental",
+            "subjectCodeableConcept",
+            "subjectReference",
+            "basis",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "usage",
+            "copyright",
+            "copyrightLabel",
+            "approvalDate",
+            "lastReviewDate",
+            "effectivePeriod",
+            "topic",
+            "author",
+            "editor",
+            "reviewer",
+            "endorser",
+            "relatedArtifact",
+            "library",
+            "disclaimer",
+            "scoring",
+            "scoringUnit",
+            "compositeScoring",
+            "type",
+            "riskAdjustment",
+            "rateAggregation",
+            "rationale",
+            "clinicalRecommendationStatement",
+            "improvementNotation",
+            "term",
+            "guidance",
+            "group",
+            "supplementalData",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_900(
         cls, values: typing.Dict[str, typing.Any]
@@ -726,7 +877,10 @@ class Measure(domainresource.DomainResource):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"subject": ["subjectCodeableConcept", "subjectReference"]}
+        one_of_many_fields = {
+            "subject": ["subjectCodeableConcept", "subjectReference"],
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"],
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
@@ -750,7 +904,7 @@ class Measure(domainresource.DomainResource):
 
 
 class MeasureGroup(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -760,6 +914,28 @@ class MeasureGroup(backboneelement.BackboneElement):
 
     resource_type = Field("MeasureGroup", const=True)
 
+    basis: fhirtypes.Code = Field(
+        None,
+        alias="basis",
+        title="Population basis",
+        description=(
+            "The population basis specifies the type of elements in the population."
+            " For a subject-based measure, this is boolean (because the subject and"
+            " the population basis are the same, and the population criteria define"
+            " yes/no values for each individual in the population). For measures "
+            "that have a population basis that is different than the subject, this "
+            "element specifies the type of the population basis. For example, an "
+            "encounter-based measure has a subject of Patient and a population "
+            "basis of Encounter, and the population criteria all return lists of "
+            "Encounters."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    basis__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_basis", title="Extension field for ``basis``."
+    )
+
     code: fhirtypes.CodeableConceptType = Field(
         None,
         alias="code",
@@ -774,7 +950,7 @@ class MeasureGroup(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="Summary description",
@@ -786,6 +962,51 @@ class MeasureGroup(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    improvementNotation: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="improvementNotation",
+        title="increase | decrease",
+        description=(
+            "Information on whether an increase or decrease in score is the "
+            "preferred result (e.g., a higher score indicates better quality OR a "
+            "lower score indicates better quality OR quality is within a range)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    library: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
+        None,
+        alias="library",
+        title="Logic used by the measure group",
+        description=(
+            "A reference to a Library resource containing the formal logic used by "
+            "the measure group."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Library"],
+    )
+    library__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_library", title="Extension field for ``library``.")
+
+    linkId: fhirtypes.String = Field(
+        None,
+        alias="linkId",
+        title="Unique id for group in measure",
+        description=(
+            "An identifier that is unique within the Measure allowing linkage to "
+            "the equivalent item in a MeasureReport resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    linkId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_linkId", title="Extension field for ``linkId``."
+    )
+
     population: typing.List[fhirtypes.MeasureGroupPopulationType] = Field(
         None,
         alias="population",
@@ -795,6 +1016,47 @@ class MeasureGroup(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    rateAggregation: fhirtypes.Markdown = Field(
+        None,
+        alias="rateAggregation",
+        title="How is rate aggregation performed for this measure",
+        description=(
+            "Describes how to combine the information calculated, based on logic in"
+            " each of several populations, into one summarized result."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    rateAggregation__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_rateAggregation", title="Extension field for ``rateAggregation``."
+    )
+
+    scoring: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="scoring",
+        title="proportion | ratio | continuous-variable | cohort",
+        description=(
+            "Indicates how the calculation is performed for the measure, including "
+            "proportion, ratio, continuous-variable, and cohort. The value set is "
+            "extensible, allowing additional measure scoring types to be "
+            "represented."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    scoringUnit: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="scoringUnit",
+        title="What units?",
+        description=(
+            "Defines the expected units of measure for the measure score. This "
+            "element SHOULD be specified as a UCUM unit."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     stratifier: typing.List[fhirtypes.MeasureGroupStratifierType] = Field(
         None,
         alias="stratifier",
@@ -808,9 +1070,126 @@ class MeasureGroup(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    subjectCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="subjectCodeableConcept",
+        title=(
+            "E.g. Patient, Practitioner, RelatedPerson, Organization, Location, "
+            "Device"
+        ),
+        description=(
+            "The intended subjects for the measure. If this element is not "
+            "provided, a Patient subject is assumed, but the subject of the measure"
+            " can be anything."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e subject[x]
+        one_of_many="subject",
+        one_of_many_required=False,
+    )
+
+    subjectReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="subjectReference",
+        title=(
+            "E.g. Patient, Practitioner, RelatedPerson, Organization, Location, "
+            "Device"
+        ),
+        description=(
+            "The intended subjects for the measure. If this element is not "
+            "provided, a Patient subject is assumed, but the subject of the measure"
+            " can be anything."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e subject[x]
+        one_of_many="subject",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Group"],
+    )
+
+    type: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="type",
+        title="process | outcome | structure | patient-reported-outcome | composite",
+        description=(
+            "Indicates whether the measure is used to examine a process, an outcome"
+            " over time, a patient-reported outcome, or a structure measure such as"
+            " utilization."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MeasureGroup`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "linkId",
+            "code",
+            "description",
+            "type",
+            "subjectCodeableConcept",
+            "subjectReference",
+            "basis",
+            "scoring",
+            "scoringUnit",
+            "rateAggregation",
+            "improvementNotation",
+            "library",
+            "population",
+            "stratifier",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_1436(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {"subject": ["subjectCodeableConcept", "subjectReference"]}
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class MeasureGroupPopulation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -820,6 +1199,24 @@ class MeasureGroupPopulation(backboneelement.BackboneElement):
 
     resource_type = Field("MeasureGroupPopulation", const=True)
 
+    aggregateMethod: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="aggregateMethod",
+        title=(
+            "Aggregation method for a measure score (e.g. sum, average, median, "
+            "minimum, maximum, count)"
+        ),
+        description=(
+            "Specifies which method should be used to aggregate measure observation"
+            " values. For most scoring types, this is implied by scoring (e.g. a "
+            "proportion measure counts members of the populations). For continuous "
+            "variables, however, this information must be specified to ensure "
+            "correct calculation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     code: fhirtypes.CodeableConceptType = Field(
         None,
         alias="code",
@@ -834,7 +1231,7 @@ class MeasureGroupPopulation(backboneelement.BackboneElement):
     )
 
     criteria: fhirtypes.ExpressionType = Field(
-        ...,
+        None,
         alias="criteria",
         title="The criteria that defines this population",
         description=(
@@ -845,7 +1242,7 @@ class MeasureGroupPopulation(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="The human readable description of this population criteria",
@@ -857,9 +1254,80 @@ class MeasureGroupPopulation(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    groupDefinition: fhirtypes.ReferenceType = Field(
+        None,
+        alias="groupDefinition",
+        title="A group resource that defines this population",
+        description=(
+            "A Group resource that defines this population as a set of "
+            "characteristics."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Group"],
+    )
+
+    inputPopulationId: fhirtypes.String = Field(
+        None,
+        alias="inputPopulationId",
+        title="Which population",
+        description=(
+            "The id of a population element in this measure that provides the input"
+            " for this population criteria. In most cases, the scoring structure of"
+            " the measure implies specific relationships (e.g. the Numerator uses "
+            "the Denominator as the source in a proportion scoring). In some cases,"
+            " however, multiple possible choices exist and must be resolved "
+            "explicitly. For example in a ratio measure with multiple initial "
+            "populations, the denominator must specify which population should be "
+            "used as the starting point."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    inputPopulationId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_inputPopulationId",
+        title="Extension field for ``inputPopulationId``.",
+    )
+
+    linkId: fhirtypes.String = Field(
+        None,
+        alias="linkId",
+        title="Unique id for population in measure",
+        description=(
+            "An identifier that is unique within the Measure allowing linkage to "
+            "the equivalent population in a MeasureReport resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    linkId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_linkId", title="Extension field for ``linkId``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MeasureGroupPopulation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "linkId",
+            "code",
+            "description",
+            "criteria",
+            "groupDefinition",
+            "inputPopulationId",
+            "aggregateMethod",
+        ]
+
 
 class MeasureGroupStratifier(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -911,7 +1379,7 @@ class MeasureGroupStratifier(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="The human readable description of this stratifier",
@@ -923,9 +1391,56 @@ class MeasureGroupStratifier(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    groupDefinition: fhirtypes.ReferenceType = Field(
+        None,
+        alias="groupDefinition",
+        title="A group resource that defines this population",
+        description=(
+            "A Group resource that defines this population as a set of "
+            "characteristics."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Group"],
+    )
+
+    linkId: fhirtypes.String = Field(
+        None,
+        alias="linkId",
+        title="Unique id for stratifier in measure",
+        description=(
+            "An identifier that is unique within the Measure allowing linkage to "
+            "the equivalent item in a MeasureReport resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    linkId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_linkId", title="Extension field for ``linkId``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MeasureGroupStratifier`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "linkId",
+            "code",
+            "description",
+            "criteria",
+            "groupDefinition",
+            "component",
+        ]
+
 
 class MeasureGroupStratifierComponent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -952,7 +1467,7 @@ class MeasureGroupStratifierComponent(backboneelement.BackboneElement):
     )
 
     criteria: fhirtypes.ExpressionType = Field(
-        ...,
+        None,
         alias="criteria",
         title="Component of how the measure should be stratified",
         description=(
@@ -965,7 +1480,7 @@ class MeasureGroupStratifierComponent(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="The human readable description of this stratifier component",
@@ -977,9 +1492,55 @@ class MeasureGroupStratifierComponent(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    groupDefinition: fhirtypes.ReferenceType = Field(
+        None,
+        alias="groupDefinition",
+        title="A group resource that defines this population",
+        description=(
+            "A Group resource that defines this population as a set of "
+            "characteristics."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Group"],
+    )
+
+    linkId: fhirtypes.String = Field(
+        None,
+        alias="linkId",
+        title="Unique id for stratifier component in measure",
+        description=(
+            "An identifier that is unique within the Measure allowing linkage to "
+            "the equivalent item in a MeasureReport resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    linkId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_linkId", title="Extension field for ``linkId``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MeasureGroupStratifierComponent`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "linkId",
+            "code",
+            "description",
+            "criteria",
+            "groupDefinition",
+        ]
+
 
 class MeasureSupplementalData(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1019,7 +1580,7 @@ class MeasureSupplementalData(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    description: fhirtypes.String = Field(
+    description: fhirtypes.Markdown = Field(
         None,
         alias="description",
         title="The human readable description of this supplemental data",
@@ -1031,6 +1592,21 @@ class MeasureSupplementalData(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    linkId: fhirtypes.String = Field(
+        None,
+        alias="linkId",
+        title="Unique id for supplementalData in measure",
+        description=(
+            "An identifier that is unique within the Measure allowing linkage to "
+            "the equivalent item in a MeasureReport resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    linkId__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_linkId", title="Extension field for ``linkId``."
+    )
+
     usage: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="usage",
@@ -1046,3 +1622,61 @@ class MeasureSupplementalData(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MeasureSupplementalData`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "linkId",
+            "code",
+            "usage",
+            "description",
+            "criteria",
+        ]
+
+
+class MeasureTerm(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Defined terms used in the measure documentation.
+    Provides a description of an individual term used within the measure.
+    """
+
+    resource_type = Field("MeasureTerm", const=True)
+
+    code: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="code",
+        title="What term?",
+        description="A codeable representation of the defined term.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    definition: fhirtypes.Markdown = Field(
+        None,
+        alias="definition",
+        title="Meaning of the term",
+        description="Provides a definition for the term as used within the measure.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    definition__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_definition", title="Extension field for ``definition``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MeasureTerm`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "code", "definition"]
