@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Medication
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -20,27 +20,13 @@ class Medication(domainresource.DomainResource):
 
     Definition of a Medication.
     This resource is primarily used for the identification and definition of a
-    medication for the purposes of prescribing, dispensing, and administering a
-    medication as well as for making statements about medication use.
+    medication, including ingredients, for the purposes of prescribing,
+    dispensing, and administering a medication as well as for making statements
+    about medication use.
     """
 
     resource_type = Field("Medication", const=True)
 
-    amount: fhirtypes.RatioType = Field(
-        None,
-        alias="amount",
-        title="Amount of drug in package",
-        description=(
-            "Specific amount of the drug in the packaged product.  For example, "
-            "when specifying a product that has the same strength (For example, "
-            "Insulin glargine 100 unit per mL solution for injection), this "
-            "attribute provides additional clarification of the package amount (For"
-            " example, 3 mL, 10mL, etc.)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     batch: fhirtypes.MedicationBatchType = Field(
         None,
         alias="batch",
@@ -65,9 +51,23 @@ class Medication(domainresource.DomainResource):
         element_property=True,
     )
 
-    form: fhirtypes.CodeableConceptType = Field(
+    definition: fhirtypes.ReferenceType = Field(
         None,
-        alias="form",
+        alias="definition",
+        title="Knowledge about this medication",
+        description=(
+            "A reference to a knowledge resource that provides more information "
+            "about this medication."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["MedicationKnowledge"],
+    )
+
+    doseForm: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="doseForm",
         title="powder | tablets | capsule +",
         description="Describes the form of the item.  Powder; tablets; capsule.",
         # if property is element of this resource.
@@ -92,14 +92,16 @@ class Medication(domainresource.DomainResource):
         element_property=True,
     )
 
-    manufacturer: fhirtypes.ReferenceType = Field(
+    marketingAuthorizationHolder: fhirtypes.ReferenceType = Field(
         None,
-        alias="manufacturer",
-        title="Manufacturer of the item",
+        alias="marketingAuthorizationHolder",
+        title="Organization that has authorization to market medication",
         description=(
-            "Describes the details of the manufacturer of the medication product.  "
-            "This is not intended to represent the distributor of a medication "
-            "product."
+            "The company or other legal entity that has authorization, from the "
+            "appropriate drug regulatory authority,  to market a medicine in one or"
+            " more jurisdictions.  Typically abbreviated MAH.Note:  The MAH may "
+            "manufacture the product and may also contract the manufacturing of the"
+            " product to one or more companies (organizations)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -122,6 +124,25 @@ class Medication(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    totalVolume: fhirtypes.QuantityType = Field(
+        None,
+        alias="totalVolume",
+        title=(
+            "When the specified product code does not infer a package size, this is"
+            " the specific amount of drug in the product"
+        ),
+        description=(
+            "When the specified product code does not infer a package size, this is"
+            " the specific amount of drug in the product.  For example, when "
+            "specifying a product that has the same strength (For example, Insulin "
+            "glargine 100 unit per mL solution for injection), this attribute "
+            "provides additional clarification of the package amount (For example, "
+            "3 mL, 10mL, etc.)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -140,11 +161,12 @@ class Medication(domainresource.DomainResource):
             "identifier",
             "code",
             "status",
-            "manufacturer",
-            "form",
-            "amount",
+            "marketingAuthorizationHolder",
+            "doseForm",
+            "totalVolume",
             "ingredient",
             "batch",
+            "definition",
         ]
 
 
@@ -218,49 +240,76 @@ class MedicationIngredient(backboneelement.BackboneElement):
         None, alias="_isActive", title="Extension field for ``isActive``."
     )
 
-    itemCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="itemCodeableConcept",
-        title="The actual ingredient or content",
+    item: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="item",
+        title=(
+            "The ingredient (substance or medication) that the ingredient.strength "
+            "relates to"
+        ),
         description=(
-            "The actual ingredient - either a substance (simple ingredient) or "
-            "another medication of a medication."
+            "The ingredient (substance or medication) that the ingredient.strength "
+            "relates to.  This is represented as a concept from a code system or "
+            "described in another resource (Substance or Medication)."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e item[x]
-        one_of_many="item",
-        one_of_many_required=True,
-    )
-
-    itemReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="itemReference",
-        title="The actual ingredient or content",
-        description=(
-            "The actual ingredient - either a substance (simple ingredient) or "
-            "another medication of a medication."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e item[x]
-        one_of_many="item",
-        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Substance", "Medication"],
     )
 
-    strength: fhirtypes.RatioType = Field(
+    strengthCodeableConcept: fhirtypes.CodeableConceptType = Field(
         None,
-        alias="strength",
+        alias="strengthCodeableConcept",
         title="Quantity of ingredient present",
         description=(
             "Specifies how many (or how much) of the items there are in this "
             "Medication.  For example, 250 mg per tablet.  This is expressed as a "
-            "ratio where the numerator is 250mg and the denominator is 1 tablet."
+            "ratio where the numerator is 250mg and the denominator is 1 tablet but"
+            " can also be expressed a quantity when the denominator is assumed to "
+            "be 1 tablet."
         ),
         # if property is element of this resource.
         element_property=True,
+        # Choice of Data Types. i.e strength[x]
+        one_of_many="strength",
+        one_of_many_required=False,
+    )
+
+    strengthQuantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="strengthQuantity",
+        title="Quantity of ingredient present",
+        description=(
+            "Specifies how many (or how much) of the items there are in this "
+            "Medication.  For example, 250 mg per tablet.  This is expressed as a "
+            "ratio where the numerator is 250mg and the denominator is 1 tablet but"
+            " can also be expressed a quantity when the denominator is assumed to "
+            "be 1 tablet."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e strength[x]
+        one_of_many="strength",
+        one_of_many_required=False,
+    )
+
+    strengthRatio: fhirtypes.RatioType = Field(
+        None,
+        alias="strengthRatio",
+        title="Quantity of ingredient present",
+        description=(
+            "Specifies how many (or how much) of the items there are in this "
+            "Medication.  For example, 250 mg per tablet.  This is expressed as a "
+            "ratio where the numerator is 250mg and the denominator is 1 tablet but"
+            " can also be expressed a quantity when the denominator is assumed to "
+            "be 1 tablet."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e strength[x]
+        one_of_many="strength",
+        one_of_many_required=False,
     )
 
     @classmethod
@@ -273,10 +322,11 @@ class MedicationIngredient(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "itemCodeableConcept",
-            "itemReference",
+            "item",
             "isActive",
-            "strength",
+            "strengthRatio",
+            "strengthCodeableConcept",
+            "strengthQuantity",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
@@ -295,7 +345,9 @@ class MedicationIngredient(backboneelement.BackboneElement):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"item": ["itemCodeableConcept", "itemReference"]}
+        one_of_many_fields = {
+            "strength": ["strengthCodeableConcept", "strengthQuantity", "strengthRatio"]
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
