@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationAdministration
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -30,39 +30,40 @@ class MedicationAdministration(domainresource.DomainResource):
 
     resource_type = Field("MedicationAdministration", const=True)
 
-    category: fhirtypes.CodeableConceptType = Field(
+    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="category",
-        title="Type of medication usage",
+        alias="basedOn",
+        title="Plan this is fulfilled by this administration",
         description=(
-            "Indicates where the medication is expected to be consumed or "
-            "administered."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    context: fhirtypes.ReferenceType = Field(
-        None,
-        alias="context",
-        title="Encounter or Episode of Care administered as part of",
-        description=(
-            "The visit, admission, or other contact between patient and health care"
-            " provider during which the medication administration was performed."
+            "A plan that is fulfilled in whole or in part by this "
+            "MedicationAdministration."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Encounter", "EpisodeOfCare"],
+        enum_reference_types=["CarePlan"],
     )
 
-    device: typing.List[fhirtypes.ReferenceType] = Field(
+    category: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="category",
+        title="Type of medication administration",
+        description=(
+            "The type of medication administration (for example, drug "
+            "classification like ATC, where meds would be administered, legal "
+            "category of the medication)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    device: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="device",
         title="Device used to administer",
         description=(
-            "The device used in administering the medication to the patient.  For "
-            "example, a particular infusion pump."
+            "The device that is to be used for the administration of the medication"
+            " (for example, PCA Pump)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -82,43 +83,18 @@ class MedicationAdministration(domainresource.DomainResource):
         element_property=True,
     )
 
-    effectiveDateTime: fhirtypes.DateTime = Field(
+    encounter: fhirtypes.ReferenceType = Field(
         None,
-        alias="effectiveDateTime",
-        title="Start and end time of administration",
+        alias="encounter",
+        title="Encounter administered as part of",
         description=(
-            "A specific date/time or interval of time during which the "
-            "administration took place (or did not take place, when the 'notGiven' "
-            "attribute is true). For many administrations, such as swallowing a "
-            "tablet the use of dateTime is more appropriate."
+            "The visit, admission, or other contact between patient and health care"
+            " provider during which the medication administration was performed."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e effective[x]
-        one_of_many="effective",
-        one_of_many_required=True,
-    )
-    effectiveDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_effectiveDateTime",
-        title="Extension field for ``effectiveDateTime``.",
-    )
-
-    effectivePeriod: fhirtypes.PeriodType = Field(
-        None,
-        alias="effectivePeriod",
-        title="Start and end time of administration",
-        description=(
-            "A specific date/time or interval of time during which the "
-            "administration took place (or did not take place, when the 'notGiven' "
-            "attribute is true). For many administrations, such as swallowing a "
-            "tablet the use of dateTime is more appropriate."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e effective[x]
-        one_of_many="effective",
-        one_of_many_required=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Encounter"],
     )
 
     eventHistory: typing.List[fhirtypes.ReferenceType] = Field(
@@ -151,26 +127,21 @@ class MedicationAdministration(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiates: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
+    isSubPotent: bool = Field(
         None,
-        alias="instantiates",
-        title="Instantiates protocol or definition",
-        description=(
-            "A protocol, guideline, orderset, or other definition that was adhered "
-            "to in whole or in part by this event."
-        ),
+        alias="isSubPotent",
+        title="Full dose was not administered",
+        description="An indication that the full dose was not administered.",
         # if property is element of this resource.
         element_property=True,
     )
-    instantiates__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(
-        None, alias="_instantiates", title="Extension field for ``instantiates``."
+    isSubPotent__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_isSubPotent", title="Extension field for ``isSubPotent``."
     )
 
-    medicationCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="medicationCodeableConcept",
+    medication: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="medication",
         title="What was administered",
         description=(
             "Identifies the medication that was administered. This is either a link"
@@ -180,26 +151,6 @@ class MedicationAdministration(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
-    )
-
-    medicationReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="medicationReference",
-        title="What was administered",
-        description=(
-            "Identifies the medication that was administered. This is either a link"
-            " to a resource representing the details of the medication or a simple "
-            "attribute carrying a code that identifies the medication from a known "
-            "list of medications."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Medication"],
     )
@@ -216,6 +167,71 @@ class MedicationAdministration(domainresource.DomainResource):
         element_property=True,
     )
 
+    occurenceDateTime: fhirtypes.DateTime = Field(
+        None,
+        alias="occurenceDateTime",
+        title=(
+            "Specific date/time or interval of time during which the administration"
+            " took place (or did not take place)"
+        ),
+        description=(
+            "A specific date/time or interval of time during which the "
+            "administration took place (or did not take place). For many "
+            "administrations, such as swallowing a tablet the use of dateTime is "
+            "more appropriate."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurence[x]
+        one_of_many="occurence",
+        one_of_many_required=True,
+    )
+    occurenceDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_occurenceDateTime",
+        title="Extension field for ``occurenceDateTime``.",
+    )
+
+    occurencePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="occurencePeriod",
+        title=(
+            "Specific date/time or interval of time during which the administration"
+            " took place (or did not take place)"
+        ),
+        description=(
+            "A specific date/time or interval of time during which the "
+            "administration took place (or did not take place). For many "
+            "administrations, such as swallowing a tablet the use of dateTime is "
+            "more appropriate."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurence[x]
+        one_of_many="occurence",
+        one_of_many_required=True,
+    )
+
+    occurenceTiming: fhirtypes.TimingType = Field(
+        None,
+        alias="occurenceTiming",
+        title=(
+            "Specific date/time or interval of time during which the administration"
+            " took place (or did not take place)"
+        ),
+        description=(
+            "A specific date/time or interval of time during which the "
+            "administration took place (or did not take place). For many "
+            "administrations, such as swallowing a tablet the use of dateTime is "
+            "more appropriate."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurence[x]
+        one_of_many="occurence",
+        one_of_many_required=True,
+    )
+
     partOf: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="partOf",
@@ -224,44 +240,67 @@ class MedicationAdministration(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["MedicationAdministration", "Procedure"],
+        enum_reference_types=[
+            "MedicationAdministration",
+            "Procedure",
+            "MedicationDispense",
+        ],
     )
 
     performer: typing.List[fhirtypes.MedicationAdministrationPerformerType] = Field(
         None,
         alias="performer",
-        title="Who performed the medication administration and what they did",
-        description=(
-            "Indicates who or what performed the medication administration and how "
-            "they were involved."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="reasonCode",
-        title="Reason administration performed",
-        description="A code indicating why the medication was given.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
         title=(
-            "Condition or observation that supports why the medication was "
-            "administered"
+            "Who or what performed the medication administration and what type of "
+            "performance they did"
+        ),
+        description=(
+            "The performer of the medication treatment.  For devices this is the "
+            "device that performed the administration of the medication.  An IV "
+            "Pump would be an example of a device that is performing the "
+            "administration. Both the IV Pump and the practitioner that set the "
+            "rate or bolus on the pump can be listed as performers."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
+        alias="reason",
+        title=(
+            "Concept, condition or observation that supports why the medication was"
+            " administered"
+        ),
+        description=(
+            "A code, Condition or observation that supports why the medication was "
+            "administered."
         ),
-        description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Condition", "Observation", "DiagnosticReport"],
     )
 
+    recorded: fhirtypes.DateTime = Field(
+        None,
+        alias="recorded",
+        title=(
+            "When the MedicationAdministration was first captured in the subject's "
+            "record"
+        ),
+        description=(
+            "The date the occurrence of the  MedicationAdministration was first "
+            "captured in the record - potentially significantly after the "
+            "occurrence of the event."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    recorded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_recorded", title="Extension field for ``recorded``."
+    )
+
     request: fhirtypes.ReferenceType = Field(
         None,
         alias="request",
@@ -317,6 +356,15 @@ class MedicationAdministration(domainresource.DomainResource):
         element_property=True,
     )
 
+    subPotentReason: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="subPotentReason",
+        title="Reason full dose was not administered",
+        description="The reason or reasons why the full dose was not administered.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     subject: fhirtypes.ReferenceType = Field(
         ...,
         alias="subject",
@@ -334,7 +382,11 @@ class MedicationAdministration(domainresource.DomainResource):
         title="Additional information to support administration",
         description=(
             "Additional information (for example, patient height and weight) that "
-            "supports the administration of the medication."
+            "supports the administration of the medication.  This attribute can be "
+            "used to provide documentation of specific characteristics of the "
+            "patient present at the time of administration.  For example, if the "
+            'dose says "give "x" if the heartrate exceeds "y"", then the heart rate'
+            " can be included using this attribute."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -358,21 +410,23 @@ class MedicationAdministration(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "identifier",
-            "instantiates",
+            "basedOn",
             "partOf",
             "status",
             "statusReason",
             "category",
-            "medicationCodeableConcept",
-            "medicationReference",
+            "medication",
             "subject",
-            "context",
+            "encounter",
             "supportingInformation",
-            "effectiveDateTime",
-            "effectivePeriod",
+            "occurenceDateTime",
+            "occurencePeriod",
+            "occurenceTiming",
+            "recorded",
+            "isSubPotent",
+            "subPotentReason",
             "performer",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "request",
             "device",
             "note",
@@ -456,8 +510,7 @@ class MedicationAdministration(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "effective": ["effectiveDateTime", "effectivePeriod"],
-            "medication": ["medicationCodeableConcept", "medicationReference"],
+            "occurence": ["occurenceDateTime", "occurencePeriod", "occurenceTiming"]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -662,17 +715,21 @@ class MedicationAdministrationPerformer(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Who performed the medication administration and what they did.
-    Indicates who or what performed the medication administration and how they
-    were involved.
+    Who or what performed the medication administration and what type of
+    performance they did.
+    The performer of the medication treatment.  For devices this is the device
+    that performed the administration of the medication.  An IV Pump would be
+    an example of a device that is performing the administration. Both the IV
+    Pump and the practitioner that set the rate or bolus on the pump can be
+    listed as performers.
     """
 
     resource_type = Field("MedicationAdministrationPerformer", const=True)
 
-    actor: fhirtypes.ReferenceType = Field(
+    actor: fhirtypes.CodeableReferenceType = Field(
         ...,
         alias="actor",
-        title="Who performed the medication administration",
+        title="Who or what performed the medication administration",
         description="Indicates who or what performed the medication administration.",
         # if property is element of this resource.
         element_property=True,
