@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationDispense
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -41,31 +41,31 @@ class MedicationDispense(domainresource.DomainResource):
         enum_reference_types=["MedicationRequest"],
     )
 
-    category: fhirtypes.CodeableConceptType = Field(
+    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="category",
-        title="Type of medication dispense",
+        alias="basedOn",
+        title="Plan that is fulfilled by this dispense",
         description=(
-            "Indicates the type of medication dispense (for example, where the "
-            "medication is expected to be consumed or administered (i.e. inpatient "
-            "or outpatient))."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    context: fhirtypes.ReferenceType = Field(
-        None,
-        alias="context",
-        title="Encounter / Episode associated with event",
-        description=(
-            "The encounter or episode of care that establishes the context for this"
-            " event."
+            "A plan that is fulfilled in whole or in part by this "
+            "MedicationDispense."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Encounter", "EpisodeOfCare"],
+        enum_reference_types=["CarePlan"],
+    )
+
+    category: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="category",
+        title="Type of medication dispense",
+        description=(
+            "Indicates the type of medication dispense (for example, drug "
+            "classification like ATC, where meds would be administered, legal "
+            "category of the medication.)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
     )
 
     daysSupply: fhirtypes.QuantityType = Field(
@@ -80,10 +80,10 @@ class MedicationDispense(domainresource.DomainResource):
     destination: fhirtypes.ReferenceType = Field(
         None,
         alias="destination",
-        title="Where the medication was sent",
+        title="Where the medication was/will be sent",
         description=(
-            "Identification of the facility/location where the medication was "
-            "shipped to, as part of the dispense event."
+            "Identification of the facility/location where the medication was/will "
+            "be shipped to, as part of the dispense event."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -91,21 +91,6 @@ class MedicationDispense(domainresource.DomainResource):
         enum_reference_types=["Location"],
     )
 
-    detectedIssue: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="detectedIssue",
-        title="Clinical issue with action",
-        description=(
-            "Indicates an actual or potential clinical issue with or between one or"
-            " more active or proposed clinical actions for a patient; e.g. drug-"
-            "drug interaction, duplicate therapy, dosage alert etc."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["DetectedIssue"],
-    )
-
     dosageInstruction: typing.List[fhirtypes.DosageType] = Field(
         None,
         alias="dosageInstruction",
@@ -118,6 +103,17 @@ class MedicationDispense(domainresource.DomainResource):
         element_property=True,
     )
 
+    encounter: fhirtypes.ReferenceType = Field(
+        None,
+        alias="encounter",
+        title="Encounter associated with event",
+        description="The encounter that establishes the context for this event.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Encounter"],
+    )
+
     eventHistory: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="eventHistory",
@@ -159,42 +155,33 @@ class MedicationDispense(domainresource.DomainResource):
         enum_reference_types=["Location"],
     )
 
-    medicationCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="medicationCodeableConcept",
+    medication: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="medication",
         title="What medication was supplied",
         description=(
-            "Identifies the medication being administered. This is either a link to"
-            " a resource representing the details of the medication or a simple "
+            "Identifies the medication supplied. This is either a link to a "
+            "resource representing the details of the medication or a simple "
             "attribute carrying a code that identifies the medication from a known "
             "list of medications."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
-    )
-
-    medicationReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="medicationReference",
-        title="What medication was supplied",
-        description=(
-            "Identifies the medication being administered. This is either a link to"
-            " a resource representing the details of the medication or a simple "
-            "attribute carrying a code that identifies the medication from a known "
-            "list of medications."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Medication"],
     )
 
+    notPerformedReason: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="notPerformedReason",
+        title="Why a dispense was not performed",
+        description="Indicates the reason why a dispense was not performed.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["DetectedIssue"],
+    )
+
     note: typing.List[fhirtypes.AnnotationType] = Field(
         None,
         alias="note",
@@ -211,11 +198,13 @@ class MedicationDispense(domainresource.DomainResource):
         None,
         alias="partOf",
         title="Event that dispense is part of",
-        description="The procedure that trigger the dispense.",
+        description=(
+            "The procedure or medication administration that triggered the " "dispense."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Procedure"],
+        enum_reference_types=["Procedure", "MedicationAdministration"],
     )
 
     performer: typing.List[fhirtypes.MedicationDispensePerformerType] = Field(
@@ -242,16 +231,57 @@ class MedicationDispense(domainresource.DomainResource):
     receiver: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="receiver",
-        title="Who collected the medication",
+        title="Who collected the medication or where the medication was delivered",
         description=(
-            "Identifies the person who picked up the medication.  This will usually"
-            " be a patient or their caregiver, but some cases exist where it can be"
-            " a healthcare professional."
+            "Identifies the person who picked up the medication or the location of "
+            "where the medication was delivered.  This will usually be a patient or"
+            " their caregiver, but some cases exist where it can be a healthcare "
+            "professional or a location."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient", "Practitioner"],
+        enum_reference_types=[
+            "Patient",
+            "Practitioner",
+            "RelatedPerson",
+            "Location",
+            "PractitionerRole",
+        ],
+    )
+
+    recorded: fhirtypes.DateTime = Field(
+        None,
+        alias="recorded",
+        title="When the recording of the dispense started",
+        description=(
+            "The date (and maybe time) when the dispense activity started if "
+            "whenPrepared or whenHandedOver is not populated."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    recorded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_recorded", title="Extension field for ``recorded``."
+    )
+
+    renderedDosageInstruction: fhirtypes.Markdown = Field(
+        None,
+        alias="renderedDosageInstruction",
+        title="Full representation of the dosage instructions",
+        description=(
+            "The full representation of the dose of the medication included in all "
+            "dosage instructions.  To be used when multiple dosage instructions are"
+            " included to represent complex dosing such as increasing or tapering "
+            "doses."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    renderedDosageInstruction__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_renderedDosageInstruction",
+        title="Extension field for ``renderedDosageInstruction``.",
     )
 
     status: fhirtypes.Code = Field(
@@ -283,34 +313,23 @@ class MedicationDispense(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    statusReasonCodeableConcept: fhirtypes.CodeableConceptType = Field(
+    statusChanged: fhirtypes.DateTime = Field(
         None,
-        alias="statusReasonCodeableConcept",
-        title="Why a dispense was not performed",
-        description="Indicates the reason why a dispense was not performed.",
+        alias="statusChanged",
+        title="When the status changed",
+        description=(
+            "The date (and maybe time) when the status of the dispense record "
+            "changed."
+        ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e statusReason[x]
-        one_of_many="statusReason",
-        one_of_many_required=False,
     )
-
-    statusReasonReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="statusReasonReference",
-        title="Why a dispense was not performed",
-        description="Indicates the reason why a dispense was not performed.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e statusReason[x]
-        one_of_many="statusReason",
-        one_of_many_required=False,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["DetectedIssue"],
+    statusChanged__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_statusChanged", title="Extension field for ``statusChanged``."
     )
 
     subject: fhirtypes.ReferenceType = Field(
-        None,
+        ...,
         alias="subject",
         title="Who the dispense is for",
         description=(
@@ -342,7 +361,12 @@ class MedicationDispense(domainresource.DomainResource):
         None,
         alias="supportingInformation",
         title="Information that supports the dispensing of the medication",
-        description="Additional information that supports the medication being dispensed.",
+        description=(
+            "Additional information that supports the medication being dispensed.  "
+            "For example, there may be requirements that a specific lab test has "
+            "been completed prior to dispensing or the patient's weight at the time"
+            " of dispensing is documented."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -352,7 +376,7 @@ class MedicationDispense(domainresource.DomainResource):
     type: fhirtypes.CodeableConceptType = Field(
         None,
         alias="type",
-        title="Trial fill, partial fill, emergency fill, etc.",
+        title="Trial fill, partial fill, emergency fill, etc",
         description=(
             "Indicates the type of dispensing event that is performed. For example,"
             " Trial Fill, Completion of Trial, Partial Fill, Emergency Fill, "
@@ -405,15 +429,15 @@ class MedicationDispense(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "identifier",
+            "basedOn",
             "partOf",
             "status",
-            "statusReasonCodeableConcept",
-            "statusReasonReference",
+            "notPerformedReason",
+            "statusChanged",
             "category",
-            "medicationCodeableConcept",
-            "medicationReference",
+            "medication",
             "subject",
-            "context",
+            "encounter",
             "supportingInformation",
             "performer",
             "location",
@@ -421,14 +445,15 @@ class MedicationDispense(domainresource.DomainResource):
             "type",
             "quantity",
             "daysSupply",
+            "recorded",
             "whenPrepared",
             "whenHandedOver",
             "destination",
             "receiver",
             "note",
+            "renderedDosageInstruction",
             "dosageInstruction",
             "substitution",
-            "detectedIssue",
             "eventHistory",
         ]
 
@@ -491,47 +516,6 @@ class MedicationDispense(domainresource.DomainResource):
 
         return values
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_2026(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {
-            "medication": ["medicationCodeableConcept", "medicationReference"],
-            "statusReason": ["statusReasonCodeableConcept", "statusReasonReference"],
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
 
 class MedicationDispensePerformer(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -562,6 +546,7 @@ class MedicationDispensePerformer(backboneelement.BackboneElement):
             "Patient",
             "Device",
             "RelatedPerson",
+            "CareTeam",
         ],
     )
 
@@ -613,7 +598,7 @@ class MedicationDispenseSubstitution(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    responsibleParty: typing.List[fhirtypes.ReferenceType] = Field(
+    responsibleParty: fhirtypes.ReferenceType = Field(
         None,
         alias="responsibleParty",
         title="Who is responsible for the substitution",
@@ -624,7 +609,7 @@ class MedicationDispenseSubstitution(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole"],
+        enum_reference_types=["Practitioner", "PractitionerRole", "Organization"],
     )
 
     type: fhirtypes.CodeableConceptType = Field(
