@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationRequest
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -49,11 +49,11 @@ class MedicationRequest(domainresource.DomainResource):
     basedOn: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="basedOn",
-        title="What request fulfills",
-        description=(
+        title=(
             "A plan or request that is fulfilled in whole or in part by this "
-            "medication request."
+            "medication request"
         ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -68,11 +68,12 @@ class MedicationRequest(domainresource.DomainResource):
     category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
-        title="Type of medication usage",
+        title="Grouping or category of medication request",
         description=(
-            "Indicates the type of medication request (for example, where the "
-            "medication is expected to be consumed or administered (i.e. inpatient "
-            "or outpatient))."
+            "An arbitrary categorization or grouping of the medication request.  It"
+            " could be used for indicating where meds are intended to be "
+            "administered, eg. in an inpatient setting or in a patient's home, or a"
+            " legal category of the medication."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -83,26 +84,25 @@ class MedicationRequest(domainresource.DomainResource):
         alias="courseOfTherapyType",
         title="Overall pattern of medication administration",
         description=(
-            "The description of the overall patte3rn of the administration of the "
+            "The description of the overall pattern of the administration of the "
             "medication to the patient."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    detectedIssue: typing.List[fhirtypes.ReferenceType] = Field(
+    device: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="detectedIssue",
-        title="Clinical Issue with action",
+        alias="device",
+        title="Intended type of device for the administration",
         description=(
-            "Indicates an actual or potential clinical issue with or between one or"
-            " more active or proposed clinical actions for a patient; e.g. Drug-"
-            "drug interaction, duplicate therapy, dosage alert etc."
+            "The intended type of device that is to be used for the administration "
+            "of the medication (for example, PCA Pump)."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["DetectedIssue"],
+        enum_reference_types=["DeviceDefinition"],
     )
 
     dispenseRequest: fhirtypes.MedicationRequestDispenseRequestType = Field(
@@ -124,10 +124,16 @@ class MedicationRequest(domainresource.DomainResource):
     doNotPerform: bool = Field(
         None,
         alias="doNotPerform",
-        title="True if request is prohibiting action",
+        title=(
+            "True if patient is to stop taking or not to start taking the " "medication"
+        ),
         description=(
-            "If true indicates that the provider is asking for the medication "
-            "request not to occur."
+            "If true, indicates that the provider is asking for the patient to "
+            "either stop taking or to not start taking the specified medication. "
+            "For example, the patient is taking an existing medication and the "
+            "provider is changing their medication. They want to create two "
+            "seperate requests: one to stop using the current medication and "
+            "another to start the new medication."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -139,8 +145,25 @@ class MedicationRequest(domainresource.DomainResource):
     dosageInstruction: typing.List[fhirtypes.DosageType] = Field(
         None,
         alias="dosageInstruction",
-        title="How the medication should be taken",
-        description="Indicates how the medication is to be used by the patient.",
+        title="Specific instructions for how the medication should be taken",
+        description=(
+            "Specific instructions for how the medication is to be used by the "
+            "patient."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    effectiveDosePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="effectiveDosePeriod",
+        title="Period over which the medication is to be taken",
+        description=(
+            "The period over which the medication is to be taken.  Where there are "
+            "multiple dosageInstruction lines (for example, tapering doses), this "
+            "is the earliest date and the latest end date of the "
+            "dosageInstructions."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -180,9 +203,13 @@ class MedicationRequest(domainresource.DomainResource):
         alias="groupIdentifier",
         title="Composite request this is part of",
         description=(
-            "A shared identifier common to all requests that were authorized more "
-            "or less simultaneously by a single author, representing the identifier"
-            " of the requisition or prescription."
+            "A shared identifier common to multiple independent Request instances "
+            "that were activated/authorized more or less simultaneously by a single"
+            " author.  The presence of the same identifier on each request ties "
+            "those requests together and may have business ramifications in terms "
+            "of reporting of results, billing, etc.  E.g. a requisition number "
+            "shared by a set of lab tests ordered together, or a prescription "
+            "number shared by all meds ordered at one time."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -204,42 +231,28 @@ class MedicationRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
+    informationSource: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="instantiatesCanonical",
-        title="Instantiates FHIR protocol or definition",
+        alias="informationSource",
+        title=(
+            "The person or organization who provided the information about this "
+            "request, if the source is someone other than the requestor"
+        ),
         description=(
-            "The URL pointing to a protocol, guideline, orderset, or other "
-            "definition that is adhered to in whole or in part by this "
-            "MedicationRequest."
+            "The person or organization who provided the information about this "
+            "request, if the source is someone other than the requestor.  This is "
+            "often used when the MedicationRequest is reported by another person."
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-    instantiatesCanonical__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(
-        None,
-        alias="_instantiatesCanonical",
-        title="Extension field for ``instantiatesCanonical``.",
-    )
-
-    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
-        None,
-        alias="instantiatesUri",
-        title="Instantiates external protocol or definition",
-        description=(
-            "The URL pointing to an externally maintained protocol, guideline, "
-            "orderset or other definition that is adhered to in whole or in part by"
-            " this MedicationRequest."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    instantiatesUri__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(
-        None, alias="_instantiatesUri", title="Extension field for ``instantiatesUri``."
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "Organization",
+        ],
     )
 
     insurance: typing.List[fhirtypes.ReferenceType] = Field(
@@ -285,9 +298,9 @@ class MedicationRequest(domainresource.DomainResource):
         None, alias="_intent", title="Extension field for ``intent``."
     )
 
-    medicationCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="medicationCodeableConcept",
+    medication: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="medication",
         title="Medication to be taken",
         description=(
             "Identifies the medication being requested. This is a link to a "
@@ -297,26 +310,6 @@ class MedicationRequest(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
-    )
-
-    medicationReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="medicationReference",
-        title="Medication to be taken",
-        description=(
-            "Identifies the medication being requested. This is a link to a "
-            "resource that represents the medication which may be the details of "
-            "the medication or simply an attribute carrying a code that identifies "
-            "the medication from a known list of medications."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Medication"],
     )
@@ -333,13 +326,17 @@ class MedicationRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    performer: fhirtypes.ReferenceType = Field(
+    performer: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="performer",
         title="Intended performer of administration",
         description=(
             "The specified desired performer of the medication treatment (e.g. the "
-            "performer of the medication administration)."
+            "performer of the medication administration).  For devices, this is the"
+            " device that is intended to perform the administration of the "
+            "medication.  An IV Pump would be an example of a device that is "
+            "performing the administration.  Both the IV Pump and the practitioner "
+            "that set the rate or bolus on the pump can be listed as performers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -349,9 +346,10 @@ class MedicationRequest(domainresource.DomainResource):
             "PractitionerRole",
             "Organization",
             "Patient",
-            "Device",
+            "DeviceDefinition",
             "RelatedPerson",
             "CareTeam",
+            "HealthcareService",
         ],
     )
 
@@ -370,11 +368,11 @@ class MedicationRequest(domainresource.DomainResource):
     priorPrescription: fhirtypes.ReferenceType = Field(
         None,
         alias="priorPrescription",
-        title="An order/prescription that is being replaced",
-        description=(
-            "A link to a resource representing an earlier order related order or "
-            "prescription."
+        title=(
+            "Reference to an order/prescription that is being replaced by this "
+            "MedicationRequest"
         ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -399,9 +397,9 @@ class MedicationRequest(domainresource.DomainResource):
         None, alias="_priority", title="Extension field for ``priority``."
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Reason or indication for ordering or not ordering the medication",
         description=(
             "The reason or the indication for ordering or not ordering the "
@@ -409,18 +407,6 @@ class MedicationRequest(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title=(
-            "Condition or observation that supports why the prescription is being "
-            "written"
-        ),
-        description="Condition or observation that supports why the medication was ordered.",
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Condition", "Observation"],
     )
@@ -439,28 +425,28 @@ class MedicationRequest(domainresource.DomainResource):
         enum_reference_types=["Practitioner", "PractitionerRole"],
     )
 
-    reportedBoolean: bool = Field(
+    renderedDosageInstruction: fhirtypes.Markdown = Field(
         None,
-        alias="reportedBoolean",
-        title="Reported rather than primary record",
+        alias="renderedDosageInstruction",
+        title="Full representation of the dosage instructions",
         description=(
-            "Indicates if this record was captured as a secondary 'reported' record"
-            " rather than as an original primary source-of-truth record.  It may "
-            "also indicate the source of the report."
+            "The full representation of the dose of the medication included in all "
+            "dosage instructions.  To be used when multiple dosage instructions are"
+            " included to represent complex dosing such as increasing or tapering "
+            "doses."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e reported[x]
-        one_of_many="reported",
-        one_of_many_required=False,
     )
-    reportedBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_reportedBoolean", title="Extension field for ``reportedBoolean``."
+    renderedDosageInstruction__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_renderedDosageInstruction",
+        title="Extension field for ``renderedDosageInstruction``.",
     )
 
-    reportedReference: fhirtypes.ReferenceType = Field(
+    reported: bool = Field(
         None,
-        alias="reportedReference",
+        alias="reported",
         title="Reported rather than primary record",
         description=(
             "Indicates if this record was captured as a secondary 'reported' record"
@@ -469,17 +455,9 @@ class MedicationRequest(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e reported[x]
-        one_of_many="reported",
-        one_of_many_required=False,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Patient",
-            "Practitioner",
-            "PractitionerRole",
-            "RelatedPerson",
-            "Organization",
-        ],
+    )
+    reported__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_reported", title="Extension field for ``reported``."
     )
 
     requester: fhirtypes.ReferenceType = Field(
@@ -507,8 +485,8 @@ class MedicationRequest(domainresource.DomainResource):
         None,
         alias="status",
         title=(
-            "active | on-hold | cancelled | completed | entered-in-error | stopped "
-            "| draft | unknown"
+            "active | on-hold | ended | stopped | completed | cancelled | entered-"
+            "in-error | draft | unknown"
         ),
         description=(
             "A code specifying the current state of the order.  Generally, this "
@@ -522,10 +500,11 @@ class MedicationRequest(domainresource.DomainResource):
         enum_values=[
             "active",
             "on-hold",
-            "cancelled",
-            "completed",
-            "entered-in-error",
+            "ended",
             "stopped",
+            "completed",
+            "cancelled",
+            "entered-in-error",
             "draft",
             "unknown",
         ],
@@ -534,6 +513,18 @@ class MedicationRequest(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    statusChanged: fhirtypes.DateTime = Field(
+        None,
+        alias="statusChanged",
+        title="When the status was changed",
+        description="The date (and perhaps time) when the status was changed.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    statusChanged__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_statusChanged", title="Extension field for ``statusChanged``."
+    )
+
     statusReason: fhirtypes.CodeableConceptType = Field(
         None,
         alias="statusReason",
@@ -546,11 +537,8 @@ class MedicationRequest(domainresource.DomainResource):
     subject: fhirtypes.ReferenceType = Field(
         ...,
         alias="subject",
-        title="Who or group medication request is for",
-        description=(
-            "A link to a resource representing the person or set of individuals to "
-            "whom the medication will be given."
-        ),
+        title="Individual or group for whom the medication has been requested",
+        description="The individual or group for whom the medication has been requested.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -574,10 +562,11 @@ class MedicationRequest(domainresource.DomainResource):
     supportingInformation: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="supportingInformation",
-        title="Information to support ordering of the medication",
+        title="Information to support fulfilling of the medication",
         description=(
-            "Include additional information (for example, patient height and "
-            "weight) that supports the ordering of the medication."
+            "Information to support fulfilling (i.e. dispensing or administering) "
+            "of the medication, for example, patient height and weight, a "
+            "MedicationStatement for the patient)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -601,38 +590,37 @@ class MedicationRequest(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "identifier",
+            "basedOn",
+            "priorPrescription",
+            "groupIdentifier",
             "status",
             "statusReason",
+            "statusChanged",
             "intent",
             "category",
             "priority",
             "doNotPerform",
-            "reportedBoolean",
-            "reportedReference",
-            "medicationCodeableConcept",
-            "medicationReference",
+            "medication",
             "subject",
+            "informationSource",
             "encounter",
             "supportingInformation",
             "authoredOn",
             "requester",
-            "performer",
+            "reported",
             "performerType",
+            "performer",
+            "device",
             "recorder",
-            "reasonCode",
-            "reasonReference",
-            "instantiatesCanonical",
-            "instantiatesUri",
-            "basedOn",
-            "groupIdentifier",
+            "reason",
             "courseOfTherapyType",
             "insurance",
             "note",
+            "renderedDosageInstruction",
+            "effectiveDosePeriod",
             "dosageInstruction",
             "dispenseRequest",
             "substitution",
-            "priorPrescription",
-            "detectedIssue",
             "eventHistory",
         ]
 
@@ -695,47 +683,6 @@ class MedicationRequest(domainresource.DomainResource):
 
         return values
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_1959(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {
-            "medication": ["medicationCodeableConcept", "medicationReference"],
-            "reported": ["reportedBoolean", "reportedReference"],
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
-
 
 class MedicationRequestDispenseRequest(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -765,6 +712,44 @@ class MedicationRequestDispenseRequest(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    dispenser: fhirtypes.ReferenceType = Field(
+        None,
+        alias="dispenser",
+        title="Intended performer of dispense",
+        description=(
+            "Indicates the intended performing Organization that will dispense the "
+            "medication as specified by the prescriber."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Organization"],
+    )
+
+    dispenserInstruction: typing.List[fhirtypes.AnnotationType] = Field(
+        None,
+        alias="dispenserInstruction",
+        title="Additional information for the dispenser",
+        description=(
+            "Provides additional information to the dispenser, for example, "
+            "counselling to be provided to the patient."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    doseAdministrationAid: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="doseAdministrationAid",
+        title="Type of adherence packaging to use for the dispense",
+        description=(
+            "Provides information about the type of adherence packaging to be "
+            "supplied for the medication dispense."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     expectedSupplyDuration: fhirtypes.DurationType = Field(
         None,
         alias="expectedSupplyDuration",
@@ -812,20 +797,6 @@ class MedicationRequestDispenseRequest(backboneelement.BackboneElement):
         title="Extension field for ``numberOfRepeatsAllowed``.",
     )
 
-    performer: fhirtypes.ReferenceType = Field(
-        None,
-        alias="performer",
-        title="Intended dispenser",
-        description=(
-            "Indicates the intended dispensing Organization specified by the "
-            "prescriber."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Organization"],
-    )
-
     quantity: fhirtypes.QuantityType = Field(
         None,
         alias="quantity",
@@ -863,7 +834,9 @@ class MedicationRequestDispenseRequest(backboneelement.BackboneElement):
             "numberOfRepeatsAllowed",
             "quantity",
             "expectedSupplyDuration",
-            "performer",
+            "dispenser",
+            "dispenserInstruction",
+            "doseAdministrationAid",
         ]
 
 
