@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationStatement
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,11 +12,11 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import domainresource, fhirtypes
+from . import backboneelement, domainresource, fhirtypes
 
 
 class MedicationStatement(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -32,69 +32,56 @@ class MedicationStatement(domainresource.DomainResource):
     prescription bottle,  or from a list of medications the patient, clinician
     or other party maintains.
 
-    The primary difference between a medication statement and a medication
-    administration is that the medication administration has complete
+    The primary difference between a medicationstatement and a
+    medicationadministration is that the medication administration has complete
     administration information and is based on actual administration
-    information from the person who administered the medication.  A medication
-    statement is often, if not always, less specific.  There is no required
-    date/time when the medication was administered, in fact we only know that a
-    source has reported the patient is taking this medication, where details
-    such as time, quantity, or rate or even medication product may be
-    incomplete or missing or less precise.  As stated earlier, the medication
-    statement information may come from the patient's memory, from a
+    information from the person who administered the medication.  A
+    medicationstatement is often, if not always, less specific.  There is no
+    required date/time when the medication was administered, in fact we only
+    know that a source has reported the patient is taking this medication,
+    where details such as time, quantity, or rate or even medication product
+    may be incomplete or missing or less precise.  As stated earlier, the
+    Medication Statement information may come from the patient's memory, from a
     prescription bottle or from a list of medications the patient, clinician or
     other party maintains.  Medication administration is more formal and is not
     missing detailed information.
+
+    The MedicationStatement resource was previously called MedicationStatement.
     """
 
     resource_type = Field("MedicationStatement", const=True)
 
-    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
+    adherence: fhirtypes.MedicationStatementAdherenceType = Field(
         None,
-        alias="basedOn",
-        title="Fulfils plan, proposal or order",
-        description=(
-            "A plan, proposal or order that is fulfilled in whole or in part by "
-            "this event."
+        alias="adherence",
+        title=(
+            "Indicates whether the medication is or is not being consumed or "
+            "administered"
         ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["MedicationRequest", "CarePlan", "ServiceRequest"],
     )
 
-    category: fhirtypes.CodeableConceptType = Field(
+    category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
-        title="Type of medication usage",
+        title="Type of medication statement",
         description=(
-            "Indicates where the medication is expected to be consumed or "
-            "administered."
+            "Type of medication statement (for example, drug classification like "
+            "ATC, where meds would be administered, legal category of the "
+            "medication.)."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    context: fhirtypes.ReferenceType = Field(
-        None,
-        alias="context",
-        title="Encounter / Episode associated with MedicationStatement",
-        description=(
-            "The encounter or episode of care that establishes the context for this"
-            " MedicationStatement."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Encounter", "EpisodeOfCare"],
-    )
-
     dateAsserted: fhirtypes.DateTime = Field(
         None,
         alias="dateAsserted",
-        title="When the statement was asserted?",
+        title="When the usage was asserted?",
         description=(
-            "The date when the medication statement was asserted by the information"
+            "The date when the Medication Statement was asserted by the information"
             " source."
         ),
         # if property is element of this resource.
@@ -107,7 +94,7 @@ class MedicationStatement(domainresource.DomainResource):
     derivedFrom: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="derivedFrom",
-        title="Additional supporting information",
+        title="Link to information used to derive the MedicationStatement",
         description=(
             "Allows linking the MedicationStatement to the underlying "
             "MedicationRequest, or to other information that supports or is used to"
@@ -135,7 +122,7 @@ class MedicationStatement(domainresource.DomainResource):
         description=(
             "The interval of time during which it is being asserted that the "
             "patient is/was/will be taking the medication (or was not taking, when "
-            "the MedicationStatement.taken element is No)."
+            "the MedicationStatement.adherence element is Not Taking)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -156,7 +143,7 @@ class MedicationStatement(domainresource.DomainResource):
         description=(
             "The interval of time during which it is being asserted that the "
             "patient is/was/will be taking the medication (or was not taking, when "
-            "the MedicationStatement.taken element is No)."
+            "the MedicationStatement.adherence element is Not Taking)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -165,6 +152,36 @@ class MedicationStatement(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
+    effectiveTiming: fhirtypes.TimingType = Field(
+        None,
+        alias="effectiveTiming",
+        title="The date/time or interval when the medication is/was/will be taken",
+        description=(
+            "The interval of time during which it is being asserted that the "
+            "patient is/was/will be taking the medication (or was not taking, when "
+            "the MedicationStatement.adherence element is Not Taking)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e effective[x]
+        one_of_many="effective",
+        one_of_many_required=False,
+    )
+
+    encounter: fhirtypes.ReferenceType = Field(
+        None,
+        alias="encounter",
+        title="Encounter associated with MedicationStatement",
+        description=(
+            "The encounter that establishes the context for this "
+            "MedicationStatement."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Encounter"],
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -181,7 +198,7 @@ class MedicationStatement(domainresource.DomainResource):
         element_property=True,
     )
 
-    informationSource: fhirtypes.ReferenceType = Field(
+    informationSource: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="informationSource",
         title=(
@@ -206,9 +223,9 @@ class MedicationStatement(domainresource.DomainResource):
         ],
     )
 
-    medicationCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="medicationCodeableConcept",
+    medication: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="medication",
         title="What medication was taken",
         description=(
             "Identifies the medication being administered. This is either a link to"
@@ -218,26 +235,6 @@ class MedicationStatement(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
-    )
-
-    medicationReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="medicationReference",
-        title="What medication was taken",
-        description=(
-            "Identifies the medication being administered. This is either a link to"
-            " a resource representing the details of the medication or a simple "
-            "attribute carrying a code that identifies the medication from a known "
-            "list of medications."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e medication[x]
-        one_of_many="medication",
-        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Medication"],
     )
@@ -245,9 +242,9 @@ class MedicationStatement(domainresource.DomainResource):
     note: typing.List[fhirtypes.AnnotationType] = Field(
         None,
         alias="note",
-        title="Further information about the statement",
+        title="Further information about the usage",
         description=(
-            "Provides extra information about the medication statement that is not "
+            "Provides extra information about the Medication Statement that is not "
             "conveyed by the other attributes."
         ),
         # if property is element of this resource.
@@ -258,83 +255,79 @@ class MedicationStatement(domainresource.DomainResource):
         None,
         alias="partOf",
         title="Part of referenced event",
-        description="A larger event of which this particular event is a component or step.",
+        description=(
+            "A larger event of which this particular MedicationStatement is a "
+            "component or step."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "MedicationAdministration",
-            "MedicationDispense",
-            "MedicationStatement",
-            "Procedure",
-            "Observation",
-        ],
+        enum_reference_types=["Procedure", "MedicationStatement"],
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Reason for why the medication is being/was taken",
-        description="A reason for why the medication is being/was taken.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title=(
-            "Condition or observation that supports why the medication is being/was"
-            " taken"
+        description=(
+            "A concept, Condition or observation that supports why the medication "
+            "is being/was taken."
         ),
-        description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Condition", "Observation", "DiagnosticReport"],
     )
 
+    relatedClinicalInformation: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="relatedClinicalInformation",
+        title="Link to information relevant to the usage of a medication",
+        description=(
+            "Link to information that is relevant to a medication statement, for "
+            "example, illicit drug use, gestational age, etc."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Observation", "Condition"],
+    )
+
+    renderedDosageInstruction: fhirtypes.Markdown = Field(
+        None,
+        alias="renderedDosageInstruction",
+        title="Full representation of the dosage instructions",
+        description=(
+            "The full representation of the dose of the medication included in all "
+            "dosage instructions.  To be used when multiple dosage instructions are"
+            " included to represent complex dosing such as increasing or tapering "
+            "doses."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    renderedDosageInstruction__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_renderedDosageInstruction",
+        title="Extension field for ``renderedDosageInstruction``.",
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title=(
-            "active | completed | entered-in-error | intended | stopped | on-hold |"
-            " unknown | not-taken"
-        ),
-        description=(
-            "A code representing the patient or other source's judgment about the "
-            "state of the medication used that this statement is about.  Generally,"
-            " this will be active or completed."
-        ),
+        title="recorded | entered-in-error | draft",
+        description="A code representing the status of recording the medication statement.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "active",
-            "completed",
-            "entered-in-error",
-            "intended",
-            "stopped",
-            "on-hold",
-            "unknown",
-            "not-taken",
-        ],
+        enum_values=["recorded", "entered-in-error", "draft"],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    statusReason: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="statusReason",
-        title="Reason for current status",
-        description="Captures the reason for the current state of the MedicationStatement.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     subject: fhirtypes.ReferenceType = Field(
         ...,
         alias="subject",
@@ -346,6 +339,42 @@ class MedicationStatement(domainresource.DomainResource):
         enum_reference_types=["Patient", "Group"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationStatement`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "partOf",
+            "status",
+            "category",
+            "medication",
+            "subject",
+            "encounter",
+            "effectiveDateTime",
+            "effectivePeriod",
+            "effectiveTiming",
+            "dateAsserted",
+            "informationSource",
+            "derivedFrom",
+            "reason",
+            "note",
+            "relatedClinicalInformation",
+            "renderedDosageInstruction",
+            "dosage",
+            "adherence",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2163(
         cls, values: typing.Dict[str, typing.Any]
@@ -422,8 +451,7 @@ class MedicationStatement(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "effective": ["effectiveDateTime", "effectivePeriod"],
-            "medication": ["medicationCodeableConcept", "medicationReference"],
+            "effective": ["effectiveDateTime", "effectivePeriod", "effectiveTiming"]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -445,3 +473,41 @@ class MedicationStatement(domainresource.DomainResource):
                 raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
+
+
+class MedicationStatementAdherence(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Indicates whether the medication is or is not being consumed or
+    administered.
+    """
+
+    resource_type = Field("MedicationStatementAdherence", const=True)
+
+    code: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="code",
+        title="Type of adherence",
+        description="Type of the adherence for the medication.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    reason: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="reason",
+        title="Details of the reason for the current use of the medication",
+        description="Captures the reason for the current use or adherence of a medication.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationStatementAdherence`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "code", "reason"]
