@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MessageDefinition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -103,15 +103,33 @@ class MessageDefinition(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the message definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the message definition changes."
+            "The date  (and optionally time) when the message definition was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the message definition "
+            "changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -192,15 +210,15 @@ class MessageDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
-    graph: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
+    graph: fhirtypes.Canonical = Field(
         None,
         alias="graph",
         title="Canonical reference to a GraphDefinition",
         description=(
-            "Canonical reference to a GraphDefinition. If a URL is provided, it is "
-            "the canonical reference to a [GraphDefinition](graphdefinition.html) "
-            "that it controls what resources are to be added to the bundle when "
-            "building the document. The GraphDefinition can also specify profiles "
+            "Graph is Canonical reference to a GraphDefinition. If a URL is "
+            "provided, it is the canonical reference to a GraphDefinition that it "
+            "controls what additional resources are to be added to the Bundle when "
+            "building the message. The GraphDefinition can also specify profiles "
             "that apply to the various resources."
         ),
         # if property is element of this resource.
@@ -208,14 +226,14 @@ class MessageDefinition(domainresource.DomainResource):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["GraphDefinition"],
     )
-    graph__ext: typing.List[
-        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
-    ] = Field(None, alias="_graph", title="Extension field for ``graph``.")
+    graph__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_graph", title="Extension field for ``graph``."
+    )
 
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
-        title="Primary key for the message definition on a given server",
+        title="Business Identifier for a given MessageDefinition",
         description=(
             "A formal identifier that is used to identify this message definition "
             "when it is represented in other formats, or referenced in a "
@@ -273,10 +291,10 @@ class MessageDefinition(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the message "
-            "definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the message definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -368,7 +386,7 @@ class MessageDefinition(domainresource.DomainResource):
     url: fhirtypes.Uri = Field(
         None,
         alias="url",
-        title="Business Identifier for a given MessageDefinition",
+        title="The cannonical URL for a given MessageDefinition",
         description=(
             "The business identifier that is used to reference the "
             "MessageDefinition and *is* expected to be consistent from server to "
@@ -416,6 +434,41 @@ class MessageDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -434,6 +487,8 @@ class MessageDefinition(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "replaces",
@@ -447,6 +502,7 @@ class MessageDefinition(domainresource.DomainResource):
             "jurisdiction",
             "purpose",
             "copyright",
+            "copyrightLabel",
             "base",
             "parent",
             "eventCoding",
@@ -533,7 +589,10 @@ class MessageDefinition(domainresource.DomainResource):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"event": ["eventCoding", "eventUri"]}
+        one_of_many_fields = {
+            "event": ["eventCoding", "eventUri"],
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"],
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
