@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MessageHeader
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -35,7 +35,7 @@ class MessageHeader(domainresource.DomainResource):
         alias="author",
         title="The source of the decision",
         description=(
-            "The logical author of the message - the person or device that decided "
+            "The logical author of the message - the personor device that decided "
             "the described event should happen. When there is more than one "
             "candidate, pick the most proximal to the MessageHeader. Can provide "
             "other authors in extensions."
@@ -43,7 +43,12 @@ class MessageHeader(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole"],
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Device",
+            "Organization",
+        ],
     )
 
     definition: fhirtypes.Canonical = Field(
@@ -69,30 +74,37 @@ class MessageHeader(domainresource.DomainResource):
         element_property=True,
     )
 
-    enterer: fhirtypes.ReferenceType = Field(
+    eventCanonical: fhirtypes.Canonical = Field(
         None,
-        alias="enterer",
-        title="The source of the data entry",
+        alias="eventCanonical",
+        title="Event code or link to EventDefinition",
         description=(
-            "The person or device that performed the data entry leading to this "
-            "message. When there is more than one candidate, pick the most proximal"
-            " to the message. Can provide other enterers in extensions."
+            "Code that identifies the event this message represents and connects it"
+            " with its definition. Events defined as part of the FHIR specification"
+            " are defined by the implementation.  Alternatively a canonical uri to "
+            "the EventDefinition."
         ),
         # if property is element of this resource.
         element_property=True,
+        # Choice of Data Types. i.e event[x]
+        one_of_many="event",
+        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole"],
+        enum_reference_types=["EventDefinition"],
+    )
+    eventCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_eventCanonical", title="Extension field for ``eventCanonical``."
     )
 
     eventCoding: fhirtypes.CodingType = Field(
         None,
         alias="eventCoding",
-        title="Code for the event this message represents or link to event definition",
+        title="Event code or link to EventDefinition",
         description=(
             "Code that identifies the event this message represents and connects it"
             " with its definition. Events defined as part of the FHIR specification"
-            ' have the system value "http://terminology.hl7.org/CodeSystem/message-'
-            'events".  Alternatively uri to the EventDefinition.'
+            " are defined by the implementation.  Alternatively a canonical uri to "
+            "the EventDefinition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -101,33 +113,13 @@ class MessageHeader(domainresource.DomainResource):
         one_of_many_required=True,
     )
 
-    eventUri: fhirtypes.Uri = Field(
-        None,
-        alias="eventUri",
-        title="Code for the event this message represents or link to event definition",
-        description=(
-            "Code that identifies the event this message represents and connects it"
-            " with its definition. Events defined as part of the FHIR specification"
-            ' have the system value "http://terminology.hl7.org/CodeSystem/message-'
-            'events".  Alternatively uri to the EventDefinition.'
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e event[x]
-        one_of_many="event",
-        one_of_many_required=True,
-    )
-    eventUri__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_eventUri", title="Extension field for ``eventUri``."
-    )
-
     focus: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="focus",
         title="The actual content of the message",
         description=(
             "The actual data of the message - a reference to the root/focus class "
-            "of the event."
+            "of the event. This is allowed to be a Parameters resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -184,7 +176,12 @@ class MessageHeader(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole", "Organization"],
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Device",
+            "Organization",
+        ],
     )
 
     source: fhirtypes.MessageHeaderSourceType = Field(
@@ -212,10 +209,9 @@ class MessageHeader(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "eventCoding",
-            "eventUri",
+            "eventCanonical",
             "destination",
             "sender",
-            "enterer",
             "author",
             "source",
             "responsible",
@@ -241,7 +237,7 @@ class MessageHeader(domainresource.DomainResource):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"event": ["eventCoding", "eventUri"]}
+        one_of_many_fields = {"event": ["eventCanonical", "eventCoding"]}
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
@@ -275,17 +271,33 @@ class MessageHeaderDestination(backboneelement.BackboneElement):
 
     resource_type = Field("MessageHeaderDestination", const=True)
 
-    endpoint: fhirtypes.Url = Field(
+    endpointReference: fhirtypes.ReferenceType = Field(
         None,
-        alias="endpoint",
-        title="Actual destination address or id",
-        description="Indicates where the message should be routed to.",
+        alias="endpointReference",
+        title="Actual destination address or Endpoint resource",
+        description="Indicates where the message should be routed.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
+        # Choice of Data Types. i.e endpoint[x]
+        one_of_many="endpoint",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Endpoint"],
     )
-    endpoint__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_endpoint", title="Extension field for ``endpoint``."
+
+    endpointUrl: fhirtypes.Url = Field(
+        None,
+        alias="endpointUrl",
+        title="Actual destination address or Endpoint resource",
+        description="Indicates where the message should be routed.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e endpoint[x]
+        one_of_many="endpoint",
+        one_of_many_required=False,
+    )
+    endpointUrl__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_endpointUrl", title="Extension field for ``endpointUrl``."
     )
 
     name: fhirtypes.String = Field(
@@ -339,68 +351,48 @@ class MessageHeaderDestination(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
+            "endpointUrl",
+            "endpointReference",
             "name",
             "target",
-            "endpoint",
             "receiver",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_2635(
+    def validate_one_of_many_2635(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
         """
-        required_fields = [("endpoint", "endpoint__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
+        one_of_many_fields = {"endpoint": ["endpointReference", "endpointUrl"]}
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
 
@@ -447,20 +439,16 @@ class MessageHeaderResponse(backboneelement.BackboneElement):
         enum_reference_types=["OperationOutcome"],
     )
 
-    identifier: fhirtypes.Id = Field(
-        None,
+    identifier: fhirtypes.IdentifierType = Field(
+        ...,
         alias="identifier",
-        title="Id of original message",
+        title="Bundle.identifier of original message",
         description=(
-            "The MessageHeader.id of the message to which this message is a "
+            "The Bundle.identifier of the message to which this message is a "
             "response."
         ),
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
-    )
-    identifier__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_identifier", title="Extension field for ``identifier``."
     )
 
     @classmethod
@@ -482,7 +470,7 @@ class MessageHeaderResponse(backboneelement.BackboneElement):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("code", "code__ext"), ("identifier", "identifier__ext")]
+        required_fields = [("code", "code__ext")]
         _missing = object()
 
         def _fallback():
@@ -554,17 +542,33 @@ class MessageHeaderSource(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    endpoint: fhirtypes.Url = Field(
+    endpointReference: fhirtypes.ReferenceType = Field(
         None,
-        alias="endpoint",
-        title="Actual message source address or id",
+        alias="endpointReference",
+        title="Actual source address or Endpoint resource",
         description="Identifies the routing target to send acknowledgements to.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
+        # Choice of Data Types. i.e endpoint[x]
+        one_of_many="endpoint",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Endpoint"],
     )
-    endpoint__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_endpoint", title="Extension field for ``endpoint``."
+
+    endpointUrl: fhirtypes.Url = Field(
+        None,
+        alias="endpointUrl",
+        title="Actual source address or Endpoint resource",
+        description="Identifies the routing target to send acknowledgements to.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e endpoint[x]
+        one_of_many="endpoint",
+        one_of_many_required=False,
+    )
+    endpointUrl__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_endpointUrl", title="Extension field for ``endpointUrl``."
     )
 
     name: fhirtypes.String = Field(
@@ -616,68 +620,48 @@ class MessageHeaderSource(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
+            "endpointUrl",
+            "endpointReference",
             "name",
             "software",
             "version",
             "contact",
-            "endpoint",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_2097(
+    def validate_one_of_many_2097(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
         """
-        required_fields = [("endpoint", "endpoint__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
+        one_of_many_fields = {"endpoint": ["endpointReference", "endpointUrl"]}
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
