@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/NutritionOrder
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -44,6 +44,20 @@ class NutritionOrder(domainresource.DomainResource):
         enum_reference_types=["AllergyIntolerance"],
     )
 
+    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="basedOn",
+        title="What this order fulfills",
+        description=(
+            "A plan or request that is fulfilled in whole or in part by this "
+            "nutrition order."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["CarePlan", "NutritionOrder", "ServiceRequest"],
+    )
+
     dateTime: fhirtypes.DateTime = Field(
         None,
         alias="dateTime",
@@ -122,6 +136,19 @@ class NutritionOrder(domainresource.DomainResource):
         element_property=True,
     )
 
+    groupIdentifier: fhirtypes.IdentifierType = Field(
+        None,
+        alias="groupIdentifier",
+        title="Composite Request ID",
+        description=(
+            "A shared identifier common to all nutrition orders that were "
+            "authorized more or less simultaneously by a single author, "
+            "representing the composite or group identifier."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -259,18 +286,58 @@ class NutritionOrder(domainresource.DomainResource):
         enum_reference_types=["Practitioner", "PractitionerRole"],
     )
 
-    patient: fhirtypes.ReferenceType = Field(
-        ...,
-        alias="patient",
-        title="The person who requires the diet, formula or nutritional supplement",
+    outsideFoodAllowed: bool = Field(
+        None,
+        alias="outsideFoodAllowed",
+        title="Capture when a food item is brought in by the patient and/or family",
         description=(
-            "The person (patient) who needs the nutrition order for an oral diet, "
-            "nutritional supplement and/or enteral or formula feeding."
+            "This modifier is used to convey whether a food item is allowed to be "
+            "brought in by the patient and/or family.  If set to true, indicates "
+            "that the receiving system does not need to supply the food item."
         ),
         # if property is element of this resource.
         element_property=True,
+    )
+    outsideFoodAllowed__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_outsideFoodAllowed",
+        title="Extension field for ``outsideFoodAllowed``.",
+    )
+
+    performer: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
+        alias="performer",
+        title="Who is desired to perform the administration of what is being ordered",
+        description="The specified desired performer of the nutrition order.",
+        # if property is element of this resource.
+        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient"],
+        enum_reference_types=[
+            "CareTeam",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "Patient",
+            "Organization",
+        ],
+    )
+
+    priority: fhirtypes.Code = Field(
+        None,
+        alias="priority",
+        title="routine | urgent | asap | stat",
+        description=(
+            "Indicates how quickly the Nutrition Order should be addressed with "
+            "respect to other        requests."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["routine", "urgent", "asap", "stat"],
+    )
+    priority__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_priority", title="Extension field for ``priority``."
     )
 
     status: fhirtypes.Code = Field(
@@ -300,6 +367,20 @@ class NutritionOrder(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    subject: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="subject",
+        title="Who requires the diet, formula or nutritional supplement",
+        description=(
+            "The person or set of individuals who needs the nutrition order for an "
+            "oral diet, nutritional supplement and/or enteral or formula feeding."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Patient", "Group"],
+    )
+
     supplement: typing.List[fhirtypes.NutritionOrderSupplementType] = Field(
         None,
         alias="supplement",
@@ -312,6 +393,20 @@ class NutritionOrder(domainresource.DomainResource):
         element_property=True,
     )
 
+    supportingInformation: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="supportingInformation",
+        title="Information to support fulfilling of the nutrition order",
+        description=(
+            "Information to support fulfilling (i.e. dispensing or administering) "
+            "of the nutrition,        for example, patient height and weight)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -331,15 +426,21 @@ class NutritionOrder(domainresource.DomainResource):
             "instantiatesCanonical",
             "instantiatesUri",
             "instantiates",
+            "basedOn",
+            "groupIdentifier",
             "status",
             "intent",
-            "patient",
+            "priority",
+            "subject",
             "encounter",
+            "supportingInformation",
             "dateTime",
             "orderer",
+            "performer",
             "allergyIntolerance",
             "foodPreferenceModifier",
             "excludeFoodModifier",
+            "outsideFoodAllowed",
             "oralDiet",
             "supplement",
             "enteralFormula",
@@ -422,31 +523,13 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
 
     resource_type = Field("NutritionOrderEnteralFormula", const=True)
 
-    additiveProductName: fhirtypes.String = Field(
+    additive: typing.List[fhirtypes.NutritionOrderEnteralFormulaAdditiveType] = Field(
         None,
-        alias="additiveProductName",
-        title="Product or brand name of the modular additive",
+        alias="additive",
+        title="Components to add to the feeding",
         description=(
-            "The product or brand name of the type of modular component to be added"
-            " to the formula."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    additiveProductName__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_additiveProductName",
-        title="Extension field for ``additiveProductName``.",
-    )
-
-    additiveType: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="additiveType",
-        title="Type of modular component to add to the feeding",
-        description=(
-            "Indicates the type of modular component such as protein, carbohydrate,"
-            " fat or fiber to be provided in addition to or mixed with the base "
-            "formula."
+            "Indicates modular components to be provided in addition or mixed with "
+            "the base formula."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -469,7 +552,7 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    administrationInstruction: fhirtypes.String = Field(
+    administrationInstruction: fhirtypes.Markdown = Field(
         None,
         alias="administrationInstruction",
         title="Formula feeding instructions expressed as text",
@@ -503,7 +586,7 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
         title="Extension field for ``baseFormulaProductName``.",
     )
 
-    baseFormulaType: fhirtypes.CodeableConceptType = Field(
+    baseFormulaType: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="baseFormulaType",
         title="Type of enteral or infant formula",
@@ -513,6 +596,8 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["NutritionProduct"],
     )
 
     caloricDensity: fhirtypes.QuantityType = Field(
@@ -530,6 +615,20 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    deliveryDevice: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
+        alias="deliveryDevice",
+        title="Intended type of device for the administration",
+        description=(
+            "The intended type of device that is to be used for the administration "
+            "of the enteral formula."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["DeviceDefinition"],
+    )
+
     maxVolumeToDeliver: fhirtypes.QuantityType = Field(
         None,
         alias="maxVolumeToDeliver",
@@ -542,9 +641,9 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    routeofAdministration: fhirtypes.CodeableConceptType = Field(
+    routeOfAdministration: fhirtypes.CodeableConceptType = Field(
         None,
-        alias="routeofAdministration",
+        alias="routeOfAdministration",
         title="How the formula should enter the patient's gastrointestinal tract",
         description=(
             "The route or physiological path of administration into the patient's "
@@ -567,16 +666,86 @@ class NutritionOrderEnteralFormula(backboneelement.BackboneElement):
             "modifierExtension",
             "baseFormulaType",
             "baseFormulaProductName",
-            "additiveType",
-            "additiveProductName",
+            "deliveryDevice",
+            "additive",
             "caloricDensity",
-            "routeofAdministration",
+            "routeOfAdministration",
             "administration",
             "maxVolumeToDeliver",
             "administrationInstruction",
         ]
 
 
+class NutritionOrderEnteralFormulaAdditive(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Components to add to the feeding.
+    Indicates modular components to be provided in addition or mixed with the
+    base formula.
+    """
+
+    resource_type = Field("NutritionOrderEnteralFormulaAdditive", const=True)
+
+    productName: fhirtypes.String = Field(
+        None,
+        alias="productName",
+        title="Product or brand name of the modular additive",
+        description=(
+            "The product or brand name of the type of modular component to be added"
+            " to the formula."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    productName__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_productName", title="Extension field for ``productName``."
+    )
+
+    quantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="quantity",
+        title="Amount of additive to be given or mixed in",
+        description=(
+            "The amount of additive to be given in addition or to be mixed in with "
+            "the base formula."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    type: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="type",
+        title="Type of modular component to add to the feeding",
+        description=(
+            "Indicates the type of modular component such as protein, carbohydrate,"
+            " fat or fiber to be provided in addition to or mixed with the base "
+            "formula."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["NutritionProduct"],
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionOrderEnteralFormulaAdditive`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "productName",
+            "quantity",
+        ]
+
+
 class NutritionOrderEnteralFormulaAdministration(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -633,14 +802,11 @@ class NutritionOrderEnteralFormulaAdministration(backboneelement.BackboneElement
         one_of_many_required=False,
     )
 
-    schedule: fhirtypes.TimingType = Field(
+    schedule: fhirtypes.NutritionOrderEnteralFormulaAdministrationScheduleType = Field(
         None,
         alias="schedule",
-        title="Scheduled frequency of enteral feeding",
-        description=(
-            "The time period and frequency at which the enteral formula should be "
-            "delivered to the patient."
-        ),
+        title="Scheduling information for enteral formula products",
+        description="Schedule information for an enteral formula.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -700,6 +866,77 @@ class NutritionOrderEnteralFormulaAdministration(backboneelement.BackboneElement
         return values
 
 
+class NutritionOrderEnteralFormulaAdministrationSchedule(
+    backboneelement.BackboneElement
+):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Scheduling information for enteral formula products.
+    Schedule information for an enteral formula.
+    """
+
+    resource_type = Field(
+        "NutritionOrderEnteralFormulaAdministrationSchedule", const=True
+    )
+
+    asNeeded: bool = Field(
+        None,
+        alias="asNeeded",
+        title="Take 'as needed'",
+        description=(
+            "Indicates whether the enteral formula is only taken when needed within"
+            " a specific dosing schedule."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    asNeeded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_asNeeded", title="Extension field for ``asNeeded``."
+    )
+
+    asNeededFor: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="asNeededFor",
+        title="Take 'as needed' for x",
+        description=(
+            "Indicates whether the enteral formula is only taken based on a "
+            "precondition for taking the enteral formula."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    timing: typing.List[fhirtypes.TimingType] = Field(
+        None,
+        alias="timing",
+        title="Scheduled frequency of enteral formula",
+        description=(
+            "The time period and frequency at which the enteral formula should be "
+            "given.  The enteral formula should be given for the combination of all"
+            " schedules if more than one schedule is present."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionOrderEnteralFormulaAdministrationSchedule`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "timing",
+            "asNeeded",
+            "asNeededFor",
+        ]
+
+
 class NutritionOrderOralDiet(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -751,15 +988,11 @@ class NutritionOrderOralDiet(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    schedule: typing.List[fhirtypes.TimingType] = Field(
+    schedule: fhirtypes.NutritionOrderOralDietScheduleType = Field(
         None,
         alias="schedule",
-        title="Scheduled frequency of diet",
-        description=(
-            "The time period and frequency at which the diet should be given.  The "
-            "diet should be given for the combination of all schedules if more than"
-            " one schedule is present."
-        ),
+        title="Scheduling information for oral diets",
+        description="Schedule information for an oral diet.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -849,6 +1082,73 @@ class NutritionOrderOralDietNutrient(backboneelement.BackboneElement):
         return ["id", "extension", "modifierExtension", "modifier", "amount"]
 
 
+class NutritionOrderOralDietSchedule(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Scheduling information for oral diets.
+    Schedule information for an oral diet.
+    """
+
+    resource_type = Field("NutritionOrderOralDietSchedule", const=True)
+
+    asNeeded: bool = Field(
+        None,
+        alias="asNeeded",
+        title="Take 'as needed'",
+        description=(
+            "Indicates whether the product is only taken when needed within a "
+            "specific dosing schedule."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    asNeeded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_asNeeded", title="Extension field for ``asNeeded``."
+    )
+
+    asNeededFor: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="asNeededFor",
+        title="Take 'as needed' for x",
+        description=(
+            "Indicates whether the product is only taken based on a precondition "
+            "for taking the product."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    timing: typing.List[fhirtypes.TimingType] = Field(
+        None,
+        alias="timing",
+        title="Scheduled frequency of diet",
+        description=(
+            "The time period and frequency at which the diet should be given.  The "
+            "diet should be given for the combination of all schedules if more than"
+            " one schedule is present."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionOrderOralDietSchedule`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "timing",
+            "asNeeded",
+            "asNeededFor",
+        ]
+
+
 class NutritionOrderOralDietTexture(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
@@ -948,20 +1248,16 @@ class NutritionOrderSupplement(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    schedule: typing.List[fhirtypes.TimingType] = Field(
+    schedule: fhirtypes.NutritionOrderSupplementScheduleType = Field(
         None,
         alias="schedule",
-        title="Scheduled frequency of supplement",
-        description=(
-            "The time period and frequency at which the supplement(s) should be "
-            "given.  The supplement should be given for the combination of all "
-            "schedules if more than one schedule is present."
-        ),
+        title="Scheduling information for supplements",
+        description="Schedule information for a supplement.",
         # if property is element of this resource.
         element_property=True,
     )
 
-    type: fhirtypes.CodeableConceptType = Field(
+    type: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="type",
         title="Type of supplement product requested",
@@ -971,6 +1267,8 @@ class NutritionOrderSupplement(backboneelement.BackboneElement):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["NutritionProduct"],
     )
 
     @classmethod
@@ -989,3 +1287,70 @@ class NutritionOrderSupplement(backboneelement.BackboneElement):
             "quantity",
             "instruction",
         ]
+
+
+class NutritionOrderSupplementSchedule(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Scheduling information for supplements.
+    Schedule information for a supplement.
+    """
+
+    resource_type = Field("NutritionOrderSupplementSchedule", const=True)
+
+    asNeeded: bool = Field(
+        None,
+        alias="asNeeded",
+        title="Take 'as needed'",
+        description=(
+            "Indicates whether the supplement is only taken when needed within a "
+            "specific dosing schedule."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    asNeeded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_asNeeded", title="Extension field for ``asNeeded``."
+    )
+
+    asNeededFor: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="asNeededFor",
+        title="Take 'as needed' for x",
+        description=(
+            "Indicates whether the supplement is only taken based on a precondition"
+            " for taking the supplement."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    timing: typing.List[fhirtypes.TimingType] = Field(
+        None,
+        alias="timing",
+        title="Scheduled frequency of diet",
+        description=(
+            "The time period and frequency at which the supplement should be given."
+            "  The supplement should be given for the combination of all schedules "
+            "if more than one schedule is present."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionOrderSupplementSchedule`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "timing",
+            "asNeeded",
+            "asNeededFor",
+        ]
