@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/NutritionProduct
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -20,8 +20,8 @@ class NutritionProduct(domainresource.DomainResource):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    A product used for nutritional purposes.
-    A food or fluid product that is consumed by patients.
+    A product used for nutritional purposes (i.e. food or supplement).
+    A food or supplement that is consumed by patients.
     """
 
     resource_type = Field("NutritionProduct", const=True)
@@ -30,8 +30,8 @@ class NutritionProduct(domainresource.DomainResource):
         None,
         alias="category",
         title=(
-            "A category or class of the nutrition product (halal, kosher, gluten "
-            "free, vegan, etc)"
+            "Broad product groups or categories used to classify the product, such "
+            "as Legume and Legume Products, Beverages, or Beef Products"
         ),
         description=(
             "Nutrition products can have different classifications - according to "
@@ -41,13 +41,25 @@ class NutritionProduct(domainresource.DomainResource):
         element_property=True,
     )
 
+    characteristic: typing.List[fhirtypes.NutritionProductCharacteristicType] = Field(
+        None,
+        alias="characteristic",
+        title="Specifies descriptive properties of the nutrition product",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     code: fhirtypes.CodeableConceptType = Field(
         None,
         alias="code",
-        title="A code designating a specific type of nutritional product",
+        title=(
+            "A code that can identify the detailed nutrients and ingredients in a "
+            "specific food product"
+        ),
         description=(
-            "The code assigned to the product, for example a manufacturer number or"
-            " other terminology."
+            "The code assigned to the product, for example a USDA NDB number, a "
+            "USDA FDC ID number, or a Langual code."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -62,7 +74,7 @@ class NutritionProduct(domainresource.DomainResource):
         element_property=True,
     )
 
-    instance: fhirtypes.NutritionProductInstanceType = Field(
+    instance: typing.List[fhirtypes.NutritionProductInstanceType] = Field(
         None,
         alias="instance",
         title=(
@@ -96,7 +108,7 @@ class NutritionProduct(domainresource.DomainResource):
         alias="manufacturer",
         title="Manufacturer, representative or officially responsible for the product",
         description=(
-            "The organisation (manufacturer, representative or legal authorisation "
+            "The organisation (manufacturer, representative or legal authorization "
             "holder) that is responsible for the device."
         ),
         # if property is element of this resource.
@@ -123,17 +135,6 @@ class NutritionProduct(domainresource.DomainResource):
         element_property=True,
     )
 
-    productCharacteristic: typing.List[
-        fhirtypes.NutritionProductProductCharacteristicType
-    ] = Field(
-        None,
-        alias="productCharacteristic",
-        title="Specifies descriptive properties of the nutrition product",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -165,14 +166,14 @@ class NutritionProduct(domainresource.DomainResource):
             "contained",
             "extension",
             "modifierExtension",
+            "code",
             "status",
             "category",
-            "code",
             "manufacturer",
             "nutrient",
             "ingredient",
             "knownAllergen",
-            "productCharacteristic",
+            "characteristic",
             "instance",
             "note",
         ]
@@ -237,183 +238,7 @@ class NutritionProduct(domainresource.DomainResource):
         return values
 
 
-class NutritionProductIngredient(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Ingredients contained in this product.
-    """
-
-    resource_type = Field("NutritionProductIngredient", const=True)
-
-    amount: typing.List[fhirtypes.RatioType] = Field(
-        None,
-        alias="amount",
-        title="The amount of ingredient that is in the product",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    item: fhirtypes.CodeableReferenceType = Field(
-        ...,
-        alias="item",
-        title="The ingredient contained in the product",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["NutritionProduct"],
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``NutritionProductIngredient`` according specification,
-        with preserving original sequence order.
-        """
-        return ["id", "extension", "modifierExtension", "item", "amount"]
-
-
-class NutritionProductInstance(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    One or several physical instances or occurrences of the nutrition product.
-    Conveys instance-level information about this product item. One or several
-    physical, countable instances or occurrences of the product.
-    """
-
-    resource_type = Field("NutritionProductInstance", const=True)
-
-    expiry: fhirtypes.DateTime = Field(
-        None,
-        alias="expiry",
-        title="The expiry date or date and time for the product",
-        description=(
-            "The time after which the product is no longer expected to be in proper"
-            " condition, or its use is not advised or not allowed."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    expiry__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_expiry", title="Extension field for ``expiry``."
-    )
-
-    identifier: typing.List[fhirtypes.IdentifierType] = Field(
-        None,
-        alias="identifier",
-        title="The identifier for the physical instance, typically a serial number",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    lotNumber: fhirtypes.String = Field(
-        None,
-        alias="lotNumber",
-        title="The identification of the batch or lot of the product",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    lotNumber__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_lotNumber", title="Extension field for ``lotNumber``."
-    )
-
-    quantity: fhirtypes.QuantityType = Field(
-        None,
-        alias="quantity",
-        title="The amount of items or instances",
-        description=(
-            "The amount of items or instances that the resource considers, for "
-            "instance when referring to 2 identical units together."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    useBy: fhirtypes.DateTime = Field(
-        None,
-        alias="useBy",
-        title=(
-            "The date until which the product is expected to be good for " "consumption"
-        ),
-        description=(
-            "The time after which the product is no longer expected to be in proper"
-            " condition, or its use is not advised or not allowed."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    useBy__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_useBy", title="Extension field for ``useBy``."
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``NutritionProductInstance`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "quantity",
-            "identifier",
-            "lotNumber",
-            "expiry",
-            "useBy",
-        ]
-
-
-class NutritionProductNutrient(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    The product's nutritional information expressed by the nutrients.
-    """
-
-    resource_type = Field("NutritionProductNutrient", const=True)
-
-    amount: typing.List[fhirtypes.RatioType] = Field(
-        None,
-        alias="amount",
-        title=(
-            "The amount of nutrient expressed in one or more units: X per pack / "
-            "per serving / per dose"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    item: fhirtypes.CodeableReferenceType = Field(
-        None,
-        alias="item",
-        title="The (relevant) nutrients in the product",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Substance"],
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``NutritionProductNutrient`` according specification,
-        with preserving original sequence order.
-        """
-        return ["id", "extension", "modifierExtension", "item", "amount"]
-
-
-class NutritionProductProductCharacteristic(backboneelement.BackboneElement):
+class NutritionProductCharacteristic(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -421,7 +246,7 @@ class NutritionProductProductCharacteristic(backboneelement.BackboneElement):
     Specifies descriptive properties of the nutrition product.
     """
 
-    resource_type = Field("NutritionProductProductCharacteristic", const=True)
+    resource_type = Field("NutritionProductCharacteristic", const=True)
 
     type: fhirtypes.CodeableConceptType = Field(
         ...,
@@ -521,7 +346,7 @@ class NutritionProductProductCharacteristic(backboneelement.BackboneElement):
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``NutritionProductProductCharacteristic`` according specification,
+        ``NutritionProductCharacteristic`` according specification,
         with preserving original sequence order.
         """
         return [
@@ -538,7 +363,7 @@ class NutritionProductProductCharacteristic(backboneelement.BackboneElement):
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_4072(
+    def validate_one_of_many_3335(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
         """https://www.hl7.org/fhir/formats.html#choice
@@ -583,3 +408,209 @@ class NutritionProductProductCharacteristic(backboneelement.BackboneElement):
                 raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
+
+
+class NutritionProductIngredient(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Ingredients contained in this product.
+    """
+
+    resource_type = Field("NutritionProductIngredient", const=True)
+
+    amount: typing.List[fhirtypes.RatioType] = Field(
+        None,
+        alias="amount",
+        title="The amount of ingredient that is in the product",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    item: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="item",
+        title="The ingredient contained in the product",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["NutritionProduct"],
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionProductIngredient`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "item", "amount"]
+
+
+class NutritionProductInstance(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    One or several physical instances or occurrences of the nutrition product.
+    Conveys instance-level information about this product item. One or several
+    physical, countable instances or occurrences of the product.
+    """
+
+    resource_type = Field("NutritionProductInstance", const=True)
+
+    biologicalSourceEvent: fhirtypes.IdentifierType = Field(
+        None,
+        alias="biologicalSourceEvent",
+        title=(
+            "An identifier that supports traceability to the event during which "
+            "material in this product from one or more biological entities was "
+            "obtained or pooled"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    expiry: fhirtypes.DateTime = Field(
+        None,
+        alias="expiry",
+        title="The expiry date or date and time for the product",
+        description=(
+            "The time after which the product is no longer expected to be in proper"
+            " condition, or its use is not advised or not allowed."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    expiry__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_expiry", title="Extension field for ``expiry``."
+    )
+
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title=(
+            "The identifier for the physical instance, typically a serial number or"
+            " manufacturer number"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    lotNumber: fhirtypes.String = Field(
+        None,
+        alias="lotNumber",
+        title="The identification of the batch or lot of the product",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    lotNumber__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_lotNumber", title="Extension field for ``lotNumber``."
+    )
+
+    name: fhirtypes.String = Field(
+        None,
+        alias="name",
+        title="The name for the specific product",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_name", title="Extension field for ``name``."
+    )
+
+    quantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="quantity",
+        title="The amount of items or instances",
+        description=(
+            "The amount of items or instances that the resource considers, for "
+            "instance when referring to 2 identical units together."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    useBy: fhirtypes.DateTime = Field(
+        None,
+        alias="useBy",
+        title=(
+            "The date until which the product is expected to be good for " "consumption"
+        ),
+        description=(
+            "The time after which the product is no longer expected to be in proper"
+            " condition, or its use is not advised or not allowed."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    useBy__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_useBy", title="Extension field for ``useBy``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionProductInstance`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "quantity",
+            "identifier",
+            "name",
+            "lotNumber",
+            "expiry",
+            "useBy",
+            "biologicalSourceEvent",
+        ]
+
+
+class NutritionProductNutrient(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    The product's nutritional information expressed by the nutrients.
+    """
+
+    resource_type = Field("NutritionProductNutrient", const=True)
+
+    amount: typing.List[fhirtypes.RatioType] = Field(
+        None,
+        alias="amount",
+        title=(
+            "The amount of nutrient expressed in one or more units: X per pack / "
+            "per serving / per dose"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    item: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="item",
+        title="The (relevant) nutrients in the product",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Substance"],
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``NutritionProductNutrient`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "item", "amount"]
