@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Observation
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Observation(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -61,6 +61,20 @@ class Observation(domainresource.DomainResource):
         element_property=True,
     )
 
+    bodyStructure: fhirtypes.ReferenceType = Field(
+        None,
+        alias="bodyStructure",
+        title="Observed body structure",
+        description=(
+            "Indicates the body structure on the subject's body where the "
+            "observation was made (i.e. the target site)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["BodyStructure"],
+    )
+
     category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
@@ -112,7 +126,7 @@ class Observation(domainresource.DomainResource):
     derivedFrom: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="derivedFrom",
-        title="Related measurements the observation is made from",
+        title="Related resource from which the observation is made",
         description=(
             "The target resource that represents a measurement from which this "
             "observation value is derived. For example, a calculated anion gap or a"
@@ -124,18 +138,22 @@ class Observation(domainresource.DomainResource):
         enum_reference_types=[
             "DocumentReference",
             "ImagingStudy",
-            "Media",
+            "ImagingSelection",
             "QuestionnaireResponse",
             "Observation",
             "MolecularSequence",
+            "GenomicStudy",
         ],
     )
 
     device: fhirtypes.ReferenceType = Field(
         None,
         alias="device",
-        title="(Measurement) Device",
-        description="The device used to generate the observation data.",
+        title=(
+            "A reference to the device that generates the measurements or the "
+            "device settings for the device"
+        ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -291,10 +309,51 @@ class Observation(domainresource.DomainResource):
         element_property=True,
     )
 
+    instantiatesCanonical: fhirtypes.Canonical = Field(
+        None,
+        alias="instantiatesCanonical",
+        title="Instantiates FHIR ObservationDefinition",
+        description=(
+            "The reference to a FHIR ObservationDefinition resource that provides "
+            "the definition that is adhered to in whole or in part by this "
+            "Observation instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e instantiates[x]
+        one_of_many="instantiates",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["ObservationDefinition"],
+    )
+    instantiatesCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_instantiatesCanonical",
+        title="Extension field for ``instantiatesCanonical``.",
+    )
+
+    instantiatesReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="instantiatesReference",
+        title="Instantiates FHIR ObservationDefinition",
+        description=(
+            "The reference to a FHIR ObservationDefinition resource that provides "
+            "the definition that is adhered to in whole or in part by this "
+            "Observation instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e instantiates[x]
+        one_of_many="instantiates",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["ObservationDefinition"],
+    )
+
     interpretation: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="interpretation",
-        title="High, low, normal, etc.",
+        title="High, low, normal, etc",
         description=(
             "A categorical assessment of an observation value.  For example, high, "
             "low, normal."
@@ -355,6 +414,7 @@ class Observation(domainresource.DomainResource):
             "Procedure",
             "Immunization",
             "ImagingStudy",
+            "GenomicStudy",
         ],
     )
 
@@ -398,7 +458,7 @@ class Observation(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Specimen"],
+        enum_reference_types=["Specimen", "Group"],
     )
 
     status: fhirtypes.Code = Field(
@@ -422,16 +482,56 @@ class Observation(domainresource.DomainResource):
         alias="subject",
         title="Who and/or what the observation is about",
         description=(
-            "The patient, or group of patients, location, or device this "
-            "observation is about and into whose record the observation is placed. "
-            "If the actual focus of the observation is different from the subject "
-            "(or a sample of, part, or region of the subject), the `focus` element "
-            "or the `code` itself specifies the actual focus of the observation."
+            "The patient, or group of patients, location, device, organization, "
+            "procedure or practitioner this observation is about and into whose or "
+            "what record the observation is placed. If the actual focus of the "
+            "observation is different from the subject (or a sample of, part, or "
+            "region of the subject), the `focus` element or the `code` itself "
+            "specifies the actual focus of the observation."
         ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient", "Group", "Device", "Location"],
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "Device",
+            "Location",
+            "Organization",
+            "Procedure",
+            "Practitioner",
+            "Medication",
+            "Substance",
+            "BiologicallyDerivedProduct",
+            "NutritionProduct",
+        ],
+    )
+
+    triggeredBy: typing.List[fhirtypes.ObservationTriggeredByType] = Field(
+        None,
+        alias="triggeredBy",
+        title="Triggering observation(s)",
+        description=(
+            "Identifies the observation(s) that triggered the performance of this "
+            "observation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    valueAttachment: fhirtypes.AttachmentType = Field(
+        None,
+        alias="valueAttachment",
+        title="Actual result",
+        description=(
+            "The information determined as a result of making the observation, if "
+            "the information has a simple value."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
     )
 
     valueBoolean: bool = Field(
@@ -563,6 +663,23 @@ class Observation(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
+    valueReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="valueReference",
+        title="Actual result",
+        description=(
+            "The information determined as a result of making the observation, if "
+            "the information has a simple value."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["MolecularSequence"],
+    )
+
     valueSampledData: fhirtypes.SampledDataType = Field(
         None,
         alias="valueSampledData",
@@ -614,6 +731,66 @@ class Observation(domainresource.DomainResource):
         None, alias="_valueTime", title="Extension field for ``valueTime``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Observation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "instantiatesCanonical",
+            "instantiatesReference",
+            "basedOn",
+            "triggeredBy",
+            "partOf",
+            "status",
+            "category",
+            "code",
+            "subject",
+            "focus",
+            "encounter",
+            "effectiveDateTime",
+            "effectivePeriod",
+            "effectiveTiming",
+            "effectiveInstant",
+            "issued",
+            "performer",
+            "valueQuantity",
+            "valueCodeableConcept",
+            "valueString",
+            "valueBoolean",
+            "valueInteger",
+            "valueRange",
+            "valueRatio",
+            "valueSampledData",
+            "valueTime",
+            "valueDateTime",
+            "valuePeriod",
+            "valueAttachment",
+            "valueReference",
+            "dataAbsentReason",
+            "interpretation",
+            "note",
+            "bodySite",
+            "bodyStructure",
+            "method",
+            "specimen",
+            "device",
+            "referenceRange",
+            "hasMember",
+            "derivedFrom",
+            "component",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1353(
         cls, values: typing.Dict[str, typing.Any]
@@ -696,7 +873,9 @@ class Observation(domainresource.DomainResource):
                 "effectivePeriod",
                 "effectiveTiming",
             ],
+            "instantiates": ["instantiatesCanonical", "instantiatesReference"],
             "value": [
+                "valueAttachment",
                 "valueBoolean",
                 "valueCodeableConcept",
                 "valueDateTime",
@@ -705,6 +884,7 @@ class Observation(domainresource.DomainResource):
                 "valueQuantity",
                 "valueRange",
                 "valueRatio",
+                "valueReference",
                 "valueSampledData",
                 "valueString",
                 "valueTime",
@@ -733,7 +913,7 @@ class Observation(domainresource.DomainResource):
 
 
 class ObservationComponent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -774,7 +954,7 @@ class ObservationComponent(backboneelement.BackboneElement):
     interpretation: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="interpretation",
-        title="High, low, normal, etc.",
+        title="High, low, normal, etc",
         description=(
             "A categorical assessment of an observation value.  For example, high, "
             "low, normal."
@@ -795,6 +975,21 @@ class ObservationComponent(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    valueAttachment: fhirtypes.AttachmentType = Field(
+        None,
+        alias="valueAttachment",
+        title="Actual component result",
+        description=(
+            "The information determined as a result of making the observation, if "
+            "the information has a simple value."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueBoolean: bool = Field(
         None,
         alias="valueBoolean",
@@ -924,6 +1119,23 @@ class ObservationComponent(backboneelement.BackboneElement):
         one_of_many_required=False,
     )
 
+    valueReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="valueReference",
+        title="Actual component result",
+        description=(
+            "The information determined as a result of making the observation, if "
+            "the information has a simple value."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["MolecularSequence"],
+    )
+
     valueSampledData: fhirtypes.SampledDataType = Field(
         None,
         alias="valueSampledData",
@@ -975,6 +1187,35 @@ class ObservationComponent(backboneelement.BackboneElement):
         None, alias="_valueTime", title="Extension field for ``valueTime``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ObservationComponent`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "valueQuantity",
+            "valueCodeableConcept",
+            "valueString",
+            "valueBoolean",
+            "valueInteger",
+            "valueRange",
+            "valueRatio",
+            "valueSampledData",
+            "valueTime",
+            "valueDateTime",
+            "valuePeriod",
+            "valueAttachment",
+            "valueReference",
+            "dataAbsentReason",
+            "interpretation",
+            "referenceRange",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2306(
         cls, values: typing.Dict[str, typing.Any]
@@ -993,6 +1234,7 @@ class ObservationComponent(backboneelement.BackboneElement):
         """
         one_of_many_fields = {
             "value": [
+                "valueAttachment",
                 "valueBoolean",
                 "valueCodeableConcept",
                 "valueDateTime",
@@ -1001,6 +1243,7 @@ class ObservationComponent(backboneelement.BackboneElement):
                 "valueQuantity",
                 "valueRange",
                 "valueRatio",
+                "valueReference",
                 "valueSampledData",
                 "valueString",
                 "valueTime",
@@ -1029,7 +1272,7 @@ class ObservationComponent(backboneelement.BackboneElement):
 
 
 class ObservationReferenceRange(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1098,7 +1341,16 @@ class ObservationReferenceRange(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    text: fhirtypes.String = Field(
+    normalValue: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="normalValue",
+        title="Normal value, if relevant",
+        description="The value of the normal value of the reference range.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    text: fhirtypes.Markdown = Field(
         None,
         alias="text",
         title="Text based reference range in an observation",
@@ -1126,3 +1378,144 @@ class ObservationReferenceRange(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ObservationReferenceRange`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "low",
+            "high",
+            "normalValue",
+            "type",
+            "appliesTo",
+            "age",
+            "text",
+        ]
+
+
+class ObservationTriggeredBy(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Triggering observation(s).
+    Identifies the observation(s) that triggered the performance of this
+    observation.
+    """
+
+    resource_type = Field("ObservationTriggeredBy", const=True)
+
+    observation: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="observation",
+        title="Triggering observation",
+        description="Reference to the triggering observation.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Observation"],
+    )
+
+    reason: fhirtypes.String = Field(
+        None,
+        alias="reason",
+        title="Reason that the observation was triggered",
+        description=(
+            "Provides the reason why this observation was performed as a result of "
+            "the observation(s) referenced."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    reason__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_reason", title="Extension field for ``reason``."
+    )
+
+    type: fhirtypes.Code = Field(
+        None,
+        alias="type",
+        title="reflex | repeat | re-run",
+        description="The type of trigger. Reflex | Repeat | Re-run.",
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["reflex", "repeat", "re-run"],
+    )
+    type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_type", title="Extension field for ``type``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ObservationTriggeredBy`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "observation", "type", "reason"]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_required_primitive_elements_2476(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/extensibility.html#Special-Case
+        In some cases, implementers might find that they do not have appropriate data for
+        an element with minimum cardinality = 1. In this case, the element must be present,
+        but unless the resource or a profile on it has made the actual value of the primitive
+        data type mandatory, it is possible to provide an extension that explains why
+        the primitive value is not present.
+        """
+        required_fields = [("type", "type__ext")]
+        _missing = object()
+
+        def _fallback():
+            return ""
+
+        errors: typing.List["ErrorWrapper"] = []
+        for name, ext in required_fields:
+            field = cls.__fields__[name]
+            ext_field = cls.__fields__[ext]
+            value = values.get(field.alias, _missing)
+            if value not in (_missing, None):
+                continue
+            ext_value = values.get(ext_field.alias, _missing)
+            missing_ext = True
+            if ext_value not in (_missing, None):
+                if isinstance(ext_value, dict):
+                    missing_ext = len(ext_value.get("extension", [])) == 0
+                elif (
+                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
+                    == "FHIRPrimitiveExtension"
+                ):
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+                else:
+                    validate_pass = True
+                    for validator in ext_field.type_.__get_validators__():
+                        try:
+                            ext_value = validator(v=ext_value)
+                        except ValidationError as exc:
+                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
+                            validate_pass = False
+                    if not validate_pass:
+                        continue
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+            if missing_ext:
+                if value is _missing:
+                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
+                else:
+                    errors.append(
+                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
+                    )
+        if len(errors) > 0:
+            raise ValidationError(errors, cls)  # type: ignore
+
+        return values
