@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/OperationDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -62,8 +62,13 @@ class OperationDefinition(domainresource.DomainResource):
     code: fhirtypes.Code = Field(
         None,
         alias="code",
-        title="Name used to invoke the operation",
-        description="The name used to invoke the operation.",
+        title="Recommended name for operation in search url",
+        description=(
+            "The label that is recommended to be used in the URL for this "
+            "operation. In some cases, servers may need to use a different "
+            "CapabilityStatement operation.name to differentiate between multiple "
+            "SearchParameters that happen to have the same code."
+        ),
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -96,16 +101,49 @@ class OperationDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
+    copyright: fhirtypes.Markdown = Field(
+        None,
+        alias="copyright",
+        title="Use and/or publishing restrictions",
+        description=(
+            "A copyright statement relating to the operation definition and/or its "
+            "contents. Copyright statements are generally legal restrictions on the"
+            " use and publishing of the operation definition."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyright__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyright", title="Extension field for ``copyright``."
+    )
+
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the operation definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the operation definition "
-            "changes."
+            "The date  (and optionally time) when the operation definition was last"
+            " significantly changed. The date must change when the business version"
+            " changes and it must change if the status code changes. In addition, "
+            "it should change when the substantive content of the operation "
+            "definition changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -136,7 +174,7 @@ class OperationDefinition(domainresource.DomainResource):
         description=(
             "A Boolean value to indicate that this operation definition is authored"
             " for testing purposes (or education/evaluation/marketing) and is not "
-            "intended to be used for genuine usage."
+            "intended for genuine usage."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -145,6 +183,22 @@ class OperationDefinition(domainresource.DomainResource):
         None, alias="_experimental", title="Extension field for ``experimental``."
     )
 
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title=(
+            "Additional identifier for the implementation guide (business "
+            "identifier)"
+        ),
+        description=(
+            "A formal identifier that is used to identify this implementation guide"
+            " when it is represented in other formats, or referenced in a "
+            "specification, model, design or an instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     inputProfile: fhirtypes.Canonical = Field(
         None,
         alias="inputProfile",
@@ -267,10 +321,10 @@ class OperationDefinition(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the "
-            "operation definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the operation definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -294,7 +348,7 @@ class OperationDefinition(domainresource.DomainResource):
         None, alias="_purpose", title="Extension field for ``purpose``."
     )
 
-    resource: typing.List[fhirtypes.Code] = Field(
+    resource: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="resource",
         title="Types this operation applies to",
@@ -310,10 +364,7 @@ class OperationDefinition(domainresource.DomainResource):
         None,
         alias="status",
         title="draft | active | retired | unknown",
-        description=(
-            "The status of this operation definition. Enables tracking the life-"
-            "cycle of the content."
-        ),
+        description="The current state of this operation definition.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -377,14 +428,14 @@ class OperationDefinition(domainresource.DomainResource):
         None,
         alias="url",
         title=(
-            "Canonical identifier for this operation definition, represented as a "
-            "URI (globally unique)"
+            "Canonical identifier for this operation definition, represented as an "
+            "absolute URI (globally unique)"
         ),
         description=(
             "An absolute URI that is used to identify this operation definition "
             "when it is referenced in a specification, model, design or an "
             "instance; also called its canonical identifier. This SHOULD be "
-            "globally unique and SHOULD be a literal address at which at which an "
+            "globally unique and SHOULD be a literal address at which an "
             "authoritative instance of this operation definition is (or will be) "
             "published. This URL can be the target of a canonical reference. It "
             "SHALL remain the same when the operation definition is stored on "
@@ -406,7 +457,7 @@ class OperationDefinition(domainresource.DomainResource):
             "contexts that are listed. These contexts may be general categories "
             "(gender, age, ...) or may be references to specific programs "
             "(insurance plans, studies, ...) and may be used to assist with "
-            "indexing and searching for appropriate operation definition instances."
+            "indexing and searching for appropriate operation definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -432,6 +483,41 @@ class OperationDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -448,7 +534,10 @@ class OperationDefinition(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "url",
+            "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "status",
@@ -461,6 +550,8 @@ class OperationDefinition(domainresource.DomainResource):
             "useContext",
             "jurisdiction",
             "purpose",
+            "copyright",
+            "copyrightLabel",
             "affectsState",
             "code",
             "comment",
@@ -542,6 +633,46 @@ class OperationDefinition(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2167(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class OperationDefinitionOverload(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -568,7 +699,7 @@ class OperationDefinitionOverload(backboneelement.BackboneElement):
         None, alias="_comment", title="Extension field for ``comment``."
     )
 
-    parameterName: typing.List[fhirtypes.String] = Field(
+    parameterName: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="parameterName",
         title="Name of parameter to include in overload",
@@ -602,6 +733,21 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
 
     resource_type = Field("OperationDefinitionParameter", const=True)
 
+    allowedType: typing.List[typing.Optional[fhirtypes.Code]] = Field(
+        None,
+        alias="allowedType",
+        title="Allowed sub-type this parameter can have (if type is abstract)",
+        description=(
+            "Support for polymorphic types. If the parameter type is abstract, this"
+            " element lists allowed sub-types for the parameter."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    allowedType__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_allowedType", title="Extension field for ``allowedType``.")
+
     binding: fhirtypes.OperationDefinitionParameterBindingType = Field(
         None,
         alias="binding",
@@ -614,7 +760,7 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    documentation: fhirtypes.String = Field(
+    documentation: fhirtypes.Markdown = Field(
         None,
         alias="documentation",
         title="Description of meaning/use",
@@ -694,6 +840,24 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    scope: typing.List[typing.Optional[fhirtypes.Code]] = Field(
+        None,
+        alias="scope",
+        title="instance | type | system",
+        description=(
+            "If present, indicates that the parameter applies when the operation is"
+            " being invoked at the specified level."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["instance", "type", "system"],
+    )
+    scope__ext: typing.List[
+        typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
+    ] = Field(None, alias="_scope", title="Extension field for ``scope``.")
+
     searchType: fhirtypes.Code = Field(
         None,
         alias="searchType",
@@ -702,8 +866,8 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
             "uri | special"
         ),
         description=(
-            "How the parameter is understood as a search parameter. This is only "
-            "used if the parameter type is 'string'."
+            "How the parameter is understood if/when it used as search parameter. "
+            "This is only used if the parameter is a string."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -725,10 +889,13 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
         None, alias="_searchType", title="Extension field for ``searchType``."
     )
 
-    targetProfile: typing.List[fhirtypes.Canonical] = Field(
+    targetProfile: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="targetProfile",
-        title="If type is Reference | canonical, allowed targets",
+        title=(
+            "If type is Reference | canonical, allowed targets. If type is "
+            "'Resource', then this constrains the allowed resource types"
+        ),
         description=(
             'Used when the type is "Reference" or "canonical", and identifies a '
             "profile structure or implementation Guide that applies to the target "
@@ -791,10 +958,12 @@ class OperationDefinitionParameter(backboneelement.BackboneElement):
             "modifierExtension",
             "name",
             "use",
+            "scope",
             "min",
             "max",
             "documentation",
             "type",
+            "allowedType",
             "targetProfile",
             "searchType",
             "binding",
