@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/OrganizationAffiliation
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -18,8 +18,8 @@ class OrganizationAffiliation(domainresource.DomainResource):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Defines an affiliation/assotiation/relationship between 2 distinct
-    oganizations, that is not a part-of relationship/sub-division relationship.
+    Defines an affiliation/association/relationship between 2 distinct
+    organizations, that is not a part-of relationship/sub-division relationship.
     """
 
     resource_type = Field("OrganizationAffiliation", const=True)
@@ -48,6 +48,21 @@ class OrganizationAffiliation(domainresource.DomainResource):
         element_property=True,
     )
 
+    contact: typing.List[fhirtypes.ExtendedContactDetailType] = Field(
+        None,
+        alias="contact",
+        title=(
+            "Official contact details at the participatingOrganization relevant to "
+            "this Affiliation"
+        ),
+        description=(
+            "The contact details of communication devices available at the "
+            "participatingOrganization relevant to this Affiliation."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     endpoint: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="endpoint",
@@ -96,9 +111,8 @@ class OrganizationAffiliation(domainresource.DomainResource):
         None,
         alias="network",
         title=(
-            "Health insurance provider network in which the "
-            "participatingOrganization provides the role's services (if defined) at"
-            " the indicated locations (if defined)"
+            "The network in which the participatingOrganization provides the role's"
+            " services (if defined) at the indicated locations (if defined)"
         ),
         description=None,
         # if property is element of this resource.
@@ -163,18 +177,6 @@ class OrganizationAffiliation(domainresource.DomainResource):
         element_property=True,
     )
 
-    telecom: typing.List[fhirtypes.ContactPointType] = Field(
-        None,
-        alias="telecom",
-        title=(
-            "Contact details at the participatingOrganization relevant to this "
-            "Affiliation"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -200,6 +202,6 @@ class OrganizationAffiliation(domainresource.DomainResource):
             "specialty",
             "location",
             "healthcareService",
-            "telecom",
+            "contact",
             "endpoint",
         ]
