@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/PackagedProductDefinition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -23,7 +23,23 @@ class PackagedProductDefinition(domainresource.DomainResource):
 
     resource_type = Field("PackagedProductDefinition", const=True)
 
-    characteristic: typing.List[fhirtypes.CodeableConceptType] = Field(
+    attachedDocument: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="attachedDocument",
+        title=(
+            "Additional information or supporting documentation about the packaged "
+            "product"
+        ),
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["DocumentReference"],
+    )
+
+    characteristic: typing.List[
+        fhirtypes.PackagedProductDefinitionPackagingPropertyType
+    ] = Field(
         None,
         alias="characteristic",
         title=(
@@ -44,7 +60,8 @@ class PackagedProductDefinition(domainresource.DomainResource):
         title=(
             "A total of the complete count of contained items of a particular "
             "type/form, independent of sub-packaging or organization. This can be "
-            "considered as the pack size"
+            "considered as the pack size. See also packaging.containedItem.amount "
+            "(especially the long definition)"
         ),
         description=(
             "A total of the complete count of contained items of a particular "
@@ -70,12 +87,12 @@ class PackagedProductDefinition(domainresource.DomainResource):
         None,
         alias="copackagedIndicator",
         title=(
-            "If the drug product is supplied with another item such as a diluent or"
-            " adjuvant"
+            "Identifies if the drug product is supplied with another item such as a"
+            " diluent or adjuvant"
         ),
         description=(
-            "States whether a drug product is supplied with another item such as a "
-            "diluent or adjuvant."
+            "Identifies if the package contains different items, such as when a "
+            "drug product is supplied with another item e.g. a diluent or adjuvant."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -104,11 +121,15 @@ class PackagedProductDefinition(domainresource.DomainResource):
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
-        title="A unique identifier for this package as whole",
+        title=(
+            "A unique identifier for this package as whole - not for the content of"
+            " the package"
+        ),
         description=(
-            "A unique identifier for this package as whole. Unique instance "
-            "identifiers assigned to a package by manufacturers, regulators, drug "
-            "catalogue custodians or other organizations."
+            "A unique identifier for this package as whole - not the the content of"
+            " the package. Unique instance identifiers assigned to a package by "
+            "manufacturers, regulators, drug catalogue custodians or other "
+            "organizations."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -175,9 +196,23 @@ class PackagedProductDefinition(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
-    package: fhirtypes.PackagedProductDefinitionPackageType = Field(
+    packageFor: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="package",
+        alias="packageFor",
+        title="The product that this is a pack for",
+        description=(
+            "The product this package model relates to, not the contents of the "
+            "package (for which see package.containedItem)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["MedicinalProductDefinition"],
+    )
+
+    packaging: fhirtypes.PackagedProductDefinitionPackagingType = Field(
+        None,
+        alias="packaging",
         title=(
             "A packaging item, as a container for medically related items, possibly"
             " with other packaging items within, or a packaging component, such as "
@@ -192,17 +227,6 @@ class PackagedProductDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
-    packageFor: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="packageFor",
-        title="The product that this is a pack for",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["MedicinalProductDefinition"],
-    )
-
     status: fhirtypes.CodeableConceptType = Field(
         None,
         alias="status",
@@ -272,10 +296,11 @@ class PackagedProductDefinition(domainresource.DomainResource):
             "description",
             "legalStatusOfSupply",
             "marketingStatus",
-            "characteristic",
             "copackagedIndicator",
             "manufacturer",
-            "package",
+            "attachedDocument",
+            "packaging",
+            "characteristic",
         ]
 
 
@@ -326,7 +351,7 @@ class PackagedProductDefinitionLegalStatusOfSupply(backboneelement.BackboneEleme
         return ["id", "extension", "modifierExtension", "code", "jurisdiction"]
 
 
-class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
+class PackagedProductDefinitionPackaging(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -338,7 +363,7 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
     (which is not a device or a medication manufactured item).
     """
 
-    resource_type = Field("PackagedProductDefinitionPackage", const=True)
+    resource_type = Field("PackagedProductDefinitionPackaging", const=True)
 
     alternateMaterial: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
@@ -356,8 +381,27 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    componentPart: bool = Field(
+        None,
+        alias="componentPart",
+        title=(
+            "Is this a part of the packaging (e.g. a cap or bottle stopper), rather"
+            " than the packaging itself (e.g. a bottle or vial)"
+        ),
+        description=(
+            "Is this a part of the packaging (e.g. a cap or bottle stopper), rather"
+            " than the packaging itself (e.g. a bottle or vial). The latter type "
+            "are designed be a container, but the former are not."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    componentPart__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_componentPart", title="Extension field for ``componentPart``."
+    )
+
     containedItem: typing.List[
-        fhirtypes.PackagedProductDefinitionPackageContainedItemType
+        fhirtypes.PackagedProductDefinitionPackagingContainedItemType
     ] = Field(
         None,
         alias="containedItem",
@@ -375,8 +419,9 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
             "packaging. Including possibly a Data Carrier Identifier"
         ),
         description=(
-            "An identifier that is specific to this particular part of the "
-            "packaging. Including possibly Data Carrier Identifier (a GS1 barcode)."
+            "A business identifier that is specific to this particular part of the "
+            "packaging, often assigned by the manufacturer. Including possibly Data"
+            " Carrier Identifier (a GS1 barcode)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -386,12 +431,12 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
         None,
         alias="manufacturer",
         title=(
-            "Manufacturer of this package Item (multiple means these are all "
-            "possible manufacturers)"
+            "Manufacturer of this packaging item (multiple means these are all "
+            "potential manufacturers)"
         ),
         description=(
-            "Manufacturer of this package Item. When there are multiple it means "
-            "these are all possible manufacturers."
+            "Manufacturer of this packaging item. When there are multiple values "
+            "each one is a potential manufacturer of this packaging item."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -408,24 +453,24 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    package: typing.List[fhirtypes.PackagedProductDefinitionPackageType] = Field(
+    packaging: typing.List[fhirtypes.PackagedProductDefinitionPackagingType] = Field(
         None,
-        alias="package",
+        alias="packaging",
         title=(
-            "Allows containers (and parts of containers) within containers, still a"
-            " single packaged product"
+            "Allows containers (and parts of containers) within containers, still "
+            "as a part of single packaged product"
         ),
         description=(
-            "Allows containers (and parts of containers) parwithin containers, "
-            "still a single packaged product.  See also PackagedProductDefinition.p"
-            "ackage.containedItem.item(PackagedProductDefinition)."
+            "Allows containers (and parts of containers) within containers, still "
+            "as a part of a single packaged product. See also PackagedProductDefini"
+            "tion.packaging.containedItem.item(PackagedProductDefinition)."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
     property: typing.List[
-        fhirtypes.PackagedProductDefinitionPackagePropertyType
+        fhirtypes.PackagedProductDefinitionPackagingPropertyType
     ] = Field(
         None,
         alias="property",
@@ -443,8 +488,11 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
             "it (with the outermost level being 1)"
         ),
         description=(
-            "The quantity of this level of packaging in the package that contains "
-            "it. If specified, the outermost level is always 1."
+            "The quantity of packaging items contained at this layer of the "
+            "package. This does not relate to the number of contained items but "
+            "relates solely to the number of packaging items. When looking at the "
+            "outermost layer it is always 1. If there are two boxes within, at the "
+            "next layer it would be 2."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -453,9 +501,7 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
         None, alias="_quantity", title="Extension field for ``quantity``."
     )
 
-    shelfLifeStorage: typing.List[
-        fhirtypes.PackagedProductDefinitionPackageShelfLifeStorageType
-    ] = Field(
+    shelfLifeStorage: typing.List[fhirtypes.ProductShelfLifeType] = Field(
         None,
         alias="shelfLifeStorage",
         title="Shelf Life and storage information",
@@ -476,7 +522,7 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``PackagedProductDefinitionPackage`` according specification,
+        ``PackagedProductDefinitionPackaging`` according specification,
         with preserving original sequence order.
         """
         return [
@@ -485,6 +531,7 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
             "modifierExtension",
             "identifier",
             "type",
+            "componentPart",
             "quantity",
             "material",
             "alternateMaterial",
@@ -492,11 +539,11 @@ class PackagedProductDefinitionPackage(backboneelement.BackboneElement):
             "manufacturer",
             "property",
             "containedItem",
-            "package",
+            "packaging",
         ]
 
 
-class PackagedProductDefinitionPackageContainedItem(backboneelement.BackboneElement):
+class PackagedProductDefinitionPackagingContainedItem(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -504,12 +551,17 @@ class PackagedProductDefinitionPackageContainedItem(backboneelement.BackboneElem
     The item(s) within the packaging.
     """
 
-    resource_type = Field("PackagedProductDefinitionPackageContainedItem", const=True)
+    resource_type = Field("PackagedProductDefinitionPackagingContainedItem", const=True)
 
     amount: fhirtypes.QuantityType = Field(
         None,
         alias="amount",
-        title="The number of this type of item within this packaging",
+        title=(
+            "The number of this type of item within this packaging or for "
+            "continuous items such as liquids it is the quantity (for example "
+            "25ml). See also PackagedProductDefinition.containedItemQuantity "
+            "(especially the long definition)"
+        ),
         description=None,
         # if property is element of this resource.
         element_property=True,
@@ -531,7 +583,7 @@ class PackagedProductDefinitionPackageContainedItem(backboneelement.BackboneElem
             "allows another whole packaged product to be included, which is solely "
             "for the case where a package of other entire packages is wanted - such"
             " as a wholesale or distribution pack (for layers within one package, "
-            "use PackagedProductDefinition.package.package)."
+            "use PackagedProductDefinition.packaging.packaging)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -548,13 +600,13 @@ class PackagedProductDefinitionPackageContainedItem(backboneelement.BackboneElem
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``PackagedProductDefinitionPackageContainedItem`` according specification,
+        ``PackagedProductDefinitionPackagingContainedItem`` according specification,
         with preserving original sequence order.
         """
         return ["id", "extension", "modifierExtension", "item", "amount"]
 
 
-class PackagedProductDefinitionPackageProperty(backboneelement.BackboneElement):
+class PackagedProductDefinitionPackagingProperty(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -562,7 +614,7 @@ class PackagedProductDefinitionPackageProperty(backboneelement.BackboneElement):
     General characteristics of this item.
     """
 
-    resource_type = Field("PackagedProductDefinitionPackageProperty", const=True)
+    resource_type = Field("PackagedProductDefinitionPackagingProperty", const=True)
 
     type: fhirtypes.CodeableConceptType = Field(
         ...,
@@ -642,7 +694,7 @@ class PackagedProductDefinitionPackageProperty(backboneelement.BackboneElement):
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
-        ``PackagedProductDefinitionPackageProperty`` according specification,
+        ``PackagedProductDefinitionPackagingProperty`` according specification,
         with preserving original sequence order.
         """
         return [
@@ -658,7 +710,7 @@ class PackagedProductDefinitionPackageProperty(backboneelement.BackboneElement):
         ]
 
     @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_4308(
+    def validate_one_of_many_4525(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
         """https://www.hl7.org/fhir/formats.html#choice
@@ -702,138 +754,3 @@ class PackagedProductDefinitionPackageProperty(backboneelement.BackboneElement):
                 raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
-
-
-class PackagedProductDefinitionPackageShelfLifeStorage(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Shelf Life and storage information.
-    """
-
-    resource_type = Field(
-        "PackagedProductDefinitionPackageShelfLifeStorage", const=True
-    )
-
-    periodDuration: fhirtypes.DurationType = Field(
-        None,
-        alias="periodDuration",
-        title=(
-            "The shelf life time period can be specified using a numerical value "
-            "for the period of time and its unit of time measurement The unit of "
-            "measurement shall be specified in accordance with ISO 11240 and the "
-            "resulting terminology The symbol and the symbol identifier shall be "
-            "used"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e period[x]
-        one_of_many="period",
-        one_of_many_required=False,
-    )
-
-    periodString: fhirtypes.String = Field(
-        None,
-        alias="periodString",
-        title=(
-            "The shelf life time period can be specified using a numerical value "
-            "for the period of time and its unit of time measurement The unit of "
-            "measurement shall be specified in accordance with ISO 11240 and the "
-            "resulting terminology The symbol and the symbol identifier shall be "
-            "used"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e period[x]
-        one_of_many="period",
-        one_of_many_required=False,
-    )
-    periodString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_periodString", title="Extension field for ``periodString``."
-    )
-
-    specialPrecautionsForStorage: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="specialPrecautionsForStorage",
-        title=(
-            "Special precautions for storage, if any, can be specified using an "
-            "appropriate controlled vocabulary. The controlled term and the "
-            "controlled term identifier shall be specified"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    type: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="type",
-        title=(
-            "This describes the shelf life, taking into account various scenarios "
-            "such as shelf life of the packaged Medicinal Product itself, shelf "
-            "life after transformation where necessary and shelf life after the "
-            "first opening of a bottle, etc. The shelf life type shall be specified"
-            " using an appropriate controlled vocabulary The controlled term and "
-            "the controlled term identifier shall be specified"
-        ),
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    @classmethod
-    def elements_sequence(cls):
-        """returning all elements names from
-        ``PackagedProductDefinitionPackageShelfLifeStorage`` according specification,
-        with preserving original sequence order.
-        """
-        return [
-            "id",
-            "extension",
-            "modifierExtension",
-            "type",
-            "periodDuration",
-            "periodString",
-            "specialPrecautionsForStorage",
-        ]
-
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_5026(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
-        """
-        one_of_many_fields = {"period": ["periodDuration", "periodString"]}
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
-
-        return values
