@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Parameters
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,14 +16,14 @@ from . import backboneelement, fhirtypes, resource
 
 
 class Parameters(resource.Resource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     Operation Request or Response.
-    This resource is a non-persisted resource used to pass information into and
-    back from an [operation](operations.html). It has no other use, and there
-    is no RESTful endpoint associated with it.
+    This resource is used to pass information into and back from an operation
+    (whether invoked directly from REST or within a messaging environment).  It
+    is not persisted or allowed to be referenced by other resources.
     """
 
     resource_type = Field("Parameters", const=True)
@@ -37,9 +37,17 @@ class Parameters(resource.Resource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Parameters`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "meta", "implicitRules", "language", "parameter"]
+
 
 class ParametersParameter(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -75,7 +83,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="resource",
         title="If parameter is a whole resource",
-        description="If the parameter is a whole resource.",
+        description="Conveys the content if the parameter is a whole resource.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -84,7 +92,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueAddress",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -96,7 +104,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueAge",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -108,7 +116,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueAnnotation",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -120,7 +128,19 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueAttachment",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
+    valueAvailability: fhirtypes.AvailabilityType = Field(
+        None,
+        alias="valueAvailability",
+        title="If parameter is a data type",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -132,7 +152,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueBase64Binary",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -149,7 +169,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueBoolean",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -164,7 +184,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueCanonical",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -179,7 +199,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueCode",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -194,7 +214,19 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueCodeableConcept",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
+    valueCodeableReference: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="valueCodeableReference",
+        title="If parameter is a data type",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -206,7 +238,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueCoding",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -218,7 +250,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueContactDetail",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -230,19 +262,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueContactPoint",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e value[x]
-        one_of_many="value",
-        one_of_many_required=False,
-    )
-
-    valueContributor: fhirtypes.ContributorType = Field(
-        None,
-        alias="valueContributor",
-        title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -254,7 +274,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueCount",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -266,7 +286,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDataRequirement",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -278,7 +298,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDate",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -293,7 +313,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDateTime",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -308,7 +328,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDecimal",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -323,7 +343,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDistance",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -335,7 +355,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDosage",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -347,7 +367,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueDuration",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -359,7 +379,19 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueExpression",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
+    valueExtendedContactDetail: fhirtypes.ExtendedContactDetailType = Field(
+        None,
+        alias="valueExtendedContactDetail",
+        title="If parameter is a data type",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -371,7 +403,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueHumanName",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -383,7 +415,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueId",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -398,7 +430,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueIdentifier",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -410,7 +442,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueInstant",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -425,7 +457,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueInteger",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -436,11 +468,26 @@ class ParametersParameter(backboneelement.BackboneElement):
         None, alias="_valueInteger", title="Extension field for ``valueInteger``."
     )
 
+    valueInteger64: fhirtypes.Integer64 = Field(
+        None,
+        alias="valueInteger64",
+        title="If parameter is a data type",
+        description="Conveys the content if the parameter is a data type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+    valueInteger64__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueInteger64", title="Extension field for ``valueInteger64``."
+    )
+
     valueMarkdown: fhirtypes.Markdown = Field(
         None,
         alias="valueMarkdown",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -455,7 +502,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueMeta",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -467,7 +514,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueMoney",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -479,7 +526,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueOid",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -494,7 +541,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueParameterDefinition",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -506,7 +553,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valuePeriod",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -518,7 +565,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valuePositiveInt",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -535,7 +582,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueQuantity",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -547,7 +594,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueRange",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -559,7 +606,19 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueRatio",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
+    valueRatioRange: fhirtypes.RatioRangeType = Field(
+        None,
+        alias="valueRatioRange",
+        title="If parameter is a data type",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -571,7 +630,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueReference",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -583,7 +642,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueRelatedArtifact",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -595,7 +654,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueSampledData",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -607,7 +666,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueSignature",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -619,7 +678,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueString",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -634,7 +693,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueTime",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -649,7 +708,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueTiming",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -661,7 +720,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueTriggerDefinition",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -673,7 +732,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueUnsignedInt",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -690,7 +749,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueUri",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -705,7 +764,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueUrl",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -720,7 +779,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueUsageContext",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -732,7 +791,7 @@ class ParametersParameter(backboneelement.BackboneElement):
         None,
         alias="valueUuid",
         title="If parameter is a data type",
-        description="If the parameter is a data type.",
+        description="Conveys the content if the parameter is a data type.",
         # if property is element of this resource.
         element_property=True,
         # Choice of Data Types. i.e value[x]
@@ -743,6 +802,75 @@ class ParametersParameter(backboneelement.BackboneElement):
         None, alias="_valueUuid", title="Extension field for ``valueUuid``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ParametersParameter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "name",
+            "valueBase64Binary",
+            "valueBoolean",
+            "valueCanonical",
+            "valueCode",
+            "valueDate",
+            "valueDateTime",
+            "valueDecimal",
+            "valueId",
+            "valueInstant",
+            "valueInteger",
+            "valueInteger64",
+            "valueMarkdown",
+            "valueOid",
+            "valuePositiveInt",
+            "valueString",
+            "valueTime",
+            "valueUnsignedInt",
+            "valueUri",
+            "valueUrl",
+            "valueUuid",
+            "valueAddress",
+            "valueAge",
+            "valueAnnotation",
+            "valueAttachment",
+            "valueCodeableConcept",
+            "valueCodeableReference",
+            "valueCoding",
+            "valueContactPoint",
+            "valueCount",
+            "valueDistance",
+            "valueDuration",
+            "valueHumanName",
+            "valueIdentifier",
+            "valueMoney",
+            "valuePeriod",
+            "valueQuantity",
+            "valueRange",
+            "valueRatio",
+            "valueRatioRange",
+            "valueReference",
+            "valueSampledData",
+            "valueSignature",
+            "valueTiming",
+            "valueContactDetail",
+            "valueDataRequirement",
+            "valueExpression",
+            "valueParameterDefinition",
+            "valueRelatedArtifact",
+            "valueTriggerDefinition",
+            "valueUsageContext",
+            "valueAvailability",
+            "valueExtendedContactDetail",
+            "valueDosage",
+            "valueMeta",
+            "resource",
+            "part",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2167(
         cls, values: typing.Dict[str, typing.Any]
@@ -824,15 +952,16 @@ class ParametersParameter(backboneelement.BackboneElement):
                 "valueAge",
                 "valueAnnotation",
                 "valueAttachment",
+                "valueAvailability",
                 "valueBase64Binary",
                 "valueBoolean",
                 "valueCanonical",
                 "valueCode",
                 "valueCodeableConcept",
+                "valueCodeableReference",
                 "valueCoding",
                 "valueContactDetail",
                 "valueContactPoint",
-                "valueContributor",
                 "valueCount",
                 "valueDataRequirement",
                 "valueDate",
@@ -842,11 +971,13 @@ class ParametersParameter(backboneelement.BackboneElement):
                 "valueDosage",
                 "valueDuration",
                 "valueExpression",
+                "valueExtendedContactDetail",
                 "valueHumanName",
                 "valueId",
                 "valueIdentifier",
                 "valueInstant",
                 "valueInteger",
+                "valueInteger64",
                 "valueMarkdown",
                 "valueMeta",
                 "valueMoney",
@@ -857,6 +988,7 @@ class ParametersParameter(backboneelement.BackboneElement):
                 "valueQuantity",
                 "valueRange",
                 "valueRatio",
+                "valueRatioRange",
                 "valueReference",
                 "valueRelatedArtifact",
                 "valueSampledData",
