@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Patient
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Patient(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -161,10 +161,11 @@ class Patient(domainresource.DomainResource):
     link: typing.List[fhirtypes.PatientLinkType] = Field(
         None,
         alias="link",
-        title="Link to another patient resource that concerns the same actual person",
-        description=(
-            "Link to another patient resource that concerns the same actual " "patient."
+        title=(
+            "Link to a Patient or RelatedPerson resource that concerns the same "
+            "actual individual"
         ),
+        description=None,
         # if property is element of this resource.
         element_property=True,
     )
@@ -259,6 +260,41 @@ class Patient(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Patient`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "active",
+            "name",
+            "telecom",
+            "gender",
+            "birthDate",
+            "deceasedBoolean",
+            "deceasedDateTime",
+            "address",
+            "maritalStatus",
+            "multipleBirthBoolean",
+            "multipleBirthInteger",
+            "photo",
+            "contact",
+            "communication",
+            "generalPractitioner",
+            "managingOrganization",
+            "link",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_921(
         cls, values: typing.Dict[str, typing.Any]
@@ -302,7 +338,7 @@ class Patient(domainresource.DomainResource):
 
 
 class PatientCommunication(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -323,7 +359,7 @@ class PatientCommunication(backboneelement.BackboneElement):
             "The ISO-639-1 alpha 2 code in lower case for the language, optionally "
             "followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in"
             ' upper case; e.g. "en" for English, or "en-US" for American English '
-            'versus "en-EN" for England English.'
+            'versus "en-AU" for Australian English.'
         ),
         # if property is element of this resource.
         element_property=True,
@@ -344,9 +380,17 @@ class PatientCommunication(backboneelement.BackboneElement):
         None, alias="_preferred", title="Extension field for ``preferred``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PatientCommunication`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "language", "preferred"]
+
 
 class PatientContact(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -441,14 +485,33 @@ class PatientContact(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PatientContact`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "relationship",
+            "name",
+            "telecom",
+            "address",
+            "gender",
+            "organization",
+            "period",
+        ]
+
 
 class PatientLink(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Link to another patient resource that concerns the same actual person.
-    Link to another patient resource that concerns the same actual patient.
+    Link to a Patient or RelatedPerson resource that concerns the same actual
+    individual.
     """
 
     resource_type = Field("PatientLink", const=True)
@@ -457,7 +520,10 @@ class PatientLink(backboneelement.BackboneElement):
         ...,
         alias="other",
         title="The other patient or related person resource that the link refers to",
-        description="The other patient resource that the link refers to.",
+        description=(
+            "Link to a Patient or RelatedPerson resource that concerns the same "
+            "actual individual."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -483,6 +549,14 @@ class PatientLink(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PatientLink`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "other", "type"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1310(
         cls, values: typing.Dict[str, typing.Any]
