@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Procedure
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,34 +16,21 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Procedure(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    An action that is being or was performed on a patient.
-    An action that is or was performed on or for a patient. This can be a
-    physical intervention like an operation, or less invasive like long term
-    services, counseling, or hypnotherapy.
+    An action that is being or was performed on an individual or entity.
+    An action that is or was performed on or for a patient, practitioner,
+    device, organization, or location. For example, this can be a physical
+    intervention on a patient like an operation, or less invasive like long
+    term services, counseling, or hypnotherapy.  This can be a quality or
+    safety inspection for a location, organization, or device.  This can be an
+    accreditation procedure on a practitioner for licensing.
     """
 
     resource_type = Field("Procedure", const=True)
 
-    asserter: fhirtypes.ReferenceType = Field(
-        None,
-        alias="asserter",
-        title="Person who asserts this procedure",
-        description="Individual who is making the procedure statement.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=[
-            "Patient",
-            "RelatedPerson",
-            "Practitioner",
-            "PractitionerRole",
-        ],
-    )
-
     basedOn: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="basedOn",
@@ -70,7 +57,7 @@ class Procedure(domainresource.DomainResource):
         element_property=True,
     )
 
-    category: fhirtypes.CodeableConceptType = Field(
+    category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
         title="Classification of the procedure",
@@ -94,7 +81,7 @@ class Procedure(domainresource.DomainResource):
         element_property=True,
     )
 
-    complication: typing.List[fhirtypes.CodeableConceptType] = Field(
+    complication: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="complication",
         title="Complication following the procedure",
@@ -106,18 +93,6 @@ class Procedure(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-
-    complicationDetail: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="complicationDetail",
-        title="A condition that is a result of the procedure",
-        description=(
-            "Any complications that occurred during the procedure, or in the "
-            "immediate post-performance period."
-        ),
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Condition"],
     )
@@ -125,7 +100,7 @@ class Procedure(domainresource.DomainResource):
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
-        title="Encounter created as part of",
+        title="The Encounter during which this Procedure was created",
         description=(
             "The Encounter during which this Procedure was created or performed or "
             "to which the creation of this record is tightly associated."
@@ -149,6 +124,40 @@ class Procedure(domainresource.DomainResource):
         element_property=True,
     )
 
+    focus: fhirtypes.ReferenceType = Field(
+        None,
+        alias="focus",
+        title=(
+            "Who is the target of the procedure when it is not the subject of "
+            "record only"
+        ),
+        description=(
+            "Who is the target of the procedure when it is not the subject of "
+            "record only.  If focus is not present, then subject is the focus.  If "
+            "focus is present and the subject is one of the targets of the "
+            "procedure, include subject as a focus as well. If focus is present and"
+            " the subject is not included in focus, it implies that the procedure "
+            "was only targeted on the focus. For example, when a caregiver is given"
+            " education for a patient, the caregiver would be the focus and the "
+            "procedure record is associated with the subject (e.g. patient).  For "
+            "example, use focus when recording the target of the education, "
+            "training, or counseling is the parent or relative of a patient."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "RelatedPerson",
+            "Practitioner",
+            "Organization",
+            "CareTeam",
+            "PractitionerRole",
+            "Specimen",
+        ],
+    )
+
     followUp: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="followUp",
@@ -176,7 +185,7 @@ class Procedure(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -204,7 +213,7 @@ class Procedure(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
@@ -245,6 +254,118 @@ class Procedure(domainresource.DomainResource):
         element_property=True,
     )
 
+    occurrenceAge: fhirtypes.AgeType = Field(
+        None,
+        alias="occurrenceAge",
+        title="When the procedure occurred or is occurring",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " did occur or is occurring.  Allows a period to support complex "
+            "procedures that span more than one date, and also allows for the "
+            "length of the procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurrence[x]
+        one_of_many="occurrence",
+        one_of_many_required=False,
+    )
+
+    occurrenceDateTime: fhirtypes.DateTime = Field(
+        None,
+        alias="occurrenceDateTime",
+        title="When the procedure occurred or is occurring",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " did occur or is occurring.  Allows a period to support complex "
+            "procedures that span more than one date, and also allows for the "
+            "length of the procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurrence[x]
+        one_of_many="occurrence",
+        one_of_many_required=False,
+    )
+    occurrenceDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_occurrenceDateTime",
+        title="Extension field for ``occurrenceDateTime``.",
+    )
+
+    occurrencePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="occurrencePeriod",
+        title="When the procedure occurred or is occurring",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " did occur or is occurring.  Allows a period to support complex "
+            "procedures that span more than one date, and also allows for the "
+            "length of the procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurrence[x]
+        one_of_many="occurrence",
+        one_of_many_required=False,
+    )
+
+    occurrenceRange: fhirtypes.RangeType = Field(
+        None,
+        alias="occurrenceRange",
+        title="When the procedure occurred or is occurring",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " did occur or is occurring.  Allows a period to support complex "
+            "procedures that span more than one date, and also allows for the "
+            "length of the procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurrence[x]
+        one_of_many="occurrence",
+        one_of_many_required=False,
+    )
+
+    occurrenceString: fhirtypes.String = Field(
+        None,
+        alias="occurrenceString",
+        title="When the procedure occurred or is occurring",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " did occur or is occurring.  Allows a period to support complex "
+            "procedures that span more than one date, and also allows for the "
+            "length of the procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurrence[x]
+        one_of_many="occurrence",
+        one_of_many_required=False,
+    )
+    occurrenceString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_occurrenceString",
+        title="Extension field for ``occurrenceString``.",
+    )
+
+    occurrenceTiming: fhirtypes.TimingType = Field(
+        None,
+        alias="occurrenceTiming",
+        title="When the procedure occurred or is occurring",
+        description=(
+            "Estimated or actual date, date-time, period, or age when the procedure"
+            " did occur or is occurring.  Allows a period to support complex "
+            "procedures that span more than one date, and also allows for the "
+            "length of the procedure to be captured."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e occurrence[x]
+        one_of_many="occurrence",
+        one_of_many_required=False,
+    )
+
     outcome: fhirtypes.CodeableConceptType = Field(
         None,
         alias="outcome",
@@ -271,125 +392,27 @@ class Procedure(domainresource.DomainResource):
         enum_reference_types=["Procedure", "Observation", "MedicationAdministration"],
     )
 
-    performedAge: fhirtypes.AgeType = Field(
-        None,
-        alias="performedAge",
-        title="When the procedure was performed",
-        description=(
-            "Estimated or actual date, date-time, period, or age when the procedure"
-            " was performed.  Allows a period to support complex procedures that "
-            "span more than one date, and also allows for the length of the "
-            "procedure to be captured."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e performed[x]
-        one_of_many="performed",
-        one_of_many_required=False,
-    )
-
-    performedDateTime: fhirtypes.DateTime = Field(
-        None,
-        alias="performedDateTime",
-        title="When the procedure was performed",
-        description=(
-            "Estimated or actual date, date-time, period, or age when the procedure"
-            " was performed.  Allows a period to support complex procedures that "
-            "span more than one date, and also allows for the length of the "
-            "procedure to be captured."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e performed[x]
-        one_of_many="performed",
-        one_of_many_required=False,
-    )
-    performedDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_performedDateTime",
-        title="Extension field for ``performedDateTime``.",
-    )
-
-    performedPeriod: fhirtypes.PeriodType = Field(
-        None,
-        alias="performedPeriod",
-        title="When the procedure was performed",
-        description=(
-            "Estimated or actual date, date-time, period, or age when the procedure"
-            " was performed.  Allows a period to support complex procedures that "
-            "span more than one date, and also allows for the length of the "
-            "procedure to be captured."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e performed[x]
-        one_of_many="performed",
-        one_of_many_required=False,
-    )
-
-    performedRange: fhirtypes.RangeType = Field(
-        None,
-        alias="performedRange",
-        title="When the procedure was performed",
-        description=(
-            "Estimated or actual date, date-time, period, or age when the procedure"
-            " was performed.  Allows a period to support complex procedures that "
-            "span more than one date, and also allows for the length of the "
-            "procedure to be captured."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e performed[x]
-        one_of_many="performed",
-        one_of_many_required=False,
-    )
-
-    performedString: fhirtypes.String = Field(
-        None,
-        alias="performedString",
-        title="When the procedure was performed",
-        description=(
-            "Estimated or actual date, date-time, period, or age when the procedure"
-            " was performed.  Allows a period to support complex procedures that "
-            "span more than one date, and also allows for the length of the "
-            "procedure to be captured."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e performed[x]
-        one_of_many="performed",
-        one_of_many_required=False,
-    )
-    performedString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_performedString", title="Extension field for ``performedString``."
-    )
-
     performer: typing.List[fhirtypes.ProcedurePerformerType] = Field(
         None,
         alias="performer",
-        title="The people who performed the procedure",
-        description='Limited to "real" people rather than equipment.',
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="reasonCode",
-        title="Coded reason procedure performed",
+        title="Who performed the procedure and what they did",
         description=(
-            "The coded reason why the procedure was performed. This may be a coded "
-            "entity of some type, or may simply be present as text."
+            "Indicates who or what performed the procedure and how they were "
+            "involved."
         ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonReference",
+        alias="reason",
         title="The justification that the procedure was performed",
-        description="The justification of why the procedure was performed.",
+        description=(
+            "The coded reason or reference why the procedure was performed. This "
+            "may be a coded entity of some type, be present as text, or be a "
+            "reference to one of several resources that justify the procedure."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -402,6 +425,22 @@ class Procedure(domainresource.DomainResource):
         ],
     )
 
+    recorded: fhirtypes.DateTime = Field(
+        None,
+        alias="recorded",
+        title="When the procedure was first captured in the subject's record",
+        description=(
+            "The date the occurrence of the procedure was first captured in the "
+            "record regardless of Procedure.status (potentially after the "
+            "occurrence of the event)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    recorded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_recorded", title="Extension field for ``recorded``."
+    )
+
     recorder: fhirtypes.ReferenceType = Field(
         None,
         alias="recorder",
@@ -435,6 +474,49 @@ class Procedure(domainresource.DomainResource):
         enum_reference_types=["DiagnosticReport", "DocumentReference", "Composition"],
     )
 
+    reportedBoolean: bool = Field(
+        None,
+        alias="reportedBoolean",
+        title="Reported rather than primary record",
+        description=(
+            "Indicates if this record was captured as a secondary 'reported' record"
+            " rather than as an original primary source-of-truth record.  It may "
+            "also indicate the source of the report."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e reported[x]
+        one_of_many="reported",
+        one_of_many_required=False,
+    )
+    reportedBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_reportedBoolean", title="Extension field for ``reportedBoolean``."
+    )
+
+    reportedReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="reportedReference",
+        title="Reported rather than primary record",
+        description=(
+            "Indicates if this record was captured as a secondary 'reported' record"
+            " rather than as an original primary source-of-truth record.  It may "
+            "also indicate the source of the report."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e reported[x]
+        one_of_many="reported",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "RelatedPerson",
+            "Practitioner",
+            "PractitionerRole",
+            "Organization",
+        ],
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -478,26 +560,49 @@ class Procedure(domainresource.DomainResource):
     subject: fhirtypes.ReferenceType = Field(
         ...,
         alias="subject",
-        title="Who the procedure was performed on",
-        description="The person, animal or group on which the procedure was performed.",
+        title="Individual or entity the procedure was performed on",
+        description=(
+            "On whom or on what the procedure was performed. This is usually an "
+            "individual human, but can also be performed on animals, groups of "
+            "humans or animals, organizations or practitioners (for licensing), "
+            "locations or devices (for safety inspections or regulatory "
+            "authorizations).  If the actual focus of the procedure is different "
+            "from the subject, the focus element specifies the actual focus of the "
+            "procedure."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient", "Group"],
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "Device",
+            "Practitioner",
+            "Organization",
+            "Location",
+        ],
     )
 
-    usedCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    supportingInfo: typing.List[fhirtypes.ReferenceType] = Field(
         None,
-        alias="usedCode",
-        title="Coded items used during the procedure",
-        description="Identifies coded items that were used as part of the procedure.",
+        alias="supportingInfo",
+        title="Extra information relevant to the procedure",
+        description=(
+            "Other resources from the patient record that may be relevant to the "
+            "procedure.  The information from these resources was either used to "
+            "create the instance or is provided to help with its interpretation. "
+            "This extension should not be used if more specific inline elements or "
+            "extensions are available."
+        ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
     )
 
-    usedReference: typing.List[fhirtypes.ReferenceType] = Field(
+    used: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="usedReference",
+        alias="used",
         title="Items used during procedure",
         description=(
             "Identifies medications, devices and any other substance used as part "
@@ -506,9 +611,65 @@ class Procedure(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Device", "Medication", "Substance"],
+        enum_reference_types=[
+            "Device",
+            "Medication",
+            "Substance",
+            "BiologicallyDerivedProduct",
+        ],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Procedure`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "instantiatesCanonical",
+            "instantiatesUri",
+            "basedOn",
+            "partOf",
+            "status",
+            "statusReason",
+            "category",
+            "code",
+            "subject",
+            "focus",
+            "encounter",
+            "occurrenceDateTime",
+            "occurrencePeriod",
+            "occurrenceString",
+            "occurrenceAge",
+            "occurrenceRange",
+            "occurrenceTiming",
+            "recorded",
+            "recorder",
+            "reportedBoolean",
+            "reportedReference",
+            "performer",
+            "location",
+            "reason",
+            "bodySite",
+            "outcome",
+            "report",
+            "complication",
+            "followUp",
+            "note",
+            "focalDevice",
+            "used",
+            "supportingInfo",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1118(
         cls, values: typing.Dict[str, typing.Any]
@@ -585,13 +746,15 @@ class Procedure(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "performed": [
-                "performedAge",
-                "performedDateTime",
-                "performedPeriod",
-                "performedRange",
-                "performedString",
-            ]
+            "occurrence": [
+                "occurrenceAge",
+                "occurrenceDateTime",
+                "occurrencePeriod",
+                "occurrenceRange",
+                "occurrenceString",
+                "occurrenceTiming",
+            ],
+            "reported": ["reportedBoolean", "reportedReference"],
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
@@ -616,7 +779,7 @@ class Procedure(domainresource.DomainResource):
 
 
 class ProcedureFocalDevice(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -648,14 +811,22 @@ class ProcedureFocalDevice(backboneelement.BackboneElement):
         enum_reference_types=["Device"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ProcedureFocalDevice`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "action", "manipulated"]
+
 
 class ProcedurePerformer(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    The people who performed the procedure.
-    Limited to "real" people rather than equipment.
+    Who performed the procedure and what they did.
+    Indicates who or what performed the procedure and how they were involved.
     """
 
     resource_type = Field("ProcedurePerformer", const=True)
@@ -663,8 +834,8 @@ class ProcedurePerformer(backboneelement.BackboneElement):
     actor: fhirtypes.ReferenceType = Field(
         ...,
         alias="actor",
-        title="The reference to the practitioner",
-        description="The practitioner who was involved in the procedure.",
+        title="Who performed the procedure",
+        description="Indicates who or what performed the procedure.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -675,6 +846,8 @@ class ProcedurePerformer(backboneelement.BackboneElement):
             "Patient",
             "RelatedPerson",
             "Device",
+            "CareTeam",
+            "HealthcareService",
         ],
     )
 
@@ -694,9 +867,37 @@ class ProcedurePerformer(backboneelement.BackboneElement):
         None,
         alias="onBehalfOf",
         title="Organization the device or practitioner was acting for",
-        description="The organization the device or practitioner was acting on behalf of.",
+        description=(
+            "The Organization the Patient, RelatedPerson, Device, CareTeam, and "
+            "HealthcareService was acting on behalf of."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Organization"],
     )
+
+    period: fhirtypes.PeriodType = Field(
+        None,
+        alias="period",
+        title="When the performer performed the procedure",
+        description="Time period during which the performer performed the procedure.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ProcedurePerformer`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "function",
+            "actor",
+            "onBehalfOf",
+            "period",
+        ]
