@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Provenance
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -60,6 +60,59 @@ class Provenance(domainresource.DomainResource):
         element_property=True,
     )
 
+    authorization: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
+        alias="authorization",
+        title="Authorization (purposeOfUse) related to the event",
+        description=(
+            "The authorization (e.g., PurposeOfUse) that was used during the event "
+            "being recorded."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="basedOn",
+        title="Workflow authorization within which this event occurred",
+        description=(
+            "Allows tracing of authorizatino for the events and tracking whether "
+            "proposals/recommendations were acted upon."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "CarePlan",
+            "DeviceRequest",
+            "ImmunizationRecommendation",
+            "MedicationRequest",
+            "NutritionOrder",
+            "ServiceRequest",
+            "Task",
+        ],
+    )
+
+    encounter: fhirtypes.ReferenceType = Field(
+        None,
+        alias="encounter",
+        title=(
+            "Encounter within which this event occurred or which the event is "
+            "tightly associated"
+        ),
+        description=(
+            "This will typically be the encounter the event occurred, but some "
+            "events may be initiated prior to or after the official completion of "
+            "an encounter but still be tied to the context of the encounter (e.g. "
+            "pre-admission lab tests)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Encounter"],
+    )
+
     entity: typing.List[fhirtypes.ProvenanceEntityType] = Field(
         None,
         alias="entity",
@@ -109,7 +162,25 @@ class Provenance(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
-    policy: typing.List[fhirtypes.Uri] = Field(
+    patient: fhirtypes.ReferenceType = Field(
+        None,
+        alias="patient",
+        title=(
+            "The patient is the subject of the data created/updated (.target) by "
+            "the activity"
+        ),
+        description=(
+            "The patient element is available to enable deterministic tracking of "
+            "activities that involve the patient as the subject of the data used in"
+            " an activity."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Patient"],
+    )
+
+    policy: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="policy",
         title="Policy or plan the activity was defined by",
@@ -125,15 +196,6 @@ class Provenance(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_policy", title="Extension field for ``policy``.")
 
-    reason: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="reason",
-        title="Reason the activity is occurring",
-        description="The reason that the activity was taking place.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     recorded: fhirtypes.Instant = Field(
         None,
         alias="recorded",
@@ -141,7 +203,6 @@ class Provenance(domainresource.DomainResource):
         description="The instant of time at which the activity was recorded.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
     )
     recorded__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_recorded", title="Extension field for ``recorded``."
@@ -196,72 +257,16 @@ class Provenance(domainresource.DomainResource):
             "recorded",
             "policy",
             "location",
-            "reason",
+            "authorization",
             "activity",
+            "basedOn",
+            "patient",
+            "encounter",
             "agent",
             "entity",
             "signature",
         ]
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_1222(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
-        """
-        required_fields = [("recorded", "recorded__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
-
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1222(
         cls, values: typing.Dict[str, typing.Any]
@@ -316,18 +321,20 @@ class ProvenanceAgent(backboneelement.BackboneElement):
     onBehalfOf: fhirtypes.ReferenceType = Field(
         None,
         alias="onBehalfOf",
-        title="Who the agent is representing",
-        description="The individual, device, or organization for whom the change was made.",
+        title="The agent that delegated",
+        description=(
+            "The agent that delegated authority to perform the activity performed "
+            "by the agent.who element."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Practitioner",
             "PractitionerRole",
-            "RelatedPerson",
-            "Patient",
-            "Device",
             "Organization",
+            "CareTeam",
+            "Patient",
         ],
     )
 
@@ -336,8 +343,8 @@ class ProvenanceAgent(backboneelement.BackboneElement):
         alias="role",
         title="What the agents role was",
         description=(
-            "The function of the agent with respect to the activity. The security "
-            "role enabling the agent with respect to the activity."
+            "The structural roles of the agent indicating the agent's competency. "
+            "The security role enabling the agent with respect to the activity."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -347,7 +354,7 @@ class ProvenanceAgent(backboneelement.BackboneElement):
         None,
         alias="type",
         title="How the agent participated",
-        description="The participation the agent had with respect to the activity.",
+        description="The Functional Role of the agent with respect to the activity.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -355,18 +362,19 @@ class ProvenanceAgent(backboneelement.BackboneElement):
     who: fhirtypes.ReferenceType = Field(
         ...,
         alias="who",
-        title="Who participated",
-        description="The individual, device or organization that participated in the event.",
+        title="The agent that participated in the event",
+        description="Indicates who or what performed in the event.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Practitioner",
             "PractitionerRole",
-            "RelatedPerson",
+            "Organization",
+            "CareTeam",
             "Patient",
             "Device",
-            "Organization",
+            "RelatedPerson",
         ],
     )
 
@@ -405,7 +413,7 @@ class ProvenanceEntity(backboneelement.BackboneElement):
             "The entity is attributed to an agent to express the agent's "
             "responsibility for that entity, possibly along with other agents. This"
             " description can be understood as shorthand for saying that the agent "
-            "was responsible for the activity which generated the entity."
+            "was responsible for the activity which used the entity."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -414,14 +422,14 @@ class ProvenanceEntity(backboneelement.BackboneElement):
     role: fhirtypes.Code = Field(
         None,
         alias="role",
-        title="derivation | revision | quotation | source | removal",
+        title="revision | quotation | source | instantiates | removal",
         description="How the entity was used during the activity.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["derivation", "revision", "quotation", "source", "removal"],
+        enum_values=["revision", "quotation", "source", "instantiates", "removal"],
     )
     role__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_role", title="Extension field for ``role``."
