@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/SimpleQuantity
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 from pydantic import Field
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Quantity(element.Element):
+class Quantity(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -42,7 +42,7 @@ class Quantity(element.Element):
     comparator: fhirtypes.Code = Field(
         None,
         alias="comparator",
-        title="< | <= | >= | > - how to understand the value",
+        title="< | <= | >= | > | ad - how to understand the value",
         description=(
             "How the value should be understood and represented - whether the "
             "actual value is greater or less than the stated value due to "
@@ -53,7 +53,7 @@ class Quantity(element.Element):
         element_property=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["\u003c", "\u003c=", "\u003e=", "\u003e"],
+        enum_values=["\u003c", "\u003c=", "\u003e=", "\u003e", "ad"],
     )
     comparator__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_comparator", title="Extension field for ``comparator``."
