@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Questionnaire
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -50,7 +50,7 @@ class Questionnaire(domainresource.DomainResource):
         alias="code",
         title="Concept that represents the overall questionnaire",
         description=(
-            "An identifier for this question or group of questions in a particular "
+            "An identifier for this collection of questions in a particular "
             "terminology such as LOINC."
         ),
         # if property is element of this resource.
@@ -85,15 +85,33 @@ class Questionnaire(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the questionnaire was published. "
-            "The date must change when the business version changes and it must "
-            "change if the status code changes. In addition, it should change when "
-            "the substantive content of the questionnaire changes."
+            "The date  (and optionally time) when the questionnaire was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the questionnaire "
+            "changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -102,10 +120,10 @@ class Questionnaire(domainresource.DomainResource):
         None, alias="_date", title="Extension field for ``date``."
     )
 
-    derivedFrom: typing.List[fhirtypes.Canonical] = Field(
+    derivedFrom: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="derivedFrom",
-        title="Instantiates protocol or definition",
+        title="Based on Questionnaire",
         description="The URL of a Questionnaire that this Questionnaire is based on.",
         # if property is element of this resource.
         element_property=True,
@@ -150,7 +168,7 @@ class Questionnaire(domainresource.DomainResource):
         description=(
             "A Boolean value to indicate that this questionnaire is authored for "
             "testing purposes (or education/evaluation/marketing) and is not "
-            "intended to be used for genuine usage."
+            "intended for genuine usage."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -162,7 +180,7 @@ class Questionnaire(domainresource.DomainResource):
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
-        title="Additional identifier for the questionnaire",
+        title="Business identifier for questionnaire",
         description=(
             "A formal identifier that is used to identify this questionnaire when "
             "it is represented in other formats, or referenced in a specification, "
@@ -199,7 +217,7 @@ class Questionnaire(domainresource.DomainResource):
     lastReviewDate: fhirtypes.Date = Field(
         None,
         alias="lastReviewDate",
-        title="When the questionnaire was last reviewed",
+        title="When the questionnaire was last reviewed by the publisher",
         description=(
             "The date on which the resource content was last reviewed. Review "
             "happens periodically after approval but does not change the original "
@@ -231,10 +249,10 @@ class Questionnaire(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the "
-            "questionnaire."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the questionnaire."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -262,10 +280,7 @@ class Questionnaire(domainresource.DomainResource):
         None,
         alias="status",
         title="draft | active | retired | unknown",
-        description=(
-            "The status of this questionnaire. Enables tracking the life-cycle of "
-            "the content."
-        ),
+        description="The current state of this questionnaire.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -277,7 +292,7 @@ class Questionnaire(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    subjectType: typing.List[fhirtypes.Code] = Field(
+    subjectType: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="subjectType",
         title="Resource that can be subject of QuestionnaireResponse",
@@ -308,17 +323,17 @@ class Questionnaire(domainresource.DomainResource):
         None,
         alias="url",
         title=(
-            "Canonical identifier for this questionnaire, represented as a URI "
-            "(globally unique)"
+            "Canonical identifier for this questionnaire, represented as an "
+            "absolute URI (globally unique)"
         ),
         description=(
             "An absolute URI that is used to identify this questionnaire when it is"
             " referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this questionnaire is (or will be) published. This URL can"
-            " be the target of a canonical reference. It SHALL remain the same when"
-            " the questionnaire is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " questionnaire is (or will be) published. This URL can be the target "
+            "of a canonical reference. It SHALL remain the same when the "
+            "questionnaire is stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -336,7 +351,7 @@ class Questionnaire(domainresource.DomainResource):
             "contexts that are listed. These contexts may be general categories "
             "(gender, age, ...) or may be references to specific programs "
             "(insurance plans, studies, ...) and may be used to assist with "
-            "indexing and searching for appropriate questionnaire instances."
+            "indexing and searching for appropriate questionnaires."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -362,6 +377,41 @@ class Questionnaire(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -380,6 +430,8 @@ class Questionnaire(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "derivedFrom",
@@ -394,6 +446,7 @@ class Questionnaire(domainresource.DomainResource):
             "jurisdiction",
             "purpose",
             "copyright",
+            "copyrightLabel",
             "approvalDate",
             "lastReviewDate",
             "effectivePeriod",
@@ -460,6 +513,46 @@ class Questionnaire(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_1565(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class QuestionnaireItem(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -473,11 +566,32 @@ class QuestionnaireItem(backboneelement.BackboneElement):
 
     resource_type = Field("QuestionnaireItem", const=True)
 
+    answerConstraint: fhirtypes.Code = Field(
+        None,
+        alias="answerConstraint",
+        title="optionsOnly | optionsOrType | optionsOrString",
+        description=(
+            "For items that have a defined set of allowed answers (via answerOption"
+            " or answerValueSet), indicates whether values *other* than those "
+            "specified can be selected."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["optionsOnly", "optionsOrType", "optionsOrString"],
+    )
+    answerConstraint__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_answerConstraint",
+        title="Extension field for ``answerConstraint``.",
+    )
+
     answerOption: typing.List[fhirtypes.QuestionnaireItemAnswerOptionType] = Field(
         None,
         alias="answerOption",
         title="Permitted answer",
-        description='One of the permitted answers for a "choice" or "open-choice" question.',
+        description="One of the permitted answers for the question.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -485,10 +599,10 @@ class QuestionnaireItem(backboneelement.BackboneElement):
     answerValueSet: fhirtypes.Canonical = Field(
         None,
         alias="answerValueSet",
-        title="Valueset containing permitted answers",
+        title="ValueSet containing permitted answers",
         description=(
-            "A reference to a value set containing a list of codes representing "
-            'permitted answers for a "choice" or "open-choice" question.'
+            "A reference to a value set containing a list of values representing "
+            "permitted answers for a question."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -517,17 +631,12 @@ class QuestionnaireItem(backboneelement.BackboneElement):
         title="ElementDefinition - details for the item",
         description=(
             "This element is a URI that refers to an "
-            "[ElementDefinition](elementdefinition.html) that provides information "
-            "about this item, including information that might otherwise be "
-            "included in the instance of the Questionnaire resource. A detailed "
-            "description of the construction of the URI is shown in Comments, "
-            "below. If this element is present then the following element values "
-            "MAY be derived from the Element Definition if the corresponding "
-            "elements of this Questionnaire resource instance have no value:  * "
-            "code (ElementDefinition.code)  * type (ElementDefinition.type)  * "
-            "required (ElementDefinition.min)  * repeats (ElementDefinition.max)  *"
-            " maxLength (ElementDefinition.maxLength)  * answerValueSet "
-            "(ElementDefinition.binding) * options (ElementDefinition.binding)."
+            "[ElementDefinition](elementdefinition.html) or to an "
+            "[ObservationDefinition](observationdefinition.html) that provides "
+            "information about this item, including information that might "
+            "otherwise be included in the instance of the Questionnaire resource. A"
+            " detailed description of the construction of the URI is shown in "
+            "[Comments](questionnaire.html#definition), below."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -536,6 +645,24 @@ class QuestionnaireItem(backboneelement.BackboneElement):
         None, alias="_definition", title="Extension field for ``definition``."
     )
 
+    disabledDisplay: fhirtypes.Code = Field(
+        None,
+        alias="disabledDisplay",
+        title="hidden | protected",
+        description=(
+            "Indicates if and how items that are disabled (because enableWhen "
+            "evaluates to 'false') should be displayed."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["hidden", "protected"],
+    )
+    disabledDisplay__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_disabledDisplay", title="Extension field for ``disabledDisplay``."
+    )
+
     enableBehavior: fhirtypes.Code = Field(
         None,
         alias="enableBehavior",
@@ -610,7 +737,7 @@ class QuestionnaireItem(backboneelement.BackboneElement):
     maxLength: fhirtypes.Integer = Field(
         None,
         alias="maxLength",
-        title="No more than this many characters",
+        title="No more than these many characters",
         description=(
             "The maximum number of characters that are permitted in the answer to "
             'be considered a "valid" QuestionnaireResponse.'
@@ -658,9 +785,10 @@ class QuestionnaireItem(backboneelement.BackboneElement):
         alias="repeats",
         title="Whether the item may repeat",
         description=(
-            "An indication, if true, that the item may occur multiple times in the "
-            "response, collecting multiple answers for questions or multiple sets "
-            "of answers for groups."
+            "An indication, if true, that a QuestionnaireResponse for this item may"
+            " include multiple answers associated with a single instance of this "
+            "item (for question-type items) or multiple repetitions of the item "
+            "(for group-type items)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -707,7 +835,7 @@ class QuestionnaireItem(backboneelement.BackboneElement):
         description=(
             "The type of questionnaire item this is - whether text for display, a "
             "grouping of other items or a particular type of data to be captured "
-            "(string, integer, coded choice, etc.)."
+            "(string, integer, Coding, etc.)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -747,10 +875,12 @@ class QuestionnaireItem(backboneelement.BackboneElement):
             "type",
             "enableWhen",
             "enableBehavior",
+            "disabledDisplay",
             "required",
             "repeats",
             "readOnly",
             "maxLength",
+            "answerConstraint",
             "answerValueSet",
             "answerOption",
             "initial",
@@ -823,7 +953,7 @@ class QuestionnaireItemAnswerOption(backboneelement.BackboneElement):
     for FHIR Primitive Data Types.
 
     Permitted answer.
-    One of the permitted answers for a "choice" or "open-choice" question.
+    One of the permitted answers for the question.
     """
 
     resource_type = Field("QuestionnaireItemAnswerOption", const=True)
@@ -1015,7 +1145,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1033,7 +1166,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1048,7 +1184,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1066,7 +1205,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1084,7 +1226,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1102,7 +1247,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1120,7 +1268,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1135,7 +1286,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1152,7 +1306,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1170,7 +1327,10 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
         title="Value for question comparison based on operator",
         description=(
             "A value that the referenced question is tested using the specified "
-            "operator in order for the item to be enabled."
+            "operator in order for the item to be enabled.  If there are multiple "
+            "answers, a match on any of the answers suffices.  If different "
+            "behavior is desired (all must match, at least 2 must match, etc.), "
+            "consider using the enableWhenExpression extension."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1201,7 +1361,9 @@ class QuestionnaireItemEnableWhen(backboneelement.BackboneElement):
     question: fhirtypes.String = Field(
         None,
         alias="question",
-        title="Question that determines whether item is enabled",
+        title=(
+            "The linkId of question that determines whether item is " "enabled/disabled"
+        ),
         description=(
             "The linkId for the question whose answer (or lack of answer) governs "
             "whether this item is enabled."
