@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/QuestionnaireResponse
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -31,10 +31,10 @@ class QuestionnaireResponse(domainresource.DomainResource):
     author: fhirtypes.ReferenceType = Field(
         None,
         alias="author",
-        title="Person who received and recorded the answers",
+        title="The individual or device that received and recorded the answers",
         description=(
-            "Person who received the answers to the questions in the "
-            "QuestionnaireResponse and recorded them in the system."
+            "The individual or device that received the answers to the questions in"
+            " the QuestionnaireResponse and recorded them in the system."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -53,7 +53,10 @@ class QuestionnaireResponse(domainresource.DomainResource):
         None,
         alias="authored",
         title="Date the answers were gathered",
-        description="The date and/or time that this set of answers were last changed.",
+        description=(
+            "The date and/or time that this questionnaire response was last "
+            "modified by the user - e.g. changing answers or revising status."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -66,9 +69,9 @@ class QuestionnaireResponse(domainresource.DomainResource):
         alias="basedOn",
         title="Request fulfilled by this QuestionnaireResponse",
         description=(
-            "The order, proposal or plan that is fulfilled in whole or in part by "
-            "this QuestionnaireResponse.  For example, a ServiceRequest seeking an "
-            "intake assessment or a decision support recommendation to assess for "
+            "A plan, proposal or order that is fulfilled in whole or in part by "
+            "this questionnaire response.  For example, a ServiceRequest seeking an"
+            " intake assessment or a decision support recommendation to assess for "
             "post-partum depression."
         ),
         # if property is element of this resource.
@@ -80,7 +83,7 @@ class QuestionnaireResponse(domainresource.DomainResource):
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
-        title="Encounter created as part of",
+        title="Encounter the questionnaire response is part of",
         description=(
             "The Encounter during which this questionnaire response was created or "
             "to which the creation of this record is tightly associated."
@@ -91,13 +94,14 @@ class QuestionnaireResponse(domainresource.DomainResource):
         enum_reference_types=["Encounter"],
     )
 
-    identifier: fhirtypes.IdentifierType = Field(
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
-        title="Unique id for this set of answers",
+        title="Business identifier for this set of answers",
         description=(
-            "A business identifier assigned to a particular completed (or partially"
-            " completed) questionnaire."
+            "Business identifiers assigned to this questionnaire response by the "
+            "performer and/or other systems.  These identifiers remain constant as "
+            "the resource is updated and propagates from server to server."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -118,7 +122,7 @@ class QuestionnaireResponse(domainresource.DomainResource):
     partOf: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="partOf",
-        title="Part of this action",
+        title="Part of referenced event",
         description=(
             "A procedure or observation that this questionnaire was performed as "
             "part of the execution of.  For example, the surgery a checklist was "
@@ -133,13 +137,14 @@ class QuestionnaireResponse(domainresource.DomainResource):
     questionnaire: fhirtypes.Canonical = Field(
         None,
         alias="questionnaire",
-        title="Form being answered",
+        title="Canonical URL of Questionnaire being answered",
         description=(
             "The Questionnaire that defines and organizes the questions for which "
             "answers are being provided."
         ),
         # if property is element of this resource.
         element_property=True,
+        element_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Questionnaire"],
     )
@@ -150,12 +155,16 @@ class QuestionnaireResponse(domainresource.DomainResource):
     source: fhirtypes.ReferenceType = Field(
         None,
         alias="source",
-        title="The person who answered the questions",
-        description="The person who answered the questions about the subject.",
+        title="The individual or device that answered the questions",
+        description=(
+            "The individual or device that answered the questions about the " "subject."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
+            "Device",
+            "Organization",
             "Patient",
             "Practitioner",
             "PractitionerRole",
@@ -167,10 +176,7 @@ class QuestionnaireResponse(domainresource.DomainResource):
         None,
         alias="status",
         title="in-progress | completed | amended | entered-in-error | stopped",
-        description=(
-            "The position of the questionnaire response within its overall "
-            "lifecycle."
-        ),
+        description="The current state of the questionnaire response.",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
@@ -242,7 +248,10 @@ class QuestionnaireResponse(domainresource.DomainResource):
         data type mandatory, it is possible to provide an extension that explains why
         the primitive value is not present.
         """
-        required_fields = [("status", "status__ext")]
+        required_fields = [
+            ("questionnaire", "questionnaire__ext"),
+            ("status", "status__ext"),
+        ]
         _missing = object()
 
         def _fallback():
@@ -330,8 +339,8 @@ class QuestionnaireResponseItem(backboneelement.BackboneElement):
     item: typing.List[fhirtypes.QuestionnaireResponseItemType] = Field(
         None,
         alias="item",
-        title="Nested questionnaire response items",
-        description="Questions or sub-groups nested beneath a question or group.",
+        title="Child items of group item",
+        description="Sub-questions, sub-groups or display items nested beneath a group.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -458,7 +467,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
     item: typing.List[fhirtypes.QuestionnaireResponseItemType] = Field(
         None,
         alias="item",
-        title="Nested groups and questions",
+        title="Child items of question",
         description="Nested groups and/or questions found within this particular answer.",
         # if property is element of this resource.
         element_property=True,
@@ -476,7 +485,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
 
     valueBoolean: bool = Field(
@@ -491,7 +500,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueBoolean", title="Extension field for ``valueBoolean``."
@@ -509,7 +518,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
 
     valueDate: fhirtypes.Date = Field(
@@ -524,7 +533,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueDate", title="Extension field for ``valueDate``."
@@ -542,7 +551,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueDateTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueDateTime", title="Extension field for ``valueDateTime``."
@@ -560,7 +569,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueDecimal__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueDecimal", title="Extension field for ``valueDecimal``."
@@ -578,7 +587,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueInteger__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueInteger", title="Extension field for ``valueInteger``."
@@ -596,7 +605,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
 
     valueReference: fhirtypes.ReferenceType = Field(
@@ -611,7 +620,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Resource"],
     )
@@ -628,7 +637,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueString", title="Extension field for ``valueString``."
@@ -646,7 +655,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueTime", title="Extension field for ``valueTime``."
@@ -664,7 +673,7 @@ class QuestionnaireResponseItemAnswer(backboneelement.BackboneElement):
         element_property=True,
         # Choice of Data Types. i.e value[x]
         one_of_many="value",
-        one_of_many_required=False,
+        one_of_many_required=True,
     )
     valueUri__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_valueUri", title="Extension field for ``valueUri``."
