@@ -1,18 +1,18 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Reference
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 from pydantic import Field
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Reference(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+class Reference(datatype.DataType):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -78,7 +78,10 @@ class Reference(element.Element):
     type: fhirtypes.Uri = Field(
         None,
         alias="type",
-        title='Type the reference refers to (e.g. "Patient")',
+        title=(
+            'Type the reference refers to (e.g. "Patient") - must be a resource in '
+            "resources"
+        ),
         description=(
             "The expected type of the target of the reference. If both "
             "Reference.type and Reference.reference are populated and "
@@ -96,3 +99,11 @@ class Reference(element.Element):
     type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_type", title="Extension field for ``type``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Reference`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "reference", "type", "identifier", "display"]
