@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/RelatedArtifact
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,10 +12,10 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class RelatedArtifact(element.Element):
+class RelatedArtifact(datatype.DataType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -42,6 +42,15 @@ class RelatedArtifact(element.Element):
         None, alias="_citation", title="Extension field for ``citation``."
     )
 
+    classifier: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="classifier",
+        title="Additional classifiers",
+        description="Provides additional classifiers of the related artifact.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     display: fhirtypes.String = Field(
         None,
         alias="display",
@@ -84,12 +93,41 @@ class RelatedArtifact(element.Element):
         None, alias="_label", title="Extension field for ``label``."
     )
 
+    publicationDate: fhirtypes.Date = Field(
+        None,
+        alias="publicationDate",
+        title="Date of publication of the artifact being referred to",
+        description="The date of publication of the artifact being referred to.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    publicationDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_publicationDate", title="Extension field for ``publicationDate``."
+    )
+
+    publicationStatus: fhirtypes.Code = Field(
+        None,
+        alias="publicationStatus",
+        title="draft | active | retired | unknown",
+        description="The publication status of the artifact being referred to.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["draft", "active", "retired", "unknown"],
+    )
+    publicationStatus__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_publicationStatus",
+        title="Extension field for ``publicationStatus``.",
+    )
+
     resource: fhirtypes.Canonical = Field(
         None,
         alias="resource",
-        title="What resource is being referenced",
+        title="What artifact is being referenced",
         description=(
-            "The related resource, such as a library, value set, profile, or other "
+            "The related artifact, such as a library, value set, profile, or other "
             "knowledge resource."
         ),
         # if property is element of this resource.
@@ -101,12 +139,32 @@ class RelatedArtifact(element.Element):
         None, alias="_resource", title="Extension field for ``resource``."
     )
 
+    resourceReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="resourceReference",
+        title="What artifact, if not a conformance resource",
+        description=(
+            "The related artifact, if the artifact is not a canonical resource, or "
+            "a resource reference to a canonical resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
     type: fhirtypes.Code = Field(
         None,
         alias="type",
         title=(
             "documentation | justification | citation | predecessor | successor | "
-            "derived-from | depends-on | composed-of"
+            "derived-from | depends-on | composed-of | part-of | amends | amended-"
+            "with | appends | appended-with | cites | cited-by | comments-on | "
+            "comment-in | contains | contained-in | corrects | correction-in | "
+            "replaces | replaced-with | retracts | retracted-by | signs | similar-"
+            "to | supports | supported-with | transforms | transformed-into | "
+            "transformed-with | documents | specification-of | created-with | cite-"
+            "as"
         ),
         description="The type of relationship to the related artifact.",
         # if property is element of this resource.
@@ -123,27 +181,40 @@ class RelatedArtifact(element.Element):
             "derived-from",
             "depends-on",
             "composed-of",
+            "part-of",
+            "amends",
+            "amended-with",
+            "appends",
+            "appended-with",
+            "cites",
+            "cited-by",
+            "comments-on",
+            "comment-in",
+            "contains",
+            "contained-in",
+            "corrects",
+            "correction-in",
+            "replaces",
+            "replaced-with",
+            "retracts",
+            "retracted-by",
+            "signs",
+            "similar-to",
+            "supports",
+            "supported-with",
+            "transforms",
+            "transformed-into",
+            "transformed-with",
+            "documents",
+            "specification-of",
+            "created-with",
+            "cite-as",
         ],
     )
     type__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_type", title="Extension field for ``type``."
     )
 
-    url: fhirtypes.Url = Field(
-        None,
-        alias="url",
-        title="Where the artifact can be accessed",
-        description=(
-            "A url for the artifact that can be followed to access the actual "
-            "content."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-    url__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_url", title="Extension field for ``url``."
-    )
-
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -154,12 +225,15 @@ class RelatedArtifact(element.Element):
             "id",
             "extension",
             "type",
+            "classifier",
             "label",
             "display",
             "citation",
-            "url",
             "document",
             "resource",
+            "resourceReference",
+            "publicationStatus",
+            "publicationDate",
         ]
 
     @root_validator(pre=True, allow_reuse=True)
