@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/RelatedPerson
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -20,9 +20,9 @@ class RelatedPerson(domainresource.DomainResource):
 
     A person that is related to a patient, but who is not a direct target of
     care.
-    Information about a person that is involved in the care for a patient, but
-    who is not the target of healthcare, nor has a formal responsibility in the
-    care process.
+    Information about a person that is involved in a patient's health or the
+    care for a patient, but who is not the target of healthcare, nor has a
+    formal responsibility in the care process.
     """
 
     resource_type = Field("RelatedPerson", const=True)
@@ -64,8 +64,8 @@ class RelatedPerson(domainresource.DomainResource):
         None,
         alias="communication",
         title=(
-            "A language which may be used to communicate with about the patient's "
-            "health"
+            "A language which may be used to communicate with the related person "
+            "about the patient's health"
         ),
         description=None,
         # if property is element of this resource.
@@ -143,10 +143,10 @@ class RelatedPerson(domainresource.DomainResource):
     relationship: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="relationship",
-        title="The nature of the relationship",
+        title="The relationship of the related person to the patient",
         description=(
-            "The nature of the relationship between a patient and the related "
-            "person."
+            "The nature of the relationship between the related person and the "
+            "patient."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -199,7 +199,8 @@ class RelatedPersonCommunication(backboneelement.BackboneElement):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    A language which may be used to communicate with about the patient's health.
+    A language which may be used to communicate with the related person about
+    the patient's health.
     """
 
     resource_type = Field("RelatedPersonCommunication", const=True)
@@ -208,14 +209,14 @@ class RelatedPersonCommunication(backboneelement.BackboneElement):
         ...,
         alias="language",
         title=(
-            "The language which can be used to communicate with the patient about "
-            "his or her health"
+            "The language which can be used to communicate with the related person "
+            "about the patient's health"
         ),
         description=(
             "The ISO-639-1 alpha 2 code in lower case for the language, optionally "
             "followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in"
             ' upper case; e.g. "en" for English, or "en-US" for American English '
-            'versus "en-EN" for England English.'
+            'versus "en-AU" for Australian English.'
         ),
         # if property is element of this resource.
         element_property=True,
@@ -226,8 +227,8 @@ class RelatedPersonCommunication(backboneelement.BackboneElement):
         alias="preferred",
         title="Language preference indicator",
         description=(
-            "Indicates whether or not the patient prefers this language (over other"
-            " languages he masters up a certain level)."
+            "Indicates whether or not the related person prefers this language "
+            "(over other languages he or she masters up a certain level)."
         ),
         # if property is element of this resource.
         element_property=True,
