@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ResearchSubject
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,7 +12,7 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import domainresource, fhirtypes
+from . import backboneelement, domainresource, fhirtypes
 
 
 class ResearchSubject(domainresource.DomainResource):
@@ -20,16 +20,17 @@ class ResearchSubject(domainresource.DomainResource):
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
-    Physical entity which is the primary unit of interest in the study.
-    A physical entity which is the primary unit of operational and/or
-    administrative interest in a study.
+    Participant or object which is the recipient of investigative activities in
+    a study.
+    A ResearchSubject is a participant or object which is the recipient of
+    investigative activities in a research study.
     """
 
     resource_type = Field("ResearchSubject", const=True)
 
-    actualArm: fhirtypes.String = Field(
+    actualComparisonGroup: fhirtypes.Id = Field(
         None,
-        alias="actualArm",
+        alias="actualComparisonGroup",
         title="What path was followed",
         description=(
             "The name of the arm in the study the subject actually followed as part"
@@ -38,13 +39,15 @@ class ResearchSubject(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
     )
-    actualArm__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_actualArm", title="Extension field for ``actualArm``."
+    actualComparisonGroup__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_actualComparisonGroup",
+        title="Extension field for ``actualComparisonGroup``.",
     )
 
-    assignedArm: fhirtypes.String = Field(
+    assignedComparisonGroup: fhirtypes.Id = Field(
         None,
-        alias="assignedArm",
+        alias="assignedComparisonGroup",
         title="What path should be followed",
         description=(
             "The name of the arm in the study the subject is expected to follow as "
@@ -53,11 +56,13 @@ class ResearchSubject(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
     )
-    assignedArm__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_assignedArm", title="Extension field for ``assignedArm``."
+    assignedComparisonGroup__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_assignedComparisonGroup",
+        title="Extension field for ``assignedComparisonGroup``.",
     )
 
-    consent: fhirtypes.ReferenceType = Field(
+    consent: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="consent",
         title="Agreement to participate in study",
@@ -80,17 +85,6 @@ class ResearchSubject(domainresource.DomainResource):
         element_property=True,
     )
 
-    individual: fhirtypes.ReferenceType = Field(
-        ...,
-        alias="individual",
-        title="Who is part of study",
-        description="The record of the person or animal who is involved in the study.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient"],
-    )
-
     period: fhirtypes.PeriodType = Field(
         None,
         alias="period",
@@ -102,35 +96,29 @@ class ResearchSubject(domainresource.DomainResource):
         element_property=True,
     )
 
+    progress: typing.List[fhirtypes.ResearchSubjectProgressType] = Field(
+        None,
+        alias="progress",
+        title="Subject status",
+        description=(
+            "The current state (status) of the subject and resons for status change"
+            " where appropriate."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
-        title=(
-            "candidate | eligible | follow-up | ineligible | not-registered | off-"
-            "study | on-study | on-study-intervention | on-study-observation | "
-            "pending-on-study | potential-candidate | screening | withdrawn"
-        ),
-        description="The current state of the subject.",
+        title="draft | active | retired | unknown",
+        description="The publication state of the resource (not of the subject).",
         # if property is element of this resource.
         element_property=True,
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "candidate",
-            "eligible",
-            "follow-up",
-            "ineligible",
-            "not-registered",
-            "off-study",
-            "on-study",
-            "on-study-intervention",
-            "on-study-observation",
-            "pending-on-study",
-            "potential-candidate",
-            "screening",
-            "withdrawn",
-        ],
+        enum_values=["draft", "active", "retired", "unknown"],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_status", title="Extension field for ``status``."
@@ -147,6 +135,27 @@ class ResearchSubject(domainresource.DomainResource):
         enum_reference_types=["ResearchStudy"],
     )
 
+    subject: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="subject",
+        title="Who or what is part of study",
+        description=(
+            "The record of the person, animal or other entity involved in the " "study."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "Specimen",
+            "Device",
+            "Medication",
+            "Substance",
+            "BiologicallyDerivedProduct",
+        ],
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -164,11 +173,12 @@ class ResearchSubject(domainresource.DomainResource):
             "modifierExtension",
             "identifier",
             "status",
+            "progress",
             "period",
             "study",
-            "individual",
-            "assignedArm",
-            "actualArm",
+            "subject",
+            "assignedComparisonGroup",
+            "actualComparisonGroup",
             "consent",
         ]
 
@@ -230,3 +240,104 @@ class ResearchSubject(domainresource.DomainResource):
             raise ValidationError(errors, cls)  # type: ignore
 
         return values
+
+
+class ResearchSubjectProgress(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Subject status.
+    The current state (status) of the subject and resons for status change
+    where appropriate.
+    """
+
+    resource_type = Field("ResearchSubjectProgress", const=True)
+
+    endDate: fhirtypes.DateTime = Field(
+        None,
+        alias="endDate",
+        title="State change date",
+        description="The date when the state ended.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    endDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_endDate", title="Extension field for ``endDate``."
+    )
+
+    milestone: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="milestone",
+        title="SignedUp | Screened | Randomized",
+        description="The milestones the subject has passed through.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    reason: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="reason",
+        title="State change reason",
+        description=(
+            "The reason for the state change.  If coded it should follow the formal"
+            " subject state model."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    startDate: fhirtypes.DateTime = Field(
+        None,
+        alias="startDate",
+        title="State change date",
+        description="The date when the new status started.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    startDate__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_startDate", title="Extension field for ``startDate``."
+    )
+
+    subjectState: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="subjectState",
+        title=(
+            "candidate | eligible | follow-up | ineligible | not-registered | off-"
+            "study | on-study | on-study-intervention | on-study-observation | "
+            "pending-on-study | potential-candidate | screening | withdrawn"
+        ),
+        description="The current state of the subject.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    type: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="type",
+        title="state | milestone",
+        description=(
+            "Identifies the aspect of the subject's journey that the state refers "
+            "to."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ResearchSubjectProgress`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "subjectState",
+            "milestone",
+            "reason",
+            "startDate",
+            "endDate",
+        ]
