@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/RiskAssessment
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -175,11 +175,20 @@ class RiskAssessment(domainresource.DomainResource):
         None,
         alias="performer",
         title="Who did assessment?",
-        description="The provider or software application that performed the assessment.",
+        description=(
+            "The provider, patient, related person, or software application that "
+            "performed the assessment."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole", "Device"],
+        enum_reference_types=[
+            "Patient",
+            "Practitioner",
+            "PractitionerRole",
+            "RelatedPerson",
+            "Device",
+        ],
     )
 
     prediction: typing.List[fhirtypes.RiskAssessmentPredictionType] = Field(
@@ -191,22 +200,13 @@ class RiskAssessment(domainresource.DomainResource):
         element_property=True,
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Why the assessment was necessary?",
         description="The reason the risk assessment was performed.",
         # if property is element of this resource.
         element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Why the assessment was necessary?",
-        description="Resources supporting the reason the risk assessment was performed.",
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Condition",
@@ -273,8 +273,7 @@ class RiskAssessment(domainresource.DomainResource):
             "occurrencePeriod",
             "condition",
             "performer",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "basis",
             "prediction",
             "mitigation",
