@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/SearchParameter
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -66,10 +66,13 @@ class SearchParameter(domainresource.DomainResource):
     code: fhirtypes.Code = Field(
         None,
         alias="code",
-        title="Code used in URL",
+        title="Recommended name for parameter in search url",
         description=(
-            "The code used in the URL or the parameter name in a parameters "
-            "resource for this search parameter."
+            "The label that is recommended to be used in the URL or the parameter "
+            "name in a parameters resource for this search parameter.  In some "
+            "cases, servers may need to use a different CapabilityStatement "
+            "searchParam.name to differentiate between multiple SearchParameters "
+            "that happen to have the same code."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -103,6 +106,21 @@ class SearchParameter(domainresource.DomainResource):
         element_property=True,
     )
 
+    constraint: fhirtypes.String = Field(
+        None,
+        alias="constraint",
+        title="FHIRPath expression that constraints the usage of this SearchParamete",
+        description=(
+            "FHIRPath expression that defines/sets a complex constraint for when "
+            "this SearchParameter is applicable."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    constraint__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_constraint", title="Extension field for ``constraint``."
+    )
+
     contact: typing.List[fhirtypes.ContactDetailType] = Field(
         None,
         alias="contact",
@@ -115,15 +133,49 @@ class SearchParameter(domainresource.DomainResource):
         element_property=True,
     )
 
+    copyright: fhirtypes.Markdown = Field(
+        None,
+        alias="copyright",
+        title="Use and/or publishing restrictions",
+        description=(
+            "A copyright statement relating to the search parameter and/or its "
+            "contents. Copyright statements are generally legal restrictions on the"
+            " use and publishing of the search parameter."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyright__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyright", title="Extension field for ``copyright``."
+    )
+
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the search parameter was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the search parameter changes."
+            "The date  (and optionally time) when the search parameter was last "
+            "significantly changed. The date must change when the business version "
+            "changes and it must change if the status code changes. In addition, it"
+            " should change when the substantive content of the search parameter "
+            "changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -196,6 +248,19 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_expression", title="Extension field for ``expression``."
     )
 
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title="Additional identifier for the search parameter (business identifier)",
+        description=(
+            "A formal identifier that is used to identify this search parameter "
+            "when it is represented in other formats, or referenced in a "
+            "specification, model, design or an instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     jurisdiction: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="jurisdiction",
@@ -213,7 +278,7 @@ class SearchParameter(domainresource.DomainResource):
         alias="modifier",
         title=(
             "missing | exact | contains | not | text | in | not-in | below | above "
-            "| type | identifier | ofType"
+            "| type | identifier | of-type | code-text | text-advanced | iterate"
         ),
         description="A modifier supported for the search parameter.",
         # if property is element of this resource.
@@ -232,7 +297,10 @@ class SearchParameter(domainresource.DomainResource):
             "above",
             "type",
             "identifier",
-            "ofType",
+            "of-type",
+            "code-text",
+            "text-advanced",
+            "iterate",
         ],
     )
     modifier__ext: typing.List[
@@ -287,13 +355,31 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
+    processingMode: fhirtypes.Code = Field(
+        None,
+        alias="processingMode",
+        title="normal | phonetic | other",
+        description=(
+            "How the search parameter relates to the set of elements returned by "
+            "evaluating the expression query."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["normal", "phonetic", "other"],
+    )
+    processingMode__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_processingMode", title="Extension field for ``processingMode``."
+    )
+
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the search "
-            "parameter."
+            "The name of the organization or individual tresponsible for the "
+            "release and ongoing maintenance of the search parameter."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -348,6 +434,18 @@ class SearchParameter(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_target", title="Extension field for ``target``.")
 
+    title: fhirtypes.String = Field(
+        None,
+        alias="title",
+        title="Name for this search parameter (human friendly)",
+        description="A short, descriptive, user-friendly title for the search parameter.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+    title__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_title", title="Extension field for ``title``."
+    )
+
     type: fhirtypes.Code = Field(
         None,
         alias="type",
@@ -391,10 +489,10 @@ class SearchParameter(domainresource.DomainResource):
             "An absolute URI that is used to identify this search parameter when it"
             " is referenced in a specification, model, design or an instance; also "
             "called its canonical identifier. This SHOULD be globally unique and "
-            "SHOULD be a literal address at which at which an authoritative "
-            "instance of this search parameter is (or will be) published. This URL "
-            "can be the target of a canonical reference. It SHALL remain the same "
-            "when the search parameter is stored on different servers."
+            "SHOULD be a literal address at which an authoritative instance of this"
+            " search parameter is (or will be) published. This URL can be the "
+            "target of a canonical reference. It SHALL remain the same when the "
+            "search parameter is stored on different servers."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -439,37 +537,39 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
-    xpath: fhirtypes.String = Field(
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
         None,
-        alias="xpath",
-        title="XPath that extracts the values",
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
         description=(
-            "An XPath expression that returns a set of elements for the search "
-            "parameter."
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-    xpath__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_xpath", title="Extension field for ``xpath``."
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
     )
 
-    xpathUsage: fhirtypes.Code = Field(
+    versionAlgorithmString: fhirtypes.String = Field(
         None,
-        alias="xpathUsage",
-        title="normal | phonetic | nearby | distance | other",
+        alias="versionAlgorithmString",
+        title="How to compare versions",
         description=(
-            "How the search parameter relates to the set of elements returned by "
-            "evaluating the xpath query."
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
         ),
         # if property is element of this resource.
         element_property=True,
-        # note: Enum values can be used in validation,
-        # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["normal", "phonetic", "nearby", "distance", "other"],
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
     )
-    xpathUsage__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_xpathUsage", title="Extension field for ``xpathUsage``."
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
     )
 
     @classmethod
@@ -488,8 +588,12 @@ class SearchParameter(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "url",
+            "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
+            "title",
             "derivedFrom",
             "status",
             "experimental",
@@ -500,12 +604,14 @@ class SearchParameter(domainresource.DomainResource):
             "useContext",
             "jurisdiction",
             "purpose",
+            "copyright",
+            "copyrightLabel",
             "code",
             "base",
             "type",
             "expression",
-            "xpath",
-            "xpathUsage",
+            "processingMode",
+            "constraint",
             "target",
             "multipleOr",
             "multipleAnd",
@@ -582,6 +688,46 @@ class SearchParameter(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_1724(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class SearchParameterComponent(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
