@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ServiceRequest
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -12,11 +12,11 @@ from pydantic import Field, root_validator
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.errors import MissingError, NoneIsNotAllowedError
 
-from . import domainresource, fhirtypes
+from . import backboneelement, domainresource, fhirtypes
 
 
 class ServiceRequest(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -86,7 +86,7 @@ class ServiceRequest(domainresource.DomainResource):
     bodySite: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="bodySite",
-        title="Location on Body",
+        title="Coded location on Body",
         description=(
             "Anatomic location where the procedure should be performed. This is the"
             " target site."
@@ -95,6 +95,20 @@ class ServiceRequest(domainresource.DomainResource):
         element_property=True,
     )
 
+    bodyStructure: fhirtypes.ReferenceType = Field(
+        None,
+        alias="bodyStructure",
+        title="BodyStructure-based location on the body",
+        description=(
+            "Anatomic location where the procedure should be performed. This is the"
+            " target site."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["BodyStructure"],
+    )
+
     category: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="category",
@@ -107,17 +121,19 @@ class ServiceRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    code: fhirtypes.CodeableConceptType = Field(
+    code: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="code",
         title="What is being requested/ordered",
         description=(
-            "A code that identifies a particular service (i.e., procedure, "
-            "diagnostic investigation, or panel of investigations) that have been "
-            "requested."
+            "A code or reference that identifies a particular service (i.e., "
+            "procedure, diagnostic investigation, or panel of investigations) that "
+            "have been requested."
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["ActivityDefinition", "PlanDefinition"],
     )
 
     doNotPerform: bool = Field(
@@ -149,6 +165,27 @@ class ServiceRequest(domainresource.DomainResource):
         enum_reference_types=["Encounter"],
     )
 
+    focus: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="focus",
+        title=(
+            "What the service request is about, when it is not about the subject of"
+            " record"
+        ),
+        description=(
+            "The actual focus of a service request when it is not the subject of "
+            "record representing something or someone associated with the subject "
+            "such as a spouse, parent, fetus, or donor. The focus of a service "
+            "request could also be an existing condition,  an intervention, the "
+            "subject's diet,  another service request on the subject,  or a body "
+            "structure such as tumor or implanted device."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -161,7 +198,7 @@ class ServiceRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -183,7 +220,7 @@ class ServiceRequest(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
@@ -219,10 +256,7 @@ class ServiceRequest(domainresource.DomainResource):
     intent: fhirtypes.Code = Field(
         None,
         alias="intent",
-        title=(
-            "proposal | plan | directive | order | original-order | reflex-order | "
-            "filler-order | instance-order | option"
-        ),
+        title="proposal | plan | directive | order +",
         description=(
             "Whether the request is a proposal, plan, an original order or a reflex"
             " order."
@@ -232,25 +266,15 @@ class ServiceRequest(domainresource.DomainResource):
         element_required=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=[
-            "proposal",
-            "plan",
-            "directive",
-            "order",
-            "original-order",
-            "reflex-order",
-            "filler-order",
-            "instance-order",
-            "option",
-        ],
+        enum_values=["proposal", "plan", "directive", "order", "+"],
     )
     intent__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_intent", title="Extension field for ``intent``."
     )
 
-    locationCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    location: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="locationCode",
+        alias="location",
         title="Requested location",
         description=(
             "The preferred location(s) where the procedure should actually happen "
@@ -258,18 +282,6 @@ class ServiceRequest(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-
-    locationReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="locationReference",
-        title="Requested location",
-        description=(
-            "A reference to the the preferred location(s) where the procedure "
-            "should actually happen. E.g. at home or nursing day care center."
-        ),
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Location"],
     )
@@ -327,7 +339,7 @@ class ServiceRequest(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
-    orderDetail: typing.List[fhirtypes.CodeableConceptType] = Field(
+    orderDetail: typing.List[fhirtypes.ServiceRequestOrderDetailType] = Field(
         None,
         alias="orderDetail",
         title="Additional order information",
@@ -342,7 +354,9 @@ class ServiceRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    patientInstruction: fhirtypes.String = Field(
+    patientInstruction: typing.List[
+        fhirtypes.ServiceRequestPatientInstructionType
+    ] = Field(
         None,
         alias="patientInstruction",
         title="Patient or consumer-oriented instructions",
@@ -350,11 +364,6 @@ class ServiceRequest(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
     )
-    patientInstruction__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None,
-        alias="_patientInstruction",
-        title="Extension field for ``patientInstruction``.",
-    )
 
     performer: typing.List[fhirtypes.ReferenceType] = Field(
         None,
@@ -454,9 +463,9 @@ class ServiceRequest(domainresource.DomainResource):
         one_of_many_required=False,
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Explanation/Justification for procedure or service",
         description=(
             "An explanation or justification for why this service is being "
@@ -466,25 +475,13 @@ class ServiceRequest(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
-        title="Explanation/Justification for service or service",
-        description=(
-            "Indicates another resource that provides a justification for why this "
-            "service is being requested.   May relate to the resources referred to "
-            "in `supportingInfo`."
-        ),
-        # if property is element of this resource.
-        element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=[
             "Condition",
             "Observation",
             "DiagnosticReport",
             "DocumentReference",
+            "DetectedIssue",
         ],
     )
 
@@ -601,7 +598,7 @@ class ServiceRequest(domainresource.DomainResource):
         enum_reference_types=["Patient", "Group", "Location", "Device"],
     )
 
-    supportingInfo: typing.List[fhirtypes.ReferenceType] = Field(
+    supportingInfo: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
         alias="supportingInfo",
         title="Additional clinical information",
@@ -621,6 +618,61 @@ class ServiceRequest(domainresource.DomainResource):
         enum_reference_types=["Resource"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ServiceRequest`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "instantiatesCanonical",
+            "instantiatesUri",
+            "basedOn",
+            "replaces",
+            "requisition",
+            "status",
+            "intent",
+            "category",
+            "priority",
+            "doNotPerform",
+            "code",
+            "orderDetail",
+            "quantityQuantity",
+            "quantityRatio",
+            "quantityRange",
+            "subject",
+            "focus",
+            "encounter",
+            "occurrenceDateTime",
+            "occurrencePeriod",
+            "occurrenceTiming",
+            "asNeededBoolean",
+            "asNeededCodeableConcept",
+            "authoredOn",
+            "requester",
+            "performerType",
+            "performer",
+            "location",
+            "reason",
+            "insurance",
+            "supportingInfo",
+            "specimen",
+            "bodySite",
+            "bodyStructure",
+            "note",
+            "patientInstruction",
+            "relevantHistory",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1665(
         cls, values: typing.Dict[str, typing.Any]
@@ -725,3 +777,335 @@ class ServiceRequest(domainresource.DomainResource):
                 raise ValueError(f"Expect any of field value from this list {fields}.")
 
         return values
+
+
+class ServiceRequestOrderDetail(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Additional order information.
+    Additional details and instructions about the how the services are to be
+    delivered.   For example, and order for a urinary catheter may have an
+    order detail for an external or indwelling catheter, or an order for a
+    bandage may require additional instructions specifying how the bandage
+    should be applied.
+    """
+
+    resource_type = Field("ServiceRequestOrderDetail", const=True)
+
+    parameter: typing.List[fhirtypes.ServiceRequestOrderDetailParameterType] = Field(
+        ...,
+        alias="parameter",
+        title="The parameter details for the service being requested",
+        description=None,
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    parameterFocus: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="parameterFocus",
+        title="The context of the order details by reference",
+        description="Indicates the context of the order details by reference.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Device",
+            "DeviceDefinition",
+            "DeviceRequest",
+            "SupplyRequest",
+            "Medication",
+            "MedicationRequest",
+            "BiologicallyDerivedProduct",
+            "Substance",
+        ],
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ServiceRequestOrderDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "parameterFocus", "parameter"]
+
+
+class ServiceRequestOrderDetailParameter(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    The parameter details for the service being requested.
+    """
+
+    resource_type = Field("ServiceRequestOrderDetailParameter", const=True)
+
+    code: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="code",
+        title="The detail of the order being requested",
+        description=(
+            "A value representing the additional detail or instructions for the "
+            "order (e.g., catheter insertion, body elevation, descriptive device "
+            "configuration and/or setting instructions)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    valueBoolean: bool = Field(
+        None,
+        alias="valueBoolean",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueBoolean__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueBoolean", title="Extension field for ``valueBoolean``."
+    )
+
+    valueCodeableConcept: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="valueCodeableConcept",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valuePeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="valuePeriod",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueQuantity: fhirtypes.QuantityType = Field(
+        None,
+        alias="valueQuantity",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueRange: fhirtypes.RangeType = Field(
+        None,
+        alias="valueRange",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueRatio: fhirtypes.RatioType = Field(
+        None,
+        alias="valueRatio",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
+    valueString: fhirtypes.String = Field(
+        None,
+        alias="valueString",
+        title="The value for the order detail",
+        description="Indicates a value for the order detail.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueString", title="Extension field for ``valueString``."
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ServiceRequestOrderDetailParameter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "valueQuantity",
+            "valueRatio",
+            "valueRange",
+            "valueBoolean",
+            "valueCodeableConcept",
+            "valueString",
+            "valuePeriod",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_3695(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "value": [
+                "valueBoolean",
+                "valueCodeableConcept",
+                "valuePeriod",
+                "valueQuantity",
+                "valueRange",
+                "valueRatio",
+                "valueString",
+            ]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
+
+class ServiceRequestPatientInstruction(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Patient or consumer-oriented instructions.
+    Instructions in terms that are understood by the patient or consumer.
+    """
+
+    resource_type = Field("ServiceRequestPatientInstruction", const=True)
+
+    instructionMarkdown: fhirtypes.Markdown = Field(
+        None,
+        alias="instructionMarkdown",
+        title="Patient or consumer-oriented instructions",
+        description="Instructions in terms that are understood by the patient or consumer.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e instruction[x]
+        one_of_many="instruction",
+        one_of_many_required=False,
+    )
+    instructionMarkdown__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_instructionMarkdown",
+        title="Extension field for ``instructionMarkdown``.",
+    )
+
+    instructionReference: fhirtypes.ReferenceType = Field(
+        None,
+        alias="instructionReference",
+        title="Patient or consumer-oriented instructions",
+        description="Instructions in terms that are understood by the patient or consumer.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e instruction[x]
+        one_of_many="instruction",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["DocumentReference"],
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ServiceRequestPatientInstruction`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "instructionMarkdown",
+            "instructionReference",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_3570(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "instruction": ["instructionMarkdown", "instructionReference"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
