@@ -1,22 +1,20 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Signature
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
-from pydantic import Field, root_validator
-from pydantic.error_wrappers import ErrorWrapper, ValidationError
-from pydantic.errors import MissingError, NoneIsNotAllowedError
+from pydantic import Field
 
-from . import element, fhirtypes
+from . import datatype, fhirtypes
 
 
-class Signature(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+class Signature(datatype.DataType):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -99,7 +97,7 @@ class Signature(element.Element):
     )
 
     type: typing.List[fhirtypes.CodingType] = Field(
-        ...,
+        None,
         alias="type",
         title="Indication of the reason the entity signed the object(s)",
         description=(
@@ -119,14 +117,13 @@ class Signature(element.Element):
         description="When the digital signature was signed.",
         # if property is element of this resource.
         element_property=True,
-        element_required=True,
     )
     when__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_when", title="Extension field for ``when``."
     )
 
     who: fhirtypes.ReferenceType = Field(
-        ...,
+        None,
         alias="who",
         title="Who signed",
         description=(
@@ -146,61 +143,20 @@ class Signature(element.Element):
         ],
     )
 
-    @root_validator(pre=True, allow_reuse=True)
-    def validate_required_primitive_elements_1130(
-        cls, values: typing.Dict[str, typing.Any]
-    ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/extensibility.html#Special-Case
-        In some cases, implementers might find that they do not have appropriate data for
-        an element with minimum cardinality = 1. In this case, the element must be present,
-        but unless the resource or a profile on it has made the actual value of the primitive
-        data type mandatory, it is possible to provide an extension that explains why
-        the primitive value is not present.
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Signature`` according specification,
+        with preserving original sequence order.
         """
-        required_fields = [("when", "when__ext")]
-        _missing = object()
-
-        def _fallback():
-            return ""
-
-        errors: typing.List["ErrorWrapper"] = []
-        for name, ext in required_fields:
-            field = cls.__fields__[name]
-            ext_field = cls.__fields__[ext]
-            value = values.get(field.alias, _missing)
-            if value not in (_missing, None):
-                continue
-            ext_value = values.get(ext_field.alias, _missing)
-            missing_ext = True
-            if ext_value not in (_missing, None):
-                if isinstance(ext_value, dict):
-                    missing_ext = len(ext_value.get("extension", [])) == 0
-                elif (
-                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
-                    == "FHIRPrimitiveExtension"
-                ):
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-                else:
-                    validate_pass = True
-                    for validator in ext_field.type_.__get_validators__():
-                        try:
-                            ext_value = validator(v=ext_value)
-                        except ValidationError as exc:
-                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
-                            validate_pass = False
-                    if not validate_pass:
-                        continue
-                    if ext_value.extension and len(ext_value.extension) > 0:
-                        missing_ext = False
-            if missing_ext:
-                if value is _missing:
-                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
-                else:
-                    errors.append(
-                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
-                    )
-        if len(errors) > 0:
-            raise ValidationError(errors, cls)  # type: ignore
-
-        return values
+        return [
+            "id",
+            "extension",
+            "type",
+            "when",
+            "who",
+            "onBehalfOf",
+            "targetFormat",
+            "sigFormat",
+            "data",
+        ]
