@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Specimen
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
 from pydantic import Field, root_validator
+from pydantic.error_wrappers import ErrorWrapper, ValidationError
+from pydantic.errors import MissingError, NoneIsNotAllowedError
 
 from . import backboneelement, domainresource, fhirtypes
 
@@ -46,6 +48,21 @@ class Specimen(domainresource.DomainResource):
         element_property=True,
     )
 
+    combined: fhirtypes.Code = Field(
+        None,
+        alias="combined",
+        title="grouped | pooled",
+        description="This element signifies if the specimen is part of a group or pooled.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["grouped", "pooled"],
+    )
+    combined__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_combined", title="Extension field for ``combined``."
+    )
+
     condition: typing.List[fhirtypes.CodeableConceptType] = Field(
         None,
         alias="condition",
@@ -67,6 +84,21 @@ class Specimen(domainresource.DomainResource):
         element_property=True,
     )
 
+    feature: typing.List[fhirtypes.SpecimenFeatureType] = Field(
+        None,
+        alias="feature",
+        title="The physical feature of a specimen",
+        description=(
+            "A physical feature or landmark on a specimen, highlighted for context "
+            "by the collector of the specimen (e.g. surgeon), that identifies the "
+            "type of feature as well as its meaning (e.g. the red ink indicating "
+            "the resection margin of the right lobe of the excised prostate tissue "
+            "or wire loop at radiologically suspected tumor location)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
         None,
         alias="identifier",
@@ -115,8 +147,11 @@ class Specimen(domainresource.DomainResource):
     receivedTime: fhirtypes.DateTime = Field(
         None,
         alias="receivedTime",
-        title="The time when specimen was received for processing",
-        description="Time when specimen was received for processing or testing.",
+        title="The time when specimen is received by the testing laboratory",
+        description=(
+            "Time when specimen is received by the testing laboratory for "
+            "processing or testing."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -138,6 +173,15 @@ class Specimen(domainresource.DomainResource):
         enum_reference_types=["ServiceRequest"],
     )
 
+    role: typing.List[fhirtypes.CodeableConceptType] = Field(
+        None,
+        alias="role",
+        title="The role the specimen serves",
+        description="The role or reason for the specimen in the testing workflow.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     status: fhirtypes.Code = Field(
         None,
         alias="status",
@@ -159,13 +203,20 @@ class Specimen(domainresource.DomainResource):
         title=(
             "Where the specimen came from. This may be from patient(s), from a "
             "location (e.g., the source of an environmental sample), or a sampling "
-            "of a substance or a device"
+            "of a substance, a biologically-derived product, or a device"
         ),
         description=None,
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Patient", "Group", "Device", "Substance", "Location"],
+        enum_reference_types=[
+            "Patient",
+            "Group",
+            "Device",
+            "BiologicallyDerivedProduct",
+            "Substance",
+            "Location",
+        ],
     )
 
     type: fhirtypes.CodeableConceptType = Field(
@@ -200,6 +251,9 @@ class Specimen(domainresource.DomainResource):
             "receivedTime",
             "parent",
             "request",
+            "combined",
+            "role",
+            "feature",
             "collection",
             "processing",
             "container",
@@ -219,7 +273,7 @@ class SpecimenCollection(backboneelement.BackboneElement):
 
     resource_type = Field("SpecimenCollection", const=True)
 
-    bodySite: fhirtypes.CodeableConceptType = Field(
+    bodySite: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="bodySite",
         title="Anatomical collection site",
@@ -230,6 +284,8 @@ class SpecimenCollection(backboneelement.BackboneElement):
         ),
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["BodyStructure"],
     )
 
     collectedDateTime: fhirtypes.DateTime = Field(
@@ -275,7 +331,26 @@ class SpecimenCollection(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Practitioner", "PractitionerRole"],
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Patient",
+            "RelatedPerson",
+        ],
+    )
+
+    device: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="device",
+        title="Device used to perform collection",
+        description=(
+            "A coded value specifying the technique that is used to perform the "
+            "procedure."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Device"],
     )
 
     duration: fhirtypes.DurationType = Field(
@@ -329,6 +404,20 @@ class SpecimenCollection(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    procedure: fhirtypes.ReferenceType = Field(
+        None,
+        alias="procedure",
+        title="The procedure that collects the specimen",
+        description=(
+            "The procedure event during which the specimen was collected (e.g. the "
+            "surgery leading to the collection of a pathology sample)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Procedure"],
+    )
+
     quantity: fhirtypes.QuantityType = Field(
         None,
         alias="quantity",
@@ -357,6 +446,8 @@ class SpecimenCollection(backboneelement.BackboneElement):
             "duration",
             "quantity",
             "method",
+            "device",
+            "procedure",
             "bodySite",
             "fastingStatusCodeableConcept",
             "fastingStatusDuration",
@@ -416,70 +507,30 @@ class SpecimenContainer(backboneelement.BackboneElement):
 
     resource_type = Field("SpecimenContainer", const=True)
 
-    additiveCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="additiveCodeableConcept",
-        title="Additive associated with container",
+    device: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="device",
+        title="Device resource for the container",
         description=(
-            "Introduced substance to preserve, maintain or enhance the specimen. "
-            "Examples: Formalin, Citrate, EDTA."
+            "The device resource for the the container holding the specimen. If the"
+            " container is in a holder then the referenced device will point to a "
+            "parent device."
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e additive[x]
-        one_of_many="additive",
-        one_of_many_required=False,
-    )
-
-    additiveReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="additiveReference",
-        title="Additive associated with container",
-        description=(
-            "Introduced substance to preserve, maintain or enhance the specimen. "
-            "Examples: Formalin, Citrate, EDTA."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e additive[x]
-        one_of_many="additive",
-        one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Substance"],
+        enum_reference_types=["Device"],
     )
 
-    capacity: fhirtypes.QuantityType = Field(
+    location: fhirtypes.ReferenceType = Field(
         None,
-        alias="capacity",
-        title="Container volume or size",
-        description="The capacity (volume or other measure) the container may contain.",
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    description: fhirtypes.String = Field(
-        None,
-        alias="description",
-        title="Textual description of the container",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
-        None, alias="_description", title="Extension field for ``description``."
-    )
-
-    identifier: typing.List[fhirtypes.IdentifierType] = Field(
-        None,
-        alias="identifier",
-        title="Id for the container",
-        description=(
-            "Id for container. There may be multiple; a manufacturer's bar code, "
-            "lab assigned identifier, etc. The container ID may differ from the "
-            "specimen id in some circumstances."
-        ),
+        alias="location",
+        title="Where the container is",
+        description="The location of the container holding the specimen.",
         # if property is element of this resource.
         element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Location"],
     )
 
     specimenQuantity: fhirtypes.QuantityType = Field(
@@ -494,18 +545,6 @@ class SpecimenContainer(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    type: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="type",
-        title="Kind of container directly associated with specimen",
-        description=(
-            "The type of container associated with the specimen (e.g. slide, "
-            "aliquot, etc.)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -516,52 +555,113 @@ class SpecimenContainer(backboneelement.BackboneElement):
             "id",
             "extension",
             "modifierExtension",
-            "identifier",
-            "description",
-            "type",
-            "capacity",
+            "device",
+            "location",
             "specimenQuantity",
-            "additiveCodeableConcept",
-            "additiveReference",
         ]
 
+
+class SpecimenFeature(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    The physical feature of a specimen.
+    A physical feature or landmark on a specimen, highlighted for context by
+    the collector of the specimen (e.g. surgeon), that identifies the type of
+    feature as well as its meaning (e.g. the red ink indicating the resection
+    margin of the right lobe of the excised prostate tissue or wire loop at
+    radiologically suspected tumor location).
+    """
+
+    resource_type = Field("SpecimenFeature", const=True)
+
+    description: fhirtypes.String = Field(
+        None,
+        alias="description",
+        title="Information about the feature",
+        description="Description of the feature of the specimen.",
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+    )
+    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_description", title="Extension field for ``description``."
+    )
+
+    type: fhirtypes.CodeableConceptType = Field(
+        ...,
+        alias="type",
+        title="Highlighted feature",
+        description="The landmark or feature being highlighted.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SpecimenFeature`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "description"]
+
     @root_validator(pre=True, allow_reuse=True)
-    def validate_one_of_many_1948(
+    def validate_required_primitive_elements_1720(
         cls, values: typing.Dict[str, typing.Any]
     ) -> typing.Dict[str, typing.Any]:
-        """https://www.hl7.org/fhir/formats.html#choice
-        A few elements have a choice of more than one data type for their content.
-        All such elements have a name that takes the form nnn[x].
-        The "nnn" part of the name is constant, and the "[x]" is replaced with
-        the title-cased name of the type that is actually used.
-        The table view shows each of these names explicitly.
-
-        Elements that have a choice of data type cannot repeat - they must have a
-        maximum cardinality of 1. When constructing an instance of an element with a
-        choice of types, the authoring system must create a single element with a
-        data type chosen from among the list of permitted data types.
+        """https://www.hl7.org/fhir/extensibility.html#Special-Case
+        In some cases, implementers might find that they do not have appropriate data for
+        an element with minimum cardinality = 1. In this case, the element must be present,
+        but unless the resource or a profile on it has made the actual value of the primitive
+        data type mandatory, it is possible to provide an extension that explains why
+        the primitive value is not present.
         """
-        one_of_many_fields = {
-            "additive": ["additiveCodeableConcept", "additiveReference"]
-        }
-        for prefix, fields in one_of_many_fields.items():
-            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
-            required = (
-                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
-                is True
-            )
-            found = False
-            for field in fields:
-                if field in values and values[field] is not None:
-                    if found is True:
-                        raise ValueError(
-                            "Any of one field value is expected from "
-                            f"this list {fields}, but got multiple!"
-                        )
-                    else:
-                        found = True
-            if required is True and found is False:
-                raise ValueError(f"Expect any of field value from this list {fields}.")
+        required_fields = [("description", "description__ext")]
+        _missing = object()
+
+        def _fallback():
+            return ""
+
+        errors: typing.List["ErrorWrapper"] = []
+        for name, ext in required_fields:
+            field = cls.__fields__[name]
+            ext_field = cls.__fields__[ext]
+            value = values.get(field.alias, _missing)
+            if value not in (_missing, None):
+                continue
+            ext_value = values.get(ext_field.alias, _missing)
+            missing_ext = True
+            if ext_value not in (_missing, None):
+                if isinstance(ext_value, dict):
+                    missing_ext = len(ext_value.get("extension", [])) == 0
+                elif (
+                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
+                    == "FHIRPrimitiveExtension"
+                ):
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+                else:
+                    validate_pass = True
+                    for validator in ext_field.type_.__get_validators__():
+                        try:
+                            ext_value = validator(v=ext_value)
+                        except ValidationError as exc:
+                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
+                            validate_pass = False
+                    if not validate_pass:
+                        continue
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+            if missing_ext:
+                if value is _missing:
+                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
+                else:
+                    errors.append(
+                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
+                    )
+        if len(errors) > 0:
+            raise ValidationError(errors, cls)  # type: ignore
 
         return values
 
@@ -600,11 +700,11 @@ class SpecimenProcessing(backboneelement.BackboneElement):
         None, alias="_description", title="Extension field for ``description``."
     )
 
-    procedure: fhirtypes.CodeableConceptType = Field(
+    method: fhirtypes.CodeableConceptType = Field(
         None,
-        alias="procedure",
+        alias="method",
         title="Indicates the treatment step  applied to the specimen",
-        description="A coded value specifying the procedure used to process the specimen.",
+        description="A coded value specifying the method used to process the specimen.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -655,7 +755,7 @@ class SpecimenProcessing(backboneelement.BackboneElement):
             "extension",
             "modifierExtension",
             "description",
-            "procedure",
+            "method",
             "additive",
             "timeDateTime",
             "timePeriod",
