@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/StructureDefinition
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -81,7 +81,9 @@ class StructureDefinition(domainresource.DomainResource):
         title="If an extension, where it can be used in instances",
         description=(
             "Identifies the types of resource or data type elements to which the "
-            "extension can be applied."
+            "extension can be applied. For more guidance on using the 'context' "
+            "element, see the [defining extensions page](defining-"
+            "extensions.html#context)."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -114,7 +116,9 @@ class StructureDefinition(domainresource.DomainResource):
         description=(
             "A copyright statement relating to the structure definition and/or its "
             "contents. Copyright statements are generally legal restrictions on the"
-            " use and publishing of the structure definition."
+            " use and publishing of the structure definition.  The short copyright "
+            "declaration (e.g. (c) '2015+ xyz organization' should be sent in the "
+            "copyrightLabel element."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -123,16 +127,33 @@ class StructureDefinition(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
-            "The date  (and optionally time) when the structure definition was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the structure definition "
-            "changes."
+            "The date  (and optionally time) when the structure definition was last"
+            " significantly changed. The date must change when the business version"
+            " changes and it must change if the status code changes. In addition, "
+            "it should change when the substantive content of the structure "
+            "definition changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -207,7 +228,7 @@ class StructureDefinition(domainresource.DomainResource):
             "The version of the FHIR specification on which this "
             "StructureDefinition is based - this is the formal version of the "
             "specification, without the revision number, e.g. "
-            "[publication].[major].[minor], which is 4.3.0 for this version."
+            "[publication].[major].[minor], which is 4.6.0. for this version."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -246,9 +267,10 @@ class StructureDefinition(domainresource.DomainResource):
         alias="keyword",
         title="Assist with indexing and finding",
         description=(
-            "A set of key words or terms from external terminologies that may be "
-            "used to assist with indexing and searching of templates nby describing"
-            " the use of this structure definition, or the content it describes."
+            "(DEPRECATED) A set of key words or terms from external terminologies "
+            "that may be used to assist with indexing and searching of templates "
+            "nby describing the use of this structure definition, or the content it"
+            " describes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -299,10 +321,10 @@ class StructureDefinition(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the "
-            "structure definition."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the structure definition."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -384,7 +406,7 @@ class StructureDefinition(domainresource.DomainResource):
             " abstract type).  References are URLs that are relative to "
             'http://hl7.org/fhir/StructureDefinition e.g. "string" is a reference '
             "to http://hl7.org/fhir/StructureDefinition/string. Absolute URLs are "
-            "only allowed in logical models."
+            "only allowed in logical models, where they are required."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -405,7 +427,7 @@ class StructureDefinition(domainresource.DomainResource):
             "An absolute URI that is used to identify this structure definition "
             "when it is referenced in a specification, model, design or an "
             "instance; also called its canonical identifier. This SHOULD be "
-            "globally unique and SHOULD be a literal address at which at which an "
+            "globally unique and SHOULD be a literal address at which an "
             "authoritative instance of this structure definition is (or will be) "
             "published. This URL can be the target of a canonical reference. It "
             "SHALL remain the same when the structure definition is stored on "
@@ -442,10 +464,12 @@ class StructureDefinition(domainresource.DomainResource):
             "The identifier that is used to identify this version of the structure "
             "definition when it is referenced in a specification, model, design or "
             "instance. This is an arbitrary value managed by the structure "
-            "definition author and is not expected to be globally unique. For "
-            "example, it might be a timestamp (e.g. yyyymmdd) if a managed version "
-            "is not available. There is also no expectation that versions can be "
-            "placed in a lexicographical sequence."
+            "definition author and is not expected to be globally unique. There is "
+            "no expectation that versions can be placed in a lexicographical "
+            "sequence, so authors are encouraged to populate the "
+            "StructureDefinition.versionAlgorithm[x] element to enable comparisons."
+            " If there is no managed version available, authors can consider using "
+            "ISO date/time syntax (e.g., '2023-01-01')."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -454,6 +478,41 @@ class StructureDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -472,6 +531,8 @@ class StructureDefinition(domainresource.DomainResource):
             "url",
             "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "status",
@@ -484,6 +545,7 @@ class StructureDefinition(domainresource.DomainResource):
             "jurisdiction",
             "purpose",
             "copyright",
+            "copyrightLabel",
             "keyword",
             "fhirVersion",
             "mapping",
@@ -564,6 +626,46 @@ class StructureDefinition(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2203(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class StructureDefinitionContext(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -572,7 +674,8 @@ class StructureDefinitionContext(backboneelement.BackboneElement):
 
     If an extension, where it can be used in instances.
     Identifies the types of resource or data type elements to which the
-    extension can be applied.
+    extension can be applied. For more guidance on using the 'context' element,
+    see the [defining extensions page](defining-extensions.html#context).
     """
 
     resource_type = Field("StructureDefinitionContext", const=True)
@@ -723,7 +826,7 @@ class StructureDefinitionMapping(backboneelement.BackboneElement):
     comment: fhirtypes.String = Field(
         None,
         alias="comment",
-        title="Versions, Issues, Scope limitations etc.",
+        title="Versions, Issues, Scope limitations etc",
         description=(
             "Comments about this mapping, including version notes, issues, scope "
             "limitations, and other important notes for usage."
