@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/SubstanceReferenceInformation
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class SubstanceReferenceInformation(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -23,17 +23,6 @@ class SubstanceReferenceInformation(domainresource.DomainResource):
 
     resource_type = Field("SubstanceReferenceInformation", const=True)
 
-    classification: typing.List[
-        fhirtypes.SubstanceReferenceInformationClassificationType
-    ] = Field(
-        None,
-        alias="classification",
-        title="Todo",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
     comment: fhirtypes.String = Field(
         None,
         alias="comment",
@@ -75,58 +64,30 @@ class SubstanceReferenceInformation(domainresource.DomainResource):
         element_property=True,
     )
 
-
-class SubstanceReferenceInformationClassification(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
-    Resource StructureDefinition, instead used to enable Extensibility feature
-    for FHIR Primitive Data Types.
-
-    Todo.
-    """
-
-    resource_type = Field("SubstanceReferenceInformationClassification", const=True)
-
-    classification: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="classification",
-        title="Todo",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    domain: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="domain",
-        title="Todo",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    source: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="source",
-        title="Todo",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["DocumentReference"],
-    )
-
-    subtype: typing.List[fhirtypes.CodeableConceptType] = Field(
-        None,
-        alias="subtype",
-        title="Todo",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SubstanceReferenceInformation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "comment",
+            "gene",
+            "geneElement",
+            "target",
+        ]
 
 
 class SubstanceReferenceInformationGene(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -164,9 +125,24 @@ class SubstanceReferenceInformationGene(backboneelement.BackboneElement):
         enum_reference_types=["DocumentReference"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SubstanceReferenceInformationGene`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "geneSequenceOrigin",
+            "gene",
+            "source",
+        ]
+
 
 class SubstanceReferenceInformationGeneElement(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -204,9 +180,17 @@ class SubstanceReferenceInformationGeneElement(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SubstanceReferenceInformationGeneElement`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "element", "source"]
+
 
 class SubstanceReferenceInformationTarget(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -319,6 +303,28 @@ class SubstanceReferenceInformationTarget(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SubstanceReferenceInformationTarget`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "target",
+            "type",
+            "interaction",
+            "organism",
+            "organismType",
+            "amountQuantity",
+            "amountRange",
+            "amountString",
+            "amountType",
+            "source",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_3819(
         cls, values: typing.Dict[str, typing.Any]
