@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/SubstanceSourceMaterial
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -85,7 +85,7 @@ class SubstanceSourceMaterial(domainresource.DomainResource):
         element_property=True,
     )
 
-    geographicalLocation: typing.List[fhirtypes.String] = Field(
+    geographicalLocation: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="geographicalLocation",
         title=(
@@ -158,7 +158,7 @@ class SubstanceSourceMaterial(domainresource.DomainResource):
         element_property=True,
     )
 
-    parentSubstanceName: typing.List[fhirtypes.String] = Field(
+    parentSubstanceName: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="parentSubstanceName",
         title="The parent substance of the Herbal Drug, or Herbal preparation",
