@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/SupplyRequest
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -19,8 +19,9 @@ class SupplyRequest(domainresource.DomainResource):
     for FHIR Primitive Data Types.
 
     Request for a medication, substance or device.
-    A record of a request for a medication, substance or device used in the
-    healthcare setting.
+    A record of a request to deliver a medication, substance or device used in
+    the healthcare setting to a particular destination for a particular person
+    or organization.
     """
 
     resource_type = Field("SupplyRequest", const=True)
@@ -37,6 +38,17 @@ class SupplyRequest(domainresource.DomainResource):
         None, alias="_authoredOn", title="Extension field for ``authoredOn``."
     )
 
+    basedOn: typing.List[fhirtypes.ReferenceType] = Field(
+        None,
+        alias="basedOn",
+        title="What other request is fulfilled by this supply request",
+        description="Plan/proposal/order fulfilled by this request.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Resource"],
+    )
+
     category: fhirtypes.CodeableConceptType = Field(
         None,
         alias="category",
@@ -49,6 +61,20 @@ class SupplyRequest(domainresource.DomainResource):
         element_property=True,
     )
 
+    deliverFor: fhirtypes.ReferenceType = Field(
+        None,
+        alias="deliverFor",
+        title="The patient for who the supply request is for",
+        description=(
+            "The patient to whom the supply will be given or for whom they will be "
+            "used."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=["Patient"],
+    )
+
     deliverFrom: fhirtypes.ReferenceType = Field(
         None,
         alias="deliverFrom",
@@ -68,7 +94,7 @@ class SupplyRequest(domainresource.DomainResource):
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Organization", "Location", "Patient"],
+        enum_reference_types=["Organization", "Location", "Patient", "RelatedPerson"],
     )
 
     identifier: typing.List[fhirtypes.IdentifierType] = Field(
@@ -84,9 +110,9 @@ class SupplyRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    itemCodeableConcept: fhirtypes.CodeableConceptType = Field(
-        None,
-        alias="itemCodeableConcept",
+    item: fhirtypes.CodeableReferenceType = Field(
+        ...,
+        alias="item",
         title="Medication, Substance, or Device requested to be supplied",
         description=(
             "The item that is requested to be supplied. This is either a link to a "
@@ -95,27 +121,16 @@ class SupplyRequest(domainresource.DomainResource):
         ),
         # if property is element of this resource.
         element_property=True,
-        # Choice of Data Types. i.e item[x]
-        one_of_many="item",
-        one_of_many_required=True,
-    )
-
-    itemReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="itemReference",
-        title="Medication, Substance, or Device requested to be supplied",
-        description=(
-            "The item that is requested to be supplied. This is either a link to a "
-            "resource representing the details of the item or a code that "
-            "identifies the item from a known list."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e item[x]
-        one_of_many="item",
-        one_of_many_required=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Medication", "Substance", "Device"],
+        enum_reference_types=[
+            "Medication",
+            "Substance",
+            "Device",
+            "DeviceDefinition",
+            "BiologicallyDerivedProduct",
+            "NutritionProduct",
+            "InventoryItem",
+        ],
     )
 
     occurrenceDateTime: fhirtypes.DateTime = Field(
@@ -198,18 +213,9 @@ class SupplyRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    reasonCode: typing.List[fhirtypes.CodeableConceptType] = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
-        title="The reason why the supply item was requested",
-        description=None,
-        # if property is element of this resource.
-        element_property=True,
-    )
-
-    reasonReference: typing.List[fhirtypes.ReferenceType] = Field(
-        None,
-        alias="reasonReference",
+        alias="reason",
         title="The reason why the supply item was requested",
         description=None,
         # if property is element of this resource.
@@ -238,6 +244,7 @@ class SupplyRequest(domainresource.DomainResource):
             "Patient",
             "RelatedPerson",
             "Device",
+            "CareTeam",
         ],
     )
 
@@ -284,10 +291,11 @@ class SupplyRequest(domainresource.DomainResource):
             "modifierExtension",
             "identifier",
             "status",
+            "basedOn",
             "category",
             "priority",
-            "itemCodeableConcept",
-            "itemReference",
+            "deliverFor",
+            "item",
             "quantity",
             "parameter",
             "occurrenceDateTime",
@@ -296,8 +304,7 @@ class SupplyRequest(domainresource.DomainResource):
             "authoredOn",
             "requester",
             "supplier",
-            "reasonCode",
-            "reasonReference",
+            "reason",
             "deliverFrom",
             "deliverTo",
         ]
@@ -319,12 +326,7 @@ class SupplyRequest(domainresource.DomainResource):
         data type chosen from among the list of permitted data types.
         """
         one_of_many_fields = {
-            "item": ["itemCodeableConcept", "itemReference"],
-            "occurrence": [
-                "occurrenceDateTime",
-                "occurrencePeriod",
-                "occurrenceTiming",
-            ],
+            "occurrence": ["occurrenceDateTime", "occurrencePeriod", "occurrenceTiming"]
         }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
