@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Task
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Task(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -44,11 +44,11 @@ class Task(domainresource.DomainResource):
         description=(
             "BasedOn refers to a higher-level authorization that triggered the "
             'creation of the task.  It references a "request" resource such as a '
-            "ServiceRequest, MedicationRequest, ServiceRequest, CarePlan, etc. "
-            'which is distinct from the "request" resource the task is seeking to '
-            "fulfill.  This latter resource is referenced by FocusOn.  For example,"
-            " based on a ServiceRequest (= BasedOn), a task is created to fulfill a"
-            " procedureRequest ( = FocusOn ) to collect a specimen from a patient."
+            "ServiceRequest, MedicationRequest, CarePlan, etc. which is distinct "
+            'from the "request" resource the task is seeking to fulfill.  This '
+            "latter resource is referenced by focus.  For example, based on a "
+            "CarePlan (= basedOn), a task is created to fulfill a ServiceRequest ( "
+            "= focus ) to collect a specimen from a patient."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -86,6 +86,21 @@ class Task(domainresource.DomainResource):
         None, alias="_description", title="Extension field for ``description``."
     )
 
+    doNotPerform: bool = Field(
+        None,
+        alias="doNotPerform",
+        title="True if Task is prohibiting action",
+        description=(
+            "If true indicates that the Task is asking for the specified action to "
+            "*not* occur."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    doNotPerform__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_doNotPerform", title="Extension field for ``doNotPerform``."
+    )
+
     encounter: fhirtypes.ReferenceType = Field(
         None,
         alias="encounter",
@@ -118,8 +133,8 @@ class Task(domainresource.DomainResource):
         alias="focus",
         title="What task is acting on",
         description=(
-            "The request being actioned or the resource being manipulated by this "
-            "task."
+            "The request being fulfilled or the resource being manipulated "
+            "(changed, suspended, etc.) by this task."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -146,8 +161,13 @@ class Task(domainresource.DomainResource):
         alias="groupIdentifier",
         title="Requisition or grouper id",
         description=(
-            "An identifier that links together multiple tasks and other requests "
-            "that were created in the same context."
+            "A shared identifier common to multiple independent Task and Request "
+            "instances that were activated/authorized more or less simultaneously "
+            "by a single author.  The presence of the same identifier on each "
+            "request ties those requests together and may have business "
+            "ramifications in terms of reporting of results, billing, etc.  E.g. a "
+            "requisition number shared by a set of lab tests ordered together, or a"
+            " prescription number shared by all meds ordered at one time."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -271,7 +291,7 @@ class Task(domainresource.DomainResource):
         None,
         alias="location",
         title="Where task occurs",
-        description="Principal physical location where the this task is performed.",
+        description="Principal physical location where this task is performed.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -300,10 +320,7 @@ class Task(domainresource.DomainResource):
         None,
         alias="owner",
         title="Responsible individual",
-        description=(
-            "Individual organization or Device currently responsible for task "
-            "execution."
-        ),
+        description="Party responsible for managing task execution.",
         # if property is element of this resource.
         element_property=True,
         # note: Listed Resource Type(s) should be allowed as Reference.
@@ -312,9 +329,7 @@ class Task(domainresource.DomainResource):
             "PractitionerRole",
             "Organization",
             "CareTeam",
-            "HealthcareService",
             "Patient",
-            "Device",
             "RelatedPerson",
         ],
     )
@@ -330,11 +345,11 @@ class Task(domainresource.DomainResource):
         enum_reference_types=["Task"],
     )
 
-    performerType: typing.List[fhirtypes.CodeableConceptType] = Field(
+    performer: typing.List[fhirtypes.TaskPerformerType] = Field(
         None,
-        alias="performerType",
-        title="Requested performer",
-        description="The kind of participant that should perform the task.",
+        alias="performer",
+        title="Who or what performed the task",
+        description="The entity who performed the requested task.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -357,26 +372,18 @@ class Task(domainresource.DomainResource):
         None, alias="_priority", title="Extension field for ``priority``."
     )
 
-    reasonCode: fhirtypes.CodeableConceptType = Field(
+    reason: typing.List[fhirtypes.CodeableReferenceType] = Field(
         None,
-        alias="reasonCode",
+        alias="reason",
         title="Why task is needed",
-        description="A description or code indicating why this task needs to be performed.",
+        description=(
+            "A description, code, or reference indicating why this task needs to be"
+            " performed."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
 
-    reasonReference: fhirtypes.ReferenceType = Field(
-        None,
-        alias="reasonReference",
-        title="Why task is needed",
-        description="A resource reference indicating why this task needs to be performed.",
-        # if property is element of this resource.
-        element_property=True,
-        # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Resource"],
-    )
-
     relevantHistory: typing.List[fhirtypes.ReferenceType] = Field(
         None,
         alias="relevantHistory",
@@ -392,6 +399,41 @@ class Task(domainresource.DomainResource):
         enum_reference_types=["Provenance"],
     )
 
+    requestedPerformer: typing.List[fhirtypes.CodeableReferenceType] = Field(
+        None,
+        alias="requestedPerformer",
+        title="Who should perform Task",
+        description=(
+            "The kind of participant or specific participant that should perform "
+            "the task."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Organization",
+            "CareTeam",
+            "HealthcareService",
+            "Patient",
+            "Device",
+            "RelatedPerson",
+        ],
+    )
+
+    requestedPeriod: fhirtypes.PeriodType = Field(
+        None,
+        alias="requestedPeriod",
+        title="When the task should be performed",
+        description=(
+            "Indicates the start and/or end of the period of time when completion "
+            "of the task is desired to take place."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     requester: fhirtypes.ReferenceType = Field(
         None,
         alias="requester",
@@ -440,7 +482,7 @@ class Task(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    statusReason: fhirtypes.CodeableConceptType = Field(
+    statusReason: fhirtypes.CodeableReferenceType = Field(
         None,
         alias="statusReason",
         title="Reason for current status",
@@ -449,6 +491,56 @@ class Task(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Task`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "instantiatesCanonical",
+            "instantiatesUri",
+            "basedOn",
+            "groupIdentifier",
+            "partOf",
+            "status",
+            "statusReason",
+            "businessStatus",
+            "intent",
+            "priority",
+            "doNotPerform",
+            "code",
+            "description",
+            "focus",
+            "for",
+            "encounter",
+            "requestedPeriod",
+            "executionPeriod",
+            "authoredOn",
+            "lastModified",
+            "requester",
+            "requestedPerformer",
+            "owner",
+            "performer",
+            "location",
+            "reason",
+            "insurance",
+            "note",
+            "relevantHistory",
+            "restriction",
+            "input",
+            "output",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_594(
         cls, values: typing.Dict[str, typing.Any]
@@ -510,7 +602,7 @@ class Task(domainresource.DomainResource):
 
 
 class TaskInput(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -580,6 +672,18 @@ class TaskInput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueAvailability: fhirtypes.AvailabilityType = Field(
+        None,
+        alias="valueAvailability",
+        title="Content to use in performing the task",
+        description="The value of the input parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueBase64Binary: fhirtypes.Base64Binary = Field(
         None,
         alias="valueBase64Binary",
@@ -654,6 +758,18 @@ class TaskInput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueCodeableReference: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="valueCodeableReference",
+        title="Content to use in performing the task",
+        description="The value of the input parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueCoding: fhirtypes.CodingType = Field(
         None,
         alias="valueCoding",
@@ -690,18 +806,6 @@ class TaskInput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
-    valueContributor: fhirtypes.ContributorType = Field(
-        None,
-        alias="valueContributor",
-        title="Content to use in performing the task",
-        description="The value of the input parameter as a basic type.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e value[x]
-        one_of_many="value",
-        one_of_many_required=True,
-    )
-
     valueCount: fhirtypes.CountType = Field(
         None,
         alias="valueCount",
@@ -819,6 +923,18 @@ class TaskInput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueExtendedContactDetail: fhirtypes.ExtendedContactDetailType = Field(
+        None,
+        alias="valueExtendedContactDetail",
+        title="Content to use in performing the task",
+        description="The value of the input parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueHumanName: fhirtypes.HumanNameType = Field(
         None,
         alias="valueHumanName",
@@ -888,6 +1004,21 @@ class TaskInput(backboneelement.BackboneElement):
         None, alias="_valueInteger", title="Extension field for ``valueInteger``."
     )
 
+    valueInteger64: fhirtypes.Integer64 = Field(
+        None,
+        alias="valueInteger64",
+        title="Content to use in performing the task",
+        description="The value of the input parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueInteger64__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueInteger64", title="Extension field for ``valueInteger64``."
+    )
+
     valueMarkdown: fhirtypes.Markdown = Field(
         None,
         alias="valueMarkdown",
@@ -1019,6 +1150,18 @@ class TaskInput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueRatioRange: fhirtypes.RatioRangeType = Field(
+        None,
+        alias="valueRatioRange",
+        title="Content to use in performing the task",
+        description="The value of the input parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueReference: fhirtypes.ReferenceType = Field(
         None,
         alias="valueReference",
@@ -1195,6 +1338,73 @@ class TaskInput(backboneelement.BackboneElement):
         None, alias="_valueUuid", title="Extension field for ``valueUuid``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TaskInput`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "valueBase64Binary",
+            "valueBoolean",
+            "valueCanonical",
+            "valueCode",
+            "valueDate",
+            "valueDateTime",
+            "valueDecimal",
+            "valueId",
+            "valueInstant",
+            "valueInteger",
+            "valueInteger64",
+            "valueMarkdown",
+            "valueOid",
+            "valuePositiveInt",
+            "valueString",
+            "valueTime",
+            "valueUnsignedInt",
+            "valueUri",
+            "valueUrl",
+            "valueUuid",
+            "valueAddress",
+            "valueAge",
+            "valueAnnotation",
+            "valueAttachment",
+            "valueCodeableConcept",
+            "valueCodeableReference",
+            "valueCoding",
+            "valueContactPoint",
+            "valueCount",
+            "valueDistance",
+            "valueDuration",
+            "valueHumanName",
+            "valueIdentifier",
+            "valueMoney",
+            "valuePeriod",
+            "valueQuantity",
+            "valueRange",
+            "valueRatio",
+            "valueRatioRange",
+            "valueReference",
+            "valueSampledData",
+            "valueSignature",
+            "valueTiming",
+            "valueContactDetail",
+            "valueDataRequirement",
+            "valueExpression",
+            "valueParameterDefinition",
+            "valueRelatedArtifact",
+            "valueTriggerDefinition",
+            "valueUsageContext",
+            "valueAvailability",
+            "valueExtendedContactDetail",
+            "valueDosage",
+            "valueMeta",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1131(
         cls, values: typing.Dict[str, typing.Any]
@@ -1217,15 +1427,16 @@ class TaskInput(backboneelement.BackboneElement):
                 "valueAge",
                 "valueAnnotation",
                 "valueAttachment",
+                "valueAvailability",
                 "valueBase64Binary",
                 "valueBoolean",
                 "valueCanonical",
                 "valueCode",
                 "valueCodeableConcept",
+                "valueCodeableReference",
                 "valueCoding",
                 "valueContactDetail",
                 "valueContactPoint",
-                "valueContributor",
                 "valueCount",
                 "valueDataRequirement",
                 "valueDate",
@@ -1235,11 +1446,13 @@ class TaskInput(backboneelement.BackboneElement):
                 "valueDosage",
                 "valueDuration",
                 "valueExpression",
+                "valueExtendedContactDetail",
                 "valueHumanName",
                 "valueId",
                 "valueIdentifier",
                 "valueInstant",
                 "valueInteger",
+                "valueInteger64",
                 "valueMarkdown",
                 "valueMeta",
                 "valueMoney",
@@ -1250,6 +1463,7 @@ class TaskInput(backboneelement.BackboneElement):
                 "valueQuantity",
                 "valueRange",
                 "valueRatio",
+                "valueRatioRange",
                 "valueReference",
                 "valueRelatedArtifact",
                 "valueSampledData",
@@ -1288,7 +1502,7 @@ class TaskInput(backboneelement.BackboneElement):
 
 
 class TaskOutput(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1355,6 +1569,18 @@ class TaskOutput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueAvailability: fhirtypes.AvailabilityType = Field(
+        None,
+        alias="valueAvailability",
+        title="Result of output",
+        description="The value of the Output parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueBase64Binary: fhirtypes.Base64Binary = Field(
         None,
         alias="valueBase64Binary",
@@ -1429,6 +1655,18 @@ class TaskOutput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueCodeableReference: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="valueCodeableReference",
+        title="Result of output",
+        description="The value of the Output parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueCoding: fhirtypes.CodingType = Field(
         None,
         alias="valueCoding",
@@ -1465,18 +1703,6 @@ class TaskOutput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
-    valueContributor: fhirtypes.ContributorType = Field(
-        None,
-        alias="valueContributor",
-        title="Result of output",
-        description="The value of the Output parameter as a basic type.",
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e value[x]
-        one_of_many="value",
-        one_of_many_required=True,
-    )
-
     valueCount: fhirtypes.CountType = Field(
         None,
         alias="valueCount",
@@ -1594,6 +1820,18 @@ class TaskOutput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueExtendedContactDetail: fhirtypes.ExtendedContactDetailType = Field(
+        None,
+        alias="valueExtendedContactDetail",
+        title="Result of output",
+        description="The value of the Output parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueHumanName: fhirtypes.HumanNameType = Field(
         None,
         alias="valueHumanName",
@@ -1663,6 +1901,21 @@ class TaskOutput(backboneelement.BackboneElement):
         None, alias="_valueInteger", title="Extension field for ``valueInteger``."
     )
 
+    valueInteger64: fhirtypes.Integer64 = Field(
+        None,
+        alias="valueInteger64",
+        title="Result of output",
+        description="The value of the Output parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+    valueInteger64__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_valueInteger64", title="Extension field for ``valueInteger64``."
+    )
+
     valueMarkdown: fhirtypes.Markdown = Field(
         None,
         alias="valueMarkdown",
@@ -1794,6 +2047,18 @@ class TaskOutput(backboneelement.BackboneElement):
         one_of_many_required=True,
     )
 
+    valueRatioRange: fhirtypes.RatioRangeType = Field(
+        None,
+        alias="valueRatioRange",
+        title="Result of output",
+        description="The value of the Output parameter as a basic type.",
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=True,
+    )
+
     valueReference: fhirtypes.ReferenceType = Field(
         None,
         alias="valueReference",
@@ -1970,6 +2235,73 @@ class TaskOutput(backboneelement.BackboneElement):
         None, alias="_valueUuid", title="Extension field for ``valueUuid``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TaskOutput`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "valueBase64Binary",
+            "valueBoolean",
+            "valueCanonical",
+            "valueCode",
+            "valueDate",
+            "valueDateTime",
+            "valueDecimal",
+            "valueId",
+            "valueInstant",
+            "valueInteger",
+            "valueInteger64",
+            "valueMarkdown",
+            "valueOid",
+            "valuePositiveInt",
+            "valueString",
+            "valueTime",
+            "valueUnsignedInt",
+            "valueUri",
+            "valueUrl",
+            "valueUuid",
+            "valueAddress",
+            "valueAge",
+            "valueAnnotation",
+            "valueAttachment",
+            "valueCodeableConcept",
+            "valueCodeableReference",
+            "valueCoding",
+            "valueContactPoint",
+            "valueCount",
+            "valueDistance",
+            "valueDuration",
+            "valueHumanName",
+            "valueIdentifier",
+            "valueMoney",
+            "valuePeriod",
+            "valueQuantity",
+            "valueRange",
+            "valueRatio",
+            "valueRatioRange",
+            "valueReference",
+            "valueSampledData",
+            "valueSignature",
+            "valueTiming",
+            "valueContactDetail",
+            "valueDataRequirement",
+            "valueExpression",
+            "valueParameterDefinition",
+            "valueRelatedArtifact",
+            "valueTriggerDefinition",
+            "valueUsageContext",
+            "valueAvailability",
+            "valueExtendedContactDetail",
+            "valueDosage",
+            "valueMeta",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1260(
         cls, values: typing.Dict[str, typing.Any]
@@ -1992,15 +2324,16 @@ class TaskOutput(backboneelement.BackboneElement):
                 "valueAge",
                 "valueAnnotation",
                 "valueAttachment",
+                "valueAvailability",
                 "valueBase64Binary",
                 "valueBoolean",
                 "valueCanonical",
                 "valueCode",
                 "valueCodeableConcept",
+                "valueCodeableReference",
                 "valueCoding",
                 "valueContactDetail",
                 "valueContactPoint",
-                "valueContributor",
                 "valueCount",
                 "valueDataRequirement",
                 "valueDate",
@@ -2010,11 +2343,13 @@ class TaskOutput(backboneelement.BackboneElement):
                 "valueDosage",
                 "valueDuration",
                 "valueExpression",
+                "valueExtendedContactDetail",
                 "valueHumanName",
                 "valueId",
                 "valueIdentifier",
                 "valueInstant",
                 "valueInteger",
+                "valueInteger64",
                 "valueMarkdown",
                 "valueMeta",
                 "valueMoney",
@@ -2025,6 +2360,7 @@ class TaskOutput(backboneelement.BackboneElement):
                 "valueQuantity",
                 "valueRange",
                 "valueRatio",
+                "valueRatioRange",
                 "valueReference",
                 "valueRelatedArtifact",
                 "valueSampledData",
@@ -2062,8 +2398,55 @@ class TaskOutput(backboneelement.BackboneElement):
         return values
 
 
+class TaskPerformer(backboneelement.BackboneElement):
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
+    Resource StructureDefinition, instead used to enable Extensibility feature
+    for FHIR Primitive Data Types.
+
+    Who or what performed the task.
+    The entity who performed the requested task.
+    """
+
+    resource_type = Field("TaskPerformer", const=True)
+
+    actor: fhirtypes.ReferenceType = Field(
+        ...,
+        alias="actor",
+        title="Who performed the task",
+        description="The actor or entity who performed the task.",
+        # if property is element of this resource.
+        element_property=True,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "Practitioner",
+            "PractitionerRole",
+            "Organization",
+            "CareTeam",
+            "Patient",
+            "RelatedPerson",
+        ],
+    )
+
+    function: fhirtypes.CodeableConceptType = Field(
+        None,
+        alias="function",
+        title="Type of performance",
+        description="A code or description of the performer of the task.",
+        # if property is element of this resource.
+        element_property=True,
+    )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TaskPerformer`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
+
+
 class TaskRestriction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2078,8 +2461,12 @@ class TaskRestriction(backboneelement.BackboneElement):
     period: fhirtypes.PeriodType = Field(
         None,
         alias="period",
-        title="When fulfillment sought",
-        description="Over what time-period is fulfillment sought.",
+        title="When fulfillment is sought",
+        description=(
+            "The time-period for which fulfillment is sought. This must fall within"
+            " the overall time period authorized in the referenced request.  E.g. "
+            "ServiceRequest.occurance[x]."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -2089,8 +2476,8 @@ class TaskRestriction(backboneelement.BackboneElement):
         alias="recipient",
         title="For whom is fulfillment sought?",
         description=(
-            "For requests that are targeted to more than on potential "
-            "recipient/target, for whom is fulfillment sought?"
+            "For requests that are targeted to more than one potential "
+            "recipient/target, to identify who is fulfillment is sought for."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -2116,3 +2503,18 @@ class TaskRestriction(backboneelement.BackboneElement):
     repetitions__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_repetitions", title="Extension field for ``repetitions``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TaskRestriction`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "repetitions",
+            "period",
+            "recipient",
+        ]
