@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/TerminologyCapabilities
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -44,7 +44,7 @@ class TerminologyCapabilities(domainresource.DomainResource):
     codeSearch: fhirtypes.Code = Field(
         None,
         alias="codeSearch",
-        title="explicit | all",
+        title="in-compose | in-expansion | in-compose-or-expansion",
         description=(
             "The degree to which the server supports the code search parameter on "
             "ValueSet, if it is supported."
@@ -53,7 +53,7 @@ class TerminologyCapabilities(domainresource.DomainResource):
         element_property=True,
         # note: Enum values can be used in validation,
         # but use in your own responsibilities, read official FHIR documentation.
-        enum_values=["explicit", "all"],
+        enum_values=["in-compose", "in-expansion", "in-compose-or-expansion"],
     )
     codeSearch__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_codeSearch", title="Extension field for ``codeSearch``."
@@ -100,16 +100,33 @@ class TerminologyCapabilities(domainresource.DomainResource):
         None, alias="_copyright", title="Extension field for ``copyright``."
     )
 
+    copyrightLabel: fhirtypes.String = Field(
+        None,
+        alias="copyrightLabel",
+        title="Copyright holder and year(s)",
+        description=(
+            "A short string (<50 characters), suitable for inclusion in a page "
+            "footer that identifies the copyright holder, effective period, and "
+            "optionally whether rights are resctricted. (e.g. 'All rights "
+            "reserved', 'Some rights reserved')."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+    copyrightLabel__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_copyrightLabel", title="Extension field for ``copyrightLabel``."
+    )
+
     date: fhirtypes.DateTime = Field(
         None,
         alias="date",
         title="Date last changed",
         description=(
             "The date  (and optionally time) when the terminology capabilities was "
-            "published. The date must change when the business version changes and "
-            "it must change if the status code changes. In addition, it should "
-            "change when the substantive content of the terminology capabilities "
-            "changes."
+            "last significantly changed. The date must change when the business "
+            "version changes and it must change if the status code changes. In "
+            "addition, it should change when the substantive content of the "
+            "terminology capabilities changes."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -165,6 +182,19 @@ class TerminologyCapabilities(domainresource.DomainResource):
         None, alias="_experimental", title="Extension field for ``experimental``."
     )
 
+    identifier: typing.List[fhirtypes.IdentifierType] = Field(
+        None,
+        alias="identifier",
+        title="Additional identifier for the terminology capabilities",
+        description=(
+            "A formal identifier that is used to identify this terminology "
+            "capabilities when it is represented in other formats, or referenced in"
+            " a specification, model, design or an instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+    )
+
     implementation: fhirtypes.TerminologyCapabilitiesImplementationType = Field(
         None,
         alias="implementation",
@@ -242,10 +272,10 @@ class TerminologyCapabilities(domainresource.DomainResource):
     publisher: fhirtypes.String = Field(
         None,
         alias="publisher",
-        title="Name of the publisher (organization or individual)",
+        title="Name of the publisher/steward (organization or individual)",
         description=(
-            "The name of the organization or individual that published the "
-            "terminology capabilities."
+            "The name of the organization or individual responsible for the release"
+            " and ongoing maintenance of the terminology capabilities."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -339,7 +369,7 @@ class TerminologyCapabilities(domainresource.DomainResource):
             "An absolute URI that is used to identify this terminology capabilities"
             " when it is referenced in a specification, model, design or an "
             "instance; also called its canonical identifier. This SHOULD be "
-            "globally unique and SHOULD be a literal address at which at which an "
+            "globally unique and SHOULD be a literal address at which an "
             "authoritative instance of this terminology capabilities is (or will "
             "be) published. This URL can be the target of a canonical reference. It"
             " SHALL remain the same when the terminology capabilities is stored on "
@@ -400,6 +430,41 @@ class TerminologyCapabilities(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    versionAlgorithmCoding: fhirtypes.CodingType = Field(
+        None,
+        alias="versionAlgorithmCoding",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+
+    versionAlgorithmString: fhirtypes.String = Field(
+        None,
+        alias="versionAlgorithmString",
+        title="How to compare versions",
+        description=(
+            "Indicates the mechanism used to compare versions to determine which is"
+            " more current."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e versionAlgorithm[x]
+        one_of_many="versionAlgorithm",
+        one_of_many_required=False,
+    )
+    versionAlgorithmString__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_versionAlgorithmString",
+        title="Extension field for ``versionAlgorithmString``.",
+    )
+
     @classmethod
     def elements_sequence(cls):
         """returning all elements names from
@@ -416,7 +481,10 @@ class TerminologyCapabilities(domainresource.DomainResource):
             "extension",
             "modifierExtension",
             "url",
+            "identifier",
             "version",
+            "versionAlgorithmString",
+            "versionAlgorithmCoding",
             "name",
             "title",
             "status",
@@ -429,6 +497,7 @@ class TerminologyCapabilities(domainresource.DomainResource):
             "jurisdiction",
             "purpose",
             "copyright",
+            "copyrightLabel",
             "kind",
             "software",
             "implementation",
@@ -504,6 +573,46 @@ class TerminologyCapabilities(domainresource.DomainResource):
 
         return values
 
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_one_of_many_2602(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/formats.html#choice
+        A few elements have a choice of more than one data type for their content.
+        All such elements have a name that takes the form nnn[x].
+        The "nnn" part of the name is constant, and the "[x]" is replaced with
+        the title-cased name of the type that is actually used.
+        The table view shows each of these names explicitly.
+
+        Elements that have a choice of data type cannot repeat - they must have a
+        maximum cardinality of 1. When constructing an instance of an element with a
+        choice of types, the authoring system must create a single element with a
+        data type chosen from among the list of permitted data types.
+        """
+        one_of_many_fields = {
+            "versionAlgorithm": ["versionAlgorithmCoding", "versionAlgorithmString"]
+        }
+        for prefix, fields in one_of_many_fields.items():
+            assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
+            required = (
+                cls.__fields__[fields[0]].field_info.extra["one_of_many_required"]
+                is True
+            )
+            found = False
+            for field in fields:
+                if field in values and values[field] is not None:
+                    if found is True:
+                        raise ValueError(
+                            "Any of one field value is expected from "
+                            f"this list {fields}, but got multiple!"
+                        )
+                    else:
+                        found = True
+            if required is True and found is False:
+                raise ValueError(f"Expect any of field value from this list {fields}.")
+
+        return values
+
 
 class TerminologyCapabilitiesClosure(backboneelement.BackboneElement):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
@@ -551,6 +660,25 @@ class TerminologyCapabilitiesCodeSystem(backboneelement.BackboneElement):
 
     resource_type = Field("TerminologyCapabilitiesCodeSystem", const=True)
 
+    content: fhirtypes.Code = Field(
+        None,
+        alias="content",
+        title="not-present | example | fragment | complete | supplement",
+        description=(
+            "The extent of the content of the code system (the concepts and codes "
+            "it defines) are represented in this resource instance."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        element_required=True,
+        # note: Enum values can be used in validation,
+        # but use in your own responsibilities, read official FHIR documentation.
+        enum_values=["not-present", "example", "fragment", "complete", "supplement"],
+    )
+    content__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None, alias="_content", title="Extension field for ``content``."
+    )
+
     subsumption: bool = Field(
         None,
         alias="subsumption",
@@ -566,7 +694,7 @@ class TerminologyCapabilitiesCodeSystem(backboneelement.BackboneElement):
     uri: fhirtypes.Canonical = Field(
         None,
         alias="uri",
-        title="URI for the Code System",
+        title="Canonical identifier for the code system, represented as a URI",
         description=None,
         # if property is element of this resource.
         element_property=True,
@@ -597,7 +725,74 @@ class TerminologyCapabilitiesCodeSystem(backboneelement.BackboneElement):
         ``TerminologyCapabilitiesCodeSystem`` according specification,
         with preserving original sequence order.
         """
-        return ["id", "extension", "modifierExtension", "uri", "version", "subsumption"]
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "uri",
+            "version",
+            "content",
+            "subsumption",
+        ]
+
+    @root_validator(pre=True, allow_reuse=True)
+    def validate_required_primitive_elements_3620(
+        cls, values: typing.Dict[str, typing.Any]
+    ) -> typing.Dict[str, typing.Any]:
+        """https://www.hl7.org/fhir/extensibility.html#Special-Case
+        In some cases, implementers might find that they do not have appropriate data for
+        an element with minimum cardinality = 1. In this case, the element must be present,
+        but unless the resource or a profile on it has made the actual value of the primitive
+        data type mandatory, it is possible to provide an extension that explains why
+        the primitive value is not present.
+        """
+        required_fields = [("content", "content__ext")]
+        _missing = object()
+
+        def _fallback():
+            return ""
+
+        errors: typing.List["ErrorWrapper"] = []
+        for name, ext in required_fields:
+            field = cls.__fields__[name]
+            ext_field = cls.__fields__[ext]
+            value = values.get(field.alias, _missing)
+            if value not in (_missing, None):
+                continue
+            ext_value = values.get(ext_field.alias, _missing)
+            missing_ext = True
+            if ext_value not in (_missing, None):
+                if isinstance(ext_value, dict):
+                    missing_ext = len(ext_value.get("extension", [])) == 0
+                elif (
+                    getattr(ext_value.__class__, "get_resource_type", _fallback)()
+                    == "FHIRPrimitiveExtension"
+                ):
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+                else:
+                    validate_pass = True
+                    for validator in ext_field.type_.__get_validators__():
+                        try:
+                            ext_value = validator(v=ext_value)
+                        except ValidationError as exc:
+                            errors.append(ErrorWrapper(exc, loc=ext_field.alias))
+                            validate_pass = False
+                    if not validate_pass:
+                        continue
+                    if ext_value.extension and len(ext_value.extension) > 0:
+                        missing_ext = False
+            if missing_ext:
+                if value is _missing:
+                    errors.append(ErrorWrapper(MissingError(), loc=field.alias))
+                else:
+                    errors.append(
+                        ErrorWrapper(NoneIsNotAllowedError(), loc=field.alias)
+                    )
+        if len(errors) > 0:
+            raise ValidationError(errors, cls)  # type: ignore
+
+        return values
 
 
 class TerminologyCapabilitiesCodeSystemVersion(backboneelement.BackboneElement):
@@ -835,7 +1030,7 @@ class TerminologyCapabilitiesExpansion(backboneelement.BackboneElement):
         None,
         alias="incomplete",
         title="Allow request for incomplete expansions?",
-        description="Allow request for incomplete expansions?",
+        description="True if requests for incomplete expansions are allowed.",
         # if property is element of this resource.
         element_property=True,
     )
@@ -921,7 +1116,7 @@ class TerminologyCapabilitiesExpansionParameter(backboneelement.BackboneElement)
     name: fhirtypes.Code = Field(
         None,
         alias="name",
-        title="Expansion Parameter name",
+        title="Name of the supported expansion parameter",
         description=None,
         # if property is element of this resource.
         element_property=True,
