@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Timing
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
 from pydantic import Field, root_validator
 
-from . import backboneelement, element, fhirtypes
+from . import backbonetype, element, fhirtypes
 
 
-class Timing(backboneelement.BackboneElement):
+class Timing(backbonetype.BackboneType):
     """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
@@ -31,7 +31,7 @@ class Timing(backboneelement.BackboneElement):
     code: fhirtypes.CodeableConceptType = Field(
         None,
         alias="code",
-        title="BID | TID | QID | AM | PM | QD | QOD | +",
+        title="C | BID | TID | QID | AM | PM | QD | QOD | +",
         description=(
             "A code for the timing schedule (or just text in code.text). Some codes"
             " such as BID are ubiquitous, but many institutions define their own "
@@ -219,7 +219,11 @@ class TimingRepeat(element.Element):
         None,
         alias="durationUnit",
         title="s | min | h | d | wk | mo | a - unit of time (UCUM)",
-        description="The units of time for the duration, in UCUM units.",
+        description=(
+            "The units of time for the duration, in UCUM units Normal practice is "
+            "to use the 'mo' code as a calendar month when calculating the next "
+            "occurrence."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Enum values can be used in validation,
@@ -233,7 +237,10 @@ class TimingRepeat(element.Element):
     frequency: fhirtypes.PositiveInt = Field(
         None,
         alias="frequency",
-        title="Event occurs frequency times per period",
+        title=(
+            "Indicates the number of repetitions that should occur within a period."
+            " I.e. Event occurs frequency times per period"
+        ),
         description=(
             "The number of times to repeat the action within the specified period. "
             "If frequencyMax is present, this element indicates the lower bound of "
@@ -281,7 +288,10 @@ class TimingRepeat(element.Element):
     period: fhirtypes.Decimal = Field(
         None,
         alias="period",
-        title="Event occurs frequency times per period",
+        title=(
+            "The duration to which the frequency applies. I.e. Event occurs "
+            "frequency times per period"
+        ),
         description=(
             "Indicates the duration of time over which repetitions are to occur; "
             'e.g. to express "3 times per day", 3 would be the frequency and "1 '
@@ -315,7 +325,11 @@ class TimingRepeat(element.Element):
         None,
         alias="periodUnit",
         title="s | min | h | d | wk | mo | a - unit of time (UCUM)",
-        description="The units of time for the period in UCUM units.",
+        description=(
+            "The units of time for the period in UCUM units Normal practice is to "
+            "use the 'mo' code as a calendar month when calculating the next "
+            "occurrence."
+        ),
         # if property is element of this resource.
         element_property=True,
         # note: Enum values can be used in validation,
