@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/VerificationResult
-Release: R4B
-Version: 4.3.0
-Build ID: c475c22
-Last updated: 2022-05-28T12:47:40.239+10:00
+Release: R5
+Version: 5.0.0
+Build ID: 2aecd53
+Last updated: 2023-03-26T15:21:02.749+11:00
 """
 import typing
 
@@ -105,7 +105,8 @@ class VerificationResult(domainresource.DomainResource):
         None,
         alias="status",
         title=(
-            "attested | validated | in-process | req-revalid | val-fail | reval-" "fail"
+            "attested | validated | in-process | req-revalid | val-fail | reval-"
+            "fail | entered-in-error"
         ),
         description=(
             "The validation status of the target (attested; validated; in process; "
@@ -123,6 +124,7 @@ class VerificationResult(domainresource.DomainResource):
             "req-revalid",
             "val-fail",
             "reval-fail",
+            "entered-in-error",
         ],
     )
     status__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
@@ -358,7 +360,7 @@ class VerificationResultAttestation(backboneelement.BackboneElement):
     proxySignature: fhirtypes.SignatureType = Field(
         None,
         alias="proxySignature",
-        title="Proxy signature",
+        title="Proxy signature (digital or image)",
         description=(
             "Signed assertion by the proxy entity indicating that they have the "
             "right to submit attested information on behalf of the attestation "
@@ -385,7 +387,7 @@ class VerificationResultAttestation(backboneelement.BackboneElement):
     sourceSignature: fhirtypes.SignatureType = Field(
         None,
         alias="sourceSignature",
-        title="Attester signature",
+        title="Attester signature (digital or image)",
         description=(
             "Signed assertion by the attestation source that they have attested to "
             "the information."
@@ -550,7 +552,7 @@ class VerificationResultValidator(backboneelement.BackboneElement):
     attestationSignature: fhirtypes.SignatureType = Field(
         None,
         alias="attestationSignature",
-        title="Validator signature",
+        title="Validator signature (digital or image)",
         description=(
             "Signed assertion by the validator that they have validated the "
             "information."
